"use strict";


var visibleQuestions = {
    symptomatic: true,
    symptomaticText: false,
    whenToConsider: true,
    centorScore: false,
    centorScoreNumber: false,
    oneTwoResult: false,
    threeResult: false,
    moreFour: false,
    warning: false,
    noAnswerText: false,
    adults: true,
    firstLine: false,
    fenoxymetylpenicilin: false,
    or: false,
    benzatin: false,
    alternative: false,
    spiramycin: false,
    children: true,
    firstLineChildren: false,
    fenoxymetylpenicilinChildren: false,
    orChildren: false,
    benzatinChildren: false,
    alternativeChildren: false,
    klaritromycin: false,
    orChildren2: false,
    spiramycinChildren: false,
    duration: true,
    durationText: false,
    guidelines: true
};
var visibleSections = {
    symptomaticTreatment: true,
    antibiotics: true,
    choiceOfAntibiotic: true,
    antibioticDuration: true,
    link: true
};
var inputs = {
    symptomatic: null,
    whenToConsider: null,
    adults: null,
    children: null,
    duration: null,
    centorScoreNumber: null
};
var isSymptomaticClose = function () {
    return helpers_1.answerMatches(inputs.symptomatic, 'close');
};
var isWhenToConsiderClose = function () {
    return helpers_1.answerMatches(inputs.whenToConsider, 'close');
};
var isAdultsClose = function () {
    return helpers_1.answerMatches(inputs.adults, 'close');
};
var isChildrenClose = function () {
    return helpers_1.answerMatches(inputs.children, 'close');
};
var isDurationClose = function () {
    return helpers_1.answerMatches(inputs.duration, 'close');
};
var isCentorScoreNumberOneTwo = function () {
    return helpers_1.answerMatches(inputs.centorScoreNumber, 'oneTwo');
};
var isCentorScoreThree = function () {
    return helpers_1.answerMatches(inputs.centorScoreNumber, 'three');
};
var isCentorScoreMoreFour = function () {
    return helpers_1.answerMatches(inputs.centorScoreNumber, 'moreFour');
};
var isCentorScoreAnsweredIfVisible = function () {
    return helpers_1.answerMatches(inputs.whenToConsider, 'close')
        ? helpers_1.isAnswered(inputs.centorScoreNumber)
        : true;
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.symptomaticText = isSymptomaticClose();
    visibleQuestions.centorScore = isWhenToConsiderClose();
    visibleQuestions.centorScoreNumber = isWhenToConsiderClose();
    visibleQuestions.oneTwoResult = isCentorScoreNumberOneTwo();
    visibleQuestions.threeResult = isCentorScoreThree();
    visibleQuestions.moreFour = isCentorScoreMoreFour();
    visibleQuestions.warning = helpers_1.isAnswered(inputs.centorScoreNumber);
    visibleQuestions.noAnswerText =
        isWhenToConsiderClose() && !helpers_1.isAnswered(inputs.centorScoreNumber);
    visibleQuestions.firstLine = isAdultsClose();
    visibleQuestions.fenoxymetylpenicilin = isAdultsClose();
    visibleQuestions.or = isAdultsClose();
    visibleQuestions.benzatin = isAdultsClose();
    visibleQuestions.alternative = isAdultsClose();
    visibleQuestions.spiramycin = isAdultsClose();
    visibleQuestions.firstLineChildren = isChildrenClose();
    visibleQuestions.fenoxymetylpenicilinChildren = isChildrenClose();
    visibleQuestions.orChildren = isChildrenClose();
    visibleQuestions.benzatinChildren = isChildrenClose();
    visibleQuestions.alternativeChildren = isChildrenClose();
    visibleQuestions.klaritromycin = isChildrenClose();
    visibleQuestions.orChildren2 = isChildrenClose();
    visibleQuestions.spiramycinChildren = isChildrenClose();
    visibleQuestions.durationText = isDurationClose();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return (isCentorScoreAnsweredIfVisible() &&
        (helpers_1.answerMatches(inputs.symptomatic, 'close') ||
            helpers_1.answerMatches(inputs.adults, 'close') ||
            helpers_1.answerMatches(inputs.children, 'close') ||
            helpers_1.answerMatches(inputs.duration, 'close')));
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
