"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleSections = {
    typeSection: true,
    noAnswer: false,
    dosingBabies: false,
    dosingBabiesSMPCwarning: false,
    dosingTabletsOver2: false,
    dosingTabletsOver2GFR1: false,
    dosingPowderKids: false,
    dosingPowderKidsGFR3: false,
    dosingPowderKidsGFR2: false,
    dosingPowderKidsGFR1: false,
    dosingPowderKidsHigh: false,
    dosingPowderKidsHighGFR3: false,
    dosingPowderKidsHighGFR2: false,
    dosingPowderKidsHighGFR1: false,
    dosingPowderAdults: false,
    dosingPowderAdultsGFR3: false,
    dosingPowderAdultsGFR2: false,
    dosingPowderAdultsGFR1: false,
    dosingPowderAdultsHigh: false,
    dosingPowderAdultsHighGFR3: false,
    dosingPowderAdultsHighGFR2: false,
    dosingPowderAdultsHighGFR1: false,
    dosingPowderNeonat: false,
    dosingPowderNeonatGFR3: false,
    dosingPowderNeonatGFR2: false,
    dosingPowderNeonatGFR1: false
};
var visibleQuestions = {
    type: true,
    age: false,
    form: false,
    height: false,
    weight: false,
    weightNeonates: false,
    gfr: false,
    gfrChildren: false,
    noAnswerElement: true,
    doseTabletsBabies: true,
    dosingBabiesSMPCwarning1: true,
    doseTabletsOver2: true,
    durationTabletsOver2: true,
    doseTabletsOver2GFR1: true,
    durationTabletsOver2GFR1: true,
    dosePowderKids: true,
    durationPowderKids: true,
    dosePowderKidsGFR3: true,
    durationPowderKidsGFR3: true,
    dosePowderKidsGFR2: true,
    durationPowderKidsGFR2: true,
    dosePowderKidsGFR1: true,
    durationPowderKidsGFR1: true,
    dosePowderKidsHigh: true,
    durationPowderKidsHigh: true,
    dosePowderKidsHighGFR3: true,
    durationPowderKidsHighGFR3: true,
    dosePowderKidsHighGFR2: true,
    durationPowderKidsHighGFR2: true,
    dosePowderKidsHighGFR1: true,
    durationPowderKidsHighGFR1: true,
    dosePowderOther: true,
    durationPowderOther: true,
    adiposeWarningPowderOther: false,
    dosePowderAdultsGFR3: true,
    durationPowderAdultsGFR3: true,
    adiposeWarningPowderAdultsGFR3: false,
    dosePowderAdultsGFR2: true,
    durationPowderAdultsGFR2: true,
    adiposeWarningPowderAdultsGFR2: false,
    dosePowderAdultsGFR1: true,
    durationPowderAdultsGFR1: true,
    adiposeWarningPowderAdultsGFR1: false,
    dosePowderOtherHigh: true,
    durationPowderOtherHigh: true,
    adiposeWarningPowderAdultsHigh: false,
    dosePowdeAdultsHighGFR3: true,
    durationPowderAdultsHighGFR3: true,
    adiposeWarningPowderAdultsHighGFR3: false,
    dosePowderAdultsHighGFR2: true,
    durationPowderAdultsHighGFR2: true,
    adiposeWarningPowderAdultsHighGFR2: false,
    dosePowdeAdultsHighGFR1: true,
    durationPowderAdultsHighGFR1: true,
    adiposeWarningPowderAdultsHighGFR1: false,
    dosePowderNeonat: true,
    durationPowderNeonat: true,
    durationPowderNeonatB: true,
    dosePowderNeonatGFR3: true,
    durationPowderNeonatGFR3: true,
    durationPowderNeonatBGFR3: true,
    dosePowderNeonatGFR2: true,
    durationPowderNeonatGFR2: true,
    durationPowderNeonatBGFR2: true,
    dosePowderNeonatGFR1: true,
    durationPowderNeonatGFR1: true,
    durationPowderNeonatBGFR1: true
};
var inputs = {
    type: null,
    age: null,
    form: null,
    height: null,
    weight: null,
    weightNeonates: null,
    gfr: null,
    gfrChildren: null
};
var isHeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.height, min: 1, max: 180 });
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 });
};
var isWeightNeonatesValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightNeonates, min: 1, max: 10 });
};
var areAllVisibleQuesionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.type) &&
        ((isAgeVisible() && helpers_1.isAnswered(inputs.age)) || !isAgeVisible()) &&
        ((isFormVisible() && helpers_1.isAnswered(inputs.form)) || !isFormVisible()) &&
        ((isHeightVisible() && isHeightValid()) || !isHeightVisible()) &&
        ((isWeightVisible() && isWeightValid()) || !isWeightVisible()) &&
        ((isWeightNeonatesVisible() && isWeightNeonatesValid()) ||
            !isWeightNeonatesVisible()) &&
        ((isGfrVisible() && helpers_1.isAnswered(inputs.gfr)) || !isGfrVisible()) &&
        ((isGfrChildrenVisible() && helpers_1.isAnswered(inputs.gfrChildren)) ||
            !isGfrChildrenVisible()));
};
var isWeightMoreOrEqual70 = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 70, max: 200 });
};
var isAgeVisible = function () {
    return helpers_1.isAnswered(inputs.type) && !helpers_1.answerMatches(inputs.type, 'hsvNeonat');
};
var isFormVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'primGenital') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'kids') ||
            helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')));
};
var isHeightVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvEnceph') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'kids') ||
            helpers_1.answerMatches(inputs.age, 'toddlers')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()));
};
var isWeightVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvEnceph') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'kids') ||
            helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()));
};
var isWeightNeonatesVisible = function () {
    return helpers_1.answerMatches(inputs.type, 'hsvNeonat');
};
var isGfrVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'hsvHaut') ||
        helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'recurrGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvEnceph') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.isAnswered(inputs.form)) || !isFormVisible()) &&
        ((isWeightVisible() && isWeightValid()) || !isWeightVisible()));
};
var isGfrChildrenVisible = function () {
    return (((helpers_1.answerMatches(inputs.type, 'hsvHaut') ||
        helpers_1.answerMatches(inputs.type, 'recurrGenital')) &&
        isAgeVisible() &&
        helpers_1.answerMatches(inputs.age, 'kids')) ||
        ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
            helpers_1.answerMatches(inputs.type, 'hsvEnceph') ||
            helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
            isAgeVisible() &&
            (helpers_1.answerMatches(inputs.age, 'toddlers') ||
                helpers_1.answerMatches(inputs.age, 'kids')) &&
            ((isFormVisible() && helpers_1.isAnswered(inputs.form)) || !isFormVisible()) &&
            ((isHeightVisible() && isHeightValid()) || !isHeightVisible()) &&
            ((isWeightVisible() && isWeightValid()) || !isWeightVisible())) ||
        (helpers_1.answerMatches(inputs.type, 'hsvNeonat') &&
            isWeightNeonatesVisible() &&
            isWeightNeonatesValid()));
};
var isDosingBabiesSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'hsvHaut') ||
        helpers_1.answerMatches(inputs.type, 'recurrGenital')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'babies') ||
            helpers_1.answerMatches(inputs.age, 'toddlers')));
};
var isDosingBabiesSMPCwarningSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised') ||
        helpers_1.answerMatches(inputs.type, 'hsvEnceph')) &&
        isAgeVisible() &&
        helpers_1.answerMatches(inputs.age, 'babies'));
};
var isDosingTabletsOver2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'hsvHaut') ||
        helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'recurrGenital')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'kids') ||
            helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'tablets')) ||
            !isFormVisible()) &&
        ((isGfrVisible() &&
            (helpers_1.answerMatches(inputs.gfr, 'gfr2') ||
                helpers_1.answerMatches(inputs.gfr, 'gfr3') ||
                helpers_1.answerMatches(inputs.gfr, 'gfr4'))) ||
            (isGfrChildrenVisible() &&
                (helpers_1.answerMatches(inputs.gfrChildren, 'gfrC2') ||
                    helpers_1.answerMatches(inputs.gfrChildren, 'gfrC3') ||
                    helpers_1.answerMatches(inputs.gfrChildren, 'gfrC4')))));
};
var isDosingTabletsOver2GFR1SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'hsvHaut') ||
        helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'recurrGenital')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'kids') ||
            helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'tablets')) ||
            !isFormVisible()) &&
        ((isGfrVisible() && helpers_1.answerMatches(inputs.gfr, 'gfr1')) ||
            (isGfrChildrenVisible() && helpers_1.answerMatches(inputs.gfrChildren, 'gfrC1'))));
};
var isDosingPowderKidsSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC4'));
};
var isDosingPowderKidsGFR3SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC3'));
};
var isDosingPowderKidsGFR2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC2'));
};
var isDosingPowderKidsGFR1SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC1'));
};
var isDosingPowderKidsHighSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC4'));
};
var isDosingPowderKidsHighGFR3SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC3'));
};
var isDosingPowderKidsHighGFR2SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC2'));
};
var isDosingPowderKidsHighGFR1SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'toddlers') ||
            helpers_1.answerMatches(inputs.age, 'kids')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isHeightVisible() &&
        isHeightValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC1'));
};
var isDosingPowderAdultsSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr4'));
};
var isDosingPowderAdultsGFR3SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr3'));
};
var isDosingPowderAdultsGFR2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr2'));
};
var isDosingPowderAdultsGFR1SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.type, 'primGenital') ||
        helpers_1.answerMatches(inputs.type, 'hsvCompromised')) &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        ((isFormVisible() && helpers_1.answerMatches(inputs.form, 'powder')) ||
            !isFormVisible()) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr1'));
};
var isDosingPowderAdultsHighSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr4'));
};
var isDosingPowderAdultsHighGFR3SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr3'));
};
var isDosingPowderAdultsHighGFR2SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr2'));
};
var isDosingPowderAdultsHighGFR1SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvEnceph') &&
        isAgeVisible() &&
        (helpers_1.answerMatches(inputs.age, 'adolescents') ||
            helpers_1.answerMatches(inputs.age, 'adults')) &&
        isWeightVisible() &&
        isWeightValid() &&
        isGfrVisible() &&
        helpers_1.answerMatches(inputs.gfr, 'gfr1'));
};
var isDosingPowderNeonatSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvNeonat') &&
        isWeightNeonatesVisible() &&
        isWeightNeonatesValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC4'));
};
var isDosingPowderNeonatGFR3SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvNeonat') &&
        isWeightNeonatesVisible() &&
        isWeightNeonatesValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC3'));
};
var isDosingPowderNeonatGFR2SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvNeonat') &&
        isWeightNeonatesVisible() &&
        isWeightNeonatesValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC2'));
};
var isDosingPowderNeonatGFR1SectionVisible = function () {
    return (helpers_1.answerMatches(inputs.type, 'hsvNeonat') &&
        isWeightNeonatesVisible() &&
        isWeightNeonatesValid() &&
        isGfrChildrenVisible() &&
        helpers_1.answerMatches(inputs.gfrChildren, 'gfrC1'));
};
var calculateBsa = function () {
    var _a, _b;
    return Math.sqrt((((_a = inputs.height) === null || _a === void 0 ? void 0 : _a.currentPoints) * ((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints)) / 3600);
};
var calculateBsa500 = function () {
    return Math.round(500 * calculateBsa());
};
var calculateBsa250 = function () {
    return Math.round(250 * calculateBsa());
};
var calculateBsa125 = function () {
    return Math.round(125 * calculateBsa());
};
var calculateWeight5 = function () {
    var _a;
    return Math.round(5 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints));
};
var calculateWeight2Point5 = function () {
    var _a;
    return Math.round(2.5 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints));
};
var calculateWeight10 = function () {
    var _a;
    return Math.round(10 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints));
};
var calculateWeightNeonates10 = function () {
    var _a;
    return Math.round(10 * ((_a = inputs.weightNeonates) === null || _a === void 0 ? void 0 : _a.currentPoints));
};
var calculateWeightNeonates20 = function () {
    var _a;
    return Math.round(20 * ((_a = inputs.weightNeonates) === null || _a === void 0 ? void 0 : _a.currentPoints));
};
var calculatePoints = function () {
    if (isDosingPowderKidsSectionVisible()) {
        return {
            dosePowderKids: {
                qID: 'dosePowderKids',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa250(), 0), 0, 0)),
                titleTexts: 'dosePowderKids2'
            }
        };
    }
    if (isDosingPowderKidsGFR3SectionVisible()) {
        return {
            dosePowderKidsGFR3: {
                qID: 'dosePowderKidsGFR3',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa250(), 0), 0, 0)),
                titleTexts: 'dosePowderKids2GFR3'
            }
        };
    }
    if (isDosingPowderKidsGFR2SectionVisible()) {
        return {
            dosePowderKidsGFR2: {
                qID: 'dosePowderKidsGFR2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa250(), 0), 0, 0)),
                titleTexts: 'dosePowderKids2GFR2'
            }
        };
    }
    if (isDosingPowderKidsGFR1SectionVisible()) {
        return {
            dosePowderKidsGFR1: {
                qID: 'dosePowderKidsGFR1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa125(), 0), 0, 0)),
                titleTexts: 'dosePowderKids2GFR1'
            }
        };
    }
    if (isDosingPowderKidsHighSectionVisible()) {
        return {
            dosePowderKidsHigh: {
                qID: 'dosePowderKidsHigh',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa500(), 0), 0, 0)),
                titleTexts: 'dosePowderKidsHigh2'
            }
        };
    }
    if (isDosingPowderKidsHighGFR3SectionVisible()) {
        return {
            dosePowderKidsHighGFR3: {
                qID: 'dosePowderKidsHighGFR3',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa500(), 0), 0, 0)),
                titleTexts: 'dosePowderKidsHighGFR32'
            }
        };
    }
    if (isDosingPowderKidsHighGFR2SectionVisible()) {
        return {
            dosePowderKidsHighGFR2: {
                qID: 'dosePowderKidsHighGFR2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa500(), 0), 0, 0)),
                titleTexts: 'dosePowderKidsHighGFR22'
            }
        };
    }
    if (isDosingPowderKidsHighGFR1SectionVisible()) {
        return {
            dosePowderKidsHighGFR1: {
                qID: 'dosePowderKidsHighGFR1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBsa250(), 0), 0, 0)),
                titleTexts: 'dosePowderKidsHighGFR12'
            }
        };
    }
    if (isDosingPowderAdultsSectionVisible()) {
        return {
            dosePowderOther: {
                qID: 'dosePowderOther',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight5(), 0), 0, 0)),
                titleTexts: 'dosePowderOther2'
            }
        };
    }
    if (isDosingPowderAdultsGFR3SectionVisible()) {
        return {
            dosePowderAdultsGFR3: {
                qID: 'dosePowderAdultsGFR3',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight5(), 0), 0, 0)),
                titleTexts: 'dosePowderOther2'
            }
        };
    }
    if (isDosingPowderAdultsGFR2SectionVisible()) {
        return {
            dosePowderAdultsGFR2: {
                qID: 'dosePowderAdultsGFR2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight5(), 0), 0, 0)),
                titleTexts: 'dosePowderOther2'
            }
        };
    }
    if (isDosingPowderAdultsGFR1SectionVisible()) {
        return {
            dosePowderAdultsGFR1: {
                qID: 'dosePowderAdultsGFR1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight2Point5(), 0), 0, 0)),
                titleTexts: 'dosePowderAdultsGFR1'
            }
        };
    }
    if (isDosingPowderAdultsHighSectionVisible()) {
        return {
            dosePowderOtherHigh: {
                qID: 'dosePowderOtherHigh',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight10(), 0), 0, 0)),
                titleTexts: 'dosePowderOtherHigh2'
            }
        };
    }
    if (isDosingPowderAdultsHighGFR3SectionVisible()) {
        return {
            dosePowdeAdultsHighGFR3: {
                qID: 'dosePowdeAdultsHighGFR3',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight10(), 0), 0, 0)),
                titleTexts: 'dosePowderAdultsHighGFR3'
            }
        };
    }
    if (isDosingPowderAdultsHighGFR2SectionVisible()) {
        return {
            dosePowderAdultsHighGFR2: {
                qID: 'dosePowderAdultsHighGFR2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight10(), 0), 0, 0)),
                titleTexts: 'dosePowderAdultsHighGFR2'
            }
        };
    }
    if (isDosingPowderAdultsHighGFR1SectionVisible()) {
        return {
            dosePowdeAdultsHighGFR1: {
                qID: 'dosePowdeAdultsHighGFR1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeight5(), 0), 0, 0)),
                titleTexts: 'dosePowderAdultsHighGFR1'
            }
        };
    }
    if (isDosingPowderNeonatSectionVisible()) {
        return {
            dosePowderNeonat: {
                qID: 'dosePowderNeonat',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeightNeonates20(), 0), 0, 0)),
                titleTexts: 'dosePowderNeonat2'
            }
        };
    }
    if (isDosingPowderNeonatGFR3SectionVisible()) {
        return {
            dosePowderNeonatGFR3: {
                qID: 'dosePowderNeonatGFR3',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeightNeonates20(), 0), 0, 0)),
                titleTexts: 'dosePowderNeonatGFR3'
            }
        };
    }
    if (isDosingPowderNeonatGFR2SectionVisible()) {
        return {
            dosePowderNeonatGFR2: {
                qID: 'dosePowderNeonatGFR2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeightNeonates20(), 0), 0, 0)),
                titleTexts: 'dosePowderNeonatGFR3'
            }
        };
    }
    if (isDosingPowderNeonatGFR1SectionVisible()) {
        return {
            dosePowderNeonatGFR1: {
                qID: 'dosePowderNeonatGFR1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateWeightNeonates10(), 0), 0, 0)),
                titleTexts: 'dosePowderNeonatGFR1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.age = isAgeVisible();
    visibleQuestions.form = isFormVisible();
    visibleQuestions.height = isHeightVisible();
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.weightNeonates = isWeightNeonatesVisible();
    visibleQuestions.gfr = isGfrVisible();
    visibleQuestions.gfrChildren = isGfrChildrenVisible();
    visibleQuestions.adiposeWarningPowderOther = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsGFR3 = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsGFR2 = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsGFR1 = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsHigh = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsHighGFR3 = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsHighGFR2 = isWeightMoreOrEqual70();
    visibleQuestions.adiposeWarningPowderAdultsHighGFR1 = isWeightMoreOrEqual70();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = !areAllVisibleQuesionsAnswered();
    visibleSections.dosingBabies = isDosingBabiesSectionVisible();
    visibleSections.dosingBabiesSMPCwarning =
        isDosingBabiesSMPCwarningSectionVisible();
    visibleSections.dosingTabletsOver2 = isDosingTabletsOver2SectionVisible();
    visibleSections.dosingTabletsOver2GFR1 =
        isDosingTabletsOver2GFR1SectionVisible();
    visibleSections.dosingPowderKids = isDosingPowderKidsSectionVisible();
    visibleSections.dosingPowderKidsGFR3 = isDosingPowderKidsGFR3SectionVisible();
    visibleSections.dosingPowderKidsGFR2 = isDosingPowderKidsGFR2SectionVisible();
    visibleSections.dosingPowderKidsGFR1 = isDosingPowderKidsGFR1SectionVisible();
    visibleSections.dosingPowderKidsHigh = isDosingPowderKidsHighSectionVisible();
    visibleSections.dosingPowderKidsHighGFR3 =
        isDosingPowderKidsHighGFR3SectionVisible();
    visibleSections.dosingPowderKidsHighGFR2 =
        isDosingPowderKidsHighGFR2SectionVisible();
    visibleSections.dosingPowderKidsHighGFR1 =
        isDosingPowderKidsHighGFR1SectionVisible();
    visibleSections.dosingPowderAdults = isDosingPowderAdultsSectionVisible();
    visibleSections.dosingPowderAdultsGFR3 =
        isDosingPowderAdultsGFR3SectionVisible();
    visibleSections.dosingPowderAdultsGFR2 =
        isDosingPowderAdultsGFR2SectionVisible();
    visibleSections.dosingPowderAdultsGFR1 =
        isDosingPowderAdultsGFR1SectionVisible();
    visibleSections.dosingPowderAdultsHigh =
        isDosingPowderAdultsHighSectionVisible();
    visibleSections.dosingPowderAdultsHighGFR3 =
        isDosingPowderAdultsHighGFR3SectionVisible();
    visibleSections.dosingPowderAdultsHighGFR2 =
        isDosingPowderAdultsHighGFR2SectionVisible();
    visibleSections.dosingPowderAdultsHighGFR1 =
        isDosingPowderAdultsHighGFR1SectionVisible();
    visibleSections.dosingPowderNeonat = isDosingPowderNeonatSectionVisible();
    visibleSections.dosingPowderNeonatGFR3 =
        isDosingPowderNeonatGFR3SectionVisible();
    visibleSections.dosingPowderNeonatGFR2 =
        isDosingPowderNeonatGFR2SectionVisible();
    visibleSections.dosingPowderNeonatGFR1 =
        isDosingPowderNeonatGFR1SectionVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
