"use strict";


var visibleQuestions = {
    persistentPattern: true,
    inattentionNote: true,
    careless: true,
    sustainAttention: true,
    notListening: true,
    failsInstructions: true,
    difficutlyOrganizing: true,
    avoidsMentalEffort: true,
    loosesThings: true,
    easilyDistracted: true,
    forgetful: true,
    hyperactivityNote: true,
    fidgets: true,
    leavesSeat: true,
    runsAbout: true,
    loudActivities: true,
    onTheGo: true,
    talksExcessively: true,
    completesSentences: true,
    doesNotWait: true,
    interrupts: true,
    before12: true,
    moreSettings: true,
    interfereWithFunctioning: true,
    notSchizophrenia: true,
    answerAll: false,
    notClassifiedAsADHD: false,
    classifiedAsADHD: false
};
var visibleSections = {
    section0: true,
    inattentionSection: true,
    hyperactivityImpulsivitySection: true,
    additionalConditionsSection: true,
    resultsSection: false
};
var inputs = {
    careless: null,
    sustainAttention: null,
    notListening: null,
    failsInstructions: null,
    difficutlyOrganizing: null,
    avoidsMentalEffort: null,
    loosesThings: null,
    easilyDistracted: null,
    forgetful: null,
    fidgets: null,
    leavesSeat: null,
    runsAbout: null,
    loudActivities: null,
    onTheGo: null,
    talksExcessively: null,
    completesSentences: null,
    doesNotWait: null,
    interrupts: null,
    before12: null,
    moreSettings: null,
    interfereWithFunctioning: null,
    notSchizophrenia: null
};
var inattentionSectionArray = function () {
    return [
        inputs.careless,
        inputs.sustainAttention,
        inputs.notListening,
        inputs.failsInstructions,
        inputs.difficutlyOrganizing,
        inputs.avoidsMentalEffort,
        inputs.loosesThings,
        inputs.easilyDistracted,
        inputs.forgetful,
    ];
};
var hyperactivityImpulsivitySectionArray = function () {
    return [
        inputs.fidgets,
        inputs.leavesSeat,
        inputs.runsAbout,
        inputs.loudActivities,
        inputs.onTheGo,
        inputs.talksExcessively,
        inputs.completesSentences,
        inputs.doesNotWait,
        inputs.interrupts,
    ];
};
var additionalConditionsSectionArray = function () {
    return [
        inputs.before12,
        inputs.moreSettings,
        inputs.interfereWithFunctioning,
        inputs.notSchizophrenia,
    ];
};
var countPositiveAnswersHyperactivityImpulsivity = function () {
    var sum = 0;
    for (var _i = 0, _a = hyperactivityImpulsivitySectionArray(); _i < _a.length; _i++) {
        var question = _a[_i];
        sum += question === null || question === void 0 ? void 0 : question.currentPoints;
    }
    return sum;
};
var isResultsSectionVisible = function () {
    return (isAnswerAllVisible() ||
        isNotClassifiedAsADHDVisible() ||
        isF902Visible() ||
        isF900Visible() ||
        isF901Visible());
};
var countPositiveAnswersInattention = function () {
    var sum = 0;
    for (var _i = 0, _a = inattentionSectionArray(); _i < _a.length; _i++) {
        var question = _a[_i];
        sum += question === null || question === void 0 ? void 0 : question.currentPoints;
    }
    return sum;
};
var countPositiveAnswersAdditional = function () {
    var sum = 0;
    for (var _i = 0, _a = additionalConditionsSectionArray(); _i < _a.length; _i++) {
        var question = _a[_i];
        sum += question === null || question === void 0 ? void 0 : question.currentPoints;
    }
    return sum;
};
var isNotClassifiedAsADHDVisible = function () {
    return (areQuestionsAnswered(allQuestions()) &&
        ((countPositiveAnswersInattention() <= 4 &&
            countPositiveAnswersHyperactivityImpulsivity() <= 4) ||
            countPositiveAnswersAdditional() !== 4));
};
var isF901Visible = function () {
    return (areQuestionsAnswered(allQuestions()) &&
        countPositiveAnswersInattention() <= 4 &&
        countPositiveAnswersHyperactivityImpulsivity() >= 5 &&
        countPositiveAnswersAdditional() === 4);
};
var isF902Visible = function () {
    return (areQuestionsAnswered(allQuestions()) &&
        countPositiveAnswersInattention() >= 5 &&
        countPositiveAnswersHyperactivityImpulsivity() >= 5 &&
        countPositiveAnswersAdditional() === 4);
};
var isF900Visible = function () {
    return (areQuestionsAnswered(allQuestions()) &&
        countPositiveAnswersInattention() >= 5 &&
        countPositiveAnswersHyperactivityImpulsivity() <= 4 &&
        countPositiveAnswersAdditional() === 4);
};
var allQuestions = function () {
    return inattentionSectionArray().concat(hyperactivityImpulsivitySectionArray(), additionalConditionsSectionArray());
};
var areQuestionsAnswered = function (questions) {
    for (var _i = 0, questions_1 = questions; _i < questions_1.length; _i++) {
        var question = questions_1[_i];
        if (!helpers_1.isAnswered(question))
            return false;
    }
    return true;
};
var isExportResultsEnabled = function () {
    return isResultsSectionVisible();
};
var calculatePoints = function () {
    if (areQuestionsAnswered(allQuestions())) {
        if (isF900Visible()) {
            return {
                classifiedAsADHD: {
                    qID: 'classifiedAsADHD',
                    rParams: [],
                    resultTexts: 'F900'
                }
            };
        }
        else if (isF901Visible()) {
            return {
                classifiedAsADHD: {
                    qID: 'classifiedAsADHD',
                    rParams: [],
                    resultTexts: 'F901'
                }
            };
        }
        else if (isF902Visible()) {
            return {
                classifiedAsADHD: {
                    qID: 'classifiedAsADHD',
                    rParams: [],
                    resultTexts: 'F902'
                }
            };
        }
        return null;
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.answerAll = isAnswerAllVisible();
    visibleQuestions.notClassifiedAsADHD = isNotClassifiedAsADHDVisible();
    visibleQuestions.classifiedAsADHD =
        isF902Visible() || isF901Visible() || isF900Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.resultsSection = isResultsSectionVisible();
    return visibleSections;
};
var isAnswerAllVisible = function () {
    return !areQuestionsAnswered(allQuestions());
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        isExportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
