"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    introductionKids: false,
    headKids: false,
    armsKids: false,
    trunkKids: false,
    legsKids: false,
    introduction: false,
    head: false,
    arms: false,
    trunk: false,
    legs: false,
    answerAll: true,
    bsaTotalClear: false,
    bsaTotalMild: false,
    bsaTotalModerate: false,
    bsaTotalSevere: false,
    bsaLinkQuestion: false,
    bsaHead: false,
    bsaArms: false,
    bsaTrunk: false,
    bsaLegs: false
};
var visibleSections = {
    ageSection: true,
    kids: false,
    adults: false,
    answerAllSection: true,
    resultsTotalSection: false,
    resultsSection: false
};
var inputs = {
    age: null,
    headKids: null,
    armsKids: null,
    trunkKids: null,
    legsKids: null,
    head: null,
    arms: null,
    trunk: null,
    legs: null
};
var returnVisibleQuestions = function () {
    var _a;
    updateQuestionsVisibilityUsingResult((_a = calculateResult()) === null || _a === void 0 ? void 0 : _a.totalBSA);
    visibleQuestions.introductionKids = isAgeLessThan8();
    visibleQuestions.headKids = isAgeLessThan8();
    visibleQuestions.armsKids = isAgeLessThan8();
    visibleQuestions.trunkKids = isAgeLessThan8();
    visibleQuestions.legsKids = isAgeLessThan8();
    visibleQuestions.introduction = isAgeMoreOrEquals8();
    visibleQuestions.head = isAgeMoreOrEquals8();
    visibleQuestions.arms = isAgeMoreOrEquals8();
    visibleQuestions.trunk = isAgeMoreOrEquals8();
    visibleQuestions.legs = isAgeMoreOrEquals8();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    var _a;
    updateSectionsVisibilityUsingResult((_a = calculateResult()) === null || _a === void 0 ? void 0 : _a.totalBSA);
    visibleSections.kids = isAgeLessThan8();
    visibleSections.adults = isAgeMoreOrEquals8();
    return visibleSections;
};
var isAgeLessThan8 = function () {
    return helpers_1.answerMatches(inputs.age, 'lessThan8');
};
var isAgeMoreOrEquals8 = function () {
    return helpers_1.answerMatches(inputs.age, 'moreOrEquals8');
};
var areKidsQuestionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.headKids) &&
        helpers_1.isAnswered(inputs.armsKids) &&
        helpers_1.isAnswered(inputs.trunkKids) &&
        helpers_1.isAnswered(inputs.legsKids) &&
        helpers_1.numberInLimits({ input: inputs.headKids, min: 0, max: 20 }) &&
        helpers_1.numberInLimits({ input: inputs.armsKids, min: 0, max: 20 }) &&
        helpers_1.numberInLimits({ input: inputs.trunkKids, min: 0, max: 30 }) &&
        helpers_1.numberInLimits({ input: inputs.legsKids, min: 0, max: 30 }));
};
var kidsCalculation = function () {
    if (!areKidsQuestionsAnswered())
        return null;
    var totalBSA = Number(inputs.headKids.currentPoints) +
        Number(inputs.armsKids.currentPoints) +
        Number(inputs.trunkKids.currentPoints) +
        Number(inputs.legsKids.currentPoints);
    return {
        bsaHead: (100 * Number(inputs.headKids.currentPoints)) / 20,
        bsaArms: (100 * Number(inputs.armsKids.currentPoints)) / 20,
        bsaTrunk: (100 * Number(inputs.trunkKids.currentPoints)) / 30,
        bsaLegs: (100 * Number(inputs.legsKids.currentPoints)) / 30,
        totalBSA: totalBSA
    };
};
var areAdultQuestionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.head) &&
        helpers_1.isAnswered(inputs.arms) &&
        helpers_1.isAnswered(inputs.trunk) &&
        helpers_1.isAnswered(inputs.legs) &&
        helpers_1.numberInLimits({ input: inputs.head, min: 0, max: 10 }) &&
        helpers_1.numberInLimits({ input: inputs.arms, min: 0, max: 20 }) &&
        helpers_1.numberInLimits({ input: inputs.trunk, min: 0, max: 30 }) &&
        helpers_1.numberInLimits({ input: inputs.legs, min: 0, max: 40 }));
};
var adultCalculation = function () {
    if (!areAdultQuestionsAnswered())
        return null;
    var totalBSA = Number(inputs.head.currentPoints) +
        Number(inputs.arms.currentPoints) +
        Number(inputs.trunk.currentPoints) +
        Number(inputs.legs.currentPoints);
    return {
        bsaHead: (100 * Number(inputs.head.currentPoints)) / 10,
        bsaArms: (100 * Number(inputs.arms.currentPoints)) / 20,
        bsaTrunk: (100 * Number(inputs.trunk.currentPoints)) / 30,
        bsaLegs: (100 * Number(inputs.legs.currentPoints)) / 40,
        totalBSA: totalBSA
    };
};
var updateSectionsVisibilityUsingResult = function (totalBSA) {
    var isTotalBSAUndefined = totalBSA === undefined;
    visibleSections.answerAllSection = isTotalBSAUndefined;
    visibleSections.resultsTotalSection = !isTotalBSAUndefined;
    visibleSections.resultsSection = !isTotalBSAUndefined;
};
var updateQuestionsVisibilityUsingResult = function (totalBSA) {
    var isTotalBSAUndefined = totalBSA === undefined;
    visibleQuestions.answerAll = isTotalBSAUndefined;
    visibleQuestions.bsaTotalClear = isBSATotalClearVisible(totalBSA);
    visibleQuestions.bsaTotalMild = isBSATotalMildVisible(totalBSA);
    visibleQuestions.bsaTotalModerate = isBSATotalModerateVisible(totalBSA);
    visibleQuestions.bsaTotalSevere = isBSATotalSevereVisible(totalBSA);
    visibleQuestions.bsaHead = !isTotalBSAUndefined;
    visibleQuestions.bsaArms = !isTotalBSAUndefined;
    visibleQuestions.bsaTrunk = !isTotalBSAUndefined;
    visibleQuestions.bsaLegs = !isTotalBSAUndefined;
    visibleQuestions.bsaLinkQuestion = !isTotalBSAUndefined;
};
var isBSATotalClearVisible = function (totalBSA) {
    return totalBSA === 0 && totalBSA !== undefined;
};
var isBSATotalMildVisible = function (totalBSA) {
    return totalBSA > 0 && totalBSA <= 15.9 && totalBSA !== undefined;
};
var isBSATotalModerateVisible = function (totalBSA) {
    return totalBSA >= 16 && totalBSA <= 39.9 && totalBSA !== undefined;
};
var isBSATotalSevereVisible = function (totalBSA) {
    return totalBSA > 40 && totalBSA !== undefined;
};
var calculateResult = function () {
    if (helpers_1.answerMatches(inputs.age, 'lessThan8')) {
        return kidsCalculation();
    }
    if (helpers_1.answerMatches(inputs.age, 'moreOrEquals8')) {
        return adultCalculation();
    }
    return null;
};
var calculatePoints = function () {
    var result = calculateResult();
    if (result === null) {
        return null;
    }
    var bsaHead = helpers_1.formatCalculationResult(Number(result.bsaHead), 2);
    var bsaArms = helpers_1.formatCalculationResult(Number(result.bsaArms), 2);
    var bsaTrunk = helpers_1.formatCalculationResult(Number(result.bsaTrunk), 2);
    var bsaLegs = helpers_1.formatCalculationResult(Number(result.bsaLegs), 2);
    var resultQuestions = {
        bsaHead: {
            qID: 'bsaHead',
            rParams: __spreadArrays(helpers_1.returnNumberObject(bsaHead)),
            titleTexts: 'regular',
            resultTexts: 'regular'
        },
        bsaArms: {
            qID: 'bsaArms',
            rParams: __spreadArrays(helpers_1.returnNumberObject(bsaArms)),
            titleTexts: 'regular',
            resultTexts: 'regular'
        },
        bsaTrunk: {
            qID: 'bsaTrunk',
            rParams: __spreadArrays(helpers_1.returnNumberObject(bsaTrunk)),
            titleTexts: 'regular',
            resultTexts: 'regular'
        },
        bsaLegs: {
            qID: 'bsaLegs',
            rParams: __spreadArrays(helpers_1.returnNumberObject(bsaLegs)),
            titleTexts: 'regular',
            resultTexts: 'regular'
        }
    };
    if (isBSATotalClearVisible(result === null || result === void 0 ? void 0 : result.totalBSA)) {
        return __assign({ bsaTotalClear: {
                qID: 'bsaTotalClear',
                rParams: __spreadArrays(helpers_1.returnNumberObject(result === null || result === void 0 ? void 0 : result.totalBSA)),
                titleTexts: 'regular',
                resultTexts: 'regular'
            } }, resultQuestions);
    }
    if (isBSATotalMildVisible(result === null || result === void 0 ? void 0 : result.totalBSA)) {
        return __assign({ bsaTotalMild: {
                qID: 'bsaTotalMild',
                rParams: __spreadArrays(helpers_1.returnNumberObject(result === null || result === void 0 ? void 0 : result.totalBSA)),
                titleTexts: 'regular',
                resultTexts: 'regular'
            } }, resultQuestions);
    }
    if (isBSATotalModerateVisible(result === null || result === void 0 ? void 0 : result.totalBSA)) {
        return __assign({ bsaTotalModerate: {
                qID: 'bsaTotalModerate',
                rParams: __spreadArrays(helpers_1.returnNumberObject(result === null || result === void 0 ? void 0 : result.totalBSA)),
                titleTexts: 'regular',
                resultTexts: 'regular'
            } }, resultQuestions);
    }
    if (isBSATotalSevereVisible(result === null || result === void 0 ? void 0 : result.totalBSA)) {
        return __assign({ bsaTotalSevere: {
                qID: 'bsaTotalSevere',
                rParams: __spreadArrays(helpers_1.returnNumberObject(result === null || result === void 0 ? void 0 : result.totalBSA)),
                titleTexts: 'regular',
                resultTexts: 'regular'
            } }, resultQuestions);
    }
    return null;
};
var isExportResultsEnabled = function () {
    return (helpers_1.isAnswered(inputs.age) &&
        (areAdultQuestionsAnswered() || areKidsQuestionsAnswered()));
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});