"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    weight: true,
    stage: false,
    kidney: false,
    dialysis: false,
    kind: false,
    noAnswer: true,
    powderKids1: true,
    powderKids3: true,
    powderKids1KidneyMiddle: true,
    powderKids3Middle: true,
    powderKids1KidneyLow: true,
    powderKids3Low: true,
    tabletsKids1: true,
    tabletsKids3: true,
    tabletsKids1Middle: true,
    tabletsKids3Middle: true,
    tabletsKids1MiddleLow: true,
    tabletsKids3Low: true,
    powderKids1Late: true,
    powderKids3Late: true,
    powderKids1KidneyMiddleLate: true,
    powderKids3MiddleLate: true,
    powderKids1KidneyLowLate: true,
    powderKids3LowLate: true,
    tabletsKids1Late: true,
    tabletsKids3Late: true,
    tabletsKids1MiddleLate: true,
    tabletsKids3MiddleLate: true,
    tabletsKids1LowLate: true,
    tabletsKids3LowLate: true,
    tabletsAdults1: true,
    tabletsAdults3: true,
    tabletsAdults1Middle: true,
    tabletsAdults3Middle: true,
    tabletsAdults1Low: true,
    tabletsAdults3Low: true,
    powderAdults1: true,
    powderAdults3: true,
    powderAdults1Middle: true,
    powderAdults3Middle: true,
    powderAdults1Low: true,
    powderAdults3Low: true,
    tabletsAdults1Late: true,
    tabletsAdults3Late: true,
    tabletsAdults1MiddleLate: true,
    tabletsAdults3MiddleLate: true,
    tabletsAdults1LowLate: true,
    tabletsAdults3LowLate: true,
    powderAdults1Late: true,
    powderAdults3Late: true,
    powderAdults1MiddleLate: true,
    powderAdults3MiddleLate: true,
    powderAdults1LowLate: true,
    powderAdults3LowLate: true,
    tblDialyHemEarly1: true,
    tblDialyHemEarly2: true,
    pwdDialyHemEarly1: true,
    pwdDialyHemEarly2: true,
    tblDialyHemLate1: true,
    tblDialyHemLate2: true,
    pwdDialyHemLate1: true,
    pwdDialyHemLate2: true,
    anti: true
};
var visibleSections = {
    inputSection: true,
    dosing: false,
    powderKidsEarly: false,
    powderKidsKidneyMiddleEarly: false,
    powderKidsKidneyLowEarly: false,
    tabletsKidsEarly: false,
    tabletsKidsMiddleEarly: false,
    tabletsKidsMiddleLowEarly: false,
    powderKidsLate: false,
    powderKidsKidneyMiddleLate: false,
    powderKidsKidneyLowLate: false,
    tabletsKidsLate: false,
    tabletsKidsMiddleLate: false,
    tabletsKidsLowLate: false,
    tabletsAdults: false,
    tabletsAdultsMiddle: false,
    tabletsAdultsLow: false,
    powderAdults: false,
    powderAdultsMiddle: false,
    powderAdultsLow: false,
    tabletsAdultsLate: false,
    tabletsAdultsMiddleLate: false,
    tabletsAdultsLowLate: false,
    powderAdultsLate: false,
    powderAdultsMiddleLate: false,
    powderAdultsLowLate: false,
    tblDialyHemEarly: false,
    pwdDialyHemEarly: false,
    tblDialyHemLate: false,
    pwdDialyHemLate: false,
    warningAb: false
};
var inputs = {
    weight: null,
    stage: null,
    kidney: null,
    dialysis: null,
    kind: null
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 });
};
var isStageVisible = function () {
    return isWeightValid();
};
var isKidneyVisible = function () {
    return isWeightValid() && isStageVisible() && helpers_1.isAnswered(inputs.stage);
};
var isDialysisVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.isAnswered(inputs.stage) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isKindVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.isAnswered(inputs.stage) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes'));
};
var areAllVisibleQuesionsAnswered = function () {
    return (isWeightValid() &&
        ((isStageVisible() && helpers_1.isAnswered(inputs.stage)) || !isStageVisible()) &&
        ((isKidneyVisible() && helpers_1.isAnswered(inputs.kidney)) || !isKidneyVisible()) &&
        ((isDialysisVisible() && helpers_1.isAnswered(inputs.dialysis)) ||
            !isDialysisVisible()) &&
        ((isKindVisible() && helpers_1.isAnswered(inputs.kind)) || !isKindVisible()));
};
var isPowderKidsEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isPowderKidsKidneyMiddleEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isPowderKidsKidneyLowEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isTabletsKidsEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 30, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsKidsMiddleEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 33.301, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isTabletsKidsMiddleLowEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 33.301, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isPowderKidsLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isPowderKidsKidneyMiddleLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isPowderKidsKidneyLowLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isTabletsKidsLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 15, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsKidsMiddleLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 33.4, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isTabletsKidsLowLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 33.4, max: 39.999 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isTabletsAdultsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsAdultsMiddleSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isTabletsAdultsLowSectionVisible = function () {
    return ((helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'no')) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
            isStageVisible() &&
            helpers_1.answerMatches(inputs.stage, 'early') &&
            isKidneyVisible() &&
            helpers_1.answerMatches(inputs.kidney, 'low') &&
            isDialysisVisible() &&
            helpers_1.answerMatches(inputs.dialysis, 'yes') &&
            isKindVisible() &&
            helpers_1.answerMatches(inputs.kind, 'perito')));
};
var isPowderAdultsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isPowderAdultsMiddleSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isPowderAdultsLowSectionVisible = function () {
    return ((helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'no')) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
            isStageVisible() &&
            helpers_1.answerMatches(inputs.stage, 'early') &&
            isKidneyVisible() &&
            helpers_1.answerMatches(inputs.kidney, 'low') &&
            isDialysisVisible() &&
            helpers_1.answerMatches(inputs.dialysis, 'yes') &&
            isKindVisible() &&
            helpers_1.answerMatches(inputs.kind, 'perito')));
};
var isTabletsAdultsLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsAdultsMiddleLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isTabletsAdultsLowLateSectionVisible = function () {
    return ((helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'no')) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
            isStageVisible() &&
            helpers_1.answerMatches(inputs.stage, 'late') &&
            isKidneyVisible() &&
            helpers_1.answerMatches(inputs.kidney, 'low') &&
            isDialysisVisible() &&
            helpers_1.answerMatches(inputs.dialysis, 'yes') &&
            isKindVisible() &&
            helpers_1.answerMatches(inputs.kind, 'perito')));
};
var isPowderAdultsLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isPowderAdultsMiddleLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isPowderAdultsLowLateSectionVisible = function () {
    return ((helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'no')) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
            isStageVisible() &&
            helpers_1.answerMatches(inputs.stage, 'late') &&
            isKidneyVisible() &&
            helpers_1.answerMatches(inputs.kidney, 'low') &&
            isDialysisVisible() &&
            helpers_1.answerMatches(inputs.dialysis, 'yes') &&
            isKindVisible() &&
            helpers_1.answerMatches(inputs.kind, 'perito')));
};
var isTblDialyHemEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes') &&
        isKindVisible() &&
        helpers_1.answerMatches(inputs.kind, 'hemo'));
};
var isTblDialyHemLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes') &&
        isKindVisible() &&
        helpers_1.answerMatches(inputs.kind, 'hemo'));
};
var isPwdDialyHemEarlySectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'early') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes') &&
        isKindVisible() &&
        helpers_1.answerMatches(inputs.kind, 'hemo'));
};
var isPwdDialyHemLateSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isStageVisible() &&
        helpers_1.answerMatches(inputs.stage, 'late') &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes') &&
        isKindVisible() &&
        helpers_1.answerMatches(inputs.kind, 'hemo'));
};
var weight15Calculation = function () {
    var _a;
    if (helpers_1.numberInLimits({ input: inputs.weight, min: 33.4, max: 200 })) {
        return 10;
    }
    return (15 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints)) / 50;
};
var weight15Calculation2 = function () {
    var _a;
    if (helpers_1.numberInLimits({ input: inputs.weight, min: 33.4, max: 200 })) {
        return 500;
    }
    return 15 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q;
    if (isPowderKidsEarlySectionVisible()) {
        if (!helpers_1.numberInLimits({ input: inputs.weight, min: 30, max: 39.999 })) {
            return {
                powderKids1: {
                    qID: 'powderKids1',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((25 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult((50 * ((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(25 * ((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(50 * ((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints), 1), 0, 1)),
                    titleTexts: 'result1'
                }
            };
        }
        return {
            powderKids1: {
                qID: 'powderKids1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((25 * ((_e = inputs.weight) === null || _e === void 0 ? void 0 : _e.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult((50 * ((_f = inputs.weight) === null || _f === void 0 ? void 0 : _f.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(25 * ((_g = inputs.weight) === null || _g === void 0 ? void 0 : _g.currentPoints), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(50 * ((_h = inputs.weight) === null || _h === void 0 ? void 0 : _h.currentPoints), 1), 0, 1)),
                titleTexts: 'result1'
            },
            tabletsKids1: {
                qID: 'tabletsKids1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(25 * ((_j = inputs.weight) === null || _j === void 0 ? void 0 : _j.currentPoints), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(50 * ((_k = inputs.weight) === null || _k === void 0 ? void 0 : _k.currentPoints), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsKidneyMiddleEarlySectionVisible()) {
        return {
            powderKids1KidneyMiddle: {
                qID: 'powderKids1KidneyMiddle',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation2(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsKidneyLowEarlySectionVisible()) {
        return {
            powderKids1KidneyLow: {
                qID: 'powderKids1KidneyLow',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation2(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsLateSectionVisible()) {
        if (!helpers_1.numberInLimits({ input: inputs.weight, min: 15, max: 39.999 })) {
            return {
                powderKids1Late: {
                    qID: 'powderKids1Late',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((100 * ((_l = inputs.weight) === null || _l === void 0 ? void 0 : _l.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(100 * ((_m = inputs.weight) === null || _m === void 0 ? void 0 : _m.currentPoints), 1), 0, 1)),
                    titleTexts: 'result1'
                }
            };
        }
        return {
            powderKids1Late: {
                qID: 'powderKids1Late',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((100 * ((_o = inputs.weight) === null || _o === void 0 ? void 0 : _o.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(100 * ((_p = inputs.weight) === null || _p === void 0 ? void 0 : _p.currentPoints), 1), 0, 1)),
                titleTexts: 'result1'
            },
            tabletsKids1Late: {
                qID: 'tabletsKids1Late',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(100 * ((_q = inputs.weight) === null || _q === void 0 ? void 0 : _q.currentPoints), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsKidneyMiddleLateSectionVisible()) {
        return {
            powderKids1KidneyMiddleLate: {
                qID: 'powderKids1KidneyMiddleLate',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation2(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsKidneyLowLateSectionVisible()) {
        return {
            powderKids1KidneyLowLate: {
                qID: 'powderKids1KidneyLowLate',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation2(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.stage = isStageVisible();
    visibleQuestions.kidney = isKidneyVisible();
    visibleQuestions.dialysis = isDialysisVisible();
    visibleQuestions.kind = isKindVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = !areAllVisibleQuesionsAnswered();
    visibleSections.powderKidsEarly = isPowderKidsEarlySectionVisible();
    visibleSections.powderKidsKidneyMiddleEarly =
        isPowderKidsKidneyMiddleEarlySectionVisible();
    visibleSections.powderKidsKidneyLowEarly =
        isPowderKidsKidneyLowEarlySectionVisible();
    visibleSections.tabletsKidsEarly = isTabletsKidsEarlySectionVisible();
    visibleSections.tabletsKidsMiddleEarly =
        isTabletsKidsMiddleEarlySectionVisible();
    visibleSections.tabletsKidsMiddleLowEarly =
        isTabletsKidsMiddleLowEarlySectionVisible();
    visibleSections.powderKidsLate = isPowderKidsLateSectionVisible();
    visibleSections.powderKidsKidneyMiddleLate =
        isPowderKidsKidneyMiddleLateSectionVisible();
    visibleSections.powderKidsKidneyLowLate =
        isPowderKidsKidneyLowLateSectionVisible();
    visibleSections.tabletsKidsLate = isTabletsKidsLateSectionVisible();
    visibleSections.tabletsKidsMiddleLate =
        isTabletsKidsMiddleLateSectionVisible();
    visibleSections.tabletsKidsLowLate = isTabletsKidsLowLateSectionVisible();
    visibleSections.tabletsAdults = isTabletsAdultsSectionVisible();
    visibleSections.tabletsAdultsMiddle = isTabletsAdultsMiddleSectionVisible();
    visibleSections.tabletsAdultsLow = isTabletsAdultsLowSectionVisible();
    visibleSections.powderAdults = isPowderAdultsSectionVisible();
    visibleSections.powderAdultsMiddle = isPowderAdultsMiddleSectionVisible();
    visibleSections.powderAdultsLow = isPowderAdultsLowSectionVisible();
    visibleSections.tabletsAdultsLate = isTabletsAdultsLateSectionVisible();
    visibleSections.tabletsAdultsMiddleLate =
        isTabletsAdultsMiddleLateSectionVisible();
    visibleSections.tabletsAdultsLowLate = isTabletsAdultsLowLateSectionVisible();
    visibleSections.powderAdultsLate = isPowderAdultsLateSectionVisible();
    visibleSections.powderAdultsMiddleLate =
        isPowderAdultsMiddleLateSectionVisible();
    visibleSections.powderAdultsLowLate = isPowderAdultsLowLateSectionVisible();
    visibleSections.tblDialyHemEarly = isTblDialyHemEarlySectionVisible();
    visibleSections.tblDialyHemLate = isTblDialyHemLateSectionVisible();
    visibleSections.pwdDialyHemEarly = isPwdDialyHemEarlySectionVisible();
    visibleSections.pwdDialyHemLate = isPwdDialyHemLateSectionVisible();
    visibleSections.warningAb = areAllVisibleQuesionsAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
