"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    weight: true,
    kidney: false,
    dialysis: false,
    kind: false,
    noAnswer: true,
    powderKids1: true,
    powderKids3: true,
    powderKids1KidneyMiddle: true,
    powderKids3Middle: true,
    powderKids1KidneyLow: true,
    powderKids3Low: true,
    tabletsKids1: true,
    tabletsKids3: true,
    tabletsKids1Middle: true,
    tabletsKids3Middle: true,
    tabletsKids1MiddleLow: true,
    tabletsKids3Low: true,
    tabletsAdults1: true,
    divider: true,
    tabletsAdults12: true,
    tabletsAdults3: true,
    tabletsAdults1Severe: true,
    tabletsAdults3Severe: true,
    tabletsAdults1Middle: true,
    tabletsAdults3Middle: true,
    tabletsAdults1Low: true,
    tabletsAdults3Low: true,
    powderAdults1: true,
    dividerPowder: true,
    powderAdults12: true,
    powderAdults3: true,
    powderAdults1Severe: true,
    powderAdults3Severe: true,
    powderAdults1Middle: true,
    powderAdults3Middle: true,
    powderAdults1Low: true,
    powderAdults3Low: true,
    tblDialyHem1: true,
    tblDialyHem2: true,
    pwdDialyHem1: true,
    pwdDialyHem2: true,
    anti: true
};
var visibleSections = {
    inputSection: true,
    dosing: false,
    powderKids: false,
    powderKidsKidneyMiddle: false,
    powderKidsKidneyLow: false,
    tabletsKids: false,
    tabletsKidsMiddle: false,
    tabletsKidsMiddleLow: false,
    tabletsAdults: false,
    tabletsAdultsSevere: false,
    tabletsAdultsMiddle: false,
    tabletsAdultsLow: false,
    powderAdults: false,
    powderAdultsSevere: false,
    powderAdultsMiddle: false,
    powderAdultsLow: false,
    tblDialyHem: false,
    pwdDialyHem: false,
    warningAb: false
};
var inputs = {
    weight: null,
    kidney: null,
    dialysis: null,
    kind: null
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 });
};
var isKidneyVisible = function () {
    return isWeightValid();
};
var isDialysisVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isKindVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes'));
};
var areAllVisibleQuesionsAnswered = function () {
    return (isWeightValid() &&
        ((isKidneyVisible() && helpers_1.isAnswered(inputs.kidney)) || !isKidneyVisible()) &&
        ((isDialysisVisible() && helpers_1.isAnswered(inputs.dialysis)) ||
            !isDialysisVisible()) &&
        ((isKindVisible() && helpers_1.isAnswered(inputs.kind)) || !isKindVisible()));
};
var isPowderKidsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isPowderKidsKidneyMiddleSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isPowderKidsKidneyLowSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 39.999 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isTabletsKidsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 11.101, max: 39.999 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsKidsMiddleSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 33.301, max: 39.999 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isTabletsKidsMiddleLowSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 33.301, max: 39.999 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isTabletsAdultsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsAdultsMiddleSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isTabletsAdultsLowSectionVisible = function () {
    return ((helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'no')) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
            isKidneyVisible() &&
            helpers_1.answerMatches(inputs.kidney, 'low') &&
            isDialysisVisible() &&
            helpers_1.answerMatches(inputs.dialysis, 'yes') &&
            isKindVisible() &&
            helpers_1.answerMatches(inputs.kind, 'perito')));
};
var isPowderAdultsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isPowderAdultsMiddleSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'middle'));
};
var isPowderAdultsLowSectionVisible = function () {
    return ((helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'no')) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
            isKidneyVisible() &&
            helpers_1.answerMatches(inputs.kidney, 'low') &&
            isDialysisVisible() &&
            helpers_1.answerMatches(inputs.dialysis, 'yes') &&
            isKindVisible() &&
            helpers_1.answerMatches(inputs.kind, 'perito')));
};
var isTblDialyHemSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes') &&
        isKindVisible() &&
        helpers_1.answerMatches(inputs.kind, 'hemo'));
};
var isPwdDialyHemSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 200 }) &&
        isKidneyVisible() &&
        helpers_1.answerMatches(inputs.kidney, 'low') &&
        isDialysisVisible() &&
        helpers_1.answerMatches(inputs.dialysis, 'yes') &&
        isKindVisible() &&
        helpers_1.answerMatches(inputs.kind, 'hemo'));
};
var weight15Calculation = function () {
    var _a;
    if (helpers_1.numberInLimits({ input: inputs.weight, min: 33.4, max: 200 })) {
        return 10;
    }
    return (15 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints)) / 50;
};
var weight15Calculation2 = function () {
    var _a;
    if (helpers_1.numberInLimits({ input: inputs.weight, min: 33.4, max: 200 })) {
        return 500;
    }
    return 15 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
    if (isPowderKidsSectionVisible()) {
        if (!isTabletsKidsSectionVisible()) {
            return {
                powderKids1: {
                    qID: 'powderKids1',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((40 * ((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult((90 * ((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(40 * ((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(90 * ((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints), 1), 0, 1)),
                    titleTexts: 'result1'
                }
            };
        }
        return {
            powderKids1: {
                qID: 'powderKids1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((40 * ((_e = inputs.weight) === null || _e === void 0 ? void 0 : _e.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult((90 * ((_f = inputs.weight) === null || _f === void 0 ? void 0 : _f.currentPoints)) / 50, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(40 * ((_g = inputs.weight) === null || _g === void 0 ? void 0 : _g.currentPoints), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(90 * ((_h = inputs.weight) === null || _h === void 0 ? void 0 : _h.currentPoints), 1), 0, 1)),
                titleTexts: 'result1'
            },
            tabletsKids1: {
                qID: 'tabletsKids1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(40 * ((_j = inputs.weight) === null || _j === void 0 ? void 0 : _j.currentPoints), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(90 * ((_k = inputs.weight) === null || _k === void 0 ? void 0 : _k.currentPoints), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsKidneyMiddleSectionVisible()) {
        return {
            powderKids1KidneyMiddle: {
                qID: 'powderKids1KidneyMiddle',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation2(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isPowderKidsKidneyLowSectionVisible()) {
        return {
            powderKids1KidneyLow: {
                qID: 'powderKids1KidneyLow',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight15Calculation2(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.kidney = isKidneyVisible();
    visibleQuestions.dialysis = isDialysisVisible();
    visibleQuestions.kind = isKindVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = !areAllVisibleQuesionsAnswered();
    visibleSections.powderKids = isPowderKidsSectionVisible();
    visibleSections.powderKidsKidneyMiddle =
        isPowderKidsKidneyMiddleSectionVisible();
    visibleSections.powderKidsKidneyLow = isPowderKidsKidneyLowSectionVisible();
    visibleSections.tabletsKids = isTabletsKidsSectionVisible();
    visibleSections.tabletsKidsMiddle = isTabletsKidsMiddleSectionVisible();
    visibleSections.tabletsKidsMiddleLow = isTabletsKidsMiddleLowSectionVisible();
    visibleSections.tabletsAdults = isTabletsAdultsSectionVisible();
    visibleSections.tabletsAdultsSevere = isTabletsAdultsSectionVisible();
    visibleSections.tabletsAdultsMiddle = isTabletsAdultsMiddleSectionVisible();
    visibleSections.tabletsAdultsLow = isTabletsAdultsLowSectionVisible();
    visibleSections.powderAdults = isPowderAdultsSectionVisible();
    visibleSections.powderAdultsSevere = isPowderAdultsSectionVisible();
    visibleSections.powderAdultsMiddle = isPowderAdultsMiddleSectionVisible();
    visibleSections.powderAdultsLow = isPowderAdultsLowSectionVisible();
    visibleSections.tblDialyHem = isTblDialyHemSectionVisible();
    visibleSections.pwdDialyHem = isPwdDialyHemSectionVisible();
    visibleSections.warningAb = areAllVisibleQuesionsAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
