"use strict";


var visibleQuestions = {
    documentedAF: true,
    mechanicalValve: true,
    bioValve: false,
    stenosis: false,
    result1: false,
    result2: false,
    score: false,
    linkCHA2DS2: false,
    result3: false,
    result4: false,
    reservations: false,
    referralAKA: false,
    result6: false,
    hasbled: false,
    linkHASBLED: false,
    previousICH: false,
    bleeding: false,
    referralAKA2: false,
    result7: false,
    blood: false,
    linkChildPugh: false,
    indicatedNOAK: false,
    referralAKA3: false,
    patientUnderstands: false,
    referralAKA4: false,
    result9: false,
    result10: false,
    acronymsExplained: true,
    acronymsListed: false
};
var visibleSections = {
    section1: true,
    acronyms: true
};
var inputs = {
    mechanicalValve: null,
    bioValve: null,
    stenosis: null,
    score: null,
    reservations: null,
    hasbled: null,
    previousICH: null,
    bleeding: null,
    blood: null,
    patientUnderstands: null,
    acronymsExplained: null
};
var isBioValveVisible = function () {
    return helpers_1.answerMatches(inputs.mechanicalValve, 'no');
};
var isStenosisVisible = function () {
    return helpers_1.answerMatches(inputs.bioValve, 'no');
};
var isResult1Visible = function () {
    return (helpers_1.answerMatches(inputs.mechanicalValve, 'yes') ||
        helpers_1.answerMatches(inputs.bioValve, 'yes') ||
        helpers_1.answerMatches(inputs.stenosis, 'yes'));
};
var isResult2Visible = function () {
    return (helpers_1.answerMatches(inputs.mechanicalValve, 'no') &&
        helpers_1.answerMatches(inputs.bioValve, 'no') &&
        helpers_1.answerMatches(inputs.stenosis, 'no'));
};
var isResult3Visible = function () {
    return helpers_1.answerMatches(inputs.score, 'yes');
};
var isResult4Visible = function () {
    return helpers_1.answerMatches(inputs.score, 'no');
};
var isReferralAKAVisible = function () {
    return helpers_1.answerMatches(inputs.reservations, 'yes');
};
var isResult6Visible = function () {
    return helpers_1.answerMatches(inputs.reservations, 'no');
};
var isPreviousICHVisible = function () {
    return helpers_1.answerMatches(inputs.hasbled, 'no');
};
var isBleedingVisible = function () {
    return helpers_1.answerMatches(inputs.previousICH, 'no');
};
var isReferralAKA2Visible = function () {
    return (helpers_1.answerMatches(inputs.hasbled, 'yes') ||
        helpers_1.answerMatches(inputs.previousICH, 'yes') ||
        helpers_1.answerMatches(inputs.bleeding, 'yes'));
};
var isResult7Visible = function () {
    return (helpers_1.answerMatches(inputs.hasbled, 'no') &&
        helpers_1.answerMatches(inputs.previousICH, 'no') &&
        helpers_1.answerMatches(inputs.bleeding, 'no'));
};
var isIndicatedNOAKVisible = function () {
    return helpers_1.answerMatches(inputs.blood, 'yes');
};
var isReferralAKA3Visible = function () {
    return helpers_1.answerMatches(inputs.blood, 'no');
};
var isReferralAKA4Visible = function () {
    return helpers_1.answerMatches(inputs.patientUnderstands, 'no');
};
var isResult9Visible = function () {
    return helpers_1.answerMatches(inputs.patientUnderstands, 'yes');
};
var isAcronymsListedVisible = function () {
    return helpers_1.answerMatches(inputs.acronymsExplained, 'close');
};
var returnVisibleQuestions = function () {
    visibleQuestions.bioValve = isBioValveVisible();
    visibleQuestions.stenosis = isStenosisVisible();
    visibleQuestions.result1 = isResult1Visible();
    visibleQuestions.result2 = isResult2Visible();
    visibleQuestions.score = isResult2Visible();
    visibleQuestions.linkCHA2DS2 = isResult2Visible();
    visibleQuestions.result3 = isResult3Visible();
    visibleQuestions.result4 = isResult4Visible();
    visibleQuestions.reservations = isResult3Visible();
    visibleQuestions.referralAKA = isReferralAKAVisible();
    visibleQuestions.result6 = isResult6Visible();
    visibleQuestions.hasbled = isResult6Visible();
    visibleQuestions.linkHASBLED = isResult6Visible();
    visibleQuestions.previousICH = isPreviousICHVisible();
    visibleQuestions.bleeding = isBleedingVisible();
    visibleQuestions.referralAKA2 = isReferralAKA2Visible();
    visibleQuestions.result7 = isResult7Visible();
    visibleQuestions.blood = isResult7Visible();
    visibleQuestions.linkChildPugh = isResult7Visible();
    visibleQuestions.indicatedNOAK = isIndicatedNOAKVisible();
    visibleQuestions.referralAKA3 = isReferralAKA3Visible();
    visibleQuestions.patientUnderstands = isIndicatedNOAKVisible();
    visibleQuestions.referralAKA4 = isReferralAKA4Visible();
    visibleQuestions.result9 = isResult9Visible();
    visibleQuestions.result10 = isResult9Visible();
    visibleQuestions.acronymsListed = isAcronymsListedVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !areAllNotAnswered();
};
var calculatePoints = function () {
    return null;
};
var areAllNotAnswered = function () {
    return (!helpers_1.isAnswered(inputs.mechanicalValve) ||
        (isBioValveVisible() && !helpers_1.isAnswered(inputs.bioValve)) ||
        (isStenosisVisible() && !helpers_1.isAnswered(inputs.stenosis)) ||
        (isResult2Visible() && !helpers_1.isAnswered(inputs.score)) ||
        (isResult3Visible() && !helpers_1.isAnswered(inputs.reservations)) ||
        (isResult6Visible() && !helpers_1.isAnswered(inputs.hasbled)) ||
        (isPreviousICHVisible() && !helpers_1.isAnswered(inputs.previousICH)) ||
        (isBleedingVisible() && !helpers_1.isAnswered(inputs.bleeding)) ||
        (isResult7Visible() && !helpers_1.isAnswered(inputs.blood)) ||
        (isIndicatedNOAKVisible() && !helpers_1.isAnswered(inputs.patientUnderstands)));
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
