"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    weight: true,
    noAnswer1: false,
    doseSuspensionKidsSmall: false,
    durationSuspensionKidsSmall: false,
    doseSuspensionKidsLarge: false,
    durationSuspensionKidsLarge: false,
    doseTabletsAdults: false,
    durationTabletsAdults: false,
    doseSuspensionAdults: false,
    durationSuspensionAdults: false,
    kidneyWarning: false,
    warningAntimicrobial1: false
};
var visibleSections = {
    weightSection: true,
    noAnswer: false,
    suspensionKidsSmall: false,
    suspensionKidsLarge: false,
    tabletsAdults: false,
    suspensionAdults: false,
    kidney: false,
    warningAntimicrobial: false
};
var inputs = {
    weight: null
};
var weightWithinLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 300 });
};
var isNoAnswerVisible = function () {
    return !weightWithinLimits();
};
var isSuspensionKidsSmallVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 9.99 });
};
var isSuspensionKidsLargeVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 10, max: 44.99 });
};
var isTabletsAdultsVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 45, max: 300 });
};
var calculatePoints = function () {
    var _a, _b;
    if (isSuspensionKidsSmallVisible()) {
        var weight = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        var dose20MlDay1 = (20 * weight) / 20;
        var dose20MgDay1 = 20 * weight;
        var dose20MlDay2 = (10 * weight) / 20;
        var dose20MgDay2 = 10 * weight;
        return {
            doseSuspensionKidsSmall: {
                qID: 'doseSuspensionKidsSmall',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(dose20MlDay1, 1), 0, 1), helpers_1.returnNumberObject(Math.round(dose20MgDay1), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(dose20MlDay2, 1), 0, 1), helpers_1.returnNumberObject(Math.round(dose20MgDay2), 0, 0))
            },
            durationSuspensionKidsSmall: {
                qID: 'durationSuspensionKidsSmall',
                titleTexts: 'result1',
                tParams: []
            }
        };
    }
    if (isSuspensionKidsLargeVisible()) {
        var weight = Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints);
        var dose40MlDay1 = (20 * weight) / 40;
        var dose40MgDay1 = 20 * weight;
        var dose40MlDay2 = (10 * weight) / 40;
        var dose40MgDay2 = 10 * weight;
        return {
            doseSuspensionKidsLarge: {
                qID: 'doseSuspensionKidsLarge',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(dose40MlDay1, 1), 0, 1), helpers_1.returnNumberObject(Math.round(dose40MgDay1), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(dose40MlDay2, 1), 0, 1), helpers_1.returnNumberObject(Math.round(dose40MgDay2), 0, 0))
            },
            durationSuspensionKidsLarge: {
                qID: 'durationSuspensionKidsLarge',
                titleTexts: 'result1',
                tParams: []
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.noAnswer1 = isNoAnswerVisible();
    visibleQuestions.doseSuspensionKidsSmall = isSuspensionKidsSmallVisible();
    visibleQuestions.durationSuspensionKidsSmall = isSuspensionKidsSmallVisible();
    visibleQuestions.doseSuspensionKidsLarge = isSuspensionKidsLargeVisible();
    visibleQuestions.durationSuspensionKidsLarge = isSuspensionKidsLargeVisible();
    visibleQuestions.doseTabletsAdults = isTabletsAdultsVisible();
    visibleQuestions.durationTabletsAdults = isTabletsAdultsVisible();
    visibleQuestions.doseSuspensionAdults = isTabletsAdultsVisible();
    visibleQuestions.durationSuspensionAdults = isTabletsAdultsVisible();
    visibleQuestions.kidneyWarning = !isNoAnswerVisible();
    visibleQuestions.warningAntimicrobial1 = !isNoAnswerVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isNoAnswerVisible();
    visibleSections.suspensionKidsSmall = isSuspensionKidsSmallVisible();
    visibleSections.suspensionKidsLarge = isSuspensionKidsLargeVisible();
    visibleSections.tabletsAdults = isTabletsAdultsVisible();
    visibleSections.suspensionAdults = isTabletsAdultsVisible();
    visibleSections.kidney = !isNoAnswerVisible();
    visibleSections.warningAntimicrobial = !isNoAnswerVisible();
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
