"use strict";


var visibleQuestions = {
    type: true,
    observation: false,
    sizeRatio: false,
    conservationOperation: false,
    safetyMargin1: false,
    sizeDCIS: false,
    sagara1: false,
    linkSagaraIndex1: false,
    endTreatment: false,
    radiation: false,
    reoperation: false,
    safetyMargin2: false,
    sizeDCIS2: false,
    sagara2: false,
    linkSagaraIndex2: false,
    endTreatment2: false,
    radiation2: false,
    reoperationSecond: false,
    safetyMargin3: false,
    sizeDCIS3: false,
    sagara3: false,
    linkSagaraIndex3: false,
    endTreatment3: false,
    radiation3: false,
    reoperationThird: false,
    postoperativeRadiation: false,
    mastectomyReconstruction: false,
    healthy: false,
    endOfAlgorithm: false,
    considerReoperationRadiation: false,
    answerAll: false
};
var visibleSections = {
    section1: true,
    notAnswered: false
};
var inputs = {
    type: null,
    sizeRatio: null,
    safetyMargin1: null,
    sizeDCIS: null,
    sagara1: null,
    reoperation: null,
    safetyMargin2: null,
    sizeDCIS2: null,
    sagara2: null,
    reoperationSecond: null,
    safetyMargin3: null,
    sizeDCIS3: null,
    sagara3: null,
    reoperationThird: null,
    healthy: null,
    linkSagaraIndex1: null,
    linkSagaraIndex2: null,
    linkSagaraIndex3: null
};
var isObservationVisible = function () {
    return helpers_1.answerMatches(inputs.type, 'lobular');
};
var isSizeRatioVisible = function () {
    return helpers_1.answerMatches(inputs.type, 'ductal');
};
var isConservationOperationVisible = function () {
    return helpers_1.answerMatches(inputs.sizeRatio, 'good');
};
var isSizeDCISVisible = function () {
    return helpers_1.answerMatches(inputs.safetyMargin1, 'yes');
};
var isSagara1Visible = function () {
    return helpers_1.answerMatches(inputs.sizeDCIS, 'no');
};
var isLinkSagaraIndex1Visible = function () {
    return helpers_1.answerMatches(inputs.sagara1, 'calculate');
};
var isEndTreatmentVisible = function () {
    return (helpers_1.answerMatches(inputs.sizeDCIS, 'yes') ||
        helpers_1.answerMatches(inputs.sagara1, 'yes') ||
        helpers_1.answerMatches(inputs.linkSagaraIndex1, 'zero') ||
        helpers_1.answerMatches(inputs.linkSagaraIndex1, 'one'));
};
var isRadiationVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.sizeDCIS, 'no') && helpers_1.answerMatches(inputs.sagara1, 'no');
    var condition2 = (helpers_1.answerMatches(inputs.sizeDCIS, 'no') &&
        helpers_1.answerMatches(inputs.linkSagaraIndex1, 'two')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex1, 'three')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex1, 'four')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex1, 'five')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex1, 'six'));
    return condition1 || condition2;
};
var isReoperationVisible = function () {
    return helpers_1.answerMatches(inputs.safetyMargin1, 'no');
};
var isSafetyMargin2Visible = function () {
    return helpers_1.answerMatches(inputs.reoperation, 'reexcision');
};
var isSizeDCIS2Visible = function () {
    return helpers_1.answerMatches(inputs.safetyMargin2, 'yes');
};
var isSagara2Visible = function () {
    return helpers_1.answerMatches(inputs.sizeDCIS2, 'no');
};
var isLinkSagaraIndex2Visible = function () {
    return helpers_1.answerMatches(inputs.sagara2, 'calculate');
};
var isEndTreatment2Visible = function () {
    return (helpers_1.answerMatches(inputs.sizeDCIS2, 'yes') ||
        helpers_1.answerMatches(inputs.sagara2, 'yes') ||
        helpers_1.answerMatches(inputs.linkSagaraIndex2, 'zero') ||
        helpers_1.answerMatches(inputs.linkSagaraIndex2, 'one'));
};
var isRadiation2Visible = function () {
    var condition1 = helpers_1.answerMatches(inputs.sizeDCIS2, 'no') &&
        helpers_1.answerMatches(inputs.sagara2, 'no');
    var condition2 = (helpers_1.answerMatches(inputs.sizeDCIS2, 'no') &&
        helpers_1.answerMatches(inputs.linkSagaraIndex2, 'two')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS2, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex2, 'three')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS2, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex2, 'four')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS2, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex2, 'five')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS2, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex2, 'six'));
    return condition1 || condition2;
};
var isReoperationSecondVisible = function () {
    return helpers_1.answerMatches(inputs.safetyMargin2, 'no');
};
var isSafetyMargin3Visible = function () {
    return helpers_1.answerMatches(inputs.reoperationSecond, 'reexcision');
};
var isSizeDCIS3Visible = function () {
    return helpers_1.answerMatches(inputs.safetyMargin3, 'yes');
};
var isSagara3Visible = function () {
    return helpers_1.answerMatches(inputs.sizeDCIS3, 'no');
};
var isLinkSagaraIndex3Visible = function () {
    return helpers_1.answerMatches(inputs.sagara3, 'calculate');
};
var isEndTreatment3Visible = function () {
    return (helpers_1.answerMatches(inputs.sizeDCIS3, 'yes') ||
        helpers_1.answerMatches(inputs.sagara3, 'yes') ||
        helpers_1.answerMatches(inputs.linkSagaraIndex3, 'zero') ||
        helpers_1.answerMatches(inputs.linkSagaraIndex3, 'one'));
};
var isRadiation3Visible = function () {
    var condition1 = helpers_1.answerMatches(inputs.sizeDCIS3, 'no') &&
        helpers_1.answerMatches(inputs.sagara3, 'no');
    var condition2 = (helpers_1.answerMatches(inputs.sizeDCIS3, 'no') &&
        helpers_1.answerMatches(inputs.linkSagaraIndex3, 'two')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS3, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex3, 'three')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS3, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex3, 'four')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS3, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex3, 'five')) ||
        (helpers_1.answerMatches(inputs.sizeDCIS3, 'no') &&
            helpers_1.answerMatches(inputs.linkSagaraIndex3, 'six'));
    return condition1 || condition2;
};
var isReoperationThirdVisible = function () {
    return helpers_1.answerMatches(inputs.safetyMargin3, 'no');
};
var isPostoperativeRadiationVisible = function () {
    return (helpers_1.answerMatches(inputs.reoperation, 'noOperation') ||
        helpers_1.answerMatches(inputs.reoperationSecond, 'noOperation') ||
        helpers_1.answerMatches(inputs.reoperationThird, 'noOperation'));
};
var isMastectomyReconstructionVisible = function () {
    return helpers_1.answerMatches(inputs.sizeRatio, 'bad');
};
var isHealthyVisible = function () {
    return (helpers_1.answerMatches(inputs.sizeRatio, 'bad') ||
        helpers_1.answerMatches(inputs.reoperation, 'mastectomy') ||
        helpers_1.answerMatches(inputs.reoperationSecond, 'mastectomy') ||
        helpers_1.answerMatches(inputs.reoperationThird, 'mastectomy'));
};
var isEndOfAlgorithmVisible = function () {
    return helpers_1.answerMatches(inputs.healthy, 'yes');
};
var isConsiderReoperationRadiationVisible = function () {
    return helpers_1.answerMatches(inputs.healthy, 'no');
};
var returnVisibleQuestions = function () {
    visibleQuestions.observation = isObservationVisible();
    visibleQuestions.sizeRatio = isSizeRatioVisible();
    visibleQuestions.conservationOperation = isConservationOperationVisible();
    visibleQuestions.safetyMargin1 = isConservationOperationVisible();
    visibleQuestions.sizeDCIS = isSizeDCISVisible();
    visibleQuestions.sagara1 = isSagara1Visible();
    visibleQuestions.linkSagaraIndex1 = isLinkSagaraIndex1Visible();
    visibleQuestions.endTreatment = isEndTreatmentVisible();
    visibleQuestions.radiation = isRadiationVisible();
    visibleQuestions.reoperation = isReoperationVisible();
    visibleQuestions.safetyMargin2 = isSafetyMargin2Visible();
    visibleQuestions.sizeDCIS2 = isSizeDCIS2Visible();
    visibleQuestions.sagara2 = isSagara2Visible();
    visibleQuestions.linkSagaraIndex2 = isLinkSagaraIndex2Visible();
    visibleQuestions.endTreatment2 = isEndTreatment2Visible();
    visibleQuestions.radiation2 = isRadiation2Visible();
    visibleQuestions.reoperationSecond = isReoperationSecondVisible();
    visibleQuestions.safetyMargin3 = isSafetyMargin3Visible();
    visibleQuestions.sizeDCIS3 = isSizeDCIS3Visible();
    visibleQuestions.sagara3 = isSagara3Visible();
    visibleQuestions.linkSagaraIndex3 = isLinkSagaraIndex3Visible();
    visibleQuestions.endTreatment3 = isEndTreatment3Visible();
    visibleQuestions.radiation3 = isRadiation3Visible();
    visibleQuestions.reoperationThird = isReoperationThirdVisible();
    visibleQuestions.postoperativeRadiation = isPostoperativeRadiationVisible();
    visibleQuestions.mastectomyReconstruction =
        isMastectomyReconstructionVisible();
    visibleQuestions.healthy = isHealthyVisible();
    visibleQuestions.endOfAlgorithm = isEndOfAlgorithmVisible();
    visibleQuestions.considerReoperationRadiation =
        isConsiderReoperationRadiationVisible();
    visibleQuestions.answerAll = areAllNotAnswered();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.notAnswered = areAllNotAnswered();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !areAllNotAnswered();
};
var calculatePoints = function () {
    return null;
};
var areAllNotAnswered = function () {
    var sizeRatioVisibility = isSizeRatioVisible() && !helpers_1.isAnswered(inputs.sizeRatio);
    var safetyMargin1Visibility = isConservationOperationVisible() && !helpers_1.isAnswered(inputs.safetyMargin1);
    var sizeDCISVisibility = isSizeDCISVisible() && !helpers_1.isAnswered(inputs.sizeDCIS);
    var sagara1Visibility = isSagara1Visible() && !helpers_1.isAnswered(inputs.sagara1);
    var reoperationVisibility = isReoperationVisible() && !helpers_1.isAnswered(inputs.reoperation);
    var safetyMargin2Visibility = isSafetyMargin2Visible() && !helpers_1.isAnswered(inputs.safetyMargin2);
    var sizeDCIS2Visibility = isSizeDCIS2Visible() && !helpers_1.isAnswered(inputs.sizeDCIS2);
    var sagara2Visibility = isSagara2Visible() && !helpers_1.isAnswered(inputs.sagara2);
    var reoperationSecondVisibility = isReoperationSecondVisible() && !helpers_1.isAnswered(inputs.reoperationSecond);
    var safetyMargin3Visibility = isSafetyMargin3Visible() && !helpers_1.isAnswered(inputs.safetyMargin3);
    var sizeDCIS3VisibleVisibility = isSizeDCIS3Visible() && !helpers_1.isAnswered(inputs.sizeDCIS3);
    var sagara3Visibility = isSagara3Visible() && !helpers_1.isAnswered(inputs.sagara3);
    var reoperationThirdVisibility = isReoperationThirdVisible() && !helpers_1.isAnswered(inputs.reoperationThird);
    var healthyVisibility = isHealthyVisible() && !helpers_1.isAnswered(inputs.healthy);
    var linkSagaraIndex1Visibility = isLinkSagaraIndex1Visible() && !helpers_1.isAnswered(inputs.linkSagaraIndex1);
    var linkSagaraIndex2Visibility = isLinkSagaraIndex2Visible() && !helpers_1.isAnswered(inputs.linkSagaraIndex2);
    var linkSagaraIndex3Visibility = isLinkSagaraIndex3Visible() && !helpers_1.isAnswered(inputs.linkSagaraIndex3);
    return (!helpers_1.isAnswered(inputs.type) ||
        sizeRatioVisibility ||
        safetyMargin1Visibility ||
        sizeDCISVisibility ||
        sagara1Visibility ||
        reoperationVisibility ||
        safetyMargin2Visibility ||
        sizeDCIS2Visibility ||
        sagara2Visibility ||
        reoperationSecondVisibility ||
        safetyMargin3Visibility ||
        sizeDCIS3VisibleVisibility ||
        sagara3Visibility ||
        reoperationThirdVisibility ||
        healthyVisibility ||
        linkSagaraIndex1Visibility ||
        linkSagaraIndex2Visibility ||
        linkSagaraIndex3Visibility);
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
