"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    weight: true,
    height: false,
    sex: false,
    softStools: false,
    abdominalPain: false,
    wellBeing: false,
    antiDiarrhea: false,
    abdominalMass: false,
    hematocrit: false,
    arthritis: false,
    iritis: false,
    stomatitis: false,
    analFissure: false,
    otherFistula: false,
    fever: false,
    resultRange1: false,
    resultRange2: false,
    resultRange3: false,
    resultRange4: false
};
var visibleSections = {
    sectionOne: true,
    sectionTwo: false,
    sectionThree: true
};
var inputs = {
    weight: null,
    height: null,
    sex: null,
    softStools: null,
    abdominalPain: null,
    wellBeing: null,
    antiDiarrhea: null,
    abdominalMass: null,
    hematocrit: null,
    arthritis: null,
    iritis: null,
    stomatitis: null,
    analFissure: null,
    otherFistula: null,
    fever: null
};
var isHeightVisible = function () {
    return (helpers_1.isAnswered(inputs.weight) &&
        helpers_1.numberInLimits({
            input: inputs.weight,
            min: 1,
            max: 300
        }));
};
var isSexVisible = function () {
    return (helpers_1.isAnswered(inputs.height) &&
        helpers_1.numberInLimits({
            input: inputs.height,
            min: 130,
            max: 250
        }));
};
var isSoftStoolsVisible = function () {
    return helpers_1.isAnswered(inputs.sex);
};
var isAbdominalPainVisible = function () {
    return helpers_1.isAnswered(inputs.softStools);
};
var isHematrocitVisible = function () {
    return helpers_1.isAnswered(inputs.abdominalMass);
};
var isSectionTwoAndArthritisVisible = function () {
    return helpers_1.isAnswered(inputs.hematocrit);
};
var isIritisVisible = function () {
    return helpers_1.isAnswered(inputs.arthritis);
};
var isStomatitisVisible = function () {
    return helpers_1.isAnswered(inputs.iritis);
};
var isAnalFissureVisible = function () {
    return helpers_1.isAnswered(inputs.stomatitis);
};
var isOtherFistulaVisible = function () {
    return helpers_1.isAnswered(inputs.analFissure);
};
var isFeverVisible = function () {
    return helpers_1.isAnswered(inputs.otherFistula);
};
var isWellBeingVisible = function () {
    return helpers_1.isAnswered(inputs.abdominalPain);
};
var isAntiDiarrheaVisible = function () {
    return helpers_1.isAnswered(inputs.wellBeing);
};
var isAbdominalMassVisible = function () {
    return helpers_1.isAnswered(inputs.antiDiarrhea);
};
var isAnswerAllNotVisible = function () {
    return (!helpers_1.isAnswered(inputs.weight) ||
        !helpers_1.isAnswered(inputs.height) ||
        !helpers_1.isAnswered(inputs.sex) ||
        !helpers_1.isAnswered(inputs.softStools) ||
        !helpers_1.isAnswered(inputs.abdominalPain) ||
        !helpers_1.isAnswered(inputs.wellBeing) ||
        !helpers_1.isAnswered(inputs.antiDiarrhea) ||
        !helpers_1.isAnswered(inputs.abdominalMass) ||
        !helpers_1.isAnswered(inputs.hematocrit) ||
        !helpers_1.isAnswered(inputs.arthritis) ||
        !helpers_1.isAnswered(inputs.iritis) ||
        !helpers_1.isAnswered(inputs.stomatitis) ||
        !helpers_1.isAnswered(inputs.analFissure) ||
        !helpers_1.isAnswered(inputs.otherFistula) ||
        !helpers_1.isAnswered(inputs.fever));
};
var isSectionThreeVisible = function () {
    return (isAnswerAllNotVisible() ||
        isRange2Visible() ||
        isRange3Visible() ||
        isRange4Visible());
};
var calculateIdealBodyWeight = function () {
    var _a;
    var idealWeightScore = 0;
    if (((_a = inputs.sex) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'female') {
        idealWeightScore =
            45.5 + 0.91 * (Number(inputs.height.currentPoints) - 152.4);
    }
    else {
        idealWeightScore =
            50 + 0.91 * (Number(inputs.height.currentPoints) - 152.4);
    }
    return idealWeightScore;
};
var calculateBodyWeight = function () {
    return (((calculateIdealBodyWeight() - Number(inputs.weight.currentPoints)) /
        calculateIdealBodyWeight()) *
        100);
};
var calculateHematrocit = function () {
    var _a;
    if (helpers_1.isAnswered(inputs.hematocrit)) {
        if (((_a = inputs.sex) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'female') {
            return (42 - Number(inputs.hematocrit.currentPoints)) * 6;
        }
        else {
            return (47 - Number(inputs.hematocrit.currentPoints)) * 6;
        }
    }
    return 0;
};
var calculateSection2Points = function () {
    return ((Number(inputs.arthritis.currentPoints) +
        Number(inputs.iritis.currentPoints) +
        Number(inputs.stomatitis.currentPoints) +
        Number(inputs.analFissure.currentPoints) +
        Number(inputs.otherFistula.currentPoints) +
        Number(inputs.fever.currentPoints)) *
        20);
};
var calculateCDAIScore = function () {
    if (areAllQuestionsAnswered()) {
        var liquidStoolsNum = Number(inputs.softStools.currentPoints) * 2;
        var abdominapPainNum = Number(inputs.abdominalPain.currentPoints) * 7 * 5;
        var wellBeingNum = Number(inputs.wellBeing.currentPoints) * 7 * 7;
        var antiDiahrealNum = Number(inputs.antiDiarrhea.currentPoints) * 30;
        var abdominalMassNum = Number(inputs.abdominalMass.currentPoints) * 10;
        return (liquidStoolsNum +
            abdominapPainNum +
            wellBeingNum +
            antiDiahrealNum +
            calculateHematrocit() +
            abdominalMassNum +
            calculateBodyWeight() +
            calculateSection2Points());
    }
    else
        return 0;
};
var calculateScore = function () {
    return Math.round(calculateCDAIScore());
};
var calculatePoints = function () {
    if (areAllQuestionsAnswered()) {
        var score = calculateScore();
        if (score < 150) {
            return {
                resultRange2: {
                    qID: 'resultRange2',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(score, 0, 1)),
                    titleTexts: 'regular'
                }
            };
        }
        else if (score >= 150 && score < 450) {
            return {
                resultRange3: {
                    qID: 'resultRange3',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(score, 0, 1)),
                    titleTexts: 'regular'
                }
            };
        }
        else
            return {
                resultRange4: {
                    qID: 'resultRange4',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(score, 0, 1)),
                    titleTexts: 'regular'
                }
            };
    }
    else
        return null;
};
var isRange2Visible = function () {
    return areAllQuestionsAnswered() && calculateScore() < 150;
};
var isRange3Visible = function () {
    return calculateScore() >= 150 && calculateScore() < 450;
};
var isRange4Visible = function () {
    return calculateScore() >= 450;
};
var areAllQuestionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.weight) &&
        helpers_1.isAnswered(inputs.height) &&
        helpers_1.isAnswered(inputs.sex) &&
        helpers_1.isAnswered(inputs.softStools) &&
        helpers_1.isAnswered(inputs.abdominalPain) &&
        helpers_1.isAnswered(inputs.wellBeing) &&
        helpers_1.isAnswered(inputs.antiDiarrhea) &&
        helpers_1.isAnswered(inputs.abdominalMass) &&
        helpers_1.isAnswered(inputs.hematocrit) &&
        helpers_1.isAnswered(inputs.arthritis) &&
        helpers_1.isAnswered(inputs.iritis) &&
        helpers_1.isAnswered(inputs.stomatitis) &&
        helpers_1.isAnswered(inputs.analFissure) &&
        helpers_1.isAnswered(inputs.otherFistula) &&
        helpers_1.isAnswered(inputs.fever));
};
var returnVisibleQuestions = function () {
    visibleQuestions.height = isHeightVisible();
    visibleQuestions.sex = isSexVisible();
    visibleQuestions.softStools = isSoftStoolsVisible();
    visibleQuestions.abdominalPain = isAbdominalPainVisible();
    visibleQuestions.hematocrit = isHematrocitVisible();
    visibleQuestions.arthritis = isSectionTwoAndArthritisVisible();
    visibleQuestions.iritis = isIritisVisible();
    visibleQuestions.stomatitis = isStomatitisVisible();
    visibleQuestions.analFissure = isAnalFissureVisible();
    visibleQuestions.otherFistula = isOtherFistulaVisible();
    visibleQuestions.fever = isFeverVisible();
    visibleQuestions.wellBeing = isWellBeingVisible();
    visibleQuestions.antiDiarrhea = isAntiDiarrheaVisible();
    visibleQuestions.abdominalMass = isAbdominalMassVisible();
    visibleQuestions.resultRange1 = isAnswerAllNotVisible();
    visibleQuestions.resultRange2 = isRange2Visible();
    visibleQuestions.resultRange3 = isRange3Visible();
    visibleQuestions.resultRange4 = isRange4Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.sectionTwo = isSectionTwoAndArthritisVisible();
    visibleSections.sectionThree = isSectionThreeVisible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var isExportResultsEnabled = function () {
    return areAllQuestionsAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
