"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};


var visibleQuestions = {
    age: true,
    stage: true,
    serum: true,
    mutational: true,
    status: true,
    answerAll: true,
    lowRiskPoints: false,
    lowRiskPercent: false,
    intermediateRiskPoints: false,
    intermediateRiskPercent: false,
    highRiskPoints: false,
    highRiskPercent: false,
    veryHighRiskPoints: false,
    veryHighRiskPercent: false
};
var visibleSections = {
    section1: true,
    resultsRange1: true,
    resultsRange2: false,
    resultsRange3: false,
    resultsRange4: false,
    resultsRange5: false
};
var inputs = {
    age: null,
    stage: null,
    serum: null,
    mutational: null,
    status: null
};
var calculateScore = function () {
    var _a, _b, _c, _d, _e;
    if (isAnswerAllVisible()) {
        return null;
    }
    var ageScore = Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints);
    var stageScore = Number((_b = inputs.stage) === null || _b === void 0 ? void 0 : _b.currentPoints);
    var serumScore = Number((_c = inputs.serum) === null || _c === void 0 ? void 0 : _c.currentPoints);
    var mutationalScore = Number((_d = inputs.mutational) === null || _d === void 0 ? void 0 : _d.currentPoints);
    var statusScore = Number((_e = inputs.status) === null || _e === void 0 ? void 0 : _e.currentPoints);
    return ageScore + stageScore + serumScore + mutationalScore + statusScore;
};
var calculatePoints = function () {
    var totalScore = calculateScore();
    if (totalScore === null)
        return null;
    return __assign(__assign(__assign(__assign({}, (isLowRiskVisible(totalScore) && {
        lowRiskPoints: {
            qID: "lowRiskPoints",
            tParams: [{ type: "number", value: totalScore }],
            titleTexts: "regular"
        }
    })), (isIntermediateRiskVisible(totalScore) && {
        intermediateRiskPoints: {
            qID: "intermediateRiskPoints",
            tParams: [{ type: "number", value: totalScore }],
            titleTexts: "regular"
        }
    })), (isHighRiskVisible(totalScore) && {
        highRiskPoints: {
            qID: "highRiskPoints",
            tParams: [{ type: "number", value: totalScore }],
            titleTexts: "regular"
        }
    })), (isVeryHighRiskVisible(totalScore) && {
        veryHighRiskPoints: {
            qID: "veryHighRiskPoints",
            tParams: [{ type: "number", value: totalScore }],
            titleTexts: "regular"
        }
    }));
};
var isAnswerAllVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        !helpers_1.isAnswered(inputs.stage) ||
        !helpers_1.isAnswered(inputs.serum) ||
        !helpers_1.isAnswered(inputs.mutational) ||
        !helpers_1.isAnswered(inputs.status));
};
var isLowRiskVisible = function (score) {
    return score != null ? score >= 0 && score <= 1 : false;
};
var isIntermediateRiskVisible = function (score) {
    return score != null ? score >= 2 && score <= 3 : false;
};
var isHighRiskVisible = function (score) {
    return score != null ? score >= 4 && score <= 6 : false;
};
var isVeryHighRiskVisible = function (score) {
    return score != null ? score >= 7 && score <= 10 : false;
};
var returnVisibleQuestions = function () {
    var totalScore = calculateScore();
    visibleQuestions.answerAll = isAnswerAllVisible();
    visibleQuestions.lowRiskPoints = isLowRiskVisible(totalScore);
    visibleQuestions.lowRiskPercent = isLowRiskVisible(totalScore);
    visibleQuestions.intermediateRiskPoints = isIntermediateRiskVisible(totalScore);
    visibleQuestions.intermediateRiskPercent = isIntermediateRiskVisible(totalScore);
    visibleQuestions.highRiskPoints = isHighRiskVisible(totalScore);
    visibleQuestions.highRiskPercent = isHighRiskVisible(totalScore);
    visibleQuestions.veryHighRiskPoints = isVeryHighRiskVisible(totalScore);
    visibleQuestions.veryHighRiskPercent = isVeryHighRiskVisible(totalScore);
    return visibleQuestions;
};
var returnVisibleSections = function () {
    var totalScore = calculateScore();
    visibleSections.resultsRange1 = isAnswerAllVisible();
    visibleSections.resultsRange2 = isLowRiskVisible(totalScore);
    visibleSections.resultsRange3 = isIntermediateRiskVisible(totalScore);
    visibleSections.resultsRange4 = isHighRiskVisible(totalScore);
    visibleSections.resultsRange5 = isVeryHighRiskVisible(totalScore);
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});