"use strict";


var visibleQuestions = {
    MMSE: true,
    move: false,
    sitdown: false,
    stand: false,
    walk: false,
    wFrequency: false,
    wAlterability: false,
    standingBalance: false,
    walkingFrame: false,
    previousFalls: false,
    antidepressants: false,
    anxiolytics: false,
    answerAll: true,
    result1: false,
    result2: false,
    result3: false,
    result4: false,
    result5: false,
    result6: false,
    result7: false
};
var visibleSections = {
    cognitive: true,
    impulsivity: false,
    balance: false,
    frame: false,
    falls: false,
    medication: false,
    result: true
};
var inputs = {
    MMSE: null,
    move: null,
    sitdown: null,
    stand: null,
    walk: null,
    wFrequency: null,
    wAlterability: null,
    standingBalance: null,
    walkingFrame: null,
    previousFalls: null,
    antidepressants: null,
    anxiolytics: null
};
var isMMSEAnsweredWithId = function (answerId) {
    var _a;
    return ((_a = inputs.MMSE) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === answerId;
};
var isMMSEAnswered = function () {
    return isMMSEAnsweredWithId("less16") || isMMSEAnsweredWithId("more16");
};
var calculateImpulsivity = function () {
    var outputResult = helpers_1.formatCalculationResult(Number(inputs.move.currentPoints) +
        Number(inputs.sitdown.currentPoints) +
        Number(inputs.stand.currentPoints) +
        Number(inputs.walk.currentPoints) +
        Number(inputs.wFrequency.currentPoints) +
        Number(inputs.wAlterability.currentPoints));
    if (outputResult < 2)
        return 0;
    else
        return 1;
};
var isImpulsivityAnswered = function () {
    return (helpers_1.isAnswered(inputs.move) &&
        helpers_1.isAnswered(inputs.sitdown) &&
        helpers_1.isAnswered(inputs.stand) &&
        helpers_1.isAnswered(inputs.walk) &&
        helpers_1.isAnswered(inputs.wAlterability) &&
        helpers_1.isAnswered(inputs.wFrequency));
};
var isBalanceAnswered = function () {
    return helpers_1.isAnswered(inputs.standingBalance);
};
var isFrameAnswered = function () {
    return helpers_1.isAnswered(inputs.walkingFrame);
};
var isFallsAnswered = function () {
    return helpers_1.isAnswered(inputs.previousFalls);
};
var calculatePoints = function () {
    return null;
};
var calculateScore = function () {
    if (!helpers_1.isAnswered(inputs.MMSE) ||
        !isImpulsivityAnswered() ||
        !helpers_1.isAnswered(inputs.standingBalance) ||
        !helpers_1.isAnswered(inputs.walkingFrame) ||
        !helpers_1.isAnswered(inputs.previousFalls) ||
        !helpers_1.isAnswered(inputs.antidepressants) ||
        !helpers_1.isAnswered(inputs.anxiolytics))
        return null;
    var outputResult = helpers_1.formatCalculationResult(Number(inputs.MMSE.currentPoints) +
        Number(calculateImpulsivity()) +
        Number(inputs.standingBalance.currentPoints) +
        Number(inputs.walkingFrame.currentPoints) +
        Number(inputs.previousFalls.currentPoints) +
        Number(inputs.antidepressants.currentPoints) +
        Number(inputs.anxiolytics.currentPoints));
    return outputResult;
};
var returnVisibleQuestions = function () {
    visibleQuestions.move = isMMSEAnswered();
    visibleQuestions.sitdown = isMMSEAnswered();
    visibleQuestions.stand = isMMSEAnswered();
    visibleQuestions.walk = isMMSEAnswered();
    visibleQuestions.wFrequency = isMMSEAnswered();
    visibleQuestions.wAlterability = isMMSEAnswered();
    visibleQuestions.standingBalance = isImpulsivityAnswered();
    visibleQuestions.walkingFrame = isBalanceAnswered();
    visibleQuestions.previousFalls = isFrameAnswered();
    visibleQuestions.antidepressants = isFallsAnswered();
    visibleQuestions.anxiolytics = isFallsAnswered();
    visibleQuestions.answerAll = calculateScore() === null;
    visibleQuestions.result1 = calculateScore() === 0;
    visibleQuestions.result2 = calculateScore() === 1;
    visibleQuestions.result3 = calculateScore() === 2;
    visibleQuestions.result4 = calculateScore() === 3;
    visibleQuestions.result5 = calculateScore() === 4;
    visibleQuestions.result6 = calculateScore() === 5;
    visibleQuestions.result7 = calculateScore() >= 6;
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.impulsivity = isMMSEAnswered();
    visibleSections.balance = isImpulsivityAnswered();
    visibleSections.frame = isBalanceAnswered();
    visibleSections.falls = isFrameAnswered();
    visibleSections.medication = isFallsAnswered();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return calculateScore() !== null;
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        result: result,
        exportResultsEnabled: isExportResultsEnabled(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
