// Starting visibility state of all questions that change in JS. If the question isn't here, default is taken from JSON.
var visibleQuestions = {
    rate: true,
    severity: false,
    recovery: false,
    edss: true,
    edssThree: false,
    edssFour: false,
    edssFive: false,
    progression: false,
    t25FW: true,
    mri: true,
    noResult: true,
    relapseNoConcern: false,
    relapseLowConcern: false,
    relapseMediumConcern: false,
    relapseHighConcern: false,
    progressionNoConcern: false,
    progressionLowConcern: false,
    progressionMediumConcern: false,
    progressionHighConcern: false,
    mriNoConcern: false,
    mriLowConcern: false,
    mriMediumConcern: false,
    mriHighConcern: false,
    suboptimalTreatment: false,
    optimalTreatment: false
};

// Starting visibility state of all sections that change in JS. If the section isn't here, default is taken from JSON.
var visibleSections = {
    relapse: true,
    progression: true,
    mriFindings: true,
    results: true
};

// All input questions must be listed below.
var inputs = {
    rate: null,
    severity: null,
    recovery: null,
    edss: null,
    edssThree: null,
    edssFour: null,
    edssFive: null,
    progression: null,
    t25FW: null,
    mri: null
};

// Constants
var NO_CONCERN = 0.0;
var LOW_CONCERN = 1.0;
var MEDIUM_CONCERN = 2.0;
var HIGH_CONCERN = 3.0;

// Private functions
function rateVisibility() {
    return true;
}

function severityVisibility() {
    return inputs.rate.currentIdentifier != null && inputs.rate.currentIdentifier != "zero";
}

function recoveryVisibility() {
    return inputs.rate.currentIdentifier != null && inputs.rate.currentIdentifier != "zero";
}

function edssVisibility() {
    return true;
}

function edssThreeVisibility() {
    if (inputs.edss.currentIdentifier == "edssThree") {
        return true;
    } else {
        return false;
    }
}

function edssFourVisibility() {
    if (inputs.edss.currentIdentifier == "edssFour") {
        return true;
    } else {
        return false;
    }
}

function edssFiveVisibility() {
    if (inputs.edss.currentIdentifier == "edssFive") {
        return true;
    } else {
        return false;
    }
}

function progressionVisibility() {
    if (inputs.edss.currentIdentifier == "edssThree") {
        return inputs.edssThree.currentIdentifier != null && inputs.edssThree.currentIdentifier != "zero";
    } else if (inputs.edss.currentIdentifier == "edssFour") {
        return inputs.edssFour.currentIdentifier != null && inputs.edssFour.currentIdentifier != "zero";
    } else if (inputs.edss.currentIdentifier == "edssFive") {
        return inputs.edssFive.currentIdentifier != null && inputs.edssFive.currentIdentifier != "zero";
    } else {
        return false;
    }
}

function t25FWVisibility() {
    return true;
}

function mriVisibility() {
    return true;
}

function noResultVisibility() {
    return !areAllQuestionsAnswered();
}

function relapseNoConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var relapseQuestions = [inputs.rate, inputs.severity, inputs.recovery];
        var point = findMaxQuestionValue(relapseQuestions);
        return point == NO_CONCERN;
    } else {
        return false;
    }
}

function relapseLowConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var relapseQuestions = [inputs.rate, inputs.severity, inputs.recovery];
        var point = findMaxQuestionValue(relapseQuestions);
        return point == LOW_CONCERN;
    } else {
        return false;
    }
}

function relapseMediumConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var relapseQuestions = [inputs.rate, inputs.severity, inputs.recovery];
        var point = findMaxQuestionValue(relapseQuestions);
        return point == MEDIUM_CONCERN;
    } else {
        return false;
    }
}

function relapseHighConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var relapseQuestions = [inputs.rate, inputs.severity, inputs.recovery];
        var point = findMaxQuestionValue(relapseQuestions);
        return point == HIGH_CONCERN;
    } else {
        return false;
    }
}

function progressionNoConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var progressionQuestions = [inputs.edss, inputs.edssThree, inputs.edssFour, inputs.edssFive, inputs.progression, inputs.t25FW];
        var point = findMaxQuestionValue(progressionQuestions);
        return point == NO_CONCERN;
    } else {
        return false;
    }
}

function progressionLowConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var progressionQuestions = [inputs.edss, inputs.edssThree, inputs.edssFour, inputs.edssFive, inputs.progression, inputs.t25FW];
        var point = findMaxQuestionValue(progressionQuestions);
        return point == LOW_CONCERN;
    } else {
        return false;
    }
}

function progressionMediumConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var progressionQuestions = [inputs.edss, inputs.edssThree, inputs.edssFour, inputs.edssFive, inputs.progression, inputs.t25FW];
        var point = findMaxQuestionValue(progressionQuestions);
        return point == MEDIUM_CONCERN;
    } else {
        return false;
    }
}

function progressionHighConcernVisibility() {
    if (areAllQuestionsAnswered()) {
        var progressionQuestions = [inputs.edss, inputs.edssThree, inputs.edssFour, inputs.edssFive, inputs.progression, inputs.t25FW];
        var point = findMaxQuestionValue(progressionQuestions);
        return point == HIGH_CONCERN;
    } else {
        return false;
    }
}

function mriNoConcernVisibility() {
    if (areAllQuestionsAnswered() && inputs.mri.currentPoints == NO_CONCERN) {
        return true;
    } else {
        return false;
    }
}

function mriLowConcernVisibility() {
    if (areAllQuestionsAnswered() && inputs.mri.currentPoints == LOW_CONCERN) {
        return true;
    } else {
        return false;
    }
}

function mriMediumConcernVisibility() {
    if (areAllQuestionsAnswered() && inputs.mri.currentPoints == MEDIUM_CONCERN) {
        return true;
    } else {
        return false;
    }
}

function mriHighConcernVisibility() {
    if (areAllQuestionsAnswered() && inputs.mri.currentPoints == HIGH_CONCERN) {
        return true;
    } else {
        return false;
    }
}

function optimalTreatmentVisibility() {
    return areAllQuestionsAnswered() && !isSuboptimalTreatmentVisible();
}

function suboptimalTreatmentVisibility() {
    return areAllQuestionsAnswered() && isSuboptimalTreatmentVisible();
}

function isSuboptimalTreatmentVisible() {

    var relapseQuestions = [inputs.rate, inputs.severity, inputs.recovery];
    var progressionQuestions = [inputs.edss, inputs.edssThree, inputs.edssFour, inputs.edssFive, inputs.progression, inputs.t25FW];

    var points = [findMaxQuestionValue(relapseQuestions), findMaxQuestionValue(progressionQuestions), inputs.mri.currentPoints];

    var lowPoints = 0;
    var midPoints = 0;

    for (var i = 0; i < points.length; i++) {
        var point = points[i];
        if (point == LOW_CONCERN) {
            lowPoints += 1;
        } else if (point == MEDIUM_CONCERN) {
            midPoints += 1;
        } else if (point == HIGH_CONCERN) {
            return true;
        }
    }
    return lowPoints == 3 || midPoints >= 2 || (lowPoints == 2 && midPoints == 1);
}

function findMaxQuestionValue(questions) {
    var maxValue = 0.0;
    for (var i = 0; i < questions.length; i++) {
        var question = questions[i];
        if (visibleQuestions[question.questionId] && question.currentPoints != null && question.currentPoints > maxValue) {
            maxValue = question.currentPoints;
        }
    }
    return maxValue;
}

function areAllQuestionsAnswered() {
    var relapseArea = isRelapseAreaAnswered();
    var progressionArea = isProgressionAreaAnswered();
    var mriArea = isMRIAreaAnswered();
    return relapseArea && progressionArea && mriArea;
}

function isRelapseAreaAnswered() {
    if (inputs.rate.currentIdentifier != null) {
        if (inputs.rate.currentIdentifier == "zero") {
            return true;
        } else {
            return inputs.severity.currentIdentifier != null && inputs.recovery.currentIdentifier != null;
        }
    }
    return false;
}

function isProgressionAreaAnswered() {
    var isAreaAnswered = false;

    if (inputs.edss.currentIdentifier == "edssThree") {

        if (inputs.edssThree.currentIdentifier != null) {
            if (inputs.edssThree.currentIdentifier != "zero") {
                isAreaAnswered = inputs.progression.currentIdentifier != null;
            } else {
                isAreaAnswered = true;
            }
        } else {
            isAreaAnswered = false;
        }

    } else if (inputs.edss.currentIdentifier == "edssFour") {

        if (inputs.edssFour.currentIdentifier != null) {
            if (inputs.edssFour.currentIdentifier != "zero") {
                isAreaAnswered = inputs.progression.currentIdentifier != null;
            } else {
                isAreaAnswered = true;
            }
        } else {
            isAreaAnswered = false;
        }

    } else if (inputs.edss.currentIdentifier == "edssFive") {

        if (inputs.edssFive.currentIdentifier != null) {
            if (inputs.edssFive.currentIdentifier != "zero") {
                isAreaAnswered = inputs.progression.currentIdentifier != null;
            } else {
                isAreaAnswered = true;
            }
        } else {
            isAreaAnswered = false;
        }
    }

    return isAreaAnswered;
}

function isMRIAreaAnswered() {
    return inputs.mri.currentIdentifier != null;
}

// Methods below are called from the app and their name, function, and output shouldn't change.
function returnVisibleQuestions() {
    visibleQuestions.rate = rateVisibility();
    visibleQuestions.severity = severityVisibility();
    visibleQuestions.recovery = recoveryVisibility();
    visibleQuestions.edss = edssVisibility();
    visibleQuestions.edssThree = edssThreeVisibility();
    visibleQuestions.edssFour = edssFourVisibility();
    visibleQuestions.edssFive = edssFiveVisibility();
    visibleQuestions.progression = progressionVisibility();
    visibleQuestions.t25FW = t25FWVisibility();
    visibleQuestions.mri = mriVisibility();
    visibleQuestions.noResult = noResultVisibility();
    visibleQuestions.relapseNoConcern = relapseNoConcernVisibility();
    visibleQuestions.relapseLowConcern = relapseLowConcernVisibility();
    visibleQuestions.relapseMediumConcern = relapseMediumConcernVisibility();
    visibleQuestions.relapseHighConcern = relapseHighConcernVisibility();
    visibleQuestions.progressionNoConcern = progressionNoConcernVisibility();
    visibleQuestions.progressionLowConcern = progressionLowConcernVisibility();
    visibleQuestions.progressionMediumConcern = progressionMediumConcernVisibility();
    visibleQuestions.progressionHighConcern = progressionHighConcernVisibility();
    visibleQuestions.mriNoConcern = mriNoConcernVisibility();
    visibleQuestions.mriLowConcern = mriLowConcernVisibility();
    visibleQuestions.mriMediumConcern = mriMediumConcernVisibility();
    visibleQuestions.mriHighConcern = mriHighConcernVisibility();
    visibleQuestions.suboptimalTreatment = suboptimalTreatmentVisibility();
    visibleQuestions.optimalTreatment = optimalTreatmentVisibility();
    return visibleQuestions; // {no1: true, no2: true, no3: false,…}
}

function relapseSectionVisibility() {
    return true;
}

function progressionSectionVisibility() {
    return true;
}

function mriFindingsSectionVisibility() {
    return true;
}

function resultsSectionVisibility() {
    return true;
}

function returnVisibleSections() {
    visibleSections.relapse = relapseSectionVisibility();
    visibleSections.progression = progressionSectionVisibility();
    visibleSections.mriFindings = mriFindingsSectionVisibility();
    visibleSections.results = resultsSectionVisibility();
    return visibleSections;
}
// Called from the mobile app. Input questions are preloaded, so their values don't need updating.
function ut_visibleQuestions() {
    return returnVisibleQuestions();
}

function ut_visibleSections() {
    return returnVisibleSections();
}

exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
