"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    kidney: false,
    dosing1: true,
    tablets1: true,
    divider: true,
    tablets2: true,
    tablets3: true,
    suspension1: true,
    divider2: true,
    suspension2: true,
    suspension3: true,
    tablets1Low: true,
    tablets3Low: true,
    suspension1Low: true,
    suspension3Low: true,
    suspension21: true,
    divider3: true,
    suspension22: true,
    suspension23: false,
    suspension24: true,
    suspension21Low: true,
    suspension23Low: false,
    suspension24Low: true,
    warning21: true
};
var visibleSections = {
    section1: true,
    dosing: false,
    tablets: false,
    suspension: false,
    tabletsLow: false,
    suspensionLow: false,
    suspensionKids: false,
    suspensionKidsLow: false,
    warning2: false
};
var inputs = {
    age: null,
    weight: null,
    kidney: null
};
var isWeightVisible = function () {
    return helpers_1.isAnswered(inputs.age) && helpers_1.answerMatches(inputs.age, 'less12');
};
var isKidneyVisible = function () {
    return helpers_1.isAnswered(inputs.age) && (isWeightVisible() ? isWeightValid() : true);
};
var isTabletsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'more12') && helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isSuspensionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'more12') && helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isTabletsLowVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'more12') && helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isSuspensionLowVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'more12') && helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isSuspensionKidsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'less12') &&
        isWeightValid() &&
        helpers_1.answerMatches(inputs.kidney, 'high'));
};
var isSuspensionKidsLowVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'less12') &&
        isWeightValid() &&
        helpers_1.answerMatches(inputs.kidney, 'low'));
};
var isBabyWarningVisible = function () {
    var _a;
    return isWeightValid() && Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) < 10;
};
var isWeightValid = function () {
    return (helpers_1.isAnswered(inputs.weight) &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 }));
};
var isAllAnswered = function () {
    return (helpers_1.isAnswered(inputs.age) &&
        (isWeightVisible() ? isWeightValid() : true) &&
        isKidneyVisible() &&
        helpers_1.isAnswered(inputs.kidney));
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.kidney = isKidneyVisible();
    visibleQuestions.suspension23 = isBabyWarningVisible();
    visibleQuestions.suspension23Low = isBabyWarningVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = !isAllAnswered();
    visibleSections.tablets = isTabletsVisible();
    visibleSections.suspension = isSuspensionVisible();
    visibleSections.tabletsLow = isTabletsLowVisible();
    visibleSections.suspensionLow = isSuspensionLowVisible();
    visibleSections.suspensionKids = isSuspensionKidsVisible();
    visibleSections.suspensionKidsLow = isSuspensionKidsLowVisible();
    visibleSections.warning2 = isAllAnswered();
    return visibleSections;
};
var suspension21Result = function () {
    var _a, _b, _c, _d, _e;
    var ml1 = (Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 8 * 5) / 100;
    var mg1 = Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 8;
    var ml2 = (Number((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints) * 4 * 5) / 100;
    var mg2 = Number((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints) * 4;
    if (Number((_e = inputs.weight) === null || _e === void 0 ? void 0 : _e.currentPoints) > 37.5) {
        ml1 = 20;
        mg1 = 400;
        ml2 = 10;
        mg2 = 200;
    }
    return {
        suspension21: {
            qID: 'suspension21',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(ml1, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(mg1, 1), 0, 1)),
            titleTexts: 'regular'
        },
        suspension22: {
            qID: 'suspension22',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(ml2, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(mg2, 1), 0, 1)),
            titleTexts: 'regular'
        }
    };
};
var suspensionKidsLowResult = function () {
    var _a, _b, _c;
    var ml = (Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 4 * 5) / 100;
    var mg = Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 4;
    if (Number((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints) > 37.5) {
        ml = 10;
        mg = 200;
    }
    return {
        suspension21Low: {
            qID: 'suspension21Low',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(mg, 1), 0, 1)),
            titleTexts: 'regular'
        }
    };
};
var calculatePoints = function () {
    return __assign(__assign({ number: 0, range: 0 }, (isAllAnswered() &&
        isSuspensionKidsLowVisible() && __assign({}, suspensionKidsLowResult()))), (isAllAnswered() &&
        isSuspensionKidsVisible() && __assign({}, suspension21Result())));
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return isAllAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
