"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    babies: false,
    warningBabies: true,
    warningAdultsKids: false,
    dosingKids: true,
    warningKids: true,
    durationKids: true,
    dosingAdults: true,
    durationAdults: true,
    noAnswer: true,
    kidneyGray: true,
    kidneyOrange: true,
    warningOrange: true,
    guidelines: true
};
var visibleSections = {
    weightSection: true,
    babiesSection: false,
    kidsSection: false,
    adultsSection: false,
    noAnswerSection: false,
    kidneySection: false,
    guidelinesSectionSecond: false,
    guidelinesSection: false
};
var inputs = {
    age: null,
    weight: null,
    babies: null
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 });
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'children');
};
var isBabiesVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 6.99 });
};
var isBabiesSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 6.99 }) &&
        helpers_1.answerMatches(inputs.babies, 'small'));
};
var isKidsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 7, max: 49.99 }) ||
        (helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 6.99 }) &&
            helpers_1.answerMatches(inputs.babies, 'big')));
};
var isWarningAdultsKidsVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 25.01, max: 49.99 });
};
var isAdultsSectionVisible = function () {
    return (helpers_1.numberInLimits({ input: inputs.weight, min: 50, max: 70 }) ||
        helpers_1.answerMatches(inputs.age, 'adults'));
};
var isWeightInLimitsIfVisible = function () {
    return isWeightVisible() ? isWeightInLimits() : true;
};
var isBabiesAnsweredIfVisible = function () {
    return isBabiesVisible() ? helpers_1.isAnswered(inputs.babies) : true;
};
var isNoAnswerSectionVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        !isWeightInLimitsIfVisible() ||
        !isBabiesAnsweredIfVisible());
};
var isKidneySectionVisible = function () {
    return !isNoAnswerSectionVisible() && !helpers_1.answerMatches(inputs.babies, 'small');
};
var calculatePoints = function () {
    var _a;
    if (isKidsSectionVisible()) {
        var weight = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        var dosingBabiesLow = weight * 0.05;
        var dosingBabiesHigh = weight * 0.08;
        return {
            dosingKids: {
                qID: 'dosingKids',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(dosingBabiesLow, 2), 0, 2), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(dosingBabiesHigh, 2), 0, 2)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.babies = isBabiesVisible();
    visibleQuestions.warningAdultsKids = isWarningAdultsKidsVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.babiesSection = isBabiesSectionVisible();
    visibleSections.kidsSection = isKidsSectionVisible();
    visibleSections.adultsSection = isAdultsSectionVisible();
    visibleSections.noAnswerSection = isNoAnswerSectionVisible();
    visibleSections.kidneySection = isKidneySectionVisible();
    visibleSections.guidelinesSectionSecond = isKidneySectionVisible();
    visibleSections.guidelinesSection = isKidneySectionVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerSectionVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
