"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};



var visibleQuestions = {
    gender: true,
    age: true,
    weight: true,
    creatinine: true
};
var visibleSections = {
    main: true
};
var inputs = {
    gender: null,
    age: null,
    weight: null,
    creatinine: null
};
var isAgeValid = function () {
    return helpers_1.numberInLimits({ input: inputs.age, min: 1, max: 120 });
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 300 });
};
var isCreatinineValid = function () {
    var _a;
    switch ((_a = inputs.creatinine) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µmol/L':
            return helpers_1.numberInLimits({ input: inputs.creatinine, min: 1, max: 3500 });
        case 'mg/dL':
            return helpers_1.numberInLimits({ input: inputs.creatinine, min: 0.01, max: 40 });
        default:
            return false;
    }
};
var convertUnits = function () {
    if (inputs.creatinine.currentIdentifier === 'mg/dL') {
        return Number(inputs.creatinine.currentPoints);
    }
    return (Number(inputs.creatinine.currentPoints) / units_1["default"].creatinine.mgDlTOuMolL);
};
var areAllAnswered = function () {
    return isAgeValid() && isWeightValid() && isCreatinineValid();
};
var calculatePoints = function () {
    if (!areAllAnswered()) {
        return helpers_1.returnToolScoreObject({});
    }
    var outputResult = helpers_1.formatCalculationResult(((140 - Number(inputs.age.currentPoints)) *
        Number(inputs.weight.currentPoints) *
        Number(inputs.gender.currentPoints)) /
        (72 * convertUnits()), 0);
    return helpers_1.returnToolScoreObject({ number: outputResult, range: outputResult });
};
var returnVisibleQuestions = function () {
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return areAllAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return __assign(__assign({ exportResultsEnabled: isExportResultsEnabled() }, result), { visibleQuestions: ut_visibleQuestions(), visibleSections: ut_visibleSections() });
});
