"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    noAnswerText: true,
    adultsDosingLosungResult: false,
    divider1: false,
    adultsDosingLosungResult2: false,
    adultsDurationLosung: false,
    kidsLosungDose: false,
    divider2: false,
    kidsLosungDose2: false,
    kidsDurationLosung: false,
    contraBaby: false,
    kidney: false,
    infusionWarningPVC: false
};
var visibleSections = {
    patientSelection: true,
    noAnswer: true,
    adultsDosingLosung: false,
    kidsDosingLosung: false,
    babyDosing: false,
    warningKidney: false,
    warningInfusion: false
};
var inputs = {
    age: null,
    weight: null
};
var ageIsKidOrAdults = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') || helpers_1.answerMatches(inputs.age, 'adults'));
};
var isAdultAnswered = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 }));
};
var isKidAnswered = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 }));
};
var isBabyAnswered = function () {
    return helpers_1.answerMatches(inputs.age, 'baby');
};
var isAnsweredAllVisible = function () {
    return !(isAdultAnswered() || isKidAnswered() || isBabyAnswered());
};
var calculatePoints = function () {
    var _a, _b;
    if (isAdultAnswered()) {
        var weight = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        var T1 = (weight * 3) / 5;
        var T2 = (weight * 4) / 5;
        var T3 = weight * 3;
        var T4 = weight * 4;
        return {
            adultsDosingLosungResult2: {
                qID: 'adultsDosingLosungResult2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T1, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T2, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T3, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T4, 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isKidAnswered()) {
        var weight = Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints);
        var T1 = (weight * 3) / 5;
        var T2 = (weight * 4) / 5;
        var T3 = weight * 3;
        var T4 = weight * 4;
        return {
            kidsLosungDose2: {
                qID: 'kidsLosungDose2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T1, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T2, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T3, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(T4, 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = ageIsKidOrAdults();
    visibleQuestions.noAnswerText = isAnsweredAllVisible();
    visibleQuestions.adultsDosingLosungResult = isAdultAnswered();
    visibleQuestions.divider1 = isAdultAnswered();
    visibleQuestions.adultsDosingLosungResult2 = isAdultAnswered();
    visibleQuestions.adultsDurationLosung = isAdultAnswered();
    visibleQuestions.kidsLosungDose = isKidAnswered();
    visibleQuestions.divider2 = isKidAnswered();
    visibleQuestions.kidsLosungDose2 = isKidAnswered();
    visibleQuestions.kidsDurationLosung = isKidAnswered();
    visibleQuestions.contraBaby = isBabyAnswered();
    visibleQuestions.kidney = isAdultAnswered() || isKidAnswered();
    visibleQuestions.infusionWarningPVC = isAdultAnswered() || isKidAnswered();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isAnsweredAllVisible();
    visibleSections.adultsDosingLosung = isAdultAnswered();
    visibleSections.kidsDosingLosung = isKidAnswered();
    visibleSections.babyDosing = isBabyAnswered();
    visibleSections.warningKidney = isAdultAnswered() || isKidAnswered();
    visibleSections.warningInfusion = isAdultAnswered() || isKidAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isAnsweredAllVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
