"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    spleen: true,
    platelets: true,
    blasts: true,
    eosinophils: true,
    basophils: true,
    answerAll: true,
    eltsScore: false,
    sokalScore: false,
    hasfordScore: false
};
var visibleSections = {
    mainSection: true,
    results: true
};
var inputs = {
    age: null,
    spleen: null,
    platelets: null,
    blasts: null,
    eosinophils: null,
    basophils: null
};
var returnVisibleQuestions = function () {
    visibleQuestions.answerAll = !areFirstQuestionsAnswered();
    visibleQuestions.eltsScore = areFirstQuestionsAnswered();
    visibleQuestions.sokalScore = areFirstQuestionsAnswered();
    visibleQuestions.hasfordScore = areFirstQuestionsAnswered();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var areFirstQuestionsAnswered = function () {
    return (helpers_1.numberInLimits({ input: inputs.age, min: 0, max: 100 }) &&
        helpers_1.numberInLimits({ input: inputs.spleen, min: 0, max: 50 }) &&
        helpers_1.numberInLimits({ input: inputs.platelets, min: 1, max: 10000 }) &&
        helpers_1.numberInLimits({ input: inputs.blasts, min: 0, max: 100 }));
};
var areAllQuestionsAnswered = function () {
    return (areFirstQuestionsAnswered() &&
        helpers_1.numberInLimits({ input: inputs.eosinophils, min: 0, max: 100 }) &&
        helpers_1.numberInLimits({ input: inputs.basophils, min: 0, max: 100 }));
};
var calculateEltsScore = function () {
    return helpers_1.formatCalculationResult(0.0025 *
        (Math.round(Math.pow(Number(inputs.age.currentPoints) / 10, 3) * 1000) /
            1000) +
        0.0615 * Number(inputs.spleen.currentPoints) +
        0.1052 * Number(inputs.blasts.currentPoints) +
        0.4104 *
            (Math.round(Math.pow(Number(inputs.platelets.currentPoints) / 1000, -(1 / 2)) *
                1000) /
                1000), 4);
};
var calculateSokalScore = function () {
    var result = Math.exp(0.0116 * (Number(inputs.age.currentPoints) - 43.4) +
        0.0345 * (Number(inputs.spleen.currentPoints) - 7.51) +
        0.188 *
            (Math.pow(Number(inputs.platelets.currentPoints) / 700, 2) - 0.563) +
        0.0887 * (Number(inputs.blasts.currentPoints) - 2.1));
    if (!Number.isInteger(result)) {
        return helpers_1.formatCalculationResult(result, 2);
    }
    return result;
};
var calculateHasfordScore = function () {
    return helpers_1.formatCalculationResult((0.6666 * (Number(inputs.age.currentPoints) < 50 ? 0 : 1) +
        0.042 * Number(inputs.spleen.currentPoints) +
        0.0584 * Number(inputs.blasts.currentPoints) +
        0.0413 * Number(inputs.eosinophils.currentPoints) +
        0.2039 * (Number(inputs.basophils.currentPoints) < 3 ? 0 : 1) +
        1.0956 * (Number(inputs.platelets.currentPoints) < 1500 ? 0 : 1)) *
        1000, 2);
};
var getEltsResultProperties = function (eltsScore, isYoungerThan18) {
    var resultSuffix = (isYoungerThan18 && 'Young') || '';
    if (eltsScore <= 1.568) {
        var resultTexts_1 = ("lowRisk" + resultSuffix).toString();
        return {
            image: 'ActivityLevelGreen',
            resultTexts: resultTexts_1
        };
    }
    if (eltsScore > 1.568 && eltsScore <= 2.2185) {
        var resultTexts_2 = ("intermediateRisk" + resultSuffix).toString();
        return {
            image: 'ActivityLevelYellow',
            resultTexts: resultTexts_2
        };
    }
    var resultTexts = ("highRisk" + resultSuffix).toString();
    return {
        image: 'ActivityLevelRed',
        resultTexts: resultTexts
    };
};
var getSokalResultProperties = function (sokalScore) {
    if (sokalScore < 0.8) {
        return {
            image: 'ActivityLevelGreen',
            resultTexts: 'lowRisk'
        };
    }
    if (sokalScore >= 0.8 && sokalScore <= 1.2) {
        return {
            image: 'ActivityLevelYellow',
            resultTexts: 'intermediateRisk'
        };
    }
    return {
        image: 'ActivityLevelRed',
        resultTexts: 'highRisk'
    };
};
var getHasfordResultProperties = function (hasfordScore) {
    if (hasfordScore <= 780) {
        return {
            image: 'ActivityLevelGreen',
            resultTexts: 'lowRisk'
        };
    }
    if (hasfordScore >= 781 && hasfordScore <= 1480) {
        return {
            image: 'ActivityLevelYellow',
            resultTexts: 'intermediateRisk'
        };
    }
    return {
        image: 'ActivityLevelRed',
        resultTexts: 'highRisk'
    };
};
var getHasfordScore = function () {
    if (areAllQuestionsAnswered()) {
        var hasfordScore = calculateHasfordScore();
        return __assign({ rParams: __spreadArrays(helpers_1.returnNumberObject(hasfordScore, 2, 2)) }, getHasfordResultProperties(hasfordScore));
    }
    return {
        image: 'ActivityLevelGray',
        rParams: [],
        resultTexts: 'answerAll'
    };
};
var calculatePoints = function () {
    if (!areFirstQuestionsAnswered()) {
        return null;
    }
    var isYoungerThan18 = Number(inputs.age.currentPoints) < 18;
    var eltsScore = calculateEltsScore();
    var sokalScore = calculateSokalScore();
    return {
        eltsScore: __assign({ qID: 'eltsScore', rParams: __spreadArrays(helpers_1.returnNumberObject(eltsScore, 2, 4)), titleTexts: 'regular' }, getEltsResultProperties(eltsScore, isYoungerThan18)),
        sokalScore: __assign({ qID: 'sokalScore', rParams: __spreadArrays(helpers_1.returnNumberObject(sokalScore, 0, 2)), titleTexts: 'regular' }, getSokalResultProperties(sokalScore)),
        hasfordScore: __assign({ qID: 'hasfordScore', titleTexts: 'regular' }, getHasfordScore())
    };
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return areFirstQuestionsAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: calculatePoints(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
