"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};


var Country;
(function (Country) {
    Country[Country["SI"] = 0] = "SI";
    Country[Country["HR"] = 1] = "HR";
    Country[Country["CZ"] = 2] = "CZ";
    Country[Country["SK"] = 3] = "SK";
    Country[Country["RO"] = 4] = "RO";
})(Country || (Country = {}));
var Sex;
(function (Sex) {
    Sex[Sex["male"] = 0] = "male";
    Sex[Sex["female"] = 1] = "female";
})(Sex || (Sex = {}));
var ScoreType;
(function (ScoreType) {
    ScoreType[ScoreType["hologic"] = 0] = "hologic";
    ScoreType[ScoreType["norland"] = 1] = "norland";
    ScoreType[ScoreType["lunar"] = 2] = "lunar";
    ScoreType[ScoreType["dms"] = 3] = "dms";
    ScoreType[ScoreType["qct"] = 4] = "qct";
    ScoreType[ScoreType["tscore"] = 5] = "tscore";
    ScoreType[ScoreType["zscore"] = 6] = "zscore";
})(ScoreType || (ScoreType = {}));
var visibleQuestions = {
    sex: true,
    age: true,
    weight: true,
    height: true,
    fracture: true,
    parentHipFracture: true,
    smoking: true,
    glucocorticoids: true,
    arthritis: true,
    osteoporosis: true,
    alcohol: true,
    bmd: true,
    equipment: false,
    bmdHologic: false,
    bmdLunar: false,
    bmdNorland: false,
    bmdDms: false,
    bmdQct: false,
    tScore: false,
    answerAll: true,
    osteoporoticFracture: false,
    hipFracture: false
};
var visibleSections = {
    riskFactors: true,
    bmdSection: true,
    resultSection: true
};
var inputs = {
    sex: null,
    age: null,
    weight: null,
    height: null,
    fracture: null,
    parentHipFracture: null,
    smoking: null,
    glucocorticoids: null,
    arthritis: null,
    osteoporosis: null,
    alcohol: null,
    bmd: null,
    equipment: null,
    bmdHologic: null,
    bmdLunar: null,
    bmdNorland: null,
    bmdDms: null,
    bmdQct: null,
    tScore: null,
    answerAll: null,
    osteoporoticFracture: null,
    hipFracture: null
};
var bmdVisibility = function (equipment) {
    var _a, _b;
    return (((_a = inputs.bmd) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'with' &&
        ((_b = inputs.equipment) === null || _b === void 0 ? void 0 : _b.currentIdentifier) === equipment);
};
var isNotValidNumber = function (input) {
    return ((input === null || input === void 0 ? void 0 : input.currentPoints) === null ||
        (input === null || input === void 0 ? void 0 : input.currentPoints) === undefined ||
        Number.isNaN(input === null || input === void 0 ? void 0 : input.currentPoints));
};
var answerAllVisibility = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q;
    if (!helpers_1.isAnswered(inputs.sex) ||
        !helpers_1.isAnswered(inputs.age) ||
        Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints) < 1 ||
        Number((_b = inputs.age) === null || _b === void 0 ? void 0 : _b.currentPoints) > 120 ||
        !helpers_1.isAnswered(inputs.weight) ||
        Number((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints) < 25 ||
        Number((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints) > 125 ||
        !helpers_1.isAnswered(inputs.height) ||
        Number((_e = inputs.height) === null || _e === void 0 ? void 0 : _e.currentPoints) < 100 ||
        Number((_f = inputs.height) === null || _f === void 0 ? void 0 : _f.currentPoints) > 220 ||
        !helpers_1.isAnswered(inputs.bmd) ||
        (((_g = inputs.bmd) === null || _g === void 0 ? void 0 : _g.currentIdentifier) === 'with' &&
            (!helpers_1.isAnswered(inputs.equipment) ||
                (!bmdVisibility('hologic') &&
                    !bmdVisibility('lunar') &&
                    !bmdVisibility('norland') &&
                    !bmdVisibility('DMS') &&
                    !bmdVisibility('QCT') &&
                    !bmdVisibility('tScore'))))) {
        return true;
    }
    if (((_h = inputs.bmd) === null || _h === void 0 ? void 0 : _h.currentIdentifier) === 'with') {
        switch ((_j = inputs.equipment) === null || _j === void 0 ? void 0 : _j.currentIdentifier) {
            case 'hologic':
                return (Number((_k = inputs.bmdHologic) === null || _k === void 0 ? void 0 : _k.currentPoints) < 0.14 ||
                    Number((_l = inputs.bmdHologic) === null || _l === void 0 ? void 0 : _l.currentPoints) > 1.58);
            case 'lunar':
                return (Number((_m = inputs.bmdLunar) === null || _m === void 0 ? void 0 : _m.currentPoints) < 0.2 ||
                    Number((_o = inputs.bmdLunar) === null || _o === void 0 ? void 0 : _o.currentPoints) > 1.87);
            case 'norland':
                return (Number((_p = inputs.bmdNorland) === null || _p === void 0 ? void 0 : _p.currentPoints) < 0.17 ||
                    Number((_q = inputs.bmdNorland) === null || _q === void 0 ? void 0 : _q.currentPoints) > 1.76);
            case 'DMS':
                return isNotValidNumber(inputs.bmdDms);
            case 'QCT':
                return isNotValidNumber(inputs.bmdQct);
            case 'tScore':
                return isNotValidNumber(inputs.tScore);
        }
    }
    return false;
};
var returnVisibleQuestions = function () {
    var _a;
    visibleQuestions.equipment = ((_a = inputs.bmd) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'with';
    visibleQuestions.bmdHologic = bmdVisibility('hologic');
    visibleQuestions.bmdLunar = bmdVisibility('lunar');
    visibleQuestions.bmdNorland = bmdVisibility('norland');
    visibleQuestions.bmdDms = bmdVisibility('DMS');
    visibleQuestions.bmdQct = bmdVisibility('QCT');
    visibleQuestions.tScore = bmdVisibility('tScore');
    visibleQuestions.answerAll = answerAllVisibility();
    visibleQuestions.osteoporoticFracture = !answerAllVisibility();
    visibleQuestions.hipFracture = !answerAllVisibility();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    var countryCode = ((_a = inputs._countryCode) === null || _a === void 0 ? void 0 : _a.currentIdentifier) || 'si';
    var country = Country.SI;
    if (countryCode) {
        switch (countryCode.toUpperCase()) {
            case 'SK':
                country = Country.SK;
                break;
            case 'CZ':
                country = Country.CZ;
                break;
            case 'HR':
                country = Country.HR;
                break;
            case 'RO':
                country = Country.RO;
                break;
            default:
                country = Country.SI;
        }
    }
    var age = Number((_b = inputs.age) === null || _b === void 0 ? void 0 : _b.currentPoints) || 0;
    var sex = ((_c = inputs.sex) === null || _c === void 0 ? void 0 : _c.currentIdentifier) === 'male' ? Sex.male : Sex.female;
    var bmi = calculateBMI();
    var previousFracture = ((_d = inputs.fracture) === null || _d === void 0 ? void 0 : _d.currentIdentifier) === 'yes';
    var parentFracture = ((_e = inputs.parentHipFracture) === null || _e === void 0 ? void 0 : _e.currentIdentifier) === 'yes';
    var smoker = ((_f = inputs.smoking) === null || _f === void 0 ? void 0 : _f.currentIdentifier) === 'yes';
    var glucocorticosteroids = ((_g = inputs.glucocorticoids) === null || _g === void 0 ? void 0 : _g.currentIdentifier) === 'yes';
    var rheumatoidArthritis = ((_h = inputs.arthritis) === null || _h === void 0 ? void 0 : _h.currentIdentifier) === 'yes';
    var secondaryOsteoporosis = ((_j = inputs.osteoporosis) === null || _j === void 0 ? void 0 : _j.currentIdentifier) === 'yes';
    var alcoholIntake = ((_k = inputs.alcohol) === null || _k === void 0 ? void 0 : _k.currentIdentifier) === 'yes';
    var withBMD = ((_l = inputs.bmd) === null || _l === void 0 ? void 0 : _l.currentIdentifier) !== 'emptyAnswerIdentifier'
        ? ((_m = inputs.bmd) === null || _m === void 0 ? void 0 : _m.currentIdentifier) === 'with'
        : null;
    return calculate(country, age, sex, bmi, previousFracture, parentFracture, smoker, glucocorticosteroids, rheumatoidArthritis, secondaryOsteoporosis, alcoholIntake, withBMD, bmdData());
};
var b1HR = {
    0: {
        1: -9.4302,
        2: 0.08646,
        3: 0.1006,
        4: 0.07776
    },
    1: {
        1: -8.5708,
        2: 0.04697,
        3: 0.149,
        4: 0.09236
    }
};
var b1CZ = {
    0: {
        1: -10.36275,
        2: 0.1040338,
        3: 0.09028807,
        4: 0.086191
    },
    1: {
        1: -9.758694,
        2: 0.07442769,
        3: 0.1183742,
        4: 0.1050657
    }
};
var b1SK = {
    0: {
        1: -9.0561,
        2: 0.08649,
        3: 0.08484,
        4: 0.07596
    },
    1: {
        1: -8.3996,
        2: 0.05286,
        3: 0.1167,
        4: 0.1076
    }
};
var b1UK = {
    0: {
        1: -9.448,
        2: 0.0807,
        3: 0.111,
        4: 0.0921
    },
    1: {
        1: -10.456,
        2: 0.0906,
        3: 0.109,
        4: 0.101
    }
};
var b1RO = {
    0: {
        1: -9.253304,
        2: 0.09264877,
        3: 0.06968992,
        4: 0.08735065
    },
    1: {
        1: -9.666386,
        2: 0.08074564,
        3: 0.09933421,
        4: 0.1213989
    }
};
var frUK = {
    0: {
        50: 0.218,
        55: 0.264,
        60: 0.29,
        65: 0.431,
        70: 0.793,
        75: 0.832,
        80: 1.3,
        85: 1.933,
        90: 3.135
    },
    1: {
        50: 0.422,
        55: 0.679,
        60: 0.873,
        65: 1.184,
        70: 1.857,
        75: 2.321,
        80: 3.171,
        85: 5.023,
        90: 7.988
    }
};
var frhUK = {
    0: {
        50: 0.022,
        55: 0.039,
        60: 0.069,
        65: 0.121,
        70: 0.213,
        75: 0.374,
        80: 0.657,
        85: 1.115,
        90: 2.003
    },
    1: {
        50: 0.03,
        55: 0.057,
        60: 0.107,
        65: 0.201,
        70: 0.379,
        75: 0.713,
        80: 1.344,
        85: 2.532,
        90: 4.77
    }
};
var pp = {
    40: 0.726,
    41: 0.726,
    42: 0.591,
    43: 0.721,
    44: 0.5,
    45: 0.631,
    46: 0.603,
    47: 0.67,
    48: 0.663,
    49: 0.802,
    50: 0.857,
    51: 0.786,
    52: 0.704,
    53: 0.718,
    54: 0.701,
    55: 0.7,
    56: 0.65,
    57: 0.631,
    58: 0.628,
    59: 0.628,
    60: 0.69,
    61: 0.616,
    62: 0.647,
    63: 0.669,
    64: 0.643,
    65: 0.679,
    66: 0.678,
    67: 0.656,
    68: 0.692,
    69: 0.702,
    70: 0.611,
    71: 0.61,
    72: 0.586,
    73: 0.609,
    74: 0.614,
    75: 0.653,
    76: 0.695,
    77: 0.692,
    78: 0.7,
    79: 0.644,
    80: 0.677,
    81: 0.725,
    82: 0.747,
    83: 0.757,
    84: 0.774,
    85: 0.715,
    86: 0.771,
    87: 0.782,
    88: 0.788,
    89: 0.753,
    90: 0.8,
    91: 0.88,
    92: 0.859,
    93: 0.902,
    94: 0.966,
    95: 0.842,
    96: 0.733,
    97: 0.8,
    98: 0.8,
    99: 0.8,
    100: 0.8
};
var tz = {
    0: {
        1: {
            0: 1.3767,
            1: 1.2175,
            2: -0.0318,
            3: -0.0032
        },
        2: {
            0: 1.2375,
            1: 0.8158,
            2: -0.0292,
            3: 0.0041
        }
    },
    1: {
        1: {
            0: 0.8917,
            1: 0.9842,
            2: -0.034,
            3: 0.0007
        },
        2: {
            0: 1.6617,
            1: 1.2658,
            2: -0.048,
            3: -0.0044
        }
    }
};
var fracRisk = {
    1: {
        1: -0.659,
        2: 0.000519,
        3: -0.0255,
        4: 0.936,
        5: 0.726,
        6: 0.0286,
        7: 0.486,
        8: 0.286,
        9: 0.168,
        10: 0.0167,
        11: -0.00425,
        12: -0.0651,
        13: 0,
        14: 0,
        15: 0
    },
    2: {
        1: -0.527,
        2: 0.0296,
        3: -0.00877,
        4: 0.933,
        5: 0.761,
        6: -0.0418,
        7: 0.495,
        8: 0.257,
        9: 0.163,
        10: 0.0146,
        11: -0.00607,
        12: -0.0627,
        13: 0.0343,
        14: 0.189,
        15: -0.00521
    },
    3: {
        1: 0.546,
        2: -0.126,
        3: -0.0506,
        4: 2.95,
        5: 0.274,
        6: 0.416,
        7: 0.775,
        8: 0.572,
        9: 0.425,
        10: -0.00286,
        11: -0.0313,
        12: 0.0984,
        13: 0,
        14: 0,
        15: 0
    },
    4: {
        1: -0.115,
        2: 0.0101,
        3: -0.0149,
        4: 1.566,
        5: 0.0503,
        6: 0.559,
        7: 0.638,
        8: 0.353,
        9: 0.424,
        10: 0.00676,
        11: -0.0161,
        12: 0.143,
        13: -2.38,
        14: -2.306,
        15: 0.02
    },
    5: {
        1: -2.076,
        2: -0.0835,
        3: 0.00864,
        4: 0.254,
        5: 0.363,
        6: 0.0197,
        7: 0
    },
    6: {
        1: -1.225,
        2: -0.0604,
        3: 0.00278,
        4: 0.296,
        5: 0.267,
        6: 0.00782,
        7: -0.0971
    }
};
var calibration = {
    1: {
        0: {
            0: -0.956,
            1: 0.0292,
            2: 0.418
        },
        1: {
            0: -0.246,
            1: 0.0292,
            2: 0.47
        }
    },
    2: {
        0: {
            0: -5.396,
            1: 0.0331,
            2: 0.416
        },
        1: {
            0: -3.45,
            1: 0.0129,
            2: 0.375
        }
    },
    3: {
        0: {
            0: -1.397,
            1: -0.01,
            2: 0.64
        },
        1: {
            0: 0.294,
            1: 0.0129,
            2: 1.121
        }
    }
};
var bmdData = function () {
    var bmd = inputs.bmd, equipment = inputs.equipment, bmdHologic = inputs.bmdHologic, bmdLunar = inputs.bmdLunar, bmdNorland = inputs.bmdNorland, bmdDms = inputs.bmdDms, bmdQct = inputs.bmdQct, tScore = inputs.tScore;
    if ((bmd === null || bmd === void 0 ? void 0 : bmd.currentIdentifier) === 'with' && (equipment === null || equipment === void 0 ? void 0 : equipment.currentPoints) !== null) {
        switch (equipment === null || equipment === void 0 ? void 0 : equipment.currentIdentifier) {
            case 'tScore':
                if (isNotValidNumber(tScore))
                    return null;
                return { type: ScoreType.tscore, score: Number(tScore === null || tScore === void 0 ? void 0 : tScore.currentPoints) };
            case 'hologic':
                if (isNotValidNumber(bmdHologic))
                    return null;
                return {
                    type: ScoreType.hologic,
                    score: Number(bmdHologic === null || bmdHologic === void 0 ? void 0 : bmdHologic.currentPoints)
                };
            case 'lunar':
                if (isNotValidNumber(bmdLunar))
                    return null;
                return {
                    type: ScoreType.lunar,
                    score: Number(bmdLunar === null || bmdLunar === void 0 ? void 0 : bmdLunar.currentPoints)
                };
            case 'norland':
                if (isNotValidNumber(bmdNorland))
                    return null;
                if (!(bmdNorland === null || bmdNorland === void 0 ? void 0 : bmdNorland.currentPoints))
                    return null;
                return {
                    type: ScoreType.norland,
                    score: Number(bmdNorland.currentPoints)
                };
            case 'DMS':
                if (isNotValidNumber(bmdDms))
                    return null;
                return { type: ScoreType.dms, score: Number(bmdDms === null || bmdDms === void 0 ? void 0 : bmdDms.currentPoints) };
            case 'QCT':
                if (isNotValidNumber(bmdQct))
                    return null;
                return { type: ScoreType.qct, score: Number(bmdQct === null || bmdQct === void 0 ? void 0 : bmdQct.currentPoints) };
            default:
                return null;
        }
    }
    return null;
};
var calculateFRAK = function (country, sex, age) {
    var coef1;
    var coef2;
    var coef3;
    var coef4;
    var exponent;
    var expr;
    switch (country) {
        case Country.SI: {
            var ageInterval = age - (age % 5);
            if (ageInterval < 50) {
                ageInterval = 50;
            }
            if (ageInterval > 90) {
                ageInterval = 90;
            }
            return frUK[sex.valueOf()][ageInterval] / 100;
        }
        case Country.HR: {
            coef1 = Math.min(age, 57);
            coef2 = Math.max(0, Math.min(age - 57, 20));
            coef3 = Math.max(0, Math.min(age - 77, 15));
            coef4 = Math.max(0, age - 92);
            if (sex === Sex.male) {
                exponent =
                    -0.4598378 +
                        0.1107435 * coef1 +
                        0.03283212 * coef2 +
                        0.1291531 * coef3 +
                        0.01743505 * coef4;
            }
            else {
                exponent =
                    -1.917189 +
                        0.1432396 * coef1 +
                        0.05304929 * coef2 +
                        0.1094606 * coef3 -
                        0.07721833 * coef4;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        case Country.CZ: {
            coef1 = Math.min(age, 60);
            coef2 = Math.max(0, Math.min(age - 60, 12));
            coef3 = Math.max(0, Math.min(age - 72, 16));
            coef4 = Math.max(0, age - 88);
            if (sex === Sex.male) {
                exponent =
                    4.861182 +
                        0.02028646 * coef1 +
                        0.03412953 * coef2 +
                        0.107039 * coef3 +
                        0.05466905 * coef4;
            }
            else {
                exponent =
                    2.983188 +
                        0.05321684 * coef1 +
                        0.08255773 * coef2 +
                        0.09680009 * coef3 +
                        0.01707209 * coef4;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        case Country.SK: {
            coef1 = Math.min(age, 62);
            coef2 = Math.max(0, Math.min(age - 62, 15));
            coef3 = Math.max(0, Math.min(age - 77, 10));
            coef4 = Math.max(0, age - 87);
            if (sex === Sex.male) {
                exponent =
                    5.194024 +
                        0.02306557 * coef1 +
                        0.02122792 * coef2 +
                        0.1180989 * coef3 +
                        0.02530044 * coef4;
            }
            else {
                exponent =
                    2.248676 +
                        0.07333771 * coef1 +
                        0.06180958 * coef2 +
                        0.08206921 * coef3 +
                        0.009425252 * coef4;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        case Country.RO: {
            coef1 = Math.min(age, 65);
            coef2 = Math.max(0, Math.min(age - 65, 17));
            coef3 = Math.max(0, Math.min(age - 82, 10));
            coef4 = Math.max(0, age - 92);
            if (sex === Sex.male) {
                exponent =
                    5.059313 +
                        0.01655108 * coef1 +
                        0.03305538 * coef2 +
                        0.06599813 * coef3 -
                        0.0396466 * coef4;
            }
            else {
                exponent =
                    2.031183 +
                        0.06628231 * coef1 +
                        0.06222331 * coef2 +
                        0.05376148 * coef3 -
                        0.09619328 * coef4;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        default: {
            return 0;
        }
    }
};
var calculateFRAH = function (country, sex, age) {
    var coef1;
    var coef2;
    var coef3;
    var coef4;
    var exponent;
    var expr;
    switch (country) {
        case Country.SI: {
            var ageInterval = age - (age % 5);
            if (ageInterval < 50) {
                ageInterval = 50;
            }
            if (ageInterval > 90) {
                ageInterval = 90;
            }
            return frhUK[sex.valueOf()][ageInterval] / 100;
        }
        case Country.HR: {
            coef1 = Math.min(age, 60);
            coef2 = Math.max(0, Math.min(age - 60, 15));
            coef3 = Math.max(0, Math.min(age - 75, 17));
            coef4 = Math.max(0, age - 92);
            if (sex === Sex.male) {
                exponent =
                    -1.304739 +
                        0.0965275 * coef1 +
                        0.06909113 * coef2 +
                        0.1400006 * coef3 +
                        0.01418029 * coef4;
            }
            else {
                exponent =
                    -4.733166 +
                        0.1524856 * coef1 +
                        0.1193845 * coef2 +
                        0.1288371 * coef3 -
                        0.07264943 * coef4;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        case Country.CZ: {
            coef1 = Math.min(age, 70);
            coef2 = Math.max(0, Math.min(age - 70, 17));
            coef3 = Math.max(0, age - 87);
            if (sex === Sex.male) {
                exponent =
                    -0.1228294 +
                        0.07808539 * coef1 +
                        0.128546167 * coef2 +
                        0.06458697 * coef3;
            }
            else {
                exponent =
                    -3.244155 +
                        0.1268076 * coef1 +
                        0.1454315 * coef2 +
                        0.02023467 * coef3;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        case Country.SK: {
            coef1 = Math.min(age, 67);
            coef2 = Math.max(0, Math.min(age - 67, 18));
            coef3 = Math.max(0, age - 85);
            if (sex === Sex.male) {
                exponent =
                    1.725652 +
                        0.05491059 * coef1 +
                        0.1009901 * coef2 +
                        0.07372915 * coef3;
            }
            else {
                exponent =
                    -1.945618 +
                        0.1108965 * coef1 +
                        0.1352643 * coef2 +
                        0.006293731 * coef3;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        case Country.RO: {
            coef1 = Math.min(age, 70);
            coef2 = Math.max(0, Math.min(age - 70, 17));
            coef3 = Math.max(0, Math.min(age - 87, 5));
            coef4 = Math.max(0, age - 92);
            if (sex === Sex.male) {
                exponent =
                    0.2156298 +
                        0.07158623 * coef1 +
                        0.0755487 * coef2 +
                        0.04780114 * coef3 -
                        0.03399994 * coef4;
            }
            else {
                exponent =
                    -3.800455 +
                        0.1315789 * coef1 +
                        0.102793 * coef2 +
                        0.0274899 * coef3 -
                        0.08300003 * coef4;
            }
            expr = Math.exp(exponent);
            return expr / 100000;
        }
        default: {
            return 0;
        }
    }
};
var fractureCoefficients = function (country) {
    var frau = {};
    var frahu = {};
    var frak = {};
    var frah = {};
    var fra = {};
    var startAge = 40;
    for (var sex = 0; sex <= 1; sex++) {
        var frakAges = {};
        var frahAges = {};
        var fraAges = {};
        for (var age = startAge; age <= 100; age++) {
            frakAges[age] = calculateFRAK(country, sex === 0 ? Sex.male : Sex.female, age);
            frahAges[age] = calculateFRAH(country, sex === 0 ? Sex.male : Sex.female, age);
            fraAges[age] = frakAges[age] - frahAges[age];
        }
        frak[sex] = frakAges;
        frah[sex] = frahAges;
        fra[sex] = fraAges;
    }
    for (var age = startAge; age <= 100; age++) {
        frau[age] = fra[0][age] * (1 - pp[age]) + fra[1][age] * pp[age];
        frahu[age] = frah[0][age] * (1 - pp[age]) + frah[1][age] * pp[age];
    }
    return { frau: frau, frahu: frahu };
};
var rhArtRisk = function (rheumatoidArthritis, secondaryOsteoporosis) {
    if (rheumatoidArthritis) {
        return { ignoreWhenBMDPresent: false, riskCoefficient: 1 };
    }
    else if (secondaryOsteoporosis) {
        return { ignoreWhenBMDPresent: true, riskCoefficient: 1 };
    }
    else {
        return { ignoreWhenBMDPresent: false, riskCoefficient: 0 };
    }
};
var zscore = function (bmd, sex, age) {
    if (bmd === null)
        return 0;
    var tscore;
    switch (bmd.type) {
        case ScoreType.hologic:
            tscore = (bmd.score - 0.858) / 0.12;
            break;
        case ScoreType.norland:
            tscore = (0.9062 * bmd.score - 0.012 - 0.858) / 0.12;
            break;
        case ScoreType.lunar:
            tscore = (0.8638 * bmd.score - 0.0386 - 0.858) / 0.12;
            break;
        case ScoreType.dms:
            tscore = (bmd.score / 1.1177 - 0.858) / 0.12;
            break;
        case ScoreType.qct:
            tscore = ((bmd.score + 0.004) / 0.888 - 0.858) / 0.12;
            break;
        case ScoreType.tscore:
            tscore = bmd.score;
            break;
        case ScoreType.zscore:
            return bmd.score;
    }
    tscore = Math.round(tscore * 10) / 10;
    var tza = age > 55 ? 2 : 1;
    var numerator = tscore - tz[sex.valueOf()][tza][0] - tz[sex.valueOf()][tza][2] * age;
    var denominator = tz[sex.valueOf()][tza][1] + tz[sex.valueOf()][tza][3] * age;
    return numerator / denominator;
};
var coefficients = function (age, sex, bmi, previousFracture, parentFracture, smoker, glucocorticosteroids, rheumatoidArthritis, secondaryOsteoporosis, alcoholIntake, bmd) {
    var rheumatoidArthritisRisk = rhArtRisk(rheumatoidArthritis, secondaryOsteoporosis);
    var constFraction = {};
    constFraction[1] = sex.valueOf() + 1.0;
    constFraction[2] = Math.min(bmi, 25);
    constFraction[3] = Math.max(bmi - 25, 0);
    constFraction[4] = previousFracture === true ? 1 : 0;
    constFraction[5] = parentFracture === true ? 1 : 0;
    constFraction[6] = smoker === true ? 1 : 0;
    constFraction[7] = glucocorticosteroids === true ? 1 : 0;
    constFraction[8] = rheumatoidArthritisRisk.riskCoefficient;
    constFraction[9] = alcoholIntake === true ? 1 : 0;
    constFraction[10] = (sex.valueOf() + 1.0) * age;
    constFraction[11] = (previousFracture === true ? 1 : 0) * Math.min(age, 80);
    constFraction[12] =
        (parentFracture === true ? 1 : 0) * Math.max(0, Math.min(age - 65, 10));
    var zscoreValue = zscore(bmd, sex, age);
    constFraction[13] = Math.min(zscoreValue, 0);
    constFraction[14] = Math.max(zscoreValue, 0);
    constFraction[15] = zscoreValue * age;
    var risks = {};
    for (var i = 1; i <= 6; i++) {
        risks[i] = 0;
    }
    for (var i = 1; i <= 4; i++) {
        for (var j = 1; j <= 15; j++) {
            if (rheumatoidArthritisRisk.ignoreWhenBMDPresent &&
                j === 8 &&
                (i === 2 || i === 4)) {
                risks[i] = risks[i] + (constFraction[j] - 1) * fracRisk[i][j];
            }
            else {
                risks[i] = risks[i] + constFraction[j] * fracRisk[i][j];
            }
        }
    }
    constFraction[1] = sex.valueOf() + 1.0;
    constFraction[2] = Math.min(bmi, 25);
    constFraction[3] = Math.max(bmi - 25, 0);
    constFraction[4] = smoker === true ? 1 : 0;
    constFraction[5] = glucocorticosteroids === true ? 1 : 0;
    constFraction[6] = (sex.valueOf() + 1.0) * age;
    constFraction[7] = zscoreValue;
    for (var i = 5; i <= 6; i++) {
        for (var j = 1; j <= 7; j++) {
            risks[i] = risks[i] + constFraction[j] * fracRisk[i][j];
        }
    }
    var coefficients = {};
    var intermediary1;
    var intermediary2;
    intermediary1 =
        risks[1] -
            (calibration[1][0][0] +
                calibration[1][0][1] * age +
                Math.pow(calibration[1][0][2], 2) / 2);
    intermediary2 =
        risks[2] -
            (calibration[1][1][0] +
                calibration[1][1][1] * age +
                Math.pow(calibration[1][1][2], 2) / 2);
    coefficients[0] = { 0: Math.exp(intermediary1), 1: Math.exp(intermediary2) };
    intermediary1 =
        risks[3] -
            (calibration[3][0][0] +
                calibration[3][0][1] * age +
                Math.pow(calibration[3][0][2], 2) / 2);
    intermediary2 =
        risks[4] -
            (calibration[3][1][0] +
                calibration[3][1][1] * age +
                Math.pow(calibration[3][1][2], 2) / 2);
    coefficients[1] = { 0: Math.exp(intermediary1), 1: Math.exp(intermediary2) };
    intermediary1 =
        risks[5] -
            (calibration[2][0][0] +
                calibration[2][0][1] * age +
                Math.pow(calibration[2][0][2], 2) / 2);
    intermediary2 =
        risks[6] -
            (calibration[2][1][0] +
                calibration[2][1][1] * age +
                Math.pow(calibration[2][1][2], 2) / 2);
    coefficients[2] = { 0: Math.exp(intermediary1), 1: Math.exp(intermediary2) };
    return coefficients;
};
var death = function (country) {
    switch (country) {
        case Country.HR:
            return b1HR;
        case Country.CZ:
            return b1CZ;
        case Country.SK:
            return b1SK;
        case Country.RO:
            return b1RO;
        default:
            return b1UK;
    }
};
var calculate = function (country, age, sex, bmi, previousFracture, parentFracture, smoker, glucocorticosteroids, rheumatoidArthritis, secondaryOsteoporosis, alcoholIntake, withBMD, bmd) {
    var normalizedAge = age < 40 ? 40 : age > 90 ? 90 : age;
    if (bmi === 0 || withBMD === null) {
        return formatResponse(null, null);
    }
    var s = sex.valueOf();
    var fCoef = fractureCoefficients(country);
    var cCoef = coefficients(normalizedAge, sex, bmi, previousFracture, parentFracture, smoker, glucocorticosteroids, rheumatoidArthritis, secondaryOsteoporosis, alcoholIntake, bmd);
    var b1 = death(country);
    var d1Sum = 0.0;
    var d2Sum = 0.0;
    var d2Dod = 0.0;
    var mos = 0;
    var hfs = 0;
    for (var m = 0; m <= 1; m++) {
        if (m <= (withBMD === true ? 1 : 0)) {
            if (bmd === null && m === 1) {
                return formatResponse(null, null);
            }
            var sum1 = 0.0;
            var sum2 = 0.0;
            var sumH1 = 0.0;
            var sumH2 = 0.0;
            var dod = 0.0;
            for (var ic = 0; ic <= 99; ic++) {
                var u = normalizedAge + ic * 0.1;
                var resFR = fCoef.frau[Math.trunc(u)] * cCoef[0][m];
                var resFRH = fCoef.frahu[Math.trunc(u)] * cCoef[1][m];
                var a = b1[s][1] +
                    b1[s][2] * Math.min(u, 55) +
                    b1[s][3] * Math.max(0, Math.min(u - 55, 75 - 55)) +
                    b1[s][4] * Math.max(0, u - 75);
                var dea = Math.exp(a) * cCoef[2][m];
                sum1 = sum1 + (dea + resFR + resFRH) * 0.1;
                d1Sum = d1Sum + (dea + resFR + resFRH) * 0.1;
                sumH1 = sumH1 + (dea + resFRH) * 0.1;
                sum2 = sum2 + (resFR + resFRH) * Math.exp(-sum1) * 0.1;
                d2Sum = d2Sum + (resFR + resFRH) * Math.exp(-d1Sum) * 0.1;
                sumH2 = sumH2 + resFRH * Math.exp(-sumH1) * 0.1;
                dod = dod + dea * 0.1;
                d2Dod = d2Dod + dea * 0.1;
            }
            mos = sum2 * 100;
            hfs = sumH2 * 100;
        }
    }
    var response = {
        mos: {
            value: null,
            minFractions: null,
            maxFractions: null
        },
        hfs: {
            value: null,
            minFractions: null,
            maxFractions: null
        }
    };
    if (mos !== null) {
        response = __assign(__assign({}, response), { mos: formatAndRound(mos) });
    }
    if (hfs !== null) {
        response = __assign(__assign({}, response), { hfs: formatAndRound(hfs) });
    }
    return formatResponse(response.mos, response.hfs);
};
var formatResponse = function (mos, hfs) {
    return {
        hipFracture: {
            qID: 'hipFracture',
            rParams: [
                {
                    type: 'number',
                    value: hfs === null || hfs === void 0 ? void 0 : hfs.value,
                    minFractions: hfs === null || hfs === void 0 ? void 0 : hfs.minFractions,
                    maxFractions: hfs === null || hfs === void 0 ? void 0 : hfs.maxFractions
                },
            ],
            titleTexts: 'regular',
            resultTexts: 'regular'
        },
        osteoporoticFracture: {
            qID: 'osteoporoticFracture',
            rParams: [
                {
                    type: 'number',
                    value: mos === null || mos === void 0 ? void 0 : mos.value,
                    minFractions: mos === null || mos === void 0 ? void 0 : mos.minFractions,
                    maxFractions: mos === null || mos === void 0 ? void 0 : mos.maxFractions
                },
            ],
            titleTexts: 'regular',
            resultTexts: 'regular'
        }
    };
};
var calculateBMI = function () {
    if (!helpers_1.isAnswered(inputs.weight) ||
        !helpers_1.isAnswered(inputs.height) ||
        Number(inputs.weight.currentPoints) < 25 ||
        Number(inputs.weight.currentPoints) > 125 ||
        Number(inputs.height.currentPoints) < 100 ||
        Number(inputs.height.currentPoints) > 220)
        return 0;
    var outputResult = helpers_1.formatCalculationResult(Number(inputs.weight.currentPoints) /
        ((Number(inputs.height.currentPoints) / 100) *
            (Number(inputs.height.currentPoints) / 100)), 2);
    return outputResult;
};
var formatAndRound = function (value) {
    if (value === null)
        return null;
    if (value < 10) {
        var significantNumber = rounding(value, 1, 5);
        if (significantNumber === null)
            return null;
        var isNaN_1 = Number.isNaN(significantNumber);
        return {
            value: isNaN_1 ? 0.0 : Number(significantNumber),
            minFractions: 1,
            maxFractions: 1
        };
    }
    return {
        value: Number.isNaN(value) ? 0.0 : Math.round(value),
        minFractions: Number.isNaN(value) ? 1 : 0,
        maxFractions: 2
    };
};
var rounding = function (v, fractionDigits, precisionDigits) {
    var value = v;
    for (var precision = precisionDigits; precision >= fractionDigits; precision--) {
        var multiplier = Math.pow(10, precision);
        value = Math.round(value * multiplier) / multiplier;
    }
    return value;
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !answerAllVisibility();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
