"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    weight: true,
    height: true,
    waistCircumference: true,
    ggt: true,
    triglycerides: true,
    answerAll: false,
    unlikely: false,
    indeterminate: false,
    likely: false
};
var visibleSections = {
    sectionInputs: true,
    resultSection: true
};
var inputs = {
    weight: null,
    height: null,
    waistCircumference: null,
    ggt: null,
    triglycerides: null,
    answerAll: null,
    unlikely: null,
    indeterminate: null,
    likely: null
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 });
};
var isHeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.height, min: 1, max: 250 });
};
var isWaistCircumferenceValid = function () {
    return helpers_1.numberInLimits({
        input: inputs.waistCircumference,
        min: 30,
        max: 150
    });
};
var isGgtValid = function () {
    var _a;
    switch ((_a = inputs.ggt) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return helpers_1.numberInLimits({ input: inputs.ggt, min: 0, max: 500 });
        case 'UL':
            return helpers_1.numberInLimits({ input: inputs.ggt, min: 0, max: 30000 });
        default:
            return false;
    }
};
var isTriglyceridesValid = function () {
    var _a;
    switch ((_a = inputs.triglycerides) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'mg/dL':
            return helpers_1.numberInLimits({ input: inputs.triglycerides, min: 0, max: 4500 });
        case 'mmol/L':
            return helpers_1.numberInLimits({ input: inputs.triglycerides, min: 0, max: 50 });
        default:
            return false;
    }
};
var convertGgtToUL = function () {
    var _a, _b, _c;
    switch ((_a = inputs.ggt) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return Number((_b = inputs.ggt) === null || _b === void 0 ? void 0 : _b.currentPoints) / 0.0167;
        case 'UL':
            return Number((_c = inputs.ggt) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var convertTriglyceridesToMgDl = function () {
    var _a, _b, _c;
    switch ((_a = inputs.triglycerides) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'mmol/L':
            return Number((_b = inputs.triglycerides) === null || _b === void 0 ? void 0 : _b.currentPoints) / 0.0113;
        case 'mg/dL':
            return Number((_c = inputs.triglycerides) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var calculateBMI = function () {
    var _a, _b;
    if (isAnswerAllVisible())
        return 0;
    return (Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) /
        Math.pow(Number((_b = inputs.height) === null || _b === void 0 ? void 0 : _b.currentPoints) / 100, 2));
};
var calculateFLI = function () {
    var _a;
    if (isAnswerAllVisible())
        return 0;
    var triglycerides = convertTriglyceridesToMgDl();
    var bmi = calculateBMI();
    var ggt = convertGgtToUL();
    var waistCircumference = Number((_a = inputs.waistCircumference) === null || _a === void 0 ? void 0 : _a.currentPoints);
    var result = Math.exp(0.953 * Math.log(triglycerides) +
        0.139 * bmi +
        0.718 * Math.log(ggt) +
        0.053 * waistCircumference -
        15.745);
    result = result > Number.MAX_VALUE ? Number.MAX_VALUE : result;
    var FLI = (result / (1 + result)) * 100;
    return helpers_1.formatCalculationResult(FLI, 0);
};
var isAnswerAllVisible = function () {
    return (!isWeightValid() ||
        !isHeightValid() ||
        !isWaistCircumferenceValid() ||
        !isGgtValid() ||
        !isTriglyceridesValid());
};
var calculatePoints = function () {
    if (!isAnswerAllVisible()) {
        var result = calculateFLI();
        if (result < 30) {
            return {
                unlikely: {
                    qID: 'unlikely',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(result, 0, 0)),
                    rParams: [],
                    titleTexts: 'result1'
                }
            };
        }
        if (result >= 30 && result < 60) {
            return {
                indeterminate: {
                    qID: 'indeterminate',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(result, 0, 0)),
                    rParams: [],
                    titleTexts: 'result1'
                }
            };
        }
        if (result >= 60) {
            return {
                likely: {
                    qID: 'likely',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(result, 0, 0)),
                    rParams: [],
                    titleTexts: 'result1'
                }
            };
        }
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.answerAll = isAnswerAllVisible();
    visibleQuestions.unlikely = calculateFLI() < 30 && !isAnswerAllVisible();
    visibleQuestions.indeterminate =
        calculateFLI() >= 30 && calculateFLI() < 60 && !isAnswerAllVisible();
    visibleQuestions.likely = calculateFLI() >= 60 && !isAnswerAllVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
