"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    indication: true,
    age: true,
    hb: false,
    weight: false,
    answerAll: false,
    dosing2Result1: false,
    infusion3Result1: false,
    infusion3Result2: false,
    infusion3Result3: false,
    infusion3Result4: false,
    warningInfusion: false,
    injection3Result1: false,
    injection3Result2: false,
    injection3Result3: false,
    injection3Result4: false,
    infusion4Result1: false,
    infusion4Result2: false,
    infusion4Result3: false,
    warningInfusion4: false,
    injection4Result1: false,
    injection4Result2: false,
    injection4Result3: false,
    infusion5Result1: false,
    infusion5Result2: false,
    infusion5Result3: false,
    warningInfusion5: false,
    injection5Result1: false,
    injection5Result2: false,
    injection5Result3: false,
    infusion6Result1: false,
    infusion6Result2: false,
    infusion6Result3: false,
    warningInfusion6: false,
    injection6Result1: false,
    injection6Result2: false,
    injection6Result3: false,
    warning3Result1: false,
    kidneyText: false
};
var visibleSections = {
    info: true,
    dosing: false,
    dosing2: false,
    infusion3: false,
    injection3: false,
    infusion4: false,
    injection4: false,
    infusion5: false,
    injection5: false,
    infusion6: false,
    injection6: false,
    warning3: false,
    kidneySection: false
};
var inputs = {
    age: null,
    hb: null,
    weight: null
};
var isHbVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isWeightVisible = function () {
    return helpers_1.isAnswered(inputs.hb);
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 300 });
};
var isDosingVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        (isHbVisible() && !helpers_1.isAnswered(inputs.hb)) ||
        (isWeightVisible() && !isWeightInLimits()));
};
var isDosing2Visible = function () {
    return helpers_1.answerMatches(inputs.age, 'babys');
};
var isInfusion3Visible = function () {
    var condition1 = helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.isAnswered(inputs.hb) &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 34.99 });
    var condition2 = helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.answerMatches(inputs.hb, 'overSpiegel') &&
        isWeightInLimits();
    return condition1 || condition2;
};
var isInfusion3Result3Visible = function () {
    var _a, _b;
    return (isInfusion3Visible() &&
        Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 20 >= 100 &&
        Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 20 <= 200);
};
var isInfusion3Result4Visible = function () {
    var _a;
    return (isInfusion3Visible() && Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 20 > 200);
};
var isInjection3Result3Visible = function () {
    var _a, _b;
    return (isInfusion3Visible() &&
        Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 15 >= 100 &&
        Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 15 <= 200);
};
var isInjection3Result4Visible = function () {
    var _a;
    return (isInfusion3Visible() && Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 15 > 200);
};
var isInfusion4Visible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.answerMatches(inputs.hb, 'spiegel') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 35, max: 69.99 }));
};
var isInfusion5Visible = function () {
    var condition1 = helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.answerMatches(inputs.hb, 'underSpiegel') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 35, max: 69.99 });
    var condition2 = helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.answerMatches(inputs.hb, 'spiegel') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 70, max: 300 });
    return condition1 || condition2;
};
var isInfusion6Visible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.answerMatches(inputs.hb, 'underSpiegel') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 70, max: 300 }));
};
var isWarning3Visible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        helpers_1.isAnswered(inputs.hb) &&
        isWeightInLimits());
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o;
    if (isInfusion3Visible()) {
        var Infusion3Result2Ml = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 25,
            max: 300
        })
            ? 10
            : (Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 20) / 50;
        var Infusion3Result2Mg = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 25,
            max: 300
        })
            ? 500
            : Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 20;
        var Injection3Result2Ml = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 33.333,
            max: 300
        })
            ? 10
            : (Number((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints) * 15) / 50;
        var Injection3Result2Mg = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 33.333,
            max: 300
        })
            ? 500
            : Number((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints) * 15;
        var Injection3Result4Min = 0;
        if (isInjection3Result4Visible()) {
            Injection3Result4Min = helpers_1.numberInLimits({
                input: inputs.weight,
                min: 33.333,
                max: 300
            })
                ? 5
                : (Number((_e = inputs.weight) === null || _e === void 0 ? void 0 : _e.currentPoints) * 15) / 100;
        }
        return {
            infusion3Result2: {
                qID: 'infusion3Result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Infusion3Result2Ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Infusion3Result2Mg, 1), 0, 1)),
                rParams: [],
                titleTexts: 'regular',
                resultTexts: 'result1'
            },
            injection3Result2: {
                qID: 'injection3Result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection3Result2Ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection3Result2Mg, 1), 0, 1)),
                rParams: [],
                titleTexts: 'regular',
                resultTexts: 'result1'
            },
            injection3Result4: {
                qID: 'injection3Result4',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection3Result4Min, 1), 0, 1)),
                titleTexts: 'regular'
            }
        };
    }
    if (isInfusion4Visible()) {
        var Infusion4Result2Ml = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 300
        })
            ? 20
            : (Number((_f = inputs.weight) === null || _f === void 0 ? void 0 : _f.currentPoints) * 20) / 50;
        var Infusion4Result2Mg = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 300
        })
            ? 1000
            : Number((_g = inputs.weight) === null || _g === void 0 ? void 0 : _g.currentPoints) * 20;
        var Injection4Result2Ml = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 66.7,
            max: 300
        })
            ? 20
            : (Number((_h = inputs.weight) === null || _h === void 0 ? void 0 : _h.currentPoints) * 15) / 50;
        var Injection4Result2Mg = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 66.7,
            max: 300
        })
            ? 1000
            : Number((_j = inputs.weight) === null || _j === void 0 ? void 0 : _j.currentPoints) * 15;
        return {
            infusion4Result2: {
                qID: 'infusion4Result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Infusion4Result2Ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Infusion4Result2Mg, 1), 0, 1)),
                rParams: [],
                titleTexts: 'regular',
                resultTexts: 'result1'
            },
            injection4Result2: {
                qID: 'injection4Result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection4Result2Ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection4Result2Mg, 1), 0, 1)),
                rParams: [],
                titleTexts: 'regular',
                resultTexts: 'result1'
            }
        };
    }
    if (isInfusion5Visible()) {
        var Infusion5Result2Ml = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 300
        })
            ? 20
            : (Number((_k = inputs.weight) === null || _k === void 0 ? void 0 : _k.currentPoints) * 20) / 50;
        var Infusion5Result2Mg = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 300
        })
            ? 1000
            : Number((_l = inputs.weight) === null || _l === void 0 ? void 0 : _l.currentPoints) * 20;
        var Injection5Result2Ml = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 66.7,
            max: 300
        })
            ? 20
            : (Number((_m = inputs.weight) === null || _m === void 0 ? void 0 : _m.currentPoints) * 15) / 50;
        var Injection5Result2Mg = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 66.7,
            max: 300
        })
            ? 1000
            : Number((_o = inputs.weight) === null || _o === void 0 ? void 0 : _o.currentPoints) * 15;
        return {
            infusion5Result2: {
                qID: 'infusion5Result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Infusion5Result2Ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Infusion5Result2Mg, 1), 0, 1)),
                rParams: [],
                titleTexts: 'regular',
                resultTexts: 'result1'
            },
            injection5Result2: {
                qID: 'injection5Result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection5Result2Ml, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Injection5Result2Mg, 1), 0, 1)),
                rParams: [],
                titleTexts: 'regular',
                resultTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.hb = isHbVisible();
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.answerAll = isDosingVisible();
    visibleQuestions.dosing2Result1 = isDosing2Visible();
    visibleQuestions.infusion3Result1 = isInfusion3Visible();
    visibleQuestions.infusion3Result2 = isInfusion3Visible();
    visibleQuestions.infusion3Result3 = isInfusion3Result3Visible();
    visibleQuestions.infusion3Result4 = isInfusion3Result4Visible();
    visibleQuestions.warningInfusion = isInfusion3Visible();
    visibleQuestions.injection3Result1 = isInfusion3Visible();
    visibleQuestions.injection3Result2 = isInfusion3Visible();
    visibleQuestions.injection3Result3 = isInjection3Result3Visible();
    visibleQuestions.injection3Result4 = isInjection3Result4Visible();
    visibleQuestions.infusion4Result1 = isInfusion4Visible();
    visibleQuestions.infusion4Result2 = isInfusion4Visible();
    visibleQuestions.infusion4Result3 = isInfusion4Visible();
    visibleQuestions.warningInfusion4 = isInfusion4Visible();
    visibleQuestions.injection4Result1 = isInfusion4Visible();
    visibleQuestions.injection4Result2 = isInfusion4Visible();
    visibleQuestions.injection4Result3 = isInfusion4Visible();
    visibleQuestions.infusion5Result1 = isInfusion5Visible();
    visibleQuestions.infusion5Result2 = isInfusion5Visible();
    visibleQuestions.infusion5Result3 = isInfusion5Visible();
    visibleQuestions.warningInfusion5 = isInfusion5Visible();
    visibleQuestions.injection5Result1 = isInfusion5Visible();
    visibleQuestions.injection5Result2 = isInfusion5Visible();
    visibleQuestions.injection5Result3 = isInfusion5Visible();
    visibleQuestions.infusion6Result1 = isInfusion6Visible();
    visibleQuestions.infusion6Result2 = isInfusion6Visible();
    visibleQuestions.infusion6Result3 = isInfusion6Visible();
    visibleQuestions.warningInfusion6 = isInfusion6Visible();
    visibleQuestions.injection6Result1 = isInfusion6Visible();
    visibleQuestions.injection6Result2 = isInfusion6Visible();
    visibleQuestions.injection6Result3 = isInfusion6Visible();
    visibleQuestions.warning3Result1 = isWarning3Visible();
    visibleQuestions.kidneyText = isWarning3Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = isDosingVisible();
    visibleSections.dosing2 = isDosing2Visible();
    visibleSections.infusion3 = isInfusion3Visible();
    visibleSections.injection3 = isInfusion3Visible();
    visibleSections.infusion4 = isInfusion4Visible();
    visibleSections.injection4 = isInfusion4Visible();
    visibleSections.infusion5 = isInfusion5Visible();
    visibleSections.injection5 = isInfusion5Visible();
    visibleSections.infusion6 = isInfusion6Visible();
    visibleSections.injection6 = isInfusion6Visible();
    visibleSections.warning3 = isWarning3Visible();
    visibleSections.kidneySection = isWarning3Visible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isDosingVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
