"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    ast: true,
    alt: true,
    plateletes: true,
    notAnswered: true,
    green: false,
    orange: false,
    red: false,
    over65: false
};
var visibleSections = {
    questions: true,
    results: true,
    note: false
};
var inputs = {
    age: null,
    ast: null,
    alt: null,
    plateletes: null
};
var isAstValid = function () {
    var _a;
    switch ((_a = inputs.ast) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return helpers_1.numberInLimits({ input: inputs.ast, min: 0.01, max: 500 });
        case 'UL':
            return helpers_1.numberInLimits({ input: inputs.ast, min: 1, max: 30000 });
        default:
            return false;
    }
};
var isAltValid = function () {
    var _a;
    switch ((_a = inputs.alt) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return helpers_1.numberInLimits({ input: inputs.alt, min: 0.01, max: 500 });
        case 'UL':
            return helpers_1.numberInLimits({ input: inputs.alt, min: 1, max: 30000 });
        default:
            return false;
    }
};
var isPlateletesValid = function () {
    return helpers_1.numberInLimits({ input: inputs.plateletes, min: 1, max: 3000 });
};
var isAnswerAllVisible = function () {
    return !(helpers_1.numberInLimits({ input: inputs.age, min: 1, max: 120 }) &&
        isAstValid() &&
        isAltValid() &&
        isPlateletesValid());
};
var convertAstToUL = function () {
    var _a, _b, _c;
    switch ((_a = inputs.ast) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return Number((_b = inputs.ast) === null || _b === void 0 ? void 0 : _b.currentPoints) / 0.0167;
        case 'UL':
            return Number((_c = inputs.ast) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var isOver65Visible = function () {
    return (!isAnswerAllVisible() &&
        helpers_1.numberInLimits({ input: inputs.age, min: 66, max: 120 }));
};
var convertAltToUL = function () {
    var _a, _b, _c;
    switch ((_a = inputs.alt) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return Number((_b = inputs.alt) === null || _b === void 0 ? void 0 : _b.currentPoints) / 0.0167;
        case 'UL':
            return Number((_c = inputs.alt) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var calculateFib4Index = function () {
    var _a, _b;
    var alt = convertAltToUL();
    var ast = convertAstToUL();
    return ((Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints) * ast) /
        (Number((_b = inputs.plateletes) === null || _b === void 0 ? void 0 : _b.currentPoints) * Math.sqrt(alt)));
};
var calculatePoints = function () {
    if (!isAnswerAllVisible()) {
        var result = calculateFib4Index();
        var greenR = result < 1.3 ? result : 0;
        var orangeR = result >= 1.3 && result <= 3.25 ? result : 0;
        var redR = result > 3.25 ? result : 0;
        return {
            green: {
                qID: 'green',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(greenR, 2), 0, 2)),
                titleTexts: 'result1'
            },
            orange: {
                qID: 'orange',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(orangeR, 2), 0, 2)),
                titleTexts: 'result1'
            },
            red: {
                qID: 'red',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(redR, 2), 0, 2)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    var result = calculateFib4Index();
    visibleQuestions.notAnswered = isAnswerAllVisible();
    visibleQuestions.green = !isAnswerAllVisible() && result < 1.3;
    visibleQuestions.orange =
        !isAnswerAllVisible() && result >= 1.3 && result <= 3.25;
    visibleQuestions.red = !isAnswerAllVisible() && result > 3.25;
    visibleQuestions.over65 = isOver65Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.note = isOver65Visible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
