"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    puberty: false,
    weightKids: false,
    weightAdolescents: false,
    noAnswer1: true,
    miniBabyDoseInf1: false,
    miniBabyDoseInf1Limit: false,
    warningInfusionMini: true,
    miniBabyDoseInf2: true,
    warningExertion: true,
    babyDoseInf1: false,
    babyDoseInf1Limit: false,
    warningInfusion2Baby: true,
    babyDoseInf2: true,
    warningExertion2: true,
    adolescentDoseInf1: true,
    warningInfusion4Kids: true,
    adolescentDoseInf2: true,
    adolescentDoseInf1More: false,
    adolescentDoseInf1LimitMore: false,
    warningInfusion4KidsMore: true,
    adolescentDoseInf2More: true,
    adolescentDoseTbl1: true,
    adolescentDoseTbl2: true,
    adolescentDoseTbl1More: false,
    adolescentDoseTbl1LimitMore: false,
    adolescentDoseTbl2More: true,
    adolescentDoseInf22: true,
    adolescentDoseInf23: true,
    warningInfusion5Adult: true,
    adolescentDoseInf24: true,
    adolescentDoseTbl222: true,
    adolescentDoseTbl223: true,
    adolescentDoseTbl224: true,
    kidney: true,
    anti: true
};
var visibleSections = {
    inputs: true,
    noAnswer: false,
    miniBabyDoseInf: false,
    babyDoseInf: false,
    adolescentDoseInf: false,
    adolescentDoseInfMore: false,
    adolescentDoseTbl: false,
    adolescentDoseTblMore: false,
    adolescentDoseInf21: false,
    adolescentDoseTbl221: false,
    warningKidney: false,
    warningAb: false
};
var inputs = {
    age: null,
    puberty: null,
    weightKids: null,
    weightAdolescents: null
};
var isWeightKidsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 70 });
};
var isWeightAdolescentsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 1, max: 150 });
};
var isPubertyVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adolescent');
};
var isWeightKidsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'miniBaby') ||
        helpers_1.answerMatches(inputs.age, 'baby') ||
        helpers_1.answerMatches(inputs.age, 'kids'));
};
var isWeightAdolescentsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adolescent') &&
        helpers_1.answerMatches(inputs.puberty, 'no'));
};
var areAllVisibleQuesionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.age) &&
        ((isPubertyVisible() && helpers_1.isAnswered(inputs.puberty)) ||
            !isPubertyVisible()) &&
        ((isWeightKidsVisible() && isWeightKidsValid()) ||
            !isWeightKidsVisible()) &&
        ((isWeightAdolescentsVisible() && isWeightAdolescentsValid()) ||
            !isWeightAdolescentsVisible()));
};
var isWeightKidsHigh = function () {
    return helpers_1.numberInLimits({ input: inputs.weightKids, min: 66.7, max: 70 });
};
var isWeightKidsLow = function () {
    return helpers_1.numberInLimits({
        input: inputs.weightKids,
        min: 1,
        max: 66.669
    });
};
var isWeightAdolLow = function () {
    return helpers_1.numberInLimits({
        input: inputs.weightAdolescents,
        min: 1,
        max: 66.669
    });
};
var isWeightHigh = function () {
    return (helpers_1.numberInLimits({ input: inputs.weightKids, min: 66.7, max: 70 }) ||
        helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 66.7, max: 150 }));
};
var isWeightLow = function () {
    return (helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 66.669 }) ||
        helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 1, max: 66.669 }));
};
var isMiniBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'miniBaby') && isWeightKidsValid();
};
var isBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'baby') && isWeightKidsValid();
};
var isAdolescentDoseInfSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isAdolescentDoseInfMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isWeightAdolescentsValid() &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'no')) ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            isWeightKidsValid() &&
            helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 150 })));
};
var isAdolescentDoseTblSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isAdolescentDoseTblMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isWeightAdolescentsValid() &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'no')) ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            isWeightKidsValid() &&
            helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })));
};
var isAdolescentDoseInf21SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var isAdolescentDoseTbl221SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var babyLimArg1 = function () {
    var _a;
    return (((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6) / 2;
};
var babyLimArg2 = function () {
    var _a;
    if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 }))
        return 200;
    return (((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 12) / 2;
};
var babyLimArg3 = function () {
    var _a;
    return ((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6;
};
var babyLimArg4 = function () {
    var _a;
    if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 }))
        return 400;
    return ((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 12;
};
var babyArg1 = function () {
    var _a;
    return (((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6) / 2;
};
var babyArg2 = function () {
    var _a;
    return (((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 12) / 2;
};
var babyArg3 = function () {
    var _a;
    return ((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6;
};
var babyArg4 = function () {
    var _a;
    return ((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 12;
};
var adulLimArg1 = function () {
    var _a, _b;
    if (isWeightAdolescentsValid())
        return (((_a = inputs.weightAdolescents) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6) / 2;
    return (((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 6) / 2;
};
var adulLimArg2 = function () {
    var _a, _b;
    if (isWeightAdolescentsValid()) {
        if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 33.4, max: 70 }))
            return 200;
        return (((_a = inputs.weightAdolescents) === null || _a === void 0 ? void 0 : _a.currentPoints) * 12) / 2;
    }
    if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 }))
        return 200;
    return (((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 12) / 2;
};
var adulLimArg3 = function () {
    var _a, _b;
    if (isWeightAdolescentsValid())
        return ((_a = inputs.weightAdolescents) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6;
    return ((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 6;
};
var adulLimArg4 = function () {
    var _a, _b;
    if (isWeightAdolescentsValid()) {
        if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 33.4, max: 70 }))
            return 400;
        return ((_a = inputs.weightAdolescents) === null || _a === void 0 ? void 0 : _a.currentPoints) * 12;
    }
    if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 }))
        return 400;
    return ((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 12;
};
var calculatePoints = function () {
    if (isMiniBabyDoseInfSectionVisible() && isWeightKidsLow()) {
        return {
            miniBabyDoseInf1: {
                qID: 'miniBabyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg1(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg4(), 1), 0, 1)),
                titleTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg4(), 1), 0, 1)),
                resultTexts: 'result1'
            }
        };
    }
    if (isBabyDoseInfSectionVisible() && isWeightLow()) {
        return {
            babyDoseInf1: {
                qID: 'babyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg1(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg4(), 1), 0, 1)),
                titleTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyLimArg4(), 1), 0, 1)),
                resultTexts: 'result1'
            }
        };
    }
    if (isAdolescentDoseInfSectionVisible()) {
        if (isAdolescentDoseTblSectionVisible()) {
            return {
                adolescentDoseTbl1: {
                    qID: 'adolescentDoseTbl1',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg4(), 1), 0, 1)),
                    titleTexts: 'result1'
                },
                adolescentDoseInf1: {
                    qID: 'adolescentDoseInf1',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg1(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg4(), 1), 0, 1)),
                    titleTexts: 'result1'
                }
            };
        }
        return {
            adolescentDoseInf1: {
                qID: 'adolescentDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg1(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg4(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isAdolescentDoseInfMoreSectionVisible()) {
        if ((isWeightKidsValid() && isWeightKidsLow()) ||
            (isWeightAdolescentsValid() && isWeightAdolLow())) {
            return {
                adolescentDoseInf1More: {
                    qID: 'adolescentDoseInf1More',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg1(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg2(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg4(), 1), 0, 1)),
                    titleTexts: 'result1'
                },
                adolescentDoseTbl1More: {
                    qID: 'adolescentDoseTbl1More',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg4(), 1), 0, 1)),
                    titleTexts: 'result1'
                }
            };
        }
    }
    if (isAdolescentDoseTblSectionVisible()) {
        return {
            adolescentDoseTbl1: {
                qID: 'adolescentDoseTbl1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(babyArg4(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isAdolescentDoseTblMoreSectionVisible() &&
        ((isWeightKidsValid() && isWeightKidsLow()) ||
            (isWeightAdolescentsValid() && isWeightAdolLow()))) {
        return {
            adolescentDoseTbl1More: {
                qID: 'adolescentDoseTbl1More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg3(), 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(adulLimArg4(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.puberty = isPubertyVisible();
    visibleQuestions.weightKids = isWeightKidsVisible();
    visibleQuestions.weightAdolescents = isWeightAdolescentsVisible();
    visibleQuestions.miniBabyDoseInf1 = isWeightKidsLow();
    visibleQuestions.miniBabyDoseInf1Limit = isWeightKidsHigh();
    visibleQuestions.babyDoseInf1 = isWeightKidsLow();
    visibleQuestions.babyDoseInf1Limit = isWeightKidsHigh();
    visibleQuestions.adolescentDoseInf1More = isWeightLow();
    visibleQuestions.adolescentDoseInf1LimitMore = isWeightHigh();
    visibleQuestions.adolescentDoseTbl1More = isWeightLow();
    visibleQuestions.adolescentDoseTbl1LimitMore = isWeightHigh();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = !areAllVisibleQuesionsAnswered();
    visibleSections.miniBabyDoseInf = isMiniBabyDoseInfSectionVisible();
    visibleSections.babyDoseInf = isBabyDoseInfSectionVisible();
    visibleSections.adolescentDoseInf = isAdolescentDoseInfSectionVisible();
    visibleSections.adolescentDoseInfMore =
        isAdolescentDoseInfMoreSectionVisible();
    visibleSections.adolescentDoseTbl = isAdolescentDoseTblSectionVisible();
    visibleSections.adolescentDoseTblMore =
        isAdolescentDoseTblMoreSectionVisible();
    visibleSections.adolescentDoseInf21 = isAdolescentDoseInf21SectionVisible();
    visibleSections.adolescentDoseTbl221 = isAdolescentDoseTbl221SectionVisible();
    visibleSections.warningKidney = areAllVisibleQuesionsAnswered();
    visibleSections.warningAb = areAllVisibleQuesionsAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
