"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    puberty: false,
    weightKids: false,
    weightAdolescents: false,
    noAnswer1: true,
    miniBabyDoseInf1: true,
    miniBabyDoseInf2: true,
    warningInfusion11: true,
    miniBabyDoseInf3: true,
    warnigEx: true,
    warningDoseMini1: true,
    babyDoseInf1: true,
    babyDoseInf2: true,
    warningInfusion22: true,
    babyDoseInf3: true,
    warnigEx2: true,
    warningDoseBaby1: true,
    kidsDoseTbl1: true,
    kidsDoseTbl2: true,
    kidsDoseTbl3: true,
    kidsDoseTbl1More: true,
    kidsDoseTbl2More: true,
    kidsDoseTbl3More: true,
    kidsDoseInf1: true,
    kidsDoseInf2: true,
    warningInfusion32: true,
    kidsDoseInf3: true,
    kidsDoseInf1More: true,
    kidsDoseInf2More: true,
    warningInfusion32More: true,
    kidsDoseInf3More: true,
    adultDoseTbl1: true,
    adultDoseTbl2: true,
    adultDoseTbl3: true,
    adultDoseInf1: true,
    adultDoseInf2: true,
    warningInfusion42: true,
    adultDoseInf3: true,
    kidney: true,
    anti: true
};
var visibleSections = {
    inputs: true,
    noAnswer: false,
    miniBabyDoseInf: false,
    warningDoseMini: false,
    babyDoseInf: false,
    warningDoseBaby: false,
    kidsDoseTbl: false,
    kidsDoseTblMore: false,
    kidsDoseInf: false,
    kidsDoseInfMore: false,
    adultDoseTbl: false,
    adultDoseInf: false,
    warningKidney: false,
    warningAb: false
};
var inputs = {
    age: null,
    puberty: null,
    weightKids: null,
    weightAdolescents: null
};
var isWeightKidsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 70 });
};
var isWeightAdolescentsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 1, max: 150 });
};
var isPubertyVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adolescent');
};
var isWeightKidsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'miniBaby') ||
        helpers_1.answerMatches(inputs.age, 'baby') ||
        helpers_1.answerMatches(inputs.age, 'kids'));
};
var isWeightAdolescentsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adolescent') &&
        helpers_1.answerMatches(inputs.puberty, 'no'));
};
var areAllVisibleQuesionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.age) &&
        ((isPubertyVisible() && helpers_1.isAnswered(inputs.puberty)) ||
            !isPubertyVisible()) &&
        ((isWeightKidsVisible() && isWeightKidsValid()) ||
            !isWeightKidsVisible()) &&
        ((isWeightAdolescentsVisible() && isWeightAdolescentsValid()) ||
            !isWeightAdolescentsVisible()));
};
var isMiniBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'miniBaby') && isWeightKidsValid();
};
var isBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'baby') && isWeightKidsValid();
};
var isKidsDoseTblSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isKidsDoseTblMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })) ||
        (helpers_1.answerMatches(inputs.age, 'adolescent') &&
            isWeightAdolescentsValid() &&
            isPubertyVisible() &&
            helpers_1.answerMatches(inputs.puberty, 'no')));
};
var isKidsDoseInfSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isKidsDoseInfMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })) ||
        (helpers_1.answerMatches(inputs.age, 'adolescent') &&
            isWeightAdolescentsValid() &&
            isPubertyVisible() &&
            helpers_1.answerMatches(inputs.puberty, 'no')));
};
var isAdultDoseSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var arg3Safety = function () {
    var _a, _b;
    if (isWeightAdolescentsValid()) {
        if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 133.4, max: 150 }))
            return 400;
        return ((_a = inputs.weightAdolescents) === null || _a === void 0 ? void 0 : _a.currentPoints) * 3;
    }
    return ((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 3;
};
var arg6Safety = function () {
    var _a, _b;
    if (isWeightAdolescentsValid()) {
        if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 66.7, max: 150 }))
            return 400;
        return ((_a = inputs.weightAdolescents) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6;
    }
    if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 66.7, max: 70 }))
        return 400;
    return ((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 6;
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1;
    var hasReturn = false;
    var result = {};
    if (isMiniBabyDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = -1;
        var arg12 = -1;
        var arg31 = -1;
        var arg32 = -1;
        var arg21 = (((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 3) / 2;
        var arg22 = ((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 3;
        if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 66.7, max: 70 })) {
            arg11 = 200;
            arg12 = 400;
        }
        else {
            arg11 = (((_c = inputs.weightKids) === null || _c === void 0 ? void 0 : _c.currentPoints) * 6) / 2;
            arg12 = ((_d = inputs.weightKids) === null || _d === void 0 ? void 0 : _d.currentPoints) * 6;
        }
        if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 })) {
            arg31 = 200;
            arg32 = 400;
        }
        else {
            arg31 = (((_e = inputs.weightKids) === null || _e === void 0 ? void 0 : _e.currentPoints) * 12) / 2;
            arg32 = ((_f = inputs.weightKids) === null || _f === void 0 ? void 0 : _f.currentPoints) * 12;
        }
        Object.assign(result, {
            miniBabyDoseInf1: {
                qID: 'miniBabyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            },
            miniBabyDoseInf2: {
                qID: 'miniBabyDoseInf2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                titleTexts: 'result1'
            },
            warningDoseMini1: {
                qID: 'warningDoseMini1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg31, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg32, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isBabyDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = -1;
        var arg12 = -1;
        var arg31 = -1;
        var arg32 = -1;
        var arg21 = (((_g = inputs.weightKids) === null || _g === void 0 ? void 0 : _g.currentPoints) * 3) / 2;
        var arg22 = ((_h = inputs.weightKids) === null || _h === void 0 ? void 0 : _h.currentPoints) * 3;
        if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 66.7, max: 70 })) {
            arg11 = 200;
            arg12 = 400;
        }
        else {
            arg11 = (((_j = inputs.weightKids) === null || _j === void 0 ? void 0 : _j.currentPoints) * 6) / 2;
            arg12 = ((_k = inputs.weightKids) === null || _k === void 0 ? void 0 : _k.currentPoints) * 6;
        }
        if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 })) {
            arg31 = 200;
            arg32 = 400;
        }
        else {
            arg31 = (((_l = inputs.weightKids) === null || _l === void 0 ? void 0 : _l.currentPoints) * 12) / 2;
            arg32 = ((_m = inputs.weightKids) === null || _m === void 0 ? void 0 : _m.currentPoints) * 12;
        }
        Object.assign(result, {
            babyDoseInf1: {
                qID: 'babyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            },
            babyDoseInf2: {
                qID: 'babyDoseInf2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                titleTexts: 'result1'
            },
            warningDoseBaby1: {
                qID: 'warningDoseBaby1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg31, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg32, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isKidsDoseTblSectionVisible()) {
        hasReturn = true;
        var arg11 = ((_o = inputs.weightKids) === null || _o === void 0 ? void 0 : _o.currentPoints) * 6;
        var arg21 = (((_p = inputs.weightKids) === null || _p === void 0 ? void 0 : _p.currentPoints) * 6) / 2;
        Object.assign(result, {
            kidsDoseTbl1: {
                qID: 'kidsDoseTbl1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1)),
                titleTexts: 'result1'
            },
            kidsDoseTbl2: {
                qID: 'kidsDoseTbl2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isKidsDoseTblMoreSectionVisible()) {
        hasReturn = true;
        Object.assign(result, {
            kidsDoseTbl1More: {
                qID: 'kidsDoseTbl1More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg6Safety(), 1), 0, 1)),
                titleTexts: 'result1'
            },
            kidsDoseTbl2More: {
                qID: 'kidsDoseTbl2More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg3Safety(), 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isKidsDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_q = inputs.weightKids) === null || _q === void 0 ? void 0 : _q.currentPoints) * 6) / 2;
        var arg12 = ((_r = inputs.weightKids) === null || _r === void 0 ? void 0 : _r.currentPoints) * 6;
        var arg21 = (((_s = inputs.weightKids) === null || _s === void 0 ? void 0 : _s.currentPoints) * 3) / 2;
        var arg22 = ((_t = inputs.weightKids) === null || _t === void 0 ? void 0 : _t.currentPoints) * 3;
        Object.assign(result, {
            kidsDoseInf1: {
                qID: 'kidsDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            },
            kidsDoseInf2: {
                qID: 'kidsDoseInf2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isKidsDoseInfMoreSectionVisible()) {
        hasReturn = true;
        var arg11 = -1;
        var arg12 = -1;
        var arg21 = -1;
        var arg22 = -1;
        if (isWeightAdolescentsValid()) {
            if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 66.7, max: 150 })) {
                arg11 = 200;
                arg12 = 400;
            }
            else {
                arg11 = (((_u = inputs.weightAdolescents) === null || _u === void 0 ? void 0 : _u.currentPoints) * 6) / 2;
                arg12 = ((_v = inputs.weightAdolescents) === null || _v === void 0 ? void 0 : _v.currentPoints) * 6;
            }
        }
        else {
            if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 66.7, max: 70 })) {
                arg11 = 200;
                arg12 = 400;
            }
            else {
                arg11 = (((_w = inputs.weightKids) === null || _w === void 0 ? void 0 : _w.currentPoints) * 6) / 2;
                arg12 = ((_x = inputs.weightKids) === null || _x === void 0 ? void 0 : _x.currentPoints) * 6;
            }
        }
        if (isWeightAdolescentsValid()) {
            if (helpers_1.numberInLimits({
                input: inputs.weightAdolescents,
                min: 133.4,
                max: 150
            }))
                arg21 = 200;
            else {
                arg21 = (((_y = inputs.weightAdolescents) === null || _y === void 0 ? void 0 : _y.currentPoints) * 3) / 2;
            }
        }
        else {
            arg21 = (((_z = inputs.weightKids) === null || _z === void 0 ? void 0 : _z.currentPoints) * 3) / 2;
        }
        if (isWeightAdolescentsValid()) {
            if (helpers_1.numberInLimits({
                input: inputs.weightAdolescents,
                min: 133.4,
                max: 150
            }))
                arg22 = 400;
            else {
                arg22 = ((_0 = inputs.weightAdolescents) === null || _0 === void 0 ? void 0 : _0.currentPoints) * 3;
            }
        }
        else {
            arg22 = ((_1 = inputs.weightKids) === null || _1 === void 0 ? void 0 : _1.currentPoints) * 3;
        }
        Object.assign(result, {
            kidsDoseInf1More: {
                qID: 'kidsDoseInf1More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            },
            kidsDoseInf2More: {
                qID: 'kidsDoseInf2More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (hasReturn)
        return result;
    else
        return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.puberty = isPubertyVisible();
    visibleQuestions.weightKids = isWeightKidsVisible();
    visibleQuestions.weightAdolescents = isWeightAdolescentsVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = !areAllVisibleQuesionsAnswered();
    visibleSections.miniBabyDoseInf = isMiniBabyDoseInfSectionVisible();
    visibleSections.warningDoseMini = isMiniBabyDoseInfSectionVisible();
    visibleSections.babyDoseInf = isBabyDoseInfSectionVisible();
    visibleSections.warningDoseBaby = isBabyDoseInfSectionVisible();
    visibleSections.kidsDoseTbl = isKidsDoseTblSectionVisible();
    visibleSections.kidsDoseTblMore = isKidsDoseTblMoreSectionVisible();
    visibleSections.kidsDoseInf = isKidsDoseInfSectionVisible();
    visibleSections.kidsDoseInfMore = isKidsDoseInfMoreSectionVisible();
    visibleSections.adultDoseTbl = isAdultDoseSectionVisible();
    visibleSections.adultDoseInf = isAdultDoseSectionVisible();
    visibleSections.warningKidney = areAllVisibleQuesionsAnswered();
    visibleSections.warningAb = areAllVisibleQuesionsAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
