"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    puberty: false,
    weightBaby: false,
    weightKids: false,
    weightAdolescents: false,
    dosing: true,
    miniBabyDoseInf1: true,
    warningInfusion1: true,
    durationMiniBaby1: true,
    warningEx: true,
    babyDoseInf1: true,
    warningInfusion21: true,
    durationBaby1: true,
    warningEx2: true,
    adolescentDoseTbl111: true,
    durationKids1: true,
    adolescentDoseTbl111More: true,
    durationKids1More: true,
    adolescentDoseInf11: true,
    warningInfusion41: true,
    durationKids2: true,
    adolescentDoseInf11More: true,
    warningInfusion41More: true,
    durationKids2More: true,
    adolescentDoseTbl21: true,
    adolescentDoseTbl23: true,
    adolescentDoseInf31: true,
    warningInfusion51: true,
    adolescentDoseInf33: true,
    warningKidney41: true,
    warningAb62: true
};
var visibleSections = {
    ageSelection: true,
    noAnswer: false,
    miniBabyDoseInf: false,
    babyDoseInf: false,
    adolescentDoseTbl: false,
    adolescentDoseTblMore: false,
    adolescentDoseInf: false,
    adolescentDoseInfMore: false,
    adolescentDoseTbl2: false,
    adolescentDoseInf2: false,
    warningKidney4: false,
    warningAb6: false
};
var inputs = {
    age: null,
    puberty: null,
    weightBaby: null,
    weightKids: null,
    weightAdolescents: null
};
var isPubertyVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adolescent');
};
var isWeightBabyVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'miniBaby') || helpers_1.answerMatches(inputs.age, 'baby'));
};
var isWeightKidsVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isWeightAdolescentsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adolescent') &&
        helpers_1.answerMatches(inputs.puberty, 'no'));
};
var isWeightBabiesValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightBaby, min: 1, max: 10 });
};
var isWeightKidsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 70 });
};
var isWeightAdolescentsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 1, max: 150 });
};
var areAllVisibleQuesionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.age) &&
        ((isPubertyVisible() && helpers_1.isAnswered(inputs.puberty)) ||
            !isPubertyVisible()) &&
        ((isWeightBabyVisible() && isWeightBabiesValid()) ||
            !isWeightBabyVisible()) &&
        ((isWeightKidsVisible() && isWeightKidsValid()) ||
            !isWeightKidsVisible()) &&
        ((isWeightAdolescentsVisible() && isWeightAdolescentsValid()) ||
            !isWeightAdolescentsVisible()));
};
var isMiniBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'miniBaby') && isWeightBabiesValid();
};
var isBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'baby') && isWeightBabiesValid();
};
var isAdolescentDoseTblSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isAdolescentDoseTblMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isWeightAdolescentsValid() &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'no')) ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            isWeightKidsValid() &&
            helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })));
};
var isAdolescentDoseInfSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isAdolescentDoseInfMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isWeightAdolescentsValid() &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'no')) ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            isWeightKidsValid() &&
            helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })));
};
var isAdolescentDoseTbl2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var isAdolescentDoseInf2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s;
    var hasReturn = false;
    var result = {};
    if (isMiniBabyDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_a = inputs.weightBaby) === null || _a === void 0 ? void 0 : _a.currentPoints) * 6) / 2;
        var arg12 = ((_b = inputs.weightBaby) === null || _b === void 0 ? void 0 : _b.currentPoints) * 6;
        var arg21 = (((_c = inputs.weightBaby) === null || _c === void 0 ? void 0 : _c.currentPoints) * 12) / 2;
        var arg22 = ((_d = inputs.weightBaby) === null || _d === void 0 ? void 0 : _d.currentPoints) * 12;
        Object.assign(result, {
            miniBabyDoseInf1: {
                qID: 'miniBabyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                resultTexts: 'result1'
            }
        });
    }
    if (isBabyDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_e = inputs.weightBaby) === null || _e === void 0 ? void 0 : _e.currentPoints) * 6) / 2;
        var arg12 = ((_f = inputs.weightBaby) === null || _f === void 0 ? void 0 : _f.currentPoints) * 6;
        var arg21 = (((_g = inputs.weightBaby) === null || _g === void 0 ? void 0 : _g.currentPoints) * 12) / 2;
        var arg22 = ((_h = inputs.weightBaby) === null || _h === void 0 ? void 0 : _h.currentPoints) * 12;
        Object.assign(result, {
            babyDoseInf1: {
                qID: 'babyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                resultTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseTblSectionVisible()) {
        hasReturn = true;
        var arg11 = ((_j = inputs.weightKids) === null || _j === void 0 ? void 0 : _j.currentPoints) * 6;
        Object.assign(result, {
            adolescentDoseTbl111: {
                qID: 'adolescentDoseTbl111',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseTblMoreSectionVisible()) {
        hasReturn = true;
        var arg11 = -1;
        if (isWeightAdolescentsValid()) {
            if (helpers_1.numberInLimits({
                input: inputs.weightAdolescents,
                min: 66.7,
                max: 150
            }))
                arg11 = 400;
            else {
                arg11 = ((_k = inputs.weightAdolescents) === null || _k === void 0 ? void 0 : _k.currentPoints) * 6;
            }
        }
        else {
            if (helpers_1.numberInLimits({
                input: inputs.weightKids,
                min: 66.7,
                max: 70
            }))
                arg11 = 400;
            else {
                arg11 = ((_l = inputs.weightKids) === null || _l === void 0 ? void 0 : _l.currentPoints) * 6;
            }
        }
        Object.assign(result, {
            adolescentDoseTbl111More: {
                qID: 'adolescentDoseTbl111More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_m = inputs.weightKids) === null || _m === void 0 ? void 0 : _m.currentPoints) * 6) / 2;
        var arg12 = ((_o = inputs.weightKids) === null || _o === void 0 ? void 0 : _o.currentPoints) * 6;
        Object.assign(result, {
            adolescentDoseInf11: {
                qID: 'adolescentDoseInf11',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseInfMoreSectionVisible()) {
        hasReturn = true;
        var arg11 = -1;
        var arg12 = -1;
        if (isWeightAdolescentsValid()) {
            if (helpers_1.numberInLimits({
                input: inputs.weightAdolescents,
                min: 66.7,
                max: 150
            })) {
                arg11 = 200;
                arg12 = 400;
            }
            else {
                arg11 = (((_p = inputs.weightAdolescents) === null || _p === void 0 ? void 0 : _p.currentPoints) * 6) / 2;
                arg12 = ((_q = inputs.weightAdolescents) === null || _q === void 0 ? void 0 : _q.currentPoints) * 6;
            }
        }
        else {
            if (helpers_1.numberInLimits({
                input: inputs.weightKids,
                min: 66.7,
                max: 70
            })) {
                arg11 = 200;
                arg12 = 400;
            }
            else {
                arg11 = (((_r = inputs.weightKids) === null || _r === void 0 ? void 0 : _r.currentPoints) * 6) / 2;
                arg12 = ((_s = inputs.weightKids) === null || _s === void 0 ? void 0 : _s.currentPoints) * 6;
            }
        }
        Object.assign(result, {
            adolescentDoseInf11More: {
                qID: 'adolescentDoseInf11More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (hasReturn)
        return result;
    else
        return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.puberty = isPubertyVisible();
    visibleQuestions.weightBaby = isWeightBabyVisible();
    visibleQuestions.weightKids = isWeightKidsVisible();
    visibleQuestions.weightAdolescents = isWeightAdolescentsVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = !areAllVisibleQuesionsAnswered();
    visibleSections.miniBabyDoseInf = isMiniBabyDoseInfSectionVisible();
    visibleSections.babyDoseInf = isBabyDoseInfSectionVisible();
    visibleSections.adolescentDoseTbl = isAdolescentDoseTblSectionVisible();
    visibleSections.adolescentDoseTblMore =
        isAdolescentDoseTblMoreSectionVisible();
    visibleSections.adolescentDoseInf = isAdolescentDoseInfSectionVisible();
    visibleSections.adolescentDoseInfMore =
        isAdolescentDoseInfMoreSectionVisible();
    visibleSections.adolescentDoseTbl2 = isAdolescentDoseTbl2SectionVisible();
    visibleSections.adolescentDoseInf2 = isAdolescentDoseInf2SectionVisible();
    visibleSections.warningKidney4 = areAllVisibleQuesionsAnswered();
    visibleSections.warningAb6 = areAllVisibleQuesionsAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
