"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    puberty: false,
    weightKids: false,
    weightAdolescents: false,
    dosing: true,
    miniBabyDoseInf1: true,
    warningInfusion1: true,
    miniBabyDoseInf2: true,
    warningEx: true,
    babyDoseInf1: true,
    warningInfusion21: true,
    babyDoseInf2: true,
    warningEx2: true,
    adolescentDoseTbl111: true,
    adolescentDoseTbl112: true,
    adolescentDoseTbl111More: false,
    adolescentDoseTbl111LimitMore: false,
    adolescentDoseTbl112More: true,
    adolescentDoseInf11: true,
    warningInfusion41: true,
    adolescentDoseInf12: true,
    adolescentDoseInf11More: false,
    adolescentDoseInf11LimitMore: false,
    warningInfusion41More: true,
    adolescentDoseInf12More: true,
    adolescentDoseTbl21: true,
    adolescentDoseTbl23: true,
    adolescentDoseInf31: true,
    warningInfusion51: true,
    adolescentDoseInf33: true,
    warningKidney41: true,
    warningAb62: true
};
var visibleSections = {
    ageSelection: true,
    noAnswer: false,
    miniBabyDoseInf: false,
    babyDoseInf: false,
    adolescentDoseTbl: false,
    adolescentDoseTblMore: false,
    adolescentDoseInf: false,
    adolescentDoseInfMore: false,
    adolescentDoseTbl2: false,
    adolescentDoseInf2: false,
    warningKidney4: false,
    warningAb6: false
};
var inputs = {
    age: null,
    puberty: null,
    weightKids: null,
    weightAdolescents: null
};
var isWeightKidsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 70 });
};
var isWeightAdolescentsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 1, max: 150 });
};
var isPubertyVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adolescent');
};
var isWeightKidsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'miniBaby') ||
        helpers_1.answerMatches(inputs.age, 'baby') ||
        helpers_1.answerMatches(inputs.age, 'kids'));
};
var isWeightAdolescentsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adolescent') &&
        helpers_1.answerMatches(inputs.puberty, 'no'));
};
var areAllVisibleQuesionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.age) &&
        ((isPubertyVisible() && helpers_1.isAnswered(inputs.puberty)) ||
            !isPubertyVisible()) &&
        ((isWeightKidsVisible() && isWeightKidsValid()) ||
            !isWeightKidsVisible()) &&
        ((isWeightAdolescentsVisible() && isWeightAdolescentsValid()) ||
            !isWeightAdolescentsVisible()));
};
var isWeightLess133 = function () {
    return ((isWeightAdolescentsVisible() &&
        helpers_1.numberInLimits({
            input: inputs.weightAdolescents,
            min: 1,
            max: 133.399
        })) ||
        (isWeightKidsVisible() && isWeightKidsValid()));
};
var isWeightMore133 = function () {
    return (isWeightAdolescentsVisible() &&
        helpers_1.numberInLimits({
            input: inputs.weightAdolescents,
            min: 133.4,
            max: 150
        }));
};
var isMiniBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'miniBaby') && isWeightKidsValid();
};
var isBabyDoseInfSectionVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'baby') && isWeightKidsValid();
};
var isAdolescentDoseTblSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isAdolescentDoseTblMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isWeightAdolescentsValid() &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'no')) ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            isWeightKidsValid() &&
            helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })));
};
var isAdolescentDoseInfSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'kids') &&
        isWeightKidsValid() &&
        helpers_1.numberInLimits({ input: inputs.weightKids, min: 1, max: 29.999 }));
};
var isAdolescentDoseInfMoreSectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isWeightAdolescentsValid() &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'no')) ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            isWeightKidsValid() &&
            helpers_1.numberInLimits({ input: inputs.weightKids, min: 30, max: 70 })));
};
var isAdolescentDoseTbl2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var isAdolescentDoseInf2SectionVisible = function () {
    return ((helpers_1.answerMatches(inputs.age, 'adolescent') &&
        isPubertyVisible() &&
        helpers_1.answerMatches(inputs.puberty, 'yes')) ||
        helpers_1.answerMatches(inputs.age, 'adult'));
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5;
    var hasReturn = false;
    var result = {};
    if (isMiniBabyDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_a = inputs.weightKids) === null || _a === void 0 ? void 0 : _a.currentPoints) * 3) / 2;
        var arg12 = (((_b = inputs.weightKids) === null || _b === void 0 ? void 0 : _b.currentPoints) * 12) / 2;
        var arg13 = ((_c = inputs.weightKids) === null || _c === void 0 ? void 0 : _c.currentPoints) * 3;
        var arg14 = ((_d = inputs.weightKids) === null || _d === void 0 ? void 0 : _d.currentPoints) * 12;
        var arg21 = (((_e = inputs.weightKids) === null || _e === void 0 ? void 0 : _e.currentPoints) * 12) / 2;
        var arg22 = ((_f = inputs.weightKids) === null || _f === void 0 ? void 0 : _f.currentPoints) * 12;
        if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 })) {
            arg12 = 200;
            arg14 = 400;
            arg21 = 200;
            arg22 = 400;
        }
        Object.assign(result, {
            miniBabyDoseInf1: {
                qID: 'miniBabyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg13, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg14, 1), 0, 1)),
                titleTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                resultTexts: 'result1'
            }
        });
    }
    if (isBabyDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_g = inputs.weightKids) === null || _g === void 0 ? void 0 : _g.currentPoints) * 3) / 2;
        var arg12 = (((_h = inputs.weightKids) === null || _h === void 0 ? void 0 : _h.currentPoints) * 12) / 2;
        var arg13 = ((_j = inputs.weightKids) === null || _j === void 0 ? void 0 : _j.currentPoints) * 3;
        var arg14 = ((_k = inputs.weightKids) === null || _k === void 0 ? void 0 : _k.currentPoints) * 12;
        var arg21 = (((_l = inputs.weightKids) === null || _l === void 0 ? void 0 : _l.currentPoints) * 12) / 2;
        var arg22 = ((_m = inputs.weightKids) === null || _m === void 0 ? void 0 : _m.currentPoints) * 12;
        if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 })) {
            arg12 = 200;
            arg14 = 400;
            arg21 = 200;
            arg22 = 400;
        }
        Object.assign(result, {
            babyDoseInf1: {
                qID: 'babyDoseInf1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg13, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg14, 1), 0, 1)),
                titleTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg21, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg22, 1), 0, 1)),
                resultTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseTblSectionVisible()) {
        hasReturn = true;
        var arg11 = ((_o = inputs.weightKids) === null || _o === void 0 ? void 0 : _o.currentPoints) * 3;
        var arg12 = ((_p = inputs.weightKids) === null || _p === void 0 ? void 0 : _p.currentPoints) * 12;
        Object.assign(result, {
            adolescentDoseTbl111: {
                qID: 'adolescentDoseTbl111',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseTblMoreSectionVisible() && isWeightLess133()) {
        hasReturn = true;
        var arg11 = -1;
        var arg12 = -1;
        if (isWeightAdolescentsValid()) {
            arg11 = ((_q = inputs.weightAdolescents) === null || _q === void 0 ? void 0 : _q.currentPoints) * 3;
            if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 33.4, max: 150 }))
                arg12 = 400;
            else
                arg12 = ((_r = inputs.weightAdolescents) === null || _r === void 0 ? void 0 : _r.currentPoints) * 12;
        }
        else {
            arg11 = ((_s = inputs.weightKids) === null || _s === void 0 ? void 0 : _s.currentPoints) * 3;
            if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 }))
                arg12 = 400;
            else
                arg12 = ((_t = inputs.weightKids) === null || _t === void 0 ? void 0 : _t.currentPoints) * 12;
        }
        Object.assign(result, {
            adolescentDoseTbl111More: {
                qID: 'adolescentDoseTbl111More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseInfSectionVisible()) {
        hasReturn = true;
        var arg11 = (((_u = inputs.weightKids) === null || _u === void 0 ? void 0 : _u.currentPoints) * 3) / 2;
        var arg12 = (((_v = inputs.weightKids) === null || _v === void 0 ? void 0 : _v.currentPoints) * 12) / 2;
        var arg13 = ((_w = inputs.weightKids) === null || _w === void 0 ? void 0 : _w.currentPoints) * 3;
        var arg14 = ((_x = inputs.weightKids) === null || _x === void 0 ? void 0 : _x.currentPoints) * 12;
        Object.assign(result, {
            adolescentDoseInf11: {
                qID: 'adolescentDoseInf11',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg13, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg14, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (isAdolescentDoseInfMoreSectionVisible() && isWeightLess133()) {
        hasReturn = true;
        var arg11 = -1;
        var arg12 = -1;
        var arg13 = -1;
        var arg14 = -1;
        if (isWeightAdolescentsValid()) {
            arg11 = (((_y = inputs.weightAdolescents) === null || _y === void 0 ? void 0 : _y.currentPoints) * 3) / 2;
            arg13 = ((_z = inputs.weightAdolescents) === null || _z === void 0 ? void 0 : _z.currentPoints) * 3;
            if (helpers_1.numberInLimits({ input: inputs.weightAdolescents, min: 33.4, max: 150 })) {
                arg12 = 200;
                arg14 = 400;
            }
            else {
                arg12 = (((_0 = inputs.weightAdolescents) === null || _0 === void 0 ? void 0 : _0.currentPoints) * 12) / 2;
                arg14 = ((_1 = inputs.weightAdolescents) === null || _1 === void 0 ? void 0 : _1.currentPoints) * 12;
            }
        }
        else {
            arg11 = (((_2 = inputs.weightKids) === null || _2 === void 0 ? void 0 : _2.currentPoints) * 3) / 2;
            arg13 = ((_3 = inputs.weightKids) === null || _3 === void 0 ? void 0 : _3.currentPoints) * 3;
            if (helpers_1.numberInLimits({ input: inputs.weightKids, min: 33.4, max: 70 })) {
                arg12 = 200;
                arg14 = 400;
            }
            else {
                arg12 = (((_4 = inputs.weightKids) === null || _4 === void 0 ? void 0 : _4.currentPoints) * 12) / 2;
                arg14 = ((_5 = inputs.weightKids) === null || _5 === void 0 ? void 0 : _5.currentPoints) * 12;
            }
        }
        Object.assign(result, {
            adolescentDoseInf11More: {
                qID: 'adolescentDoseInf11More',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg11, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg12, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg13, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(arg14, 1), 0, 1)),
                titleTexts: 'result1'
            }
        });
    }
    if (hasReturn)
        return result;
    else
        return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.puberty = isPubertyVisible();
    visibleQuestions.weightKids = isWeightKidsVisible();
    visibleQuestions.weightAdolescents = isWeightAdolescentsVisible();
    visibleQuestions.adolescentDoseTbl111More = isWeightLess133();
    visibleQuestions.adolescentDoseTbl111LimitMore = isWeightMore133();
    visibleQuestions.adolescentDoseInf11More = isWeightLess133();
    visibleQuestions.adolescentDoseInf11LimitMore = isWeightMore133();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = !areAllVisibleQuesionsAnswered();
    visibleSections.miniBabyDoseInf = isMiniBabyDoseInfSectionVisible();
    visibleSections.babyDoseInf = isBabyDoseInfSectionVisible();
    visibleSections.adolescentDoseTbl = isAdolescentDoseTblSectionVisible();
    visibleSections.adolescentDoseTblMore =
        isAdolescentDoseTblMoreSectionVisible();
    visibleSections.adolescentDoseInf = isAdolescentDoseInfSectionVisible();
    visibleSections.adolescentDoseInfMore =
        isAdolescentDoseInfMoreSectionVisible();
    visibleSections.adolescentDoseTbl2 = isAdolescentDoseTbl2SectionVisible();
    visibleSections.adolescentDoseInf2 = isAdolescentDoseInf2SectionVisible();
    visibleSections.warningKidney4 = areAllVisibleQuesionsAnswered();
    visibleSections.warningAb6 = areAllVisibleQuesionsAnswered();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuesionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
