"use strict";


var visibleQuestions = {
    age: true,
    weight: false,
    noAnswerResult: true,
    contraindicationKids: false,
    adults50Dose: false,
    adults50Duration: false,
    adults50to59DOse: false,
    adults50to59Duration: false,
    adults60to69Dose: false,
    adults60to69Duration: false,
    adults70to79Dose: false,
    adults70to79Duration: false,
    adults80to89Dose: false,
    adults80to89Duration: false,
    adults90Dose: false,
    adults90Duration: false,
    warning: false,
    infoKidneyFunction: false,
    infoKidney: false,
    infoAdministration: false,
    info: false
};
var visibleSections = {
    inputQuestions: true,
    noAnswer: true,
    kidsResult: false,
    adults50: false,
    adults50to59: false,
    adults60to69: false,
    adults70to79: false,
    adults80to89: false,
    adults90: false,
    warningPlatlets: false,
    kidneyFunction: false,
    administering: false
};
var inputs = {
    age: null,
    weight: null,
    infoKidneyFunction: null,
    infoAdministration: null
};
var calculatePoints = function () {
    return null;
};
var isAgeKids = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isAgeAdults = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isWeightLess50 = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 49 }));
};
var isWeight50to59 = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 50, max: 59 }));
};
var isWeight60to69 = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 60, max: 69 }));
};
var isWeight70to79 = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 70, max: 79 }));
};
var isWeight80to89 = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 80, max: 89 }));
};
var isWeight90 = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 90, max: 200 }));
};
var isOnlyAdults = function () {
    return (isAgeAdults() && helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 }));
};
var isInfoKidneyFunction = function () {
    return isOnlyAdults() && helpers_1.answerMatches(inputs.infoKidneyFunction, 'close');
};
var isInfoAdministrationFunction = function () {
    return isOnlyAdults() && helpers_1.answerMatches(inputs.infoAdministration, 'close');
};
var isAnswerallVisible = function () {
    return !(isAgeKids() ||
        (isAgeAdults() &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 })));
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isAgeAdults();
    visibleQuestions.noAnswerResult = isAnswerallVisible();
    visibleQuestions.contraindicationKids = isAgeKids();
    visibleQuestions.adults50Dose = isWeightLess50();
    visibleQuestions.adults50Duration = isWeightLess50();
    visibleQuestions.adults50to59DOse = isWeight50to59();
    visibleQuestions.adults50to59Duration = isWeight50to59();
    visibleQuestions.adults60to69Dose = isWeight60to69();
    visibleQuestions.adults60to69Duration = isWeight60to69();
    visibleQuestions.adults70to79Dose = isWeight70to79();
    visibleQuestions.adults70to79Duration = isWeight70to79();
    visibleQuestions.adults80to89Dose = isWeight80to89();
    visibleQuestions.adults80to89Duration = isWeight80to89();
    visibleQuestions.adults90Dose = isWeight90();
    visibleQuestions.adults90Duration = isWeight90();
    visibleQuestions.warning = isOnlyAdults();
    visibleQuestions.infoKidneyFunction = isOnlyAdults();
    visibleQuestions.infoKidney = isInfoKidneyFunction();
    visibleQuestions.infoAdministration = isOnlyAdults();
    visibleQuestions.info = isInfoAdministrationFunction();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isAnswerallVisible();
    visibleSections.kidsResult = isAgeKids();
    visibleSections.adults50 = isWeightLess50();
    visibleSections.adults50to59 = isWeight50to59();
    visibleSections.adults60to69 = isWeight60to69();
    visibleSections.adults70to79 = isWeight70to79();
    visibleSections.adults80to89 = isWeight80to89();
    visibleSections.adults90 = isWeight90();
    visibleSections.warningPlatlets = isOnlyAdults();
    visibleSections.kidneyFunction = isOnlyAdults();
    visibleSections.administering = isOnlyAdults();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isAnswerallVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
