"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};



var visibleQuestions = {
    equation: true,
    gender: true,
    blackRace: true,
    age: true,
    creatinine: true
};
var visibleSections = {
    patientInfo: true
};
var inputs = {
    equation: null,
    gender: null,
    blackRace: null,
    age: null,
    creatinine: null
};
var isAgeValid = function () {
    return helpers_1.numberInLimits({ input: inputs.age, min: 1, max: 120 });
};
var isCreatinineValid = function () {
    var _a;
    switch ((_a = inputs.creatinine) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µmol/L':
            return helpers_1.numberInLimits({ input: inputs.creatinine, min: 1, max: 3500 });
        case 'mg/dL':
            return helpers_1.numberInLimits({ input: inputs.creatinine, min: 0.1, max: 40 });
        default:
            return false;
    }
};
var areAllAnswered = function () {
    return (helpers_1.isAnswered(inputs.gender) &&
        helpers_1.isAnswered(inputs.blackRace) &&
        isAgeValid() &&
        isCreatinineValid());
};
var calculateScore = function () {
    var _a;
    switch ((_a = inputs.equation) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'mdrd':
            return helpers_1.formatCalculationResult(resultIfEquationMdrd());
        case 'cdkepi':
            return helpers_1.formatCalculationResult(resultIfEquationCdkepi());
        default:
            return 0;
    }
};
var convertedCreatinineMdrd = function () {
    var _a, _b, _c;
    switch ((_a = inputs.creatinine) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'mg/dL':
            return (Number((_b = inputs.creatinine) === null || _b === void 0 ? void 0 : _b.currentPoints) * units_1["default"].creatinine.mgDlTOuMolL);
        case 'µmol/L':
            return Number((_c = inputs.creatinine) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var convertedCreatinineCdkepi = function () {
    var _a, _b, _c;
    switch ((_a = inputs.creatinine) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'mg/dL':
            return Number((_b = inputs.creatinine) === null || _b === void 0 ? void 0 : _b.currentPoints);
        case 'µmol/L':
            return Number((_c = inputs.creatinine) === null || _c === void 0 ? void 0 : _c.currentPoints) * 0.011312217194570135;
        default:
            return 0;
    }
};
var resultIfEquationMdrd = function () {
    var _a, _b, _c;
    var result = 0;
    var multiplicatorBlackRace = ((_a = inputs.blackRace) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'black' ? 1.212 : 1;
    var multiplicatorGender = ((_b = inputs.gender) === null || _b === void 0 ? void 0 : _b.currentIdentifier) === 'male' ? 1 : 0.742;
    result =
        32788 *
            Math.pow(convertedCreatinineMdrd(), -1.154) *
            Math.pow(Number((_c = inputs.age) === null || _c === void 0 ? void 0 : _c.currentPoints), -0.203) *
            multiplicatorBlackRace *
            multiplicatorGender;
    return result;
};
var resultIfEquationCdkepi = function () {
    var _a, _b, _c, _d, _e;
    var result = 0;
    var k = ((_a = inputs.gender) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'male' ? 0.9 : 0.7;
    var a = ((_b = inputs.gender) === null || _b === void 0 ? void 0 : _b.currentIdentifier) === 'male' ? -0.411 : -0.329;
    var multiplicatorBlackRace = ((_c = inputs.blackRace) === null || _c === void 0 ? void 0 : _c.currentIdentifier) === 'black' ? 1.159 : 1;
    var multiplicatorGender = ((_d = inputs.gender) === null || _d === void 0 ? void 0 : _d.currentIdentifier) === 'male' ? 1 : 1.018;
    result =
        141 *
            Math.pow(Math.min(convertedCreatinineCdkepi() / k, 1), a) *
            Math.pow(Math.max(convertedCreatinineCdkepi() / k, 1), -1.209) *
            Math.pow(0.993, Number((_e = inputs.age) === null || _e === void 0 ? void 0 : _e.currentPoints)) *
            multiplicatorGender *
            multiplicatorBlackRace;
    return result;
};
var calculatePoints = function () {
    if (!areAllAnswered()) {
        return helpers_1.returnToolScoreObject({});
    }
    var score = calculateScore();
    return helpers_1.returnToolScoreObject({ number: score, range: score });
};
var returnVisibleQuestions = function () {
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return areAllAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return __assign(__assign({ exportResultsEnabled: isExportResultsEnabled() }, result), { visibleQuestions: ut_visibleQuestions(), visibleSections: ut_visibleSections() });
});
