"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};

var dictionary = [];


var visibleQuestions = {
    birthDay: true,
    sex: false,
    measurementDate: false,
    height: false,
    weight: false,
    answerAll: false,
    more19: false,
    result1: false,
    result2: false,
    weightOver10: false,
    result3Thinness: false,
    result3NormalWeight: false,
    result3Overweight: false,
    result3Obesity: false,
    roundingResultOneMonth: false,
    roundingResultMonths: false,
    roundingResultYears: false
};
var visibleSections = {
    section1: true,
    section2: false,
    notAnswered: false,
    results: false,
    roundingWarning: false,
    resultsMore19: false
};
var inputs = {
    birthDay: null,
    sex: null,
    measurementDate: null,
    height: null,
    weight: null
};
var getTextType = function (score) {
    return score < 0 ? 'regular' : 'positive';
};
var isBirthDayAnswered = function () {
    return helpers_1.isAnsweredDate(inputs.birthDay);
};
var isSexAnswered = function () {
    return helpers_1.isAnswered(inputs.sex);
};
var isMeasurementDateAnswered = function () {
    return helpers_1.isAnsweredDate(inputs.measurementDate) && isAgeLess19();
};
var isHeightAnswered = function () {
    return helpers_1.numberInLimits({
        input: inputs.height,
        min: 1,
        max: 250
    });
};
var isWeightAnswered = function () {
    return helpers_1.numberInLimits({
        input: inputs.weight,
        min: 1,
        max: 200
    });
};
var areAllQuestionsAnswered = function () {
    return (isBirthDayAnswered() &&
        isSexAnswered() &&
        isMeasurementDateAnswered() &&
        isHeightAnswered() &&
        isWeightAnswered());
};
var calculateAgeInMonths = function () {
    return Math.round(calculateAgeInMonthsDecimal());
};
var calculateAgeInMonthsDecimal = function () {
    if (!helpers_1.isAnsweredDate(inputs.measurementDate) ||
        !helpers_1.isAnsweredDate(inputs.birthDay))
        return 0;
    var diff = helpers_1.unixToDate(Number(inputs.measurementDate.currentDate)).getTime() -
        helpers_1.unixToDate(Number(inputs.birthDay.currentDate)).getTime();
    var diffInDays = diff / (1000 * 60 * 60 * 24);
    return diffInDays / 30.4;
};
var isRoundingResultOneMonthVisible = function () {
    var monthsDecimal = calculateAgeInMonthsDecimal();
    return (monthsDecimal >= 0.5 &&
        calculateAgeInMonths() <= 1 &&
        areAllQuestionsAnswered());
};
var isRoundingResultMonthsVisible = function () {
    var months = calculateAgeInMonths();
    return months > 1 && months <= 12 && areAllQuestionsAnswered();
};
var isRoundingResultYearsVisible = function () {
    var months = calculateAgeInMonths();
    return months > 12 && months <= 19 * 12 && areAllQuestionsAnswered();
};
var isAgeLess10 = function () {
    var ageInYears = calculateAgeInMonths() / 12;
    return ageInYears <= 10;
};
var isAgeLess19 = function () {
    return calculateAgeInMonths() <= 19 * 12;
};
var calculateBMIZScore = function () {
    var BMIZScore = calculateZScore(calculateBMI(), 2, false);
    return helpers_1.formatCalculationResult(BMIZScore, 1);
};
var isWeightOver10Visible = function () {
    return areAllQuestionsAnswered() && !isAgeLess10() && isAgeLess19();
};
var isResult3ThinnessVisible = function () {
    return isAgeLess19() && calculateBMIZScore() < -2;
};
var isResult3NormalWeightVisible = function () {
    return (isAgeLess19() && calculateBMIZScore() >= -2 && calculateBMIZScore() <= 1);
};
var isResult3OverweightVisible = function () {
    return isAgeLess19() && calculateBMIZScore() > 1 && calculateBMIZScore() <= 2;
};
var isResult3ObesityVisible = function () {
    return isAgeLess19() && calculateBMIZScore() > 2;
};
var returnVisibleQuestions = function () {
    visibleQuestions.sex = isBirthDayAnswered();
    visibleQuestions.measurementDate = isSexAnswered();
    visibleQuestions.height = isMeasurementDateAnswered();
    visibleQuestions.weight = isMeasurementDateAnswered();
    visibleQuestions.answerAll = !areAllQuestionsAnswered() && isAgeLess19();
    visibleQuestions.more19 = !isAgeLess19();
    visibleQuestions.result1 = areAllQuestionsAnswered() && isAgeLess19();
    visibleQuestions.result2 = areAllQuestionsAnswered() && isAgeLess10();
    visibleQuestions.weightOver10 =
        areAllQuestionsAnswered() && isWeightOver10Visible();
    visibleQuestions.result3Thinness =
        areAllQuestionsAnswered() && isResult3ThinnessVisible();
    visibleQuestions.result3NormalWeight =
        areAllQuestionsAnswered() && isResult3NormalWeightVisible();
    visibleQuestions.result3Overweight =
        areAllQuestionsAnswered() && isResult3OverweightVisible();
    visibleQuestions.result3Obesity =
        areAllQuestionsAnswered() && isResult3ObesityVisible();
    visibleQuestions.roundingResultOneMonth = isRoundingResultOneMonthVisible();
    visibleQuestions.roundingResultMonths = isRoundingResultMonthsVisible();
    visibleQuestions.roundingResultYears = isRoundingResultYearsVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.section2 = isSexAnswered();
    visibleSections.notAnswered = !areAllQuestionsAnswered() && isAgeLess19();
    visibleSections.results = areAllQuestionsAnswered();
    visibleSections.roundingWarning =
        isRoundingResultOneMonthVisible() ||
            isRoundingResultMonthsVisible() ||
            isRoundingResultYearsVisible();
    visibleSections.resultsMore19 = !isAgeLess19();
    return visibleSections;
};
var calculateZScore = function (input, index, isHeight) {
    var sexIndex = helpers_1.answerMatches(inputs.sex, 'male') ? 0 : 1;
    var inputData = dictionary[sexIndex][index];
    var ageInMonths = calculateAgeInMonths() < 1 && isHeight
        ? calculateAgeInMonthsDecimal()
        : calculateAgeInMonths();
    var resultData = inputData.find(function (item) { return item.months === ageInMonths; });
    if (!resultData) {
        return 0;
    }
    return ((Math.pow(input / resultData.median, resultData.power) - 1) /
        (resultData.power * resultData.coefficient));
};
var calculatePercentile = function (zScore) {
    return 0.5 * (1 + math_1.erf(zScore / Math.sqrt(2.0))) * 100;
};
var calculateBMI = function () {
    return (Number(inputs.weight.currentPoints) /
        Math.pow(Number(inputs.height.currentPoints) / 100, 2));
};
var calculateRoundingWarning = function () {
    if (isRoundingResultMonthsVisible()) {
        var months = calculateAgeInMonths();
        var roundingResultMonths = {
            roundingResultMonths: {
                qID: 'roundingResultMonths',
                rParams: [],
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(months, 0), 0, 0)),
                titleTexts: 'result1'
            }
        };
        return roundingResultMonths;
    }
    if (isRoundingResultYearsVisible()) {
        var allMonths = calculateAgeInMonths();
        var years = allMonths / 12;
        var monthsFromRemainder = allMonths % 12;
        var roundingResultYears = {
            roundingResultYears: {
                qID: 'roundingResultYears',
                rParams: [],
                tParams: __spreadArrays(helpers_1.returnNumberObject(Math.floor(years), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(monthsFromRemainder, 0), 0, 0)),
                titleTexts: 'result1'
            }
        };
        return roundingResultYears;
    }
    return null;
};
var calculatePoints = function () {
    var roundingWarningQuestion = calculateRoundingWarning();
    if (!areAllQuestionsAnswered() || !isAgeLess19()) {
        if (roundingWarningQuestion !== null) {
            return __assign({}, roundingWarningQuestion);
        }
        return null;
    }
    var heightZScore = calculateZScore(Number(inputs.height.currentPoints), 0, true);
    var heightPercentile = calculatePercentile(heightZScore);
    var weightZScore = calculateZScore(Number(inputs.weight.currentPoints), 1, false);
    var weightPercentile = calculatePercentile(weightZScore);
    var BMI = calculateBMI();
    var BMIZScore = calculateZScore(BMI, 2, false);
    var BMIPercentile = calculatePercentile(BMIZScore);
    var result1 = {
        qID: 'result1',
        rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(heightPercentile), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(heightZScore, 1), 1, 1)),
        tParams: [],
        resultTexts: getTextType(heightZScore),
        titleTexts: 'result1'
    };
    var result2 = {
        qID: 'result2',
        rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weightPercentile), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weightZScore, 1), 1, 1)),
        tParams: [],
        resultTexts: getTextType(weightZScore),
        titleTexts: 'result1'
    };
    if (isResult3ThinnessVisible()) {
        var result3Thinness = {
            qID: 'result3Thinness',
            rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMI, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIPercentile), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIZScore, 1), 1, 1)),
            tParams: [],
            resultTexts: getTextType(BMIZScore),
            titleTexts: 'result1'
        };
        if (isAgeLess10()) {
            return __assign({ result1: result1,
                result2: result2,
                result3Thinness: result3Thinness }, roundingWarningQuestion);
        }
        return __assign({ result1: result1,
            result3Thinness: result3Thinness }, roundingWarningQuestion);
    }
    if (isResult3NormalWeightVisible()) {
        var result3NormalWeight = {
            qID: 'result3NormalWeight',
            rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMI, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIPercentile), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIZScore, 1), 1, 1)),
            tParams: [],
            resultTexts: getTextType(BMIZScore),
            titleTexts: 'result1'
        };
        if (isAgeLess10()) {
            return __assign({ result1: result1,
                result2: result2,
                result3NormalWeight: result3NormalWeight }, roundingWarningQuestion);
        }
        return __assign({ result1: result1,
            result3NormalWeight: result3NormalWeight }, roundingWarningQuestion);
    }
    if (isResult3OverweightVisible()) {
        var result3Overweight = {
            qID: 'result3Overweight',
            rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMI, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIPercentile), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIZScore, 1), 1, 1)),
            tParams: [],
            resultTexts: getTextType(BMIZScore),
            titleTexts: 'result1'
        };
        if (isAgeLess10()) {
            return __assign({ result1: result1,
                result2: result2,
                result3Overweight: result3Overweight }, roundingWarningQuestion);
        }
        return __assign({ result1: result1,
            result3Overweight: result3Overweight }, roundingWarningQuestion);
    }
    if (isResult3ObesityVisible()) {
        var result3Obesity = {
            qID: 'result3Obesity',
            rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMI, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIPercentile), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(BMIZScore, 1), 1, 1)),
            tParams: [],
            resultTexts: getTextType(BMIZScore),
            titleTexts: 'result1'
        };
        if (isAgeLess10()) {
            return __assign({ result1: result1,
                result2: result2,
                result3Obesity: result3Obesity }, roundingWarningQuestion);
        }
        return __assign({ result1: result1,
            result3Obesity: result3Obesity }, roundingWarningQuestion);
    }
    return null;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return areAllQuestionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
