"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: true,
    height: true,
    hypertension: true,
    atrial: true,
    pulmonaryHypertension: true,
    fillingRatio: true,
    low: false,
    middle: false,
    high: false,
    noAnswerPoints: false,
    probability: true,
    noAnswer: true,
    noAnswerInfo: true
};
var visibleSections = {
    questions: true,
    totalScoreResult: true,
    probabilityResult: false,
    probabilityResultNoAnswerNoFooter: false
};
var inputs = {
    age: null,
    weight: null,
    height: null,
    hypertension: null,
    atrial: null,
    pulmonaryHypertension: null,
    fillingRatio: null
};
var isAgeValid = function () {
    return helpers_1.numberInLimits({
        input: inputs.age,
        min: 18,
        max: 130
    });
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({
        input: inputs.weight,
        min: 30,
        max: 200
    });
};
var isHeightValid = function () {
    return helpers_1.numberInLimits({
        input: inputs.height,
        min: 140,
        max: 250
    });
};
var isPulmonaryHypertensionValid = function () {
    return helpers_1.numberInLimits({
        input: inputs.pulmonaryHypertension,
        min: 0,
        max: 150
    });
};
var isFillingRatioValid = function () {
    return helpers_1.numberInLimits({
        input: inputs.fillingRatio,
        min: 0,
        max: 100
    });
};
var areAllAnswered = function () {
    return (isAgeValid() &&
        isWeightValid() &&
        isHeightValid() &&
        isPulmonaryHypertensionValid() &&
        isFillingRatioValid() &&
        helpers_1.isAnswered(inputs.hypertension) &&
        helpers_1.isAnswered(inputs.atrial));
};
var agePoints = function () {
    return helpers_1.numberInLimits({
        input: inputs.age,
        min: 18,
        max: 60
    })
        ? 0
        : 1;
};
var bmiPoints = function () {
    return calculateBMI() <= 30 ? 0 : 2;
};
var hypertensionPoints = function () {
    return helpers_1.answerMatches(inputs.hypertension, 'less2') ? 0 : 1;
};
var atrialPoints = function () {
    return helpers_1.answerMatches(inputs.atrial, 'noAf') ? 0 : 3;
};
var pulmonaryHypertensionPoints = function () {
    return helpers_1.numberInLimits({
        input: inputs.pulmonaryHypertension,
        min: 0,
        max: 35
    })
        ? 0
        : 1;
};
var fillingRatioPoints = function () {
    return helpers_1.numberInLimits({
        input: inputs.fillingRatio,
        min: 0,
        max: 9
    })
        ? 0
        : 1;
};
var calculateBMI = function () {
    var _a, _b;
    if (!(isWeightValid() && isHeightValid()))
        return 0;
    return helpers_1.formatCalculationResult(Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) /
        Math.pow(Number((_b = inputs.height) === null || _b === void 0 ? void 0 : _b.currentPoints) / 100, 2), 4);
};
var calculateSumOfPoints = function () {
    return (agePoints() +
        bmiPoints() +
        hypertensionPoints() +
        atrialPoints() +
        pulmonaryHypertensionPoints() +
        fillingRatioPoints());
};
var isProbabilityResultVisible = function () {
    return (isAgeValid() &&
        isWeightValid() &&
        isHeightValid() &&
        isPulmonaryHypertensionValid() &&
        isFillingRatioValid() &&
        helpers_1.isAnswered(inputs.atrial));
};
var calculateProbability = function () {
    var _a, _b, _c;
    if (isProbabilityResultVisible()) {
        var atrial = helpers_1.answerMatches(inputs.atrial, 'yesAf') ? 1 : 0;
        var result = Math.exp(-9.19174463966566 +
            0.0451129471272832 * Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints) +
            0.130730156015681 * calculateBMI() +
            0.0858634402456586 * Number((_b = inputs.fillingRatio) === null || _b === void 0 ? void 0 : _b.currentPoints) +
            0.051963758732548 *
                Number((_c = inputs.pulmonaryHypertension) === null || _c === void 0 ? void 0 : _c.currentPoints) +
            1.69968057294513 * atrial);
        return (result / (1 + result)) * 100;
    }
    return 0;
};
var isResultLowVisible = function () {
    return areAllAnswered() && calculateSumOfPoints() < 2;
};
var isResultMiddleVisible = function () {
    return (areAllAnswered() &&
        calculateSumOfPoints() >= 2 &&
        calculateSumOfPoints() <= 5);
};
var isResultHighVisible = function () {
    return areAllAnswered() && calculateSumOfPoints() >= 6;
};
var calculatePoints = function () {
    var resultLow = 0;
    var resultMiddle = 0;
    var resultHigh = 0;
    if (isResultLowVisible()) {
        resultLow = calculateSumOfPoints();
    }
    if (isResultMiddleVisible()) {
        resultMiddle = calculateSumOfPoints();
    }
    if (isResultHighVisible()) {
        resultHigh = calculateSumOfPoints();
    }
    return {
        probability: {
            qID: 'probability',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateProbability(), 1), 0, 1)),
            titleTexts: 'result1'
        },
        low: {
            qID: 'low',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(resultLow, 1), 0, 1)),
            titleTexts: 'result1'
        },
        middle: {
            qID: 'middle',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(resultMiddle, 1), 0, 1)),
            titleTexts: 'result1'
        },
        high: {
            qID: 'high',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(resultHigh, 1), 0, 1)),
            titleTexts: 'result1'
        }
    };
};
var returnVisibleQuestions = function () {
    visibleQuestions.low = isResultLowVisible();
    visibleQuestions.middle = isResultMiddleVisible();
    visibleQuestions.high = isResultHighVisible();
    visibleQuestions.noAnswerPoints = !areAllAnswered();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.probabilityResult = isProbabilityResultVisible();
    visibleSections.probabilityResultNoAnswerNoFooter =
        !isProbabilityResultVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
