"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};


var visibleQuestions = {
    immunofixation: true,
    immunofixationNormalFLC: false,
    serumUrineReduction: false,
    questionProteins: false,
    serumUrineReductionHigher: false,
    serumUrineReductionMinimal: false,
    questionFLC: false,
    decreaseFLC: false,
    plasmaReduction: false,
    imagingBaseline: false,
    plasmocytomas: false,
    prog1: false,
    prog2: false,
    prog3: false,
    prog4: false,
    prog5: false,
    prog6: false,
    prog7: false,
    prog8: false,
    prog9: false
};
var visibleSections = {
    criteriaChoice: true,
    progression: false
};
var inputs = {
    immunofixation: null,
    immunofixationNormalFLC: null,
    serumUrineReduction: null,
    questionProteins: null,
    serumUrineReductionHigher: null,
    serumUrineReductionMinimal: null,
    questionFLC: null,
    decreaseFLC: null,
    plasmaReduction: null,
    imagingBaseline: null,
    plasmocytomas: null,
    prog1: null,
    prog2: null,
    prog3: null,
    prog4: null,
    prog5: null,
    prog6: null,
    prog7: null,
    prog8: null,
    prog9: null
};
var isQuestionsProteinsVisible = function () {
    return (helpers_1.answerMatches(inputs.immunofixation, 'no') &&
        helpers_1.answerMatches(inputs.serumUrineReduction, 'no'));
};
var isProg9Visible = function () {
    return isQuestionFLCNoWhenVisible() && isImagingBaselineNoWhenVisible();
};
var isImmunofixationAnsweredYes = function () {
    return helpers_1.answerMatches(inputs.immunofixation, 'yes');
};
var isImmunofixationAnsweredNo = function () {
    return helpers_1.answerMatches(inputs.immunofixation, 'no');
};
var isQuestionProteinsYesWhenVisible = function () {
    return (helpers_1.answerMatches(inputs.questionProteins, 'yes') &&
        isQuestionsProteinsVisible());
};
var isQuestionProteinsNoWhenVisible = function () {
    return (helpers_1.answerMatches(inputs.questionProteins, 'no') && isQuestionsProteinsVisible());
};
var isQuestionFLCNoWhenVisible = function () {
    return (isQuestionProteinsNoWhenVisible() && helpers_1.answerMatches(inputs.questionFLC, 'no'));
};
var isQuestionFLCYesWhenVisible = function () {
    return (isQuestionProteinsNoWhenVisible() &&
        helpers_1.answerMatches(inputs.questionFLC, 'yes'));
};
var isDecreaseFLCYesWhenVisible = function () {
    return (isQuestionFLCYesWhenVisible() && helpers_1.answerMatches(inputs.decreaseFLC, 'yes'));
};
var isImagingBaselineYesWhenVisible = function () {
    return (helpers_1.answerMatches(inputs.imagingBaseline, 'yes') && isImmunofixationAnsweredNo());
};
var isImagingBaselineNoWhenVisible = function () {
    return (helpers_1.answerMatches(inputs.imagingBaseline, 'no') && isImmunofixationAnsweredNo());
};
var isSerumUrineReductionMinimalYesWhenVisible = function () {
    return (isQuestionProteinsYesWhenVisible() &&
        helpers_1.answerMatches(inputs.serumUrineReductionMinimal, 'yes'));
};
var isPlasmaReductionAnsweredYesWhenVisible = function () {
    return (isQuestionFLCNoWhenVisible() && helpers_1.answerMatches(inputs.plasmaReduction, 'yes'));
};
var isSerumUrineReductionHigherYes = function () {
    return (helpers_1.answerMatches(inputs.serumUrineReductionHigher, 'yes') &&
        isQuestionsProteinsVisible());
};
var isPlasmocytomasVisible = function () {
    var firstCondition = isImagingBaselineYesWhenVisible() && isSerumUrineReductionHigherYes();
    var secondCondition = isImagingBaselineYesWhenVisible() &&
        isSerumUrineReductionMinimalYesWhenVisible();
    var thirdCondition = isImagingBaselineYesWhenVisible() && isDecreaseFLCYesWhenVisible();
    var fourthCondition = isImagingBaselineYesWhenVisible() &&
        isPlasmaReductionAnsweredYesWhenVisible();
    return firstCondition || secondCondition || thirdCondition || fourthCondition;
};
var isProgressionVisible = function () {
    var firstCondition = isSerumUrineReductionMinimalYesWhenVisible() &&
        isSerumUrineReductionHigherYes();
    var secondCondition = isImmunofixationAnsweredNo() ||
        isQuestionProteinsYesWhenVisible() ||
        isImagingBaselineYesWhenVisible() ||
        isQuestionFLCYesWhenVisible() ||
        isQuestionFLCNoWhenVisible();
    return !firstCondition && secondCondition;
};
var isResultStringentVisible = function () {
    return (isImmunofixationAnsweredYes() &&
        helpers_1.answerMatches(inputs.immunofixationNormalFLC, 'yes'));
};
var isResultCompleteVisible = function () {
    return (isImmunofixationAnsweredYes() &&
        helpers_1.answerMatches(inputs.immunofixationNormalFLC, 'no'));
};
var isResultVeryGoodPartialVisible = function () {
    var firstCondition = isImmunofixationAnsweredNo() &&
        isSerumUrineReductionYes() &&
        isImagingBaselineNoWhenVisible() &&
        isProg6AnsweredNo();
    var secondCondition = isImmunofixationAnsweredNo() &&
        isSerumUrineReductionYes() &&
        isImagingBaselineYesWhenVisible() &&
        isProg6AnsweredNo() &&
        isProg7NoWhenVisible() &&
        isProg8NoWhenVisible();
    return firstCondition || secondCondition;
};
var prog123AnsweredNoIfVisible = function () {
    return isQuestionProteinsYesWhenVisible()
        ? helpers_1.answerMatches(inputs.prog1, 'no') &&
            helpers_1.answerMatches(inputs.prog2, 'no') &&
            helpers_1.answerMatches(inputs.prog3, 'no')
        : true;
};
var isSerumUrineReductionYes = function () {
    return (isImmunofixationAnsweredNo() &&
        helpers_1.answerMatches(inputs.serumUrineReduction, 'yes'));
};
var isProg1YesWhenVisible = function () {
    return (isQuestionProteinsYesWhenVisible() && helpers_1.answerMatches(inputs.prog1, 'yes'));
};
var isProg2YesWhenVisible = function () {
    return (isQuestionProteinsYesWhenVisible() && helpers_1.answerMatches(inputs.prog2, 'yes'));
};
var isProg3YesWhenVisible = function () {
    return (isQuestionProteinsYesWhenVisible() && helpers_1.answerMatches(inputs.prog3, 'yes'));
};
var isProg4YesWhenVisible = function () {
    return isQuestionFLCYesWhenVisible() && helpers_1.answerMatches(inputs.prog4, 'yes');
};
var isProg5YesWhenVisible = function () {
    return isQuestionFLCNoWhenVisible() && helpers_1.answerMatches(inputs.prog5, 'yes');
};
var isProg6YesWhenVisible = function () {
    return isImmunofixationAnsweredNo() && helpers_1.answerMatches(inputs.prog6, 'yes');
};
var isProg7YesWhenVisible = function () {
    return (isImagingBaselineYesWhenVisible() && helpers_1.answerMatches(inputs.prog7, 'yes'));
};
var isProg8YesWhenVisible = function () {
    return (isImagingBaselineYesWhenVisible() && helpers_1.answerMatches(inputs.prog8, 'yes'));
};
var isProg9YesWhenVisible = function () {
    return isProg9Visible() && helpers_1.answerMatches(inputs.prog9, 'yes');
};
var isProg6AnsweredNo = function () {
    return helpers_1.answerMatches(inputs.prog6, 'no') && isImmunofixationAnsweredNo();
};
var isProg7NoWhenVisible = function () {
    return helpers_1.answerMatches(inputs.prog7, 'no') && isImagingBaselineYesWhenVisible();
};
var isProg8NoWhenVisible = function () {
    return helpers_1.answerMatches(inputs.prog8, 'no') && isImagingBaselineYesWhenVisible();
};
var prog4AnsweredNoIfVisible = function () {
    return isQuestionFLCYesWhenVisible()
        ? helpers_1.answerMatches(inputs.prog4, 'no')
        : true;
};
var prog5AnsweredNoIfVisible = function () {
    return isQuestionFLCNoWhenVisible()
        ? helpers_1.answerMatches(inputs.prog5, 'no')
        : true;
};
var prog6AnsweredNoIfVisible = function () {
    return isImmunofixationAnsweredNo()
        ? helpers_1.answerMatches(inputs.prog6, 'no')
        : true;
};
var prog7And8AnsweredNoIfVisible = function () {
    return isImagingBaselineYesWhenVisible()
        ? helpers_1.answerMatches(inputs.prog7, 'no') && helpers_1.answerMatches(inputs.prog8, 'no')
        : true;
};
var prog9AnsweredNoIfVisible = function () {
    return isProg9Visible() ? helpers_1.answerMatches(inputs.prog9, 'no') : true;
};
var areAllVisibleQuestionsInProgressionNo = function () {
    return (prog123AnsweredNoIfVisible() &&
        prog4AnsweredNoIfVisible() &&
        prog5AnsweredNoIfVisible() &&
        prog6AnsweredNoIfVisible() &&
        prog7And8AnsweredNoIfVisible() &&
        prog9AnsweredNoIfVisible());
};
var isPlasmocytomasAnsweredYes = function () {
    return isPlasmocytomasVisible() && helpers_1.answerMatches(inputs.plasmocytomas, 'yes');
};
var plasmocytomasAnsweredYesIfVisible = function () {
    return isPlasmocytomasVisible()
        ? helpers_1.answerMatches(inputs.plasmocytomas, 'yes')
        : true;
};
var immunofixationNormalFLCAnsweredNoIfVisible = function () {
    return isImmunofixationAnsweredYes()
        ? helpers_1.answerMatches(inputs.immunofixationNormalFLC, 'no')
        : true;
};
var serumUrineReductionAnsweredNoIfVisible = function () {
    return isQuestionProteinsYesWhenVisible()
        ? helpers_1.answerMatches(inputs.serumUrineReductionHigher, 'no') &&
            helpers_1.answerMatches(inputs.serumUrineReduction, 'no')
        : true;
};
var questionFLCAnsweredNoIfVisible = function () {
    return isQuestionProteinsNoWhenVisible()
        ? helpers_1.answerMatches(inputs.questionFLC, 'no')
        : true;
};
var decreaseFLCAnsweredNoIfVisible = function () {
    return isQuestionFLCYesWhenVisible()
        ? helpers_1.answerMatches(inputs.decreaseFLC, 'no')
        : true;
};
var plasmaReductionAnsweredNoIfVisible = function () {
    return isQuestionFLCNoWhenVisible()
        ? helpers_1.answerMatches(inputs.plasmaReduction, 'no')
        : true;
};
var isResultPartialVisible = function () {
    var firstCondition = isSerumUrineReductionHigherYes() ||
        isDecreaseFLCYesWhenVisible() ||
        isPlasmaReductionAnsweredYesWhenVisible();
    return (firstCondition &&
        areAllVisibleQuestionsInProgressionNo() &&
        plasmocytomasAnsweredYesIfVisible());
};
var isResultMinimalVisible = function () {
    return (plasmocytomasAnsweredYesIfVisible() &&
        immunofixationNormalFLCAnsweredNoIfVisible() &&
        serumUrineReductionAnsweredNoIfVisible() &&
        questionFLCAnsweredNoIfVisible() &&
        decreaseFLCAnsweredNoIfVisible() &&
        plasmaReductionAnsweredNoIfVisible() &&
        areAllVisibleQuestionsInProgressionNo() &&
        isSerumUrineReductionMinimalYesWhenVisible() &&
        isQuestionProteinsYesWhenVisible() &&
        helpers_1.isAnswered(inputs.imagingBaseline) &&
        isImmunofixationAnsweredNo());
};
var isResultProgressionYesVisible = function () {
    var firstCondition = isProg1YesWhenVisible() ||
        isProg2YesWhenVisible() ||
        isProg3YesWhenVisible() ||
        isProg4YesWhenVisible() ||
        isProg5YesWhenVisible() ||
        isProg6YesWhenVisible() ||
        isProg7YesWhenVisible() ||
        isProg8YesWhenVisible() ||
        isProg9YesWhenVisible();
    var secondCondition = !isResultWarningMProteinVisible() &&
        !isResultWarningImagingVisible() &&
        !isResultWarningFLCVisible() &&
        !isResultWarningPlasmaVisible() &&
        !isResultWarningProteinAndImagingVisible() &&
        !isResultWarningFLCAndImagingVisible() &&
        !isResultWarningPlasmaAndImagingVisible();
    return firstCondition && secondCondition;
};
var isResultWarningMProteinVisible = function () {
    var firstCondition = isSerumUrineReductionMinimalYesWhenVisible() &&
        isSerumUrineReductionHigherYes();
    var secondCondition = isSerumUrineReductionMinimalYesWhenVisible() ||
        isSerumUrineReductionHigherYes();
    var thirdCondition = isProg1YesWhenVisible() ||
        isProg2YesWhenVisible() ||
        isProg3YesWhenVisible();
    return firstCondition || (secondCondition && thirdCondition);
};
var isResultWarningImagingVisible = function () {
    var firstCondition = isPlasmocytomasAnsweredYes() && isProg7YesWhenVisible();
    var secondCondition = isPlasmocytomasAnsweredYes() && isProg8YesWhenVisible();
    var thirdCondition = isPlasmocytomasAnsweredYes() &&
        isProg7YesWhenVisible() &&
        isProg8YesWhenVisible();
    return firstCondition || secondCondition || thirdCondition;
};
var isResultWarningFLCVisible = function () {
    return isDecreaseFLCYesWhenVisible() && isProg4YesWhenVisible();
};
var isResultWarningPlasmaVisible = function () {
    return isPlasmaReductionAnsweredYesWhenVisible() && isProg5YesWhenVisible();
};
var isResultWarningProteinAndImagingVisible = function () {
    return isResultWarningMProteinVisible() && isResultWarningImagingVisible();
};
var isResultWarningFLCAndImagingVisible = function () {
    return isResultWarningFLCVisible() && isResultWarningImagingVisible();
};
var isResultWarningPlasmaAndImagingVisible = function () {
    return isResultWarningPlasmaVisible() && isResultWarningImagingVisible();
};
var calculatePoints = function () {
    if (isResultStringentVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'stringent' });
    }
    if (isResultCompleteVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'complete' });
    }
    if (isResultVeryGoodPartialVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'veryGoodPartial' });
    }
    if (isResultMinimalVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'minimal' });
    }
    if (isResultWarningProteinAndImagingVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningProteinAndImaging' });
    }
    if (isResultWarningFLCAndImagingVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningFLCAndImaging' });
    }
    if (isResultWarningPlasmaAndImagingVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningPlasmaAndImaging' });
    }
    if (isResultWarningMProteinVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningMProtein' });
    }
    if (isResultProgressionYesVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'progressionYes' });
    }
    if (isResultWarningImagingVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningImaging' });
    }
    if (isResultWarningFLCVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningFLC' });
    }
    if (isResultWarningPlasmaVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'warningPlasma' });
    }
    if (isResultPartialVisible()) {
        return helpers_1.returnToolScoreObject({ resultById: 'partial' });
    }
    return helpers_1.returnToolScoreObject({ resultById: 'stable' });
};
var returnVisibleQuestions = function () {
    visibleQuestions.immunofixationNormalFLC = isImmunofixationAnsweredYes();
    visibleQuestions.serumUrineReduction = isImmunofixationAnsweredNo();
    visibleQuestions.questionProteins = isQuestionsProteinsVisible();
    visibleQuestions.serumUrineReductionHigher =
        isQuestionProteinsYesWhenVisible();
    visibleQuestions.serumUrineReductionMinimal =
        isQuestionProteinsYesWhenVisible();
    visibleQuestions.questionFLC = isQuestionProteinsNoWhenVisible();
    visibleQuestions.decreaseFLC = isQuestionFLCYesWhenVisible();
    visibleQuestions.plasmaReduction = isQuestionFLCNoWhenVisible();
    visibleQuestions.imagingBaseline = isImmunofixationAnsweredNo();
    visibleQuestions.plasmocytomas = isPlasmocytomasVisible();
    visibleQuestions.prog1 =
        isProgressionVisible() && isQuestionProteinsYesWhenVisible();
    visibleQuestions.prog2 =
        isProgressionVisible() && isQuestionProteinsYesWhenVisible();
    visibleQuestions.prog3 =
        isProgressionVisible() && isQuestionProteinsYesWhenVisible();
    visibleQuestions.prog4 =
        isProgressionVisible() && isQuestionFLCYesWhenVisible();
    visibleQuestions.prog5 =
        isProgressionVisible() && isQuestionFLCNoWhenVisible();
    visibleQuestions.prog6 =
        isProgressionVisible() && isImmunofixationAnsweredNo();
    visibleQuestions.prog7 =
        isProgressionVisible() && isImagingBaselineYesWhenVisible();
    visibleQuestions.prog8 =
        isProgressionVisible() && isImagingBaselineYesWhenVisible();
    visibleQuestions.prog9 = isProg9Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.progression = isProgressionVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return (!isResultWarningProteinAndImagingVisible() &&
        !isResultWarningFLCAndImagingVisible() &&
        !isResultWarningPlasmaAndImagingVisible() &&
        !isResultWarningMProteinVisible() &&
        !isResultWarningImagingVisible() &&
        !isResultWarningFLCVisible() &&
        !isResultWarningPlasmaVisible());
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return __assign(__assign({ exportResultsEnabled: isExportResultsEnabled() }, result), { visibleQuestions: ut_visibleQuestions(), visibleSections: ut_visibleSections() });
});
