"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    version: true,
    activeJointCount: true,
    physicianGlobalAssessment: true,
    parentPatient: true,
    erythrocyteSedimentationRate: true,
    answerVersion: false,
    answer1: false,
    inactiveO1: false,
    minimalO1: false,
    moderateO1: false,
    highO1: false,
    answer2: false,
    inactiveP1: false,
    minimalP1: false,
    moderateP1: false,
    highP1: false,
    answerAll1: false,
    inactiveO: false,
    minimalO: false,
    moderateO: false,
    highO: false,
    answerAll2: false,
    inactiveP: false,
    minimalP: false,
    moderateP: false,
    highP: false
};
var visibleSections = {
    section1: true,
    notAnsweredSection: false,
    resultRange3: false,
    resultRange4: false,
    resultRange1: false,
    resultRange2: false
};
var inputs = {
    version: null,
    activeJointCount: null,
    physicianGlobalAssessment: null,
    parentPatient: null,
    erythrocyteSedimentationRate: null
};
var calculateESRValue = function () {
    var _a, _b;
    var ESRValue = 20;
    if (Number((_a = inputs.erythrocyteSedimentationRate) === null || _a === void 0 ? void 0 : _a.currentPoints) > 120) {
        ESRValue = 120;
    }
    if (helpers_1.numberInLimits({
        input: inputs.erythrocyteSedimentationRate,
        min: 20,
        max: 120
    })) {
        ESRValue = Number((_b = inputs.erythrocyteSedimentationRate) === null || _b === void 0 ? void 0 : _b.currentPoints);
    }
    return (ESRValue - 20) / 10;
};
var PGAValue = function () {
    var _a, _b, _c;
    switch ((_a = inputs.physicianGlobalAssessment) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'cm':
            return Number((_b = inputs.physicianGlobalAssessment) === null || _b === void 0 ? void 0 : _b.currentPoints);
        case 'mm':
            return Number((_c = inputs.physicianGlobalAssessment) === null || _c === void 0 ? void 0 : _c.currentPoints) / 10;
        default:
            return 0;
    }
};
var parentPatientValue = function () {
    var _a, _b, _c;
    switch ((_a = inputs.parentPatient) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'cm':
            return Number((_b = inputs.parentPatient) === null || _b === void 0 ? void 0 : _b.currentPoints);
        case 'mm':
            return Number((_c = inputs.parentPatient) === null || _c === void 0 ? void 0 : _c.currentPoints) / 10;
        default:
            return 0;
    }
};
var JADASResult = function () {
    var _a;
    return helpers_1.formatCalculationResult(Number((_a = inputs.activeJointCount) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        PGAValue() +
        parentPatientValue() +
        calculateESRValue(), 1);
};
var cJADASResult = function () {
    var _a;
    return helpers_1.formatCalculationResult(Number((_a = inputs.activeJointCount) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        PGAValue() +
        parentPatientValue(), 1);
};
var activeJointCountInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.activeJointCount,
        min: 0,
        max: 10
    });
};
var physicianGlobalAssessmentInLimits = function () {
    var _a;
    switch ((_a = inputs.physicianGlobalAssessment) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'cm':
            return helpers_1.numberInLimits({
                input: inputs.physicianGlobalAssessment,
                min: 0,
                max: 10
            });
        case 'mm':
            return helpers_1.numberInLimits({
                input: inputs.physicianGlobalAssessment,
                min: 0,
                max: 100
            });
        default:
            return false;
    }
};
var parentPatientInLimits = function () {
    var _a;
    switch ((_a = inputs.parentPatient) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'cm':
            return helpers_1.numberInLimits({
                input: inputs.parentPatient,
                min: 0,
                max: 10
            });
        case 'mm':
            return helpers_1.numberInLimits({
                input: inputs.parentPatient,
                min: 0,
                max: 100
            });
        default:
            return false;
    }
};
var erythrocyteSedimentationRateInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.erythrocyteSedimentationRate,
        min: 0,
        max: 200
    });
};
var isResultRange1Visible = function () {
    return helpers_1.answerMatches(inputs.version, 'oligoarthritis');
};
var isResultRange2Visible = function () {
    return helpers_1.answerMatches(inputs.version, 'polyarthritis');
};
var isAnswerAllVisible = function () {
    return (!activeJointCountInLimits() ||
        !physicianGlobalAssessmentInLimits() ||
        !parentPatientInLimits() ||
        !erythrocyteSedimentationRateInLimits());
};
var isNotAnsweredSectionVisible = function () {
    return !helpers_1.isAnswered(inputs.version);
};
var isAnswerVisible = function () {
    return (!activeJointCountInLimits() ||
        !physicianGlobalAssessmentInLimits() ||
        !parentPatientInLimits());
};
var calculatePoints = function () {
    var resInactiveO1 = 0;
    var resMinimalO1 = 0;
    var resModerateO1 = 0;
    var resHighO1 = 0;
    var resInactiveO = 0;
    var resMinimalO = 0;
    var resModerateO = 0;
    var resHighO = 0;
    var resInactiveP1 = 0;
    var resMinimalP1 = 0;
    var resModerateP1 = 0;
    var resHighP1 = 0;
    var resInactiveP = 0;
    var resMinimalP = 0;
    var resModerateP = 0;
    var resHighP = 0;
    if (isResultRange1Visible()) {
        if (cJADASResult() <= 1.1 && !isAnswerVisible()) {
            resInactiveO1 = cJADASResult();
        }
        if (cJADASResult() >= 1.2 && cJADASResult() <= 4 && !isAnswerVisible()) {
            resMinimalO1 = cJADASResult();
        }
        if (cJADASResult() >= 4.1 && cJADASResult() <= 12 && !isAnswerVisible()) {
            resModerateO1 = cJADASResult();
        }
        if (cJADASResult() > 12 && !isAnswerVisible()) {
            resHighO1 = cJADASResult();
        }
        if (JADASResult() <= 1.4 && !isAnswerAllVisible()) {
            resInactiveO = JADASResult();
        }
        if (JADASResult() >= 1.5 && JADASResult() <= 4 && !isAnswerAllVisible()) {
            resMinimalO = JADASResult();
        }
        if (JADASResult() >= 4.1 && JADASResult() <= 13 && !isAnswerAllVisible()) {
            resModerateO = JADASResult();
        }
        if (JADASResult() > 13 && !isAnswerAllVisible()) {
            resHighO = JADASResult();
        }
    }
    if (isResultRange2Visible()) {
        if (cJADASResult() <= 2.5 && !isAnswerVisible()) {
            resInactiveP1 = cJADASResult();
        }
        if (cJADASResult() >= 2.6 && cJADASResult() <= 5 && !isAnswerVisible()) {
            resMinimalP1 = cJADASResult();
        }
        if (cJADASResult() >= 5.1 && cJADASResult() <= 16 && !isAnswerVisible()) {
            resModerateP1 = cJADASResult();
        }
        if (cJADASResult() > 16 && !isAnswerVisible()) {
            resHighP1 = cJADASResult();
        }
        if (JADASResult() <= 2.7 && !isAnswerAllVisible()) {
            resInactiveP = JADASResult();
        }
        if (JADASResult() >= 2.8 && JADASResult() <= 6 && !isAnswerAllVisible()) {
            resMinimalP = JADASResult();
        }
        if (JADASResult() >= 6.1 && JADASResult() <= 17 && !isAnswerAllVisible()) {
            resModerateP = JADASResult();
        }
        if (JADASResult() > 17 && !isAnswerAllVisible()) {
            resHighP = JADASResult();
        }
    }
    return {
        inactiveO1: {
            qID: 'inactiveO1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resInactiveO1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        minimalO1: {
            qID: 'minimalO1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resMinimalO1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        moderateO1: {
            qID: 'moderateO1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resModerateO1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        highO1: {
            qID: 'highO1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resHighO1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        inactiveO: {
            qID: 'inactiveO',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resInactiveO, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        minimalO: {
            qID: 'minimalO',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resMinimalO, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        moderateO: {
            qID: 'moderateO',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resModerateO, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        highO: {
            qID: 'highO',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resHighO, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        inactiveP1: {
            qID: 'inactiveP1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resInactiveP1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        minimalP1: {
            qID: 'minimalP1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resMinimalP1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        moderateP1: {
            qID: 'moderateP1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resModerateP1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        highP1: {
            qID: 'highP1',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resHighP1, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        inactiveP: {
            qID: 'inactiveP',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resInactiveP, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        minimalP: {
            qID: 'minimalP',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resMinimalP, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        moderateP: {
            qID: 'moderateP',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resModerateP, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        highP: {
            qID: 'highP',
            tParams: [],
            rParams: __spreadArrays(helpers_1.returnNumberObject(resHighP, 0, 1)),
            titleTexts: 'result1',
            resultTexts: 'result1'
        }
    };
};
var returnVisibleQuestions = function () {
    visibleQuestions.answerVersion = isNotAnsweredSectionVisible();
    visibleQuestions.answer1 = isAnswerVisible() && isResultRange1Visible();
    visibleQuestions.inactiveO1 =
        isResultRange1Visible() && cJADASResult() <= 1.1 && !isAnswerVisible();
    visibleQuestions.minimalO1 =
        isResultRange1Visible() &&
            cJADASResult() >= 1.2 &&
            cJADASResult() <= 4 &&
            !isAnswerVisible();
    visibleQuestions.moderateO1 =
        isResultRange1Visible() &&
            cJADASResult() >= 4.1 &&
            cJADASResult() <= 12 &&
            !isAnswerVisible();
    visibleQuestions.highO1 =
        isResultRange1Visible() && cJADASResult() > 12 && !isAnswerVisible();
    visibleQuestions.answer2 = isAnswerVisible() && isResultRange2Visible();
    visibleQuestions.inactiveP1 =
        isResultRange2Visible() && cJADASResult() <= 2.5 && !isAnswerVisible();
    visibleQuestions.minimalP1 =
        isResultRange2Visible() &&
            cJADASResult() >= 2.6 &&
            cJADASResult() <= 5 &&
            !isAnswerVisible();
    visibleQuestions.moderateP1 =
        isResultRange2Visible() &&
            cJADASResult() >= 5.1 &&
            cJADASResult() <= 16 &&
            !isAnswerVisible();
    visibleQuestions.highP1 =
        isResultRange2Visible() && cJADASResult() > 16 && !isAnswerVisible();
    visibleQuestions.answerAll1 = isResultRange1Visible() && isAnswerAllVisible();
    visibleQuestions.inactiveO =
        isResultRange1Visible() && JADASResult() <= 1.4 && !isAnswerAllVisible();
    visibleQuestions.minimalO =
        isResultRange1Visible() &&
            JADASResult() >= 1.5 &&
            JADASResult() <= 4 &&
            !isAnswerAllVisible();
    visibleQuestions.moderateO =
        isResultRange1Visible() &&
            JADASResult() >= 4.1 &&
            JADASResult() <= 13 &&
            !isAnswerAllVisible();
    visibleQuestions.highO =
        isResultRange1Visible() && JADASResult() > 13 && !isAnswerAllVisible();
    visibleQuestions.answerAll2 = isResultRange2Visible() && isAnswerAllVisible();
    visibleQuestions.inactiveP =
        isResultRange2Visible() && JADASResult() <= 2.7 && !isAnswerAllVisible();
    visibleQuestions.minimalP =
        isResultRange2Visible() &&
            JADASResult() >= 2.8 &&
            JADASResult() <= 6 &&
            !isAnswerAllVisible();
    visibleQuestions.moderateP =
        isResultRange2Visible() &&
            JADASResult() >= 6.1 &&
            JADASResult() <= 17 &&
            !isAnswerAllVisible();
    visibleQuestions.highP =
        isResultRange2Visible() && JADASResult() > 17 && !isAnswerAllVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.notAnsweredSection = isNotAnsweredSectionVisible();
    visibleSections.resultRange3 = isResultRange1Visible();
    visibleSections.resultRange4 = isResultRange2Visible();
    visibleSections.resultRange1 = isResultRange1Visible();
    visibleSections.resultRange2 = isResultRange2Visible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
