"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var isNotPlaceholder = function (question) {
    if (!question)
        return false;
    if (question.currentIdentifier !== null &&
        question.currentIdentifier !== 'emptyAnswerIdentifier' &&
        question.currentIdentifier !== 'placeholder') {
        return true;
    }
    return false;
};
var helpers_1 = {

    isAnswered: function (question) {
        if (!question)
            return false;
        if (question.type === 'number' && question.currentPoints !== null) {
            return true;
        }
        if (question.type === 'segmented' &&
            question.currentPoints !== null &&
            isNotPlaceholder(question)) {
            return true;
        }
        if (question.type === 'dropdown' &&
            question.currentPoints !== null &&
            isNotPlaceholder(question)) {
            return true;
        }
        if (question.type === 'boolean' || question.type === 'booleanGallery') {
            return true;
        }
        if (question.type === 'toolLink' &&
            (question.currentPoints !== null || isNotPlaceholder(question))) {
            return true;
        }
        if (question.type === 'date' && question.currentDate !== null) {
            return true;
        }
        if (question.type === null || question.type === undefined) {
            if (question.currentPoints !== null && isNotPlaceholder(question))
                return true;
            if (question.currentDate !== null)
                return true;
            if (isNotPlaceholder(question))
                return true;
        }
        return false;
    },

    addMonths: function(date, months) {
        var d = new Date(date * 1000);
        var years = Math.floor(months / 12);
        var month = months - years * 12;
        if (years)
            d.setFullYear(d.getFullYear() + years);
        if (month)
            d.setMonth(d.getMonth() + month);
        return Math.floor(d.getTime() / 1000);
    },

    addDaysToDate: function(date, numberOfDays) {
        var newDate = new Date(Number(date) * 1000);
        newDate.setDate(newDate.getDate() + numberOfDays);
        return Math.floor(newDate.getTime() / 1000);
    },

    addMonthsToDate: function(date, numberOfMonths) {
        if (!date)
            return null;
        return helpers_1.addMonths(Number(date), numberOfMonths);
    },

    differenceBetweenDates: function(startDate, endDate, unit) {
        var start = new Date(startDate * 1000);
            var end = new Date(endDate * 1000);
            var diff = Math.round(start.getTime() - end.getTime());
        switch (unit) {
            case 'weeks':
                  return diff / 1000 / 60 / 60 / 24 / 7;
                case 'days':
                  return diff / 1000 / 60 / 60 / 24;
                case 'months': {
                  return Math.max(
                    (end.getFullYear() - start.getFullYear()) * 12 +
                      end.getMonth() -
                      start.getMonth(),
                    0
                  );
                }
                case 'years': {
                  var diff_1 = end.getFullYear() - start.getFullYear();
                              return diff_1;
                }
        }
        return 0;
    },

    isAnsweredDate: function(question) {
        if (!question)
            return false;
        if (question.currentDate !== null)
            return true;
        if (helpers_1.isNotPlaceholder(question))
            return true;
        return false;
    },

    isNotPlaceholder: function(question) {
        if (!question)
            return false;
        if (question.currentIdentifier !== null &&
            question.currentIdentifier !== "emptyAnswerIdentifier" &&
            question.currentIdentifier !== "placeholder") {
            return true;
        }
        return false
    },

    formatCalculationResult: function (number, decimals) {
        if (decimals === void 0) { decimals = 0; }
        if (Number.isInteger(number)) {
            return number;
        }
        var multiplier = decimals > 0 ? Math.pow(10, decimals) : Math.pow(10, 0);
        var epsilonCorrection = number * multiplier * (1 + Number.EPSILON);
        return Number(numberRounding_1.roundNumber(epsilonCorrection / multiplier, decimals));
    },

   generatePropsObject: function (currentIdentifier, currentPoints, currentDate, type, data, questionId) {
       return {
           currentIdentifier: currentIdentifier,
           currentPoints: currentPoints,
           currentDate: currentDate,
           type: type,
           data: data,
           questionId: questionId
       };
   },

  generateQuestionObject: function (currentIdentifier, currentPoints, currentDate, type, data, questionId) {
       return {
           currentIdentifier: currentIdentifier,
           currentPoints: currentPoints,
           currentDate: currentDate,
           type: type,
           data: data,
           questionId: questionId
       };
   },

    returnNumberObject: function(value, minFractions, maxFractions) {
        if (minFractions === void 0) {
            minFractions = 0;
        }
        if (maxFractions === void 0) {
            maxFractions = 2;
        }
        return [{
            type: "number",
            value: value,
            minFractions: minFractions,
            maxFractions: maxFractions
        }];
    },

    answerMatches: function(question, answer) {
        return helpers_1.isAnswered(question) && question.currentIdentifier === answer;
    },

    inLimits: function (input, min, max) {
        if (min === void 0) { min = null; }
        if (max === void 0) { max = null; }
        return (input !== null &&
            (min === null || Number(input) >= min) &&
            (max === null || Number(input) <= max));
    },

    numberInLimits: function (_a) {
        var input = _a.input, _b = _a.min, min = _b === void 0 ? null : _b, _c = _a.max, max = _c === void 0 ? null : _c;
        return helpers_1.isAnswered(input) && helpers_1.inLimits(input === null || input === void 0 ? void 0 : input.currentPoints, min, max);
    },

    returnToolScoreObject: function (_a) {
        var _b = _a.number, number = _b === void 0 ? null : _b, _c = _a.range, range = _c === void 0 ? null : _c, _d = _a.title, title = _d === void 0 ? null : _d, _e = _a.subtitle, subtitle = _e === void 0 ? null : _e, _f = _a.resultById, resultById = _f === void 0 ? null : _f, _g = _a.activityLevel, activityLevel = _g === void 0 ? null : _g;
        return __assign(__assign({}, (resultById && { resultById: resultById })), { result: __assign(__assign(__assign({ number: number,
                range: range }, (title && { title: title })), (subtitle && { subtitle: subtitle })), (activityLevel && { activityLevel: activityLevel })) });
    },

     unixToDate: function (timestamp) {
            return new Date(timestamp * 1000);
        },

    dateToUnix: function (year, month, day) {
        return Math.floor(new Date(year, month, day).getTime() / 1000);
    },

   differenceBetweenMonths: function (start, end) {
       var startBiggerThanEnd = start > end;
       var startDate = startBiggerThanEnd ? end : start;
       var endDate = startBiggerThanEnd ? start : end;
       var yearsDifference = endDate.getFullYear() - startDate.getFullYear();
       var monthsDifference = endDate.getMonth() - startDate.getMonth();
       var daysDifference = endDate.getDate() - startDate.getDate();
       var monthCorrection = daysDifference / 30.437;
       return yearsDifference * 12 + monthsDifference + monthCorrection;
   },

};
