"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    CVRisk: true,
    baselineLDL: false,
    riskModifiers: false,
    reclassification: false,
    reCVRisk1: false,
    reCVRisk2: false,
    lifestyle: false,
    considerDrugTx: false,
    drugTx: false,
    drugTxIndication: false,
    noDrugTx: false,
    goalLow: false,
    goalModerate: false,
    goalHigh: false,
    goalVeryHigh: false,
    reductionPercent: false,
    highestStatin: false,
    goalReached1: false,
    addEzetimibe: false,
    addEzetimibe2: false,
    followup1: false,
    goalReached2: false,
    continueSE1: false,
    lifeStyle1: false,
    followup2: false,
    FH: false,
    CVD: false,
    addPCSK9: false,
    smpcLink1: false,
    smpcLink2: false,
    continueSE2: false,
    followup3: false,
    followup4: false,
    followup5: false,
    PCSK9Centers: true
};
var visibleSections = {
    section1: true,
    section2: false,
    section3: false,
    additionalInfo: true
};
var inputs = {
    CVRisk: null,
    baselineLDL: null,
    reclassification: null,
    reCVRisk1: null,
    reCVRisk2: null,
    drugTxIndication: null,
    goalReached1: null,
    goalReached2: null,
    FH: null,
    CVD: null
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e;
    var goal = 0;
    var baselineLDL = helpers_1.isAnswered(inputs.baselineLDL)
        ? Number((_a = inputs.baselineLDL) === null || _a === void 0 ? void 0 : _a.currentPoints)
        : null;
    var reclass = visibleAndHasValue("reclassification", 1);
    if (!reclass
        ? ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 1
        : visibleAndHasValue("reCVRisk1", 1) || visibleAndHasValue("reCVRisk2", 1)) {
        goal = 3;
    }
    else if (!reclass
        ? ((_c = inputs.CVRisk) === null || _c === void 0 ? void 0 : _c.currentPoints) === 2
        : visibleAndHasValue("reCVRisk1", 2) || visibleAndHasValue("reCVRisk2", 2)) {
        goal = 2.6;
    }
    else if (!reclass
        ? ((_d = inputs.CVRisk) === null || _d === void 0 ? void 0 : _d.currentPoints) === 3
        : visibleAndHasValue("reCVRisk1", 3) || visibleAndHasValue("reCVRisk2", 3)) {
        goal = 1.8;
    }
    else if (!reclass
        ? ((_e = inputs.CVRisk) === null || _e === void 0 ? void 0 : _e.currentPoints) === 4
        : visibleAndHasValue("reCVRisk1", 4) || visibleAndHasValue("reCVRisk2", 4)) {
        goal = 1.4;
    }
    var result = 0;
    if (goal !== 0 &&
        baselineLDL !== null &&
        baselineLDL !== undefined &&
        baselineLDL !== 0) {
        result = 100 - (goal * 100) / baselineLDL;
    }
    var res = {
        number: 0,
        range: 0,
        riskModifiers: {
            qID: "riskModifiers",
            resultTexts: "regular"
        },
        lifestyle: {
            qID: "lifestyle",
            resultTexts: "regular"
        },
        considerDrugTx: {
            qID: "considerDrugTx",
            resultTexts: "regular"
        },
        drugTx: {
            qID: "drugTx",
            resultTexts: "regular"
        },
        noDrugTx: {
            qID: "noDrugTx",
            resultTexts: "regular"
        },
        goalLow: {
            qID: "goalLow",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        goalModerate: {
            qID: "goalModerate",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        goalHigh: {
            qID: "goalHigh",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        goalVeryHigh: {
            qID: "goalVeryHigh",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        reductionPercent: {
            qID: "reductionPercent",
            rParams: __spreadArrays(helpers_1.returnNumberObject(result >= 0 && visibleQuestions.reductionPercent
                ? Math.round(result * 10) / 10
                : 0, 0, 1)),
            titleTexts: "regular",
            resultTexts: "regular"
        },
        highestStatin: {
            qID: "highestStatin",
            resultTexts: "regular"
        },
        addEzetimibe: {
            qID: "addEzetimibe",
            resultTexts: "regular"
        },
        addEzetimibe2: {
            qID: "addEzetimibe2",
            resultTexts: "regular"
        },
        followup1: {
            qID: "followup1",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        continueSE1: {
            qID: "continueSE1",
            resultTexts: "regular"
        },
        lifeStyle1: {
            qID: "lifeStyle1",
            resultTexts: "regular"
        },
        followup2: {
            qID: "followup2",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        addPCSK9: {
            qID: "addPCSK9",
            resultTexts: "regular"
        },
        continueSE2: {
            qID: "continueSE2",
            resultTexts: "regular"
        },
        followup3: {
            qID: "followup3",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        followup4: {
            qID: "followup4",
            resultTexts: "regular"
        },
        followup5: {
            qID: "followup5",
            resultTexts: "regular"
        }
    };
    return res;
};
var visibleAndHasValue = function (item, value) {
    var _a;
    return (visibleQuestions[item] === true &&
        helpers_1.isAnswered(inputs[item]) &&
        ((_a = inputs[item]) === null || _a === void 0 ? void 0 : _a.currentPoints) === value);
};
var returnVisibleQuestions = function () {
    return visibleQuestions;
};
var returnVisibleSections = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12, _13, _14, _15, _16, _17, _18, _19, _20, _21, _22, _23, _24, _25, _26, _27, _28, _29, _30;
    visibleQuestions.baselineLDL = helpers_1.isAnswered(inputs.CVRisk);
    visibleQuestions.riskModifiers =
        helpers_1.isAnswered(inputs.baselineLDL) &&
            (((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1 || ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 2);
    visibleQuestions.reclassification =
        helpers_1.isAnswered(inputs.baselineLDL) &&
            (((_c = inputs.CVRisk) === null || _c === void 0 ? void 0 : _c.currentPoints) === 1 || ((_d = inputs.CVRisk) === null || _d === void 0 ? void 0 : _d.currentPoints) === 2);
    visibleQuestions.reCVRisk1 =
        ((_e = inputs.reclassification) === null || _e === void 0 ? void 0 : _e.currentPoints) === 1 &&
            ((_f = inputs.CVRisk) === null || _f === void 0 ? void 0 : _f.currentPoints) === 1;
    visibleQuestions.reCVRisk2 =
        ((_g = inputs.reclassification) === null || _g === void 0 ? void 0 : _g.currentPoints) === 1 &&
            ((_h = inputs.CVRisk) === null || _h === void 0 ? void 0 : _h.currentPoints) === 2;
    var reclass = visibleAndHasValue("reclassification", 1);
    visibleQuestions.lifestyle =
        ((((_j = inputs.baselineLDL) === null || _j === void 0 ? void 0 : _j.currentPoints) < 3 &&
            (reclass
                ? visibleAndHasValue("reCVRisk2", 1)
                : visibleAndHasValue("CVRisk", 1))) ||
            (((_k = inputs.baselineLDL) === null || _k === void 0 ? void 0 : _k.currentPoints) < 2.6 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 2)
                    : visibleAndHasValue("CVRisk", 2))) ||
            (((_l = inputs.baselineLDL) === null || _l === void 0 ? void 0 : _l.currentPoints) < 1.8 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 3) ||
                        visibleAndHasValue("reCVRisk2", 3)
                    : ((_m = inputs.CVRisk) === null || _m === void 0 ? void 0 : _m.currentPoints) === 3)) ||
            (((_o = inputs.baselineLDL) === null || _o === void 0 ? void 0 : _o.currentPoints) < 1.4 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 4) ||
                        visibleAndHasValue("reCVRisk2", 4)
                    : ((_p = inputs.CVRisk) === null || _p === void 0 ? void 0 : _p.currentPoints) === 4))) &&
            helpers_1.isAnswered(inputs.baselineLDL) &&
            (visibleQuestions.reclassification
                ? helpers_1.isAnswered(inputs.reclassification)
                : true);
    visibleQuestions.considerDrugTx =
        ((((_q = inputs.baselineLDL) === null || _q === void 0 ? void 0 : _q.currentPoints) >= 3 &&
            ((_r = inputs.baselineLDL) === null || _r === void 0 ? void 0 : _r.currentPoints) < 4.9 &&
            (reclass
                ? visibleAndHasValue("reCVRisk2", 1)
                : ((_s = inputs.CVRisk) === null || _s === void 0 ? void 0 : _s.currentPoints) === 1)) ||
            (((_t = inputs.baselineLDL) === null || _t === void 0 ? void 0 : _t.currentPoints) >= 2.6 &&
                ((_u = inputs.baselineLDL) === null || _u === void 0 ? void 0 : _u.currentPoints) < 4.9 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 2)
                    : ((_v = inputs.CVRisk) === null || _v === void 0 ? void 0 : _v.currentPoints) === 2)) ||
            (((_w = inputs.baselineLDL) === null || _w === void 0 ? void 0 : _w.currentPoints) >= 1.8 &&
                ((_x = inputs.baselineLDL) === null || _x === void 0 ? void 0 : _x.currentPoints) < 2.6 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 3) ||
                        visibleAndHasValue("reCVRisk2", 3)
                    : ((_y = inputs.CVRisk) === null || _y === void 0 ? void 0 : _y.currentPoints) === 3)) ||
            (((_z = inputs.baselineLDL) === null || _z === void 0 ? void 0 : _z.currentPoints) >= 1.4 &&
                ((_0 = inputs.baselineLDL) === null || _0 === void 0 ? void 0 : _0.currentPoints) < 1.8 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 4) ||
                        visibleAndHasValue("reCVRisk2", 4)
                    : ((_1 = inputs.CVRisk) === null || _1 === void 0 ? void 0 : _1.currentPoints) === 4))) &&
            helpers_1.isAnswered(inputs.baselineLDL) &&
            (visibleQuestions.reclassification
                ? helpers_1.isAnswered(inputs.reclassification)
                : true);
    visibleQuestions.drugTx =
        ((((_2 = inputs.baselineLDL) === null || _2 === void 0 ? void 0 : _2.currentPoints) >= 4.9 &&
            (reclass
                ? visibleAndHasValue("reCVRisk2", 1) ||
                    visibleAndHasValue("reCVRisk2", 2)
                : ((_3 = inputs.CVRisk) === null || _3 === void 0 ? void 0 : _3.currentPoints) === 1 ||
                    ((_4 = inputs.CVRisk) === null || _4 === void 0 ? void 0 : _4.currentPoints) === 2)) ||
            (((_5 = inputs.baselineLDL) === null || _5 === void 0 ? void 0 : _5.currentPoints) >= 4.9 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 2)
                    : ((_6 = inputs.CVRisk) === null || _6 === void 0 ? void 0 : _6.currentPoints) === 2)) ||
            (((_7 = inputs.baselineLDL) === null || _7 === void 0 ? void 0 : _7.currentPoints) >= 2.6 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 3) ||
                        visibleAndHasValue("reCVRisk2", 3)
                    : ((_8 = inputs.CVRisk) === null || _8 === void 0 ? void 0 : _8.currentPoints) === 3)) ||
            (((_9 = inputs.baselineLDL) === null || _9 === void 0 ? void 0 : _9.currentPoints) >= 1.8 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 4) ||
                        visibleAndHasValue("reCVRisk2", 4)
                    : ((_10 = inputs.CVRisk) === null || _10 === void 0 ? void 0 : _10.currentPoints) === 4))) &&
            helpers_1.isAnswered(inputs.baselineLDL) &&
            (visibleQuestions.reclassification
                ? helpers_1.isAnswered(inputs.reclassification)
                : true);
    visibleQuestions.drugTxIndication =
        ((((_11 = inputs.baselineLDL) === null || _11 === void 0 ? void 0 : _11.currentPoints) >= 3 &&
            ((_12 = inputs.baselineLDL) === null || _12 === void 0 ? void 0 : _12.currentPoints) < 4.9 &&
            (reclass
                ? visibleAndHasValue("reCVRisk2", 1)
                : ((_13 = inputs.CVRisk) === null || _13 === void 0 ? void 0 : _13.currentPoints) === 1)) ||
            (((_14 = inputs.baselineLDL) === null || _14 === void 0 ? void 0 : _14.currentPoints) >= 2.6 &&
                ((_15 = inputs.baselineLDL) === null || _15 === void 0 ? void 0 : _15.currentPoints) < 4.9 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 2)
                    : ((_16 = inputs.CVRisk) === null || _16 === void 0 ? void 0 : _16.currentPoints) === 2)) ||
            (((_17 = inputs.baselineLDL) === null || _17 === void 0 ? void 0 : _17.currentPoints) >= 1.8 &&
                ((_18 = inputs.baselineLDL) === null || _18 === void 0 ? void 0 : _18.currentPoints) < 2.6 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 3) ||
                        visibleAndHasValue("reCVRisk2", 3)
                    : ((_19 = inputs.CVRisk) === null || _19 === void 0 ? void 0 : _19.currentPoints) === 3)) ||
            (((_20 = inputs.baselineLDL) === null || _20 === void 0 ? void 0 : _20.currentPoints) >= 1.4 &&
                ((_21 = inputs.baselineLDL) === null || _21 === void 0 ? void 0 : _21.currentPoints) < 1.8 &&
                (reclass
                    ? visibleAndHasValue("reCVRisk1", 4) ||
                        visibleAndHasValue("reCVRisk2", 4)
                    : ((_22 = inputs.CVRisk) === null || _22 === void 0 ? void 0 : _22.currentPoints) === 4))) &&
            helpers_1.isAnswered(inputs.baselineLDL) &&
            (visibleQuestions.reclassification
                ? helpers_1.isAnswered(inputs.reclassification)
                : true);
    visibleQuestions.noDrugTx = visibleAndHasValue("drugTxIndication", 0);
    if (visibleAndHasValue("drugTxIndication", 1) || visibleQuestions.drugTx) {
        visibleQuestions.goalLow = reclass
            ? visibleAndHasValue("reCVRisk1", 1) || visibleAndHasValue("reCVRisk2", 1)
            : ((_23 = inputs.CVRisk) === null || _23 === void 0 ? void 0 : _23.currentPoints) === 1;
        visibleQuestions.goalModerate = reclass
            ? visibleAndHasValue("reCVRisk1", 2) || visibleAndHasValue("reCVRisk2", 2)
            : ((_24 = inputs.CVRisk) === null || _24 === void 0 ? void 0 : _24.currentPoints) === 2;
        visibleQuestions.goalHigh = reclass
            ? visibleAndHasValue("reCVRisk1", 3) || visibleAndHasValue("reCVRisk2", 3)
            : ((_25 = inputs.CVRisk) === null || _25 === void 0 ? void 0 : _25.currentPoints) === 3;
        visibleQuestions.goalVeryHigh = reclass
            ? visibleAndHasValue("reCVRisk1", 4) || visibleAndHasValue("reCVRisk2", 4)
            : ((_26 = inputs.CVRisk) === null || _26 === void 0 ? void 0 : _26.currentPoints) === 4;
        visibleQuestions.reductionPercent =
            visibleQuestions.goalLow ||
                visibleQuestions.goalModerate ||
                visibleQuestions.goalHigh ||
                visibleQuestions.goalVeryHigh;
    }
    else {
        visibleQuestions.goalLow = false;
        visibleQuestions.goalModerate = false;
        visibleQuestions.goalHigh = false;
        visibleQuestions.goalVeryHigh = false;
        visibleQuestions.reductionPercent = false;
    }
    visibleQuestions.highestStatin = visibleQuestions.reductionPercent;
    visibleQuestions.goalReached1 = visibleQuestions.reductionPercent;
    visibleQuestions.addEzetimibe = visibleAndHasValue("goalReached1", 0);
    visibleQuestions.addEzetimibe2 = visibleAndHasValue("goalReached1", 0);
    visibleQuestions.followup1 = visibleAndHasValue("goalReached1", 1);
    visibleQuestions.goalReached2 = visibleAndHasValue("goalReached1", 0);
    if (reclass
        ? visibleAndHasValue("reCVRisk1", 1) ||
            visibleAndHasValue("reCVRisk1", 2) ||
            visibleAndHasValue("reCVRisk2", 1) ||
            visibleAndHasValue("reCVRisk2", 2)
        : ((_27 = inputs.CVRisk) === null || _27 === void 0 ? void 0 : _27.currentPoints) === 1 || ((_28 = inputs.CVRisk) === null || _28 === void 0 ? void 0 : _28.currentPoints) === 2) {
        visibleQuestions.continueSE1 = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.lifeStyle1 = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.followup2 = visibleAndHasValue("goalReached2", 1);
    }
    else {
        visibleQuestions.continueSE1 = false;
        visibleQuestions.lifeStyle1 = false;
        visibleQuestions.followup2 = false;
    }
    if (reclass
        ? visibleAndHasValue("reCVRisk1", 3) ||
            visibleAndHasValue("reCVRisk1", 4) ||
            visibleAndHasValue("reCVRisk2", 3) ||
            visibleAndHasValue("reCVRisk2", 4)
        : ((_29 = inputs.CVRisk) === null || _29 === void 0 ? void 0 : _29.currentPoints) === 3 || ((_30 = inputs.CVRisk) === null || _30 === void 0 ? void 0 : _30.currentPoints) === 4) {
        visibleQuestions.FH = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.CVD = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.addPCSK9 =
            visibleAndHasValue("FH", 1) || visibleAndHasValue("CVD", 1);
        visibleQuestions.smpcLink1 =
            visibleAndHasValue("FH", 1) || visibleAndHasValue("CVD", 1);
        visibleQuestions.smpcLink2 =
            visibleAndHasValue("FH", 1) || visibleAndHasValue("CVD", 1);
        visibleQuestions.continueSE2 =
            visibleAndHasValue("goalReached2", 1) ||
                (visibleAndHasValue("FH", 0) && visibleAndHasValue("CVD", 0));
        visibleQuestions.followup3 = visibleAndHasValue("goalReached2", 1);
        visibleQuestions.followup4 =
            visibleAndHasValue("FH", 0) && visibleAndHasValue("CVD", 0);
        visibleQuestions.followup5 =
            visibleAndHasValue("FH", 0) && visibleAndHasValue("CVD", 0);
    }
    else {
        visibleQuestions.FH = false;
        visibleQuestions.CVD = false;
        visibleQuestions.addPCSK9 = false;
        visibleQuestions.smpcLink1 = false;
        visibleQuestions.smpcLink2 = false;
        visibleQuestions.continueSE2 = false;
        visibleQuestions.followup3 = false;
        visibleQuestions.followup4 = false;
        visibleQuestions.followup5 = false;
    }
    visibleSections.section2 = visibleQuestions.goalReached1;
    visibleSections.section3 = visibleQuestions.goalReached2;
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections(),
        result: calculatePoints()
    };
});
