"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    CVRisk: true,
    baselineLDL: false,
    riskModifiers: false,
    reclassification: false,
    reCVRisk1: false,
    reCVRisk2: false,
    lifestyle: false,
    considerDrugTx: false,
    drugTx: false,
    drugTxIndication: false,
    noDrugTx: false,
    goalLow: false,
    goalModerate: false,
    goalHigh: false,
    goalVeryHigh: false,
    reductionPercent: false,
    highestStatin: false,
    goalReached1: false,
    addEzetimibe: false,
    followup1: false,
    goalReached2: false,
    continueSE1: false,
    lifeStyle1: false,
    followup2: false,
    addPCSK9: false,
    considerPCSK9: false,
    continueSE2: false,
    followup3: false
};
var visibleSections = {
    section1: true,
    section2: false,
    section3: false
};
var inputs = {
    CVRisk: null,
    baselineLDL: null,
    reclassification: null,
    reCVRisk1: null,
    reCVRisk2: null,
    drugTxIndication: null,
    goalReached1: null,
    goalReached2: null
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p;
    var goal = 0;
    var baselineLDL = helpers_1.isAnswered(inputs.baselineLDL)
        ? Number((_a = inputs.baselineLDL) === null || _a === void 0 ? void 0 : _a.currentPoints)
        : null;
    var reclass = reclassificationVisible() && ((_b = inputs.reclassification) === null || _b === void 0 ? void 0 : _b.currentPoints) === 1;
    if (!reclass
        ? ((_c = inputs.CVRisk) === null || _c === void 0 ? void 0 : _c.currentPoints) === 1
        : (reCVRisk1Visible() && ((_d = inputs.reCVRisk1) === null || _d === void 0 ? void 0 : _d.currentPoints) === 1) ||
            (reCVRisk2Visible() && ((_e = inputs.reCVRisk2) === null || _e === void 0 ? void 0 : _e.currentPoints) === 1)) {
        goal = 3;
    }
    else if (!reclass
        ? ((_f = inputs.CVRisk) === null || _f === void 0 ? void 0 : _f.currentPoints) === 2
        : (reCVRisk1Visible() && ((_g = inputs.reCVRisk1) === null || _g === void 0 ? void 0 : _g.currentPoints) === 2) ||
            (reCVRisk2Visible() && ((_h = inputs.reCVRisk2) === null || _h === void 0 ? void 0 : _h.currentPoints) === 2)) {
        goal = 2.6;
    }
    else if (!reclass
        ? ((_j = inputs.CVRisk) === null || _j === void 0 ? void 0 : _j.currentPoints) === 3
        : (reCVRisk1Visible() && ((_k = inputs.reCVRisk1) === null || _k === void 0 ? void 0 : _k.currentPoints) === 3) ||
            (reCVRisk2Visible() && ((_l = inputs.reCVRisk2) === null || _l === void 0 ? void 0 : _l.currentPoints) === 3)) {
        goal = 1.8;
    }
    else if (!reclass
        ? ((_m = inputs.CVRisk) === null || _m === void 0 ? void 0 : _m.currentPoints) === 4
        : (reCVRisk1Visible() && ((_o = inputs.reCVRisk1) === null || _o === void 0 ? void 0 : _o.currentPoints) === 4) ||
            (reCVRisk2Visible() && ((_p = inputs.reCVRisk2) === null || _p === void 0 ? void 0 : _p.currentPoints) === 4)) {
        goal = 1.4;
    }
    var reductionVisible = goalsVisible(reclass) &&
        (goalLowVisible(reclass) ||
            goalModerateVisible(reclass) ||
            goalHighVisible(reclass) ||
            goalVeryHighVisible(reclass));
    var result = 0;
    if (goal !== 0 &&
        baselineLDL !== null &&
        baselineLDL !== undefined &&
        baselineLDL !== 0) {
        result = 100 - (goal * 100) / baselineLDL;
    }
    var res = {
        number: 0,
        range: 0,
        riskModifiers: {
            qID: "riskModifiers",
            resultTexts: "regular"
        },
        lifestyle: {
            qID: "lifestyle",
            resultTexts: "regular"
        },
        considerDrugTx: {
            qID: "considerDrugTx",
            resultTexts: "regular"
        },
        drugTx: {
            qID: "drugTx",
            resultTexts: "regular"
        },
        noDrugTx: {
            qID: "noDrugTx",
            resultTexts: "regular"
        },
        goalLow: {
            qID: "goalLow",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        goalModerate: {
            qID: "goalModerate",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        goalHigh: {
            qID: "goalHigh",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        goalVeryHigh: {
            qID: "goalVeryHigh",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        reductionPercent: {
            qID: "reductionPercent",
            rParams: __spreadArrays(helpers_1.returnNumberObject(result >= 0 && reductionVisible ? Math.round(result * 10) / 10 : 0, 0, 1)),
            titleTexts: "regular",
            resultTexts: "regular"
        },
        highestStatin: {
            qID: "highestStatin",
            resultTexts: "regular"
        },
        addEzetimibe: {
            qID: "addEzetimibe",
            resultTexts: "regular"
        },
        followup1: {
            qID: "followup1",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        continueSE1: {
            qID: "continueSE1",
            resultTexts: "regular"
        },
        lifeStyle1: {
            qID: "lifeStyle1",
            resultTexts: "regular"
        },
        followup2: {
            qID: "followup2",
            titleTexts: "regular",
            resultTexts: "regular"
        },
        addPCSK9: {
            qID: "addPCSK9",
            resultTexts: "regular"
        },
        continueSE2: {
            qID: "continueSE2",
            resultTexts: "regular"
        },
        followup3: {
            qID: "followup3",
            titleTexts: "regular",
            resultTexts: "regular"
        }
    };
    return res;
};
var visibleAndHasValue = function (item, value) {
    var _a;
    return helpers_1.isAnswered(inputs[item]) && ((_a = inputs[item]) === null || _a === void 0 ? void 0 : _a.currentPoints) === value;
};
var riskModifiersVisible = function () {
    var _a, _b;
    return (helpers_1.isAnswered(inputs.baselineLDL) &&
        (((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1 || ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 2));
};
var reclassificationVisible = function () {
    var _a, _b;
    return (helpers_1.isAnswered(inputs.baselineLDL) &&
        (((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1 || ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 2));
};
var reCVRisk1Visible = function () {
    var _a, _b;
    return (((_a = inputs.reclassification) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1 &&
        ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 1);
};
var reCVRisk2Visible = function () {
    var _a, _b;
    return (((_a = inputs.reclassification) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1 &&
        ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 2);
};
var lifestyleVisible = function (reclass) {
    var _a, _b, _c, _d, _e, _f;
    return (((((_a = inputs.baselineLDL) === null || _a === void 0 ? void 0 : _a.currentPoints) < 3 &&
        (reclass
            ? visibleAndHasValue("reCVRisk2", 1)
            : visibleAndHasValue("CVRisk", 1))) ||
        (((_b = inputs.baselineLDL) === null || _b === void 0 ? void 0 : _b.currentPoints) < 2.6 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 2)
                : visibleAndHasValue("CVRisk", 2))) ||
        (((_c = inputs.baselineLDL) === null || _c === void 0 ? void 0 : _c.currentPoints) < 1.8 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 3) ||
                    visibleAndHasValue("reCVRisk2", 3)
                : ((_d = inputs.CVRisk) === null || _d === void 0 ? void 0 : _d.currentPoints) === 3)) ||
        (((_e = inputs.baselineLDL) === null || _e === void 0 ? void 0 : _e.currentPoints) < 1.4 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 4) ||
                    visibleAndHasValue("reCVRisk2", 4)
                : ((_f = inputs.CVRisk) === null || _f === void 0 ? void 0 : _f.currentPoints) === 4))) &&
        helpers_1.isAnswered(inputs.baselineLDL) &&
        (visibleQuestions.reclassification
            ? helpers_1.isAnswered(inputs.reclassification)
            : true));
};
var considerDrugTxVisible = function (reclass) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    return (((((_a = inputs.baselineLDL) === null || _a === void 0 ? void 0 : _a.currentPoints) >= 3 &&
        ((_b = inputs.baselineLDL) === null || _b === void 0 ? void 0 : _b.currentPoints) < 4.9 &&
        (reclass
            ? visibleAndHasValue("reCVRisk2", 1)
            : ((_c = inputs.CVRisk) === null || _c === void 0 ? void 0 : _c.currentPoints) === 1)) ||
        (((_d = inputs.baselineLDL) === null || _d === void 0 ? void 0 : _d.currentPoints) >= 2.6 &&
            ((_e = inputs.baselineLDL) === null || _e === void 0 ? void 0 : _e.currentPoints) < 4.9 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 2)
                : ((_f = inputs.CVRisk) === null || _f === void 0 ? void 0 : _f.currentPoints) === 2)) ||
        (((_g = inputs.baselineLDL) === null || _g === void 0 ? void 0 : _g.currentPoints) >= 1.8 &&
            ((_h = inputs.baselineLDL) === null || _h === void 0 ? void 0 : _h.currentPoints) < 2.6 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 3) ||
                    visibleAndHasValue("reCVRisk2", 3)
                : ((_j = inputs.CVRisk) === null || _j === void 0 ? void 0 : _j.currentPoints) === 3)) ||
        (((_k = inputs.baselineLDL) === null || _k === void 0 ? void 0 : _k.currentPoints) >= 1.4 &&
            ((_l = inputs.baselineLDL) === null || _l === void 0 ? void 0 : _l.currentPoints) < 1.8 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 4) ||
                    visibleAndHasValue("reCVRisk2", 4)
                : ((_m = inputs.CVRisk) === null || _m === void 0 ? void 0 : _m.currentPoints) === 4))) &&
        helpers_1.isAnswered(inputs.baselineLDL) &&
        (visibleQuestions.reclassification
            ? helpers_1.isAnswered(inputs.reclassification)
            : true));
};
var drugTxVisible = function (reclass) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    return (((((_a = inputs.baselineLDL) === null || _a === void 0 ? void 0 : _a.currentPoints) >= 4.9 &&
        (reclass
            ? visibleAndHasValue("reCVRisk2", 1) ||
                visibleAndHasValue("reCVRisk2", 2)
            : ((_b = inputs.CVRisk) === null || _b === void 0 ? void 0 : _b.currentPoints) === 1 ||
                ((_c = inputs.CVRisk) === null || _c === void 0 ? void 0 : _c.currentPoints) === 2)) ||
        (((_d = inputs.baselineLDL) === null || _d === void 0 ? void 0 : _d.currentPoints) >= 4.9 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 2)
                : ((_e = inputs.CVRisk) === null || _e === void 0 ? void 0 : _e.currentPoints) === 2)) ||
        (((_f = inputs.baselineLDL) === null || _f === void 0 ? void 0 : _f.currentPoints) >= 2.6 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 3) ||
                    visibleAndHasValue("reCVRisk2", 3)
                : ((_g = inputs.CVRisk) === null || _g === void 0 ? void 0 : _g.currentPoints) === 3)) ||
        (((_h = inputs.baselineLDL) === null || _h === void 0 ? void 0 : _h.currentPoints) >= 1.8 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 4) ||
                    visibleAndHasValue("reCVRisk2", 4)
                : ((_j = inputs.CVRisk) === null || _j === void 0 ? void 0 : _j.currentPoints) === 4))) &&
        helpers_1.isAnswered(inputs.baselineLDL) &&
        (visibleQuestions.reclassification
            ? helpers_1.isAnswered(inputs.reclassification)
            : true));
};
var drugTxIndicationVisible = function (reclass) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
    return (((((_a = inputs.baselineLDL) === null || _a === void 0 ? void 0 : _a.currentPoints) >= 3 &&
        ((_b = inputs.baselineLDL) === null || _b === void 0 ? void 0 : _b.currentPoints) < 4.9 &&
        (reclass
            ? visibleAndHasValue("reCVRisk2", 1)
            : ((_c = inputs.CVRisk) === null || _c === void 0 ? void 0 : _c.currentPoints) === 1)) ||
        (((_d = inputs.baselineLDL) === null || _d === void 0 ? void 0 : _d.currentPoints) >= 2.6 &&
            ((_e = inputs.baselineLDL) === null || _e === void 0 ? void 0 : _e.currentPoints) < 4.9 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 2)
                : ((_f = inputs.CVRisk) === null || _f === void 0 ? void 0 : _f.currentPoints) === 2)) ||
        (((_g = inputs.baselineLDL) === null || _g === void 0 ? void 0 : _g.currentPoints) >= 1.8 &&
            ((_h = inputs.baselineLDL) === null || _h === void 0 ? void 0 : _h.currentPoints) < 2.6 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 3) ||
                    visibleAndHasValue("reCVRisk2", 3)
                : ((_j = inputs.CVRisk) === null || _j === void 0 ? void 0 : _j.currentPoints) === 3)) ||
        (((_k = inputs.baselineLDL) === null || _k === void 0 ? void 0 : _k.currentPoints) >= 1.4 &&
            ((_l = inputs.baselineLDL) === null || _l === void 0 ? void 0 : _l.currentPoints) < 1.8 &&
            (reclass
                ? visibleAndHasValue("reCVRisk1", 4) ||
                    visibleAndHasValue("reCVRisk2", 4)
                : ((_m = inputs.CVRisk) === null || _m === void 0 ? void 0 : _m.currentPoints) === 4))) &&
        helpers_1.isAnswered(inputs.baselineLDL) &&
        (visibleQuestions.reclassification
            ? helpers_1.isAnswered(inputs.reclassification)
            : true));
};
var goalsVisible = function (reclass) {
    drugTxIndicationVisible(reclass);
    return visibleAndHasValue("drugTxIndication", 1) || drugTxVisible(reclass);
};
var goalLowVisible = function (reclass) {
    var _a;
    return reclass
        ? visibleAndHasValue("reCVRisk1", 1) || visibleAndHasValue("reCVRisk2", 1)
        : ((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1;
};
var goalModerateVisible = function (reclass) {
    var _a;
    return reclass
        ? visibleAndHasValue("reCVRisk1", 2) || visibleAndHasValue("reCVRisk2", 2)
        : ((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 2;
};
var goalHighVisible = function (reclass) {
    var _a;
    return reclass
        ? visibleAndHasValue("reCVRisk1", 3) || visibleAndHasValue("reCVRisk2", 3)
        : ((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 3;
};
var goalVeryHighVisible = function (reclass) {
    var _a;
    return reclass
        ? visibleAndHasValue("reCVRisk1", 4) || visibleAndHasValue("reCVRisk2", 4)
        : ((_a = inputs.CVRisk) === null || _a === void 0 ? void 0 : _a.currentPoints) === 4;
};
var returnVisibleQuestions = function () {
    return visibleQuestions;
};
var returnVisibleSections = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o;
    visibleQuestions.baselineLDL = helpers_1.isAnswered(inputs.CVRisk);
    visibleQuestions.riskModifiers = riskModifiersVisible();
    visibleQuestions.reclassification = reclassificationVisible();
    visibleQuestions.reCVRisk1 = reCVRisk1Visible();
    visibleQuestions.reCVRisk2 = reCVRisk2Visible();
    var reclass = reclassificationVisible() && ((_a = inputs.reclassification) === null || _a === void 0 ? void 0 : _a.currentPoints) === 1;
    visibleQuestions.lifestyle = lifestyleVisible(reclass);
    visibleQuestions.considerDrugTx = considerDrugTxVisible(reclass);
    visibleQuestions.drugTx = drugTxVisible(reclass);
    visibleQuestions.drugTxIndication = drugTxIndicationVisible(reclass);
    visibleQuestions.noDrugTx = visibleAndHasValue("drugTxIndication", 0);
    if (goalsVisible(reclass)) {
        visibleQuestions.goalLow = goalLowVisible(reclass);
        visibleQuestions.goalModerate = goalModerateVisible(reclass);
        visibleQuestions.goalHigh = goalHighVisible(reclass);
        visibleQuestions.goalVeryHigh = goalVeryHighVisible(reclass);
        visibleQuestions.reductionPercent =
            goalLowVisible(reclass) ||
                goalModerateVisible(reclass) ||
                goalHighVisible(reclass) ||
                goalVeryHighVisible(reclass);
    }
    else {
        visibleQuestions.goalLow = false;
        visibleQuestions.goalModerate = false;
        visibleQuestions.goalHigh = false;
        visibleQuestions.goalVeryHigh = false;
        visibleQuestions.reductionPercent = false;
    }
    visibleQuestions.highestStatin = visibleQuestions.reductionPercent;
    visibleQuestions.goalReached1 = visibleQuestions.reductionPercent;
    visibleQuestions.addEzetimibe = visibleAndHasValue("goalReached1", 0);
    visibleQuestions.followup1 = visibleAndHasValue("goalReached1", 1);
    visibleQuestions.goalReached2 = visibleAndHasValue("goalReached1", 0);
    if (reclass
        ? (reCVRisk1Visible() && ((_b = inputs.reCVRisk1) === null || _b === void 0 ? void 0 : _b.currentPoints) === 1) ||
            (reCVRisk1Visible() && ((_c = inputs.reCVRisk1) === null || _c === void 0 ? void 0 : _c.currentPoints) === 2) ||
            (reCVRisk1Visible() && ((_d = inputs.reCVRisk1) === null || _d === void 0 ? void 0 : _d.currentPoints) === 3) ||
            (reCVRisk2Visible() && ((_e = inputs.reCVRisk2) === null || _e === void 0 ? void 0 : _e.currentPoints) === 1) ||
            (reCVRisk2Visible() && ((_f = inputs.reCVRisk2) === null || _f === void 0 ? void 0 : _f.currentPoints) === 2) ||
            (reCVRisk2Visible() && ((_g = inputs.reCVRisk2) === null || _g === void 0 ? void 0 : _g.currentPoints) === 3)
        : ((_h = inputs.CVRisk) === null || _h === void 0 ? void 0 : _h.currentPoints) === 1 ||
            ((_j = inputs.CVRisk) === null || _j === void 0 ? void 0 : _j.currentPoints) === 2 ||
            ((_k = inputs.CVRisk) === null || _k === void 0 ? void 0 : _k.currentPoints) === 3) {
        visibleQuestions.continueSE1 = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.lifeStyle1 = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.followup2 = visibleAndHasValue("goalReached2", 1);
    }
    else {
        visibleQuestions.continueSE1 = false;
        visibleQuestions.lifeStyle1 = false;
        visibleQuestions.followup2 = false;
    }
    if (reclass
        ? (reCVRisk1Visible() && ((_l = inputs.reCVRisk1) === null || _l === void 0 ? void 0 : _l.currentPoints) === 4) ||
            (reCVRisk2Visible() && ((_m = inputs.reCVRisk2) === null || _m === void 0 ? void 0 : _m.currentPoints) === 4)
        : ((_o = inputs.CVRisk) === null || _o === void 0 ? void 0 : _o.currentPoints) === 4) {
        visibleQuestions.addPCSK9 = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.considerPCSK9 = visibleAndHasValue("goalReached2", 0);
        visibleQuestions.continueSE2 = visibleAndHasValue("goalReached2", 1);
        visibleQuestions.followup3 = visibleAndHasValue("goalReached2", 1);
    }
    else {
        visibleQuestions.addPCSK9 = false;
        visibleQuestions.considerPCSK9 = false;
        visibleQuestions.continueSE2 = false;
        visibleQuestions.followup3 = false;
    }
    visibleSections.section2 = visibleQuestions.goalReached1;
    visibleSections.section3 = visibleQuestions.goalReached2;
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});