"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    groupSelection: true,
    weight: false,
    noAnswerText: false,
    stopBabies: false,
    resultsChildren: false,
    durationChildren: false,
    dosingTeensCapsules: false,
    warningDailyCapsulesTeens: false,
    warningTeensCapsules: false,
    resultsTeensSolution: false,
    maxDoseTeensSolution: false,
    warningTeensSolution: false,
    dosingAdultsCapsules: false,
    disingAdultsCapsulesSecond: false,
    warningDailyCapsulesAdults: false,
    warningAdultsCapsules: false,
    resultsAdultsSolution: false,
    resultsAdultsSolutionSecond: false,
    warningAdultsSolutionMax: false,
    warningAdultsSolution: false,
    warningLiver: false,
    kidneyText: false
};
var visibleSections = {
    chooseSection: true,
    noAnswer: false,
    babiesDosing: false,
    childrenDosing: false,
    teensDosingCapsules: false,
    teensDosingSolution: false,
    adultsDosingCapsules: false,
    adultsSolution: false,
    kidneySection: false
};
var inputs = {
    groupSelection: null,
    weight: null
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.groupSelection, 'children');
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 2, max: 70 });
};
var isNoAnswerVisible = function () {
    return (!helpers_1.isAnswered(inputs.groupSelection) ||
        (isWeightVisible() && !isWeightInLimits()));
};
var isBabiesDosingVisible = function () {
    return helpers_1.answerMatches(inputs.groupSelection, 'babies');
};
var isChildrenDosingVisible = function () {
    return isWeightVisible() && isWeightInLimits();
};
var isTeensDosingCapsulesVisible = function () {
    return helpers_1.answerMatches(inputs.groupSelection, 'teens');
};
var isTeensDosingSolutionVisible = function () {
    return isTeensDosingCapsulesVisible();
};
var isAdultsDosingCapsulesVisible = function () {
    return helpers_1.answerMatches(inputs.groupSelection, 'adults');
};
var isAdultsSolutionVisible = function () {
    return isAdultsDosingCapsulesVisible();
};
var isKidneySectionVisible = function () {
    return !isNoAnswerVisible() && !isBabiesDosingVisible();
};
var calculatePoints = function () {
    var _a, _b;
    if (isChildrenDosingVisible()) {
        var res1 = Math.floor(0.5 * Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints));
        var res2 = 0.04 * Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints);
        return {
            resultsChildren: {
                qID: 'resultsChildren',
                tParams: __spreadArrays(helpers_1.returnNumberObject(res1, 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(res2, 2), 0, 2)),
                titleTexts: 'result1'
            },
            durationChildren: {
                qID: 'durationChildren',
                tParams: [],
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.noAnswerText = isNoAnswerVisible();
    visibleQuestions.stopBabies = isBabiesDosingVisible();
    visibleQuestions.resultsChildren = isChildrenDosingVisible();
    visibleQuestions.durationChildren = isChildrenDosingVisible();
    visibleQuestions.dosingTeensCapsules = isTeensDosingCapsulesVisible();
    visibleQuestions.warningDailyCapsulesTeens = isTeensDosingCapsulesVisible();
    visibleQuestions.warningTeensCapsules = isTeensDosingCapsulesVisible();
    visibleQuestions.resultsTeensSolution = isTeensDosingSolutionVisible();
    visibleQuestions.maxDoseTeensSolution = isTeensDosingSolutionVisible();
    visibleQuestions.warningTeensSolution = isTeensDosingSolutionVisible();
    visibleQuestions.dosingAdultsCapsules = isAdultsDosingCapsulesVisible();
    visibleQuestions.disingAdultsCapsulesSecond = isAdultsDosingCapsulesVisible();
    visibleQuestions.warningDailyCapsulesAdults = isAdultsDosingCapsulesVisible();
    visibleQuestions.warningAdultsCapsules = isAdultsDosingCapsulesVisible();
    visibleQuestions.resultsAdultsSolution = isAdultsSolutionVisible();
    visibleQuestions.resultsAdultsSolutionSecond = isAdultsSolutionVisible();
    visibleQuestions.warningAdultsSolutionMax = isAdultsSolutionVisible();
    visibleQuestions.warningAdultsSolution = isAdultsSolutionVisible();
    visibleQuestions.warningLiver = isKidneySectionVisible();
    visibleQuestions.kidneyText = isKidneySectionVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isNoAnswerVisible();
    visibleSections.babiesDosing = isBabiesDosingVisible();
    visibleSections.childrenDosing = isChildrenDosingVisible();
    visibleSections.teensDosingCapsules = isTeensDosingCapsulesVisible();
    visibleSections.teensDosingSolution = isTeensDosingSolutionVisible();
    visibleSections.adultsDosingCapsules = isAdultsDosingCapsulesVisible();
    visibleSections.adultsSolution = isAdultsSolutionVisible();
    visibleSections.kidneySection = isKidneySectionVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
