"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    info: true,
    missWork: true,
    reducedWorkProductivity: true,
    householdWork: true,
    reducedHouseholdProductivity: true,
    familyEvents: true,
    answerAll: false,
    noDisability: false,
    mildDisability: false,
    moderateDisability: false,
    severeDisability: false
};
var visibleSections = {
    inputSection: true,
    resultSection: true
};
var inputs = {
    missWork: null,
    reducedWorkProductivity: null,
    householdWork: null,
    reducedHouseholdProductivity: null,
    familyEvents: null
};
var isMissWorkInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.missWork, min: 0, max: 92 });
};
var isReducedWorkProductivityInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.reducedWorkProductivity,
        min: 0,
        max: 92
    });
};
var isHouseholdWorkInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.householdWork,
        min: 0,
        max: 92
    });
};
var isReducedHouseholdProductivityInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.reducedHouseholdProductivity,
        min: 0,
        max: 92
    });
};
var isFamilyEventsInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.familyEvents,
        min: 0,
        max: 92
    });
};
var isAnswerAllVisible = function () {
    return (!isMissWorkInLimits() ||
        !isReducedWorkProductivityInLimits() ||
        !isHouseholdWorkInLimits() ||
        !isReducedHouseholdProductivityInLimits() ||
        !isFamilyEventsInLimits());
};
var calculateSumOfPoints = function () {
    var _a, _b, _c, _d, _e;
    return (Number((_a = inputs.missWork) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        Number((_b = inputs.reducedWorkProductivity) === null || _b === void 0 ? void 0 : _b.currentPoints) +
        Number((_c = inputs.householdWork) === null || _c === void 0 ? void 0 : _c.currentPoints) +
        Number((_d = inputs.reducedHouseholdProductivity) === null || _d === void 0 ? void 0 : _d.currentPoints) +
        Number((_e = inputs.familyEvents) === null || _e === void 0 ? void 0 : _e.currentPoints));
};
var calculatePoints = function () {
    if (!isAnswerAllVisible()) {
        var result = calculateSumOfPoints();
        if (result >= 0 && result <= 5) {
            return {
                noDisability: {
                    qID: 'noDisability',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(result, 0), 0, 0)),
                    titleTexts: 'result1'
                }
            };
        }
        if (result >= 6 && result <= 10) {
            return {
                mildDisability: {
                    qID: 'mildDisability',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(result, 0), 0, 0)),
                    titleTexts: 'result1'
                }
            };
        }
        if (result >= 11 && result <= 20) {
            return {
                moderateDisability: {
                    qID: 'moderateDisability',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(result, 0), 0, 0)),
                    titleTexts: 'result1'
                }
            };
        }
        if (result >= 21) {
            return {
                severeDisability: {
                    qID: 'severeDisability',
                    tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(result, 0), 0, 0)),
                    titleTexts: 'result1'
                }
            };
        }
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.answerAll = isAnswerAllVisible();
    visibleQuestions.noDisability =
        !isAnswerAllVisible() &&
            calculateSumOfPoints() >= 0 &&
            calculateSumOfPoints() <= 5;
    visibleQuestions.mildDisability =
        !isAnswerAllVisible() &&
            calculateSumOfPoints() >= 6 &&
            calculateSumOfPoints() <= 10;
    visibleQuestions.moderateDisability =
        !isAnswerAllVisible() &&
            calculateSumOfPoints() >= 11 &&
            calculateSumOfPoints() <= 20;
    visibleQuestions.severeDisability =
        !isAnswerAllVisible() && calculateSumOfPoints() >= 21;
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
