"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};


var visibleQuestions = {
    fatigue: true,
    satiety: true,
    abdominalDiscomfort: true,
    inactivity: true,
    concentration: true,
    nightSweats: true,
    pruritus: true,
    bonePain: true,
    fever: true,
    weightLoss: true
};
var visibleSections = {
    fatigueSection: true,
    satietySection: true
};
var inputs = {
    fatigue: null,
    satiety: null,
    abdominalDiscomfort: null,
    inactivity: null,
    concentration: null,
    nightSweats: null,
    pruritus: null,
    bonePain: null,
    fever: null,
    weightLoss: null
};
var isFatigueValid = function () {
    return helpers_1.numberInLimits({ input: inputs.fatigue, min: 0, max: 10 });
};
var isSatietyValid = function () {
    return helpers_1.numberInLimits({ input: inputs.satiety, min: 0, max: 10 });
};
var isAbdominalDiscomfortValid = function () {
    return helpers_1.numberInLimits({ input: inputs.abdominalDiscomfort, min: 0, max: 10 });
};
var isInactivityValid = function () {
    return helpers_1.numberInLimits({ input: inputs.inactivity, min: 0, max: 10 });
};
var isConcentrationValid = function () {
    return helpers_1.numberInLimits({ input: inputs.concentration, min: 0, max: 10 });
};
var isNightSweatsValid = function () {
    return helpers_1.numberInLimits({ input: inputs.nightSweats, min: 0, max: 10 });
};
var isPruritusValid = function () {
    return helpers_1.numberInLimits({ input: inputs.pruritus, min: 0, max: 10 });
};
var isBonePainValid = function () {
    return helpers_1.numberInLimits({ input: inputs.bonePain, min: 0, max: 10 });
};
var isFeverValid = function () {
    return helpers_1.numberInLimits({ input: inputs.fever, min: 0, max: 10 });
};
var isWeightLossValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weightLoss, min: 0, max: 10 });
};
var areAllQuestionsAnswered = function () {
    return (isFatigueValid() &&
        isSatietyValid() &&
        isAbdominalDiscomfortValid() &&
        isInactivityValid() &&
        isConcentrationValid() &&
        isNightSweatsValid() &&
        isPruritusValid() &&
        isBonePainValid() &&
        isFeverValid() &&
        isWeightLossValid());
};
var sumPoints = function () {
    return (Number(inputs.fatigue.currentPoints) +
        Number(inputs.satiety.currentPoints) +
        Number(inputs.abdominalDiscomfort.currentPoints) +
        Number(inputs.inactivity.currentPoints) +
        Number(inputs.concentration.currentPoints) +
        Number(inputs.nightSweats.currentPoints) +
        Number(inputs.pruritus.currentPoints) +
        Number(inputs.bonePain.currentPoints) +
        Number(inputs.fever.currentPoints) +
        Number(inputs.weightLoss.currentPoints));
};
var calculatePoints = function () {
    var result = areAllQuestionsAnswered() ? sumPoints() : -1;
    var score = helpers_1.formatCalculationResult(result, 1);
    return helpers_1.returnToolScoreObject({ number: score, range: score });
};
var returnVisibleQuestions = function () {
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return areAllQuestionsAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return __assign(__assign({ exportResultsEnabled: isExportResultsEnabled() }, result), { visibleQuestions: ut_visibleQuestions(), visibleSections: ut_visibleSections() });
});
