"use strict";


var visibleQuestions = {
    age: true,
    condition: false,
    treatment: false,
    factors: false,
    pathology: false,
    ard: false,
    procedure: false,
    whenCrownBridge: false,
    untreated: false,
    whenDenture: false,
    ulcus: false,
    highMRONJ: true,
    recommendationsHighMRONJ: true,
    recommendationsAntibiotikMRONJ: true,
    low1: false,
    medium1: false,
    high1: false,
    info: true,
    edges: true,
    recommendations: false,
    management: false,
    low2: false,
    recommendationsLow: false,
    medium2: false,
    recommendationsMedium: false,
    high2: false,
    recommendationsHigh: false,
    recommendationsAntibiotik: true,
    answerAll: false
};
var visibleSections = {
    history: true,
    noWoundManagement: false,
    riskMRONJ: false,
    riskBefore: false,
    wound: false,
    riskAfter: false,
    result: false
};
var inputs = {
    age: null,
    condition: null,
    treatment: null,
    factors: null,
    pathology: null,
    ard: null,
    procedure: null,
    edges: null,
    management: null
};
var calculateHistorySumOfPoints = function () {
    var _a, _b, _c, _d, _e, _f, _g;
    return (Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        Number((_b = inputs.condition) === null || _b === void 0 ? void 0 : _b.currentPoints) +
        Number((_c = inputs.treatment) === null || _c === void 0 ? void 0 : _c.currentPoints) +
        Number((_d = inputs.factors) === null || _d === void 0 ? void 0 : _d.currentPoints) +
        Number((_e = inputs.pathology) === null || _e === void 0 ? void 0 : _e.currentPoints) +
        Number((_f = inputs.ard) === null || _f === void 0 ? void 0 : _f.currentPoints) +
        Number((_g = inputs.procedure) === null || _g === void 0 ? void 0 : _g.currentPoints));
};
var calculateWoundSumOfPoints = function () {
    var _a, _b;
    return (Number((_a = inputs.edges) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        Number((_b = inputs.management) === null || _b === void 0 ? void 0 : _b.currentPoints));
};
var isConditionVisible = function () {
    return helpers_1.isAnswered(inputs.age);
};
var isTreatmentVisible = function () {
    return helpers_1.isAnswered(inputs.condition);
};
var isFactorsVisible = function () {
    return (helpers_1.isAnswered(inputs.treatment) &&
        !helpers_1.answerMatches(inputs.treatment, 'bppoMore10'));
};
var isPathologyVisible = function () {
    return helpers_1.isAnswered(inputs.factors);
};
var isArdVisible = function () {
    return helpers_1.isAnswered(inputs.pathology);
};
var isProcedureVisible = function () {
    return helpers_1.isAnswered(inputs.ard);
};
var isNoWoundManagementVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.procedure, 'conservative') ||
        helpers_1.answerMatches(inputs.procedure, 'crown') ||
        helpers_1.answerMatches(inputs.procedure, 'bridge') ||
        helpers_1.answerMatches(inputs.procedure, 'denture') ||
        helpers_1.answerMatches(inputs.procedure, 'dentureFixed');
    var condition2 = !helpers_1.answerMatches(inputs.treatment, 'bppoMore10');
    return condition1 && condition2;
};
var isWhenCrownBridgeVisible = function () {
    var condition1 = isNoWoundManagementVisible();
    var condition2 = helpers_1.answerMatches(inputs.procedure, 'crown') ||
        helpers_1.answerMatches(inputs.procedure, 'bridge');
    return condition1 && condition2;
};
var isUntreatedVisible = function () {
    var condition1 = isNoWoundManagementVisible();
    var condition2 = helpers_1.answerMatches(inputs.procedure, 'conservative') ||
        helpers_1.answerMatches(inputs.procedure, 'crown') ||
        helpers_1.answerMatches(inputs.procedure, 'bridge');
    return condition1 && condition2;
};
var isWhenDentureVisible = function () {
    var condition1 = isNoWoundManagementVisible();
    var condition2 = helpers_1.answerMatches(inputs.procedure, 'denture') ||
        helpers_1.answerMatches(inputs.procedure, 'dentureFixed');
    return condition1 && condition2;
};
var isRiskMRONJVisible = function () {
    return helpers_1.answerMatches(inputs.treatment, 'bppoMore10');
};
var isRiskBeforeVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.procedure, 'extraction') ||
        helpers_1.answerMatches(inputs.procedure, 'surgical') ||
        helpers_1.answerMatches(inputs.procedure, 'incision') ||
        helpers_1.answerMatches(inputs.procedure, 'periapical') ||
        helpers_1.answerMatches(inputs.procedure, 'incision2');
    var condition2 = !helpers_1.answerMatches(inputs.treatment, 'bppoMore10');
    return condition1 && condition2;
};
var isLow1Visible = function () {
    return (isRiskBeforeVisible() &&
        calculateHistorySumOfPoints() >= 1 &&
        calculateHistorySumOfPoints() <= 10);
};
var isMedium1Visible = function () {
    return (isRiskBeforeVisible() &&
        calculateHistorySumOfPoints() >= 11 &&
        calculateHistorySumOfPoints() <= 15);
};
var isHigh1Visible = function () {
    return isRiskBeforeVisible() && calculateHistorySumOfPoints() >= 16;
};
var isRecommendationsVisible = function () {
    return isRiskBeforeVisible() && helpers_1.answerMatches(inputs.edges, 'no');
};
var isManagementVisible = function () {
    return isRiskBeforeVisible() && helpers_1.answerMatches(inputs.edges, 'yes');
};
var isRiskAfterVisible = function () {
    return (helpers_1.answerMatches(inputs.edges, 'no') ||
        (helpers_1.answerMatches(inputs.edges, 'yes') && helpers_1.isAnswered(inputs.management)));
};
var isLow2Visible = function () {
    return (isRiskAfterVisible() &&
        calculateHistorySumOfPoints() + calculateWoundSumOfPoints() <= 10);
};
var isMedium2Visible = function () {
    return (isRiskAfterVisible() &&
        calculateHistorySumOfPoints() + calculateWoundSumOfPoints() >= 11 &&
        calculateHistorySumOfPoints() + calculateWoundSumOfPoints() <= 15);
};
var isHigh2Visible = function () {
    return (isRiskAfterVisible() &&
        calculateHistorySumOfPoints() + calculateWoundSumOfPoints() >= 16);
};
var isResultVisible = function () {
    var condition1 = isConditionVisible() && !helpers_1.isAnswered(inputs.condition);
    var condition2 = isTreatmentVisible() && !helpers_1.isAnswered(inputs.treatment);
    var condition3 = isFactorsVisible() && !helpers_1.isAnswered(inputs.factors);
    var condition4 = isPathologyVisible() && !helpers_1.isAnswered(inputs.pathology);
    var condition5 = isArdVisible() && !helpers_1.isAnswered(inputs.ard);
    var condition6 = isProcedureVisible() && !helpers_1.isAnswered(inputs.procedure);
    var condition7 = isRiskBeforeVisible() && !helpers_1.isAnswered(inputs.edges);
    var condition8 = isManagementVisible() && !helpers_1.isAnswered(inputs.management);
    var condition9 = !helpers_1.isAnswered(inputs.age);
    return (condition1 ||
        condition2 ||
        condition3 ||
        condition4 ||
        condition5 ||
        condition6 ||
        condition7 ||
        condition8 ||
        condition9);
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.condition = isConditionVisible();
    visibleQuestions.treatment = isTreatmentVisible();
    visibleQuestions.factors = isFactorsVisible();
    visibleQuestions.pathology = isPathologyVisible();
    visibleQuestions.ard = isArdVisible();
    visibleQuestions.procedure = isProcedureVisible();
    visibleQuestions.whenCrownBridge = isWhenCrownBridgeVisible();
    visibleQuestions.untreated = isUntreatedVisible();
    visibleQuestions.whenDenture = isWhenDentureVisible();
    visibleQuestions.ulcus = isWhenDentureVisible();
    visibleQuestions.low1 = isLow1Visible();
    visibleQuestions.medium1 = isMedium1Visible();
    visibleQuestions.high1 = isHigh1Visible();
    visibleQuestions.recommendations = isRecommendationsVisible();
    visibleQuestions.management = isManagementVisible();
    visibleQuestions.low2 = isLow2Visible();
    visibleQuestions.recommendationsLow = isLow2Visible();
    visibleQuestions.medium2 = isMedium2Visible();
    visibleQuestions.recommendationsMedium = isMedium2Visible();
    visibleQuestions.high2 = isHigh2Visible();
    visibleQuestions.recommendationsHigh = isHigh2Visible();
    visibleQuestions.answerAll = isResultVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noWoundManagement = isNoWoundManagementVisible();
    visibleSections.riskMRONJ = isRiskMRONJVisible();
    visibleSections.riskBefore = isRiskBeforeVisible();
    visibleSections.wound = isRiskBeforeVisible();
    visibleSections.riskAfter = isRiskAfterVisible();
    visibleSections.result = isResultVisible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isResultVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
