"use strict";


var visibleQuestions = {
    RRMS: true,
    CSF: false,
    adult: false,
    EDSS: false,
    singleEvent: false,
    secondaryProgressiveMS: false,
    activeDisease: false,
    firstLine: false,
    severeForm: false,
    moderateDisease: false,
    twoFailedTreatments: false,
    seriousRelapse: false,
    incapacitatingRelapse: false,
    AUBAGIO: false,
    AVONEX: false,
    BETAFERON: false,
    COPAXONE: false,
    EXTAVIA: false,
    GILENYA: false,
    LEMTRADA: false,
    MAVENCLAD: false,
    OCREVUS: false,
    PLEGRIDY: false,
    REBIF: false,
    TECFIDERA: false,
    TYSABRI: false,
    noDrugs: false
};
var visibleSections = {
    inputSection: true,
    outputSection: false
};
var inputs = {
    RRMS: null,
    CSF: null,
    adult: null,
    EDSS: null,
    singleEvent: null,
    secondaryProgressiveMS: null,
    activeDisease: null,
    firstLine: null,
    severeForm: null,
    moderateDisease: null,
    twoFailedTreatments: null,
    seriousRelapse: null,
    incapacitatingRelapse: null,
    AUBAGIO: null,
    AVONEX: null,
    BETAFERON: null,
    COPAXONE: null,
    EXTAVIA: null,
    GILENYA: null,
    LEMTRADA: null,
    MAVENCLAD: null,
    OCREVUS: null,
    PLEGRIDY: null,
    REBIF: null,
    TECFIDERA: null,
    TYSABRI: null,
    noDrugs: null
};
var RRMSVisibility = function () {
    return true;
};
var CSFVisibility = function () {
    return helpers_1.isAnswered(inputs.RRMS);
};
var adultVisibility = function () {
    return CSFVisibility() && helpers_1.isAnswered(inputs.CSF);
};
var EDSSVisibility = function () {
    return adultVisibility() && helpers_1.isAnswered(inputs.adult);
};
var singleEventVisibility = function () {
    return EDSSVisibility() && helpers_1.isAnswered(inputs.EDSS);
};
var secondaryProgressiveMSVisibility = function () {
    return singleEventVisibility() && helpers_1.isAnswered(inputs.singleEvent);
};
var activeDiseaseVisibility = function () {
    return (secondaryProgressiveMSVisibility() &&
        helpers_1.isAnswered(inputs.secondaryProgressiveMS));
};
var firstLineVisibility = function () {
    return activeDiseaseVisibility() && helpers_1.isAnswered(inputs.activeDisease);
};
var severeFormVisibility = function () {
    return firstLineVisibility() && helpers_1.isAnswered(inputs.firstLine);
};
var moderateDiseaseVisibility = function () {
    return severeFormVisibility() && helpers_1.isAnswered(inputs.severeForm);
};
var twoFailedTreatmentsVisibility = function () {
    return moderateDiseaseVisibility() && helpers_1.isAnswered(inputs.moderateDisease);
};
var seriousRelapseVisibility = function () {
    return (twoFailedTreatmentsVisibility() && helpers_1.isAnswered(inputs.twoFailedTreatments));
};
var incapacitatingRelapseVisibility = function () {
    return seriousRelapseVisibility() && helpers_1.isAnswered(inputs.seriousRelapse);
};
var areAllQuestionsAnswered = function () {
    return (incapacitatingRelapseVisibility() &&
        helpers_1.isAnswered(inputs.incapacitatingRelapse));
};
var AUBAGIOVisibility = function () {
    return (areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.CSF.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four");
};
var PLEGRIDYVisibility = function () {
    return (areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.CSF.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four");
};
var AVONEXVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four" &&
        inputs.CSF.currentIdentifier == "yes") ||
        inputs.singleEvent.currentIdentifier == "yes");
};
var COPAXONEVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four" &&
        inputs.CSF.currentIdentifier == "yes") ||
        inputs.singleEvent.currentIdentifier == "yes");
};
var BETAFERONVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four" &&
        inputs.CSF.currentIdentifier == "yes") ||
        inputs.singleEvent.currentIdentifier == "yes" ||
        inputs.secondaryProgressiveMS.currentIdentifier == "yes");
};
var EXTAVIAVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four" &&
        inputs.CSF.currentIdentifier == "yes") ||
        inputs.singleEvent.currentIdentifier == "yes" ||
        inputs.secondaryProgressiveMS.currentIdentifier == "yes");
};
var REBIFVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four" &&
        inputs.CSF.currentIdentifier == "yes") ||
        inputs.secondaryProgressiveMS.currentIdentifier == "yes");
};
var LEMTRADAVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.activeDisease.currentIdentifier == "yes" &&
        inputs.firstLine.currentIdentifier == "yes" &&
        inputs.adult.currentIdentifier == "yes") ||
        (inputs.adult.currentIdentifier == "yes" &&
            inputs.severeForm.currentIdentifier == "four"));
};
var TECFIDERAVisibility = function () {
    return ((areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.moderateDisease.currentIdentifier == "yes" &&
        inputs.EDSS.currentIdentifier == "four" &&
        inputs.CSF.currentIdentifier == "yes") ||
        (inputs.RRMS.currentIdentifier == "yes" &&
            (inputs.EDSS.currentIdentifier == "four" ||
                inputs.EDSS.currentIdentifier == "fourFive") &&
            inputs.twoFailedTreatments.currentIdentifier == "yes"));
};
var MAVENCLADVisibility = function () {
    var condition1 = areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.adult.currentIdentifier == "yes" &&
        inputs.seriousRelapse.currentIdentifier == "yes";
    var condition2 = areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.adult.currentIdentifier == "yes" &&
        inputs.incapacitatingRelapse.currentIdentifier == "yes" &&
        inputs.CSF.currentIdentifier == "yes";
    return condition1 || condition2;
};
var GILENYAVisibility = function () {
    var condition1 = areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.twoFailedTreatments.currentIdentifier == "yes" &&
        (inputs.EDSS.currentIdentifier == "four" ||
            inputs.EDSS.currentIdentifier == "fourFive" ||
            inputs.EDSS.currentIdentifier == "five");
    var condition2 = areAllQuestionsAnswered() &&
        inputs.adult.currentIdentifier == "yes" &&
        inputs.CSF.currentIdentifier == "yes" &&
        inputs.severeForm.currentIdentifier == "yes";
    return condition1 || condition2;
};
var OCREVUSVisibility = function () {
    var condition1 = areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.twoFailedTreatments.currentIdentifier == "yes" &&
        (inputs.EDSS.currentIdentifier == "four" ||
            inputs.EDSS.currentIdentifier == "fourFive" ||
            inputs.EDSS.currentIdentifier == "five");
    var condition2 = areAllQuestionsAnswered() &&
        inputs.adult.currentIdentifier == "yes" &&
        inputs.CSF.currentIdentifier == "yes" &&
        inputs.severeForm.currentIdentifier == "yes";
    return condition1 || condition2;
};
var TYSABRIVisibility = function () {
    var condition1 = areAllQuestionsAnswered() &&
        inputs.RRMS.currentIdentifier == "yes" &&
        inputs.twoFailedTreatments.currentIdentifier == "yes" &&
        (inputs.EDSS.currentIdentifier == "four" ||
            inputs.EDSS.currentIdentifier == "fourFive" ||
            inputs.EDSS.currentIdentifier == "five");
    var condition2 = areAllQuestionsAnswered() &&
        inputs.adult.currentIdentifier == "yes" &&
        inputs.CSF.currentIdentifier == "yes" &&
        inputs.severeForm.currentIdentifier == "yes";
    return condition1 || condition2;
};
var noDrugsVisibility = function () {
    return (areAllQuestionsAnswered() &&
        !(AUBAGIOVisibility() ||
            PLEGRIDYVisibility() ||
            AVONEXVisibility() ||
            COPAXONEVisibility() ||
            BETAFERONVisibility() ||
            EXTAVIAVisibility() ||
            REBIFVisibility() ||
            LEMTRADAVisibility() ||
            TECFIDERAVisibility() ||
            MAVENCLADVisibility() ||
            GILENYAVisibility() ||
            OCREVUSVisibility() ||
            TYSABRIVisibility()));
};
var returnVisibleQuestions = function () {
    visibleQuestions.RRMS = RRMSVisibility();
    visibleQuestions.CSF = CSFVisibility();
    visibleQuestions.adult = adultVisibility();
    visibleQuestions.EDSS = EDSSVisibility();
    visibleQuestions.singleEvent = singleEventVisibility();
    visibleQuestions.secondaryProgressiveMS = secondaryProgressiveMSVisibility();
    visibleQuestions.activeDisease = activeDiseaseVisibility();
    visibleQuestions.firstLine = firstLineVisibility();
    visibleQuestions.severeForm = severeFormVisibility();
    visibleQuestions.moderateDisease = moderateDiseaseVisibility();
    visibleQuestions.twoFailedTreatments = twoFailedTreatmentsVisibility();
    visibleQuestions.seriousRelapse = seriousRelapseVisibility();
    visibleQuestions.incapacitatingRelapse = incapacitatingRelapseVisibility();
    visibleQuestions.AUBAGIO = AUBAGIOVisibility();
    visibleQuestions.AVONEX = AVONEXVisibility();
    visibleQuestions.BETAFERON = BETAFERONVisibility();
    visibleQuestions.COPAXONE = COPAXONEVisibility();
    visibleQuestions.EXTAVIA = EXTAVIAVisibility();
    visibleQuestions.GILENYA = GILENYAVisibility();
    visibleQuestions.LEMTRADA = LEMTRADAVisibility();
    visibleQuestions.MAVENCLAD = MAVENCLADVisibility();
    visibleQuestions.OCREVUS = OCREVUSVisibility();
    visibleQuestions.PLEGRIDY = PLEGRIDYVisibility();
    visibleQuestions.REBIF = REBIFVisibility();
    visibleQuestions.TECFIDERA = TECFIDERAVisibility();
    visibleQuestions.TYSABRI = TYSABRIVisibility();
    visibleQuestions.noDrugs = noDrugsVisibility();
    return visibleQuestions;
};
var inputSectionVisibility = function () {
    return true;
};
var outputSectionVisibility = function () {
    return areAllQuestionsAnswered();
};
var returnVisibleSections = function () {
    visibleSections.inputSection = inputSectionVisibility();
    visibleSections.outputSection = outputSectionVisibility();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        result: {},
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
