"use strict";


var visibleQuestions = {
    description: true,
    age: true,
    EDSS: true,
    relapse: true,
    relapsesNo: true,
    recovery: true,
    MRI: true,
    newActivity: true,
    note1: true,
    visual1: true,
    visual2: true,
    motor1: true,
    motor2: true,
    ambulatory1: true,
    ambulatory2: true,
    coordination1: true,
    coordination2: true,
    pain1: true,
    pain2: true,
    sensory1: true,
    sensory2: true,
    bladder1: true,
    bladder2: true,
    speech1: true,
    speech2: true,
    cognitive1: true,
    cognitive2: true,
    fatigue1: true,
    fatigue2: true,
    note2: true,
    mobility: true,
    selfcare: true,
    other: true,
    hobbies: true,
    work: true,
    resultAnswerAll: true,
    result0: true,
    result1: true,
    result2: true,
    result3: true,
    result4: true
};
var visibleSections = {
    questionnaire: true,
    patientData: true,
    symptoms: true,
    impacts: true,
    result: true
};
var inputs = {
    age: null,
    EDSS: null,
    relapse: null,
    relapsesNo: null,
    recovery: null,
    MRI: null,
    newActivity: null,
    mobility: null,
    selfcare: null,
    other: null,
    hobbies: null,
    work: null
};
var relapseInputs = [
    { id: 'visual1', multiplier: 1 },
    { id: 'motor1', multiplier: 2 },
    { id: 'ambulatory1', multiplier: 2 },
    { id: 'coordination1', multiplier: 1 },
    { id: 'pain1', multiplier: 1 },
    { id: 'sensory1', multiplier: 1 },
    { id: 'bladder1', multiplier: 1 },
    { id: 'speech1', multiplier: 1 },
    { id: 'cognitive1', multiplier: 2 },
    { id: 'fatigue1', multiplier: 1 },
];
var nonRelapseInputs = [
    { id: 'visual2', multiplier: 1 },
    { id: 'motor2', multiplier: 2 },
    { id: 'ambulatory2', multiplier: 2 },
    { id: 'coordination2', multiplier: 1 },
    { id: 'pain2', multiplier: 1 },
    { id: 'sensory2', multiplier: 1 },
    { id: 'bladder2', multiplier: 1 },
    { id: 'speech2', multiplier: 1 },
    { id: 'cognitive2', multiplier: 2 },
    { id: 'fatigue2', multiplier: 1 },
];
var isRelapseAnswered = function (value) {
    var _a;
    return ((_a = inputs.relapse) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === value;
};
var patientDataScore = function () {
    var _a, _b, _c;
    if (isSymptomsVisible()) {
        return ((Number((_a = inputs.relapse) === null || _a === void 0 ? void 0 : _a.currentPoints) * 3 +
            Number((_b = inputs.relapsesNo) === null || _b === void 0 ? void 0 : _b.currentPoints) * 2 +
            Number((_c = inputs.recovery) === null || _c === void 0 ? void 0 : _c.currentPoints) * 2) /
            8);
    }
    return 0;
};
var symptomsScore = function () {
    if (!isSymptomsAnswered()) {
        return 0;
    }
    var targetInputs = null;
    if (isSymptomsVisible() && isRelapseAnswered('yes')) {
        targetInputs = relapseInputs;
    }
    else if (isSymptomsVisible() && isRelapseAnswered('no')) {
        targetInputs = nonRelapseInputs;
    }
    if (!targetInputs) {
        return 0;
    }
    var qWeightSum = 0;
    var sum = targetInputs.reduce(function (prev, input) {
        var inputElement = inputs[input.id];
        if (inputElement &&
            inputElement.currentPoints !== null &&
            Number(inputElement.currentPoints) > -1) {
            qWeightSum += input.multiplier;
            return prev + Number(inputElement.currentPoints) * input.multiplier;
        }
        return prev;
    }, 0);
    return sum / 7 / (qWeightSum || 1);
};
var impactsScore = function () {
    var _a, _b, _c, _d, _e;
    if (isImpactsAnswered()) {
        return ((Number((_a = inputs.mobility) === null || _a === void 0 ? void 0 : _a.currentPoints) * 2 +
            Number((_b = inputs.selfcare) === null || _b === void 0 ? void 0 : _b.currentPoints) +
            Number((_c = inputs.other) === null || _c === void 0 ? void 0 : _c.currentPoints) * 2 +
            Number((_d = inputs.hobbies) === null || _d === void 0 ? void 0 : _d.currentPoints) +
            Number((_e = inputs.work) === null || _e === void 0 ? void 0 : _e.currentPoints)) /
            14);
    }
    return 0;
};
var clinicalScore = function () {
    var _a, _b, _c, _d, _e;
    if (!helpers_1.isAnswered(inputs.EDSS) || !helpers_1.isAnswered(inputs.age)) {
        return 0;
    }
    if (((_a = inputs.EDSS) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'NA' ||
        Number((_b = inputs.EDSS) === null || _b === void 0 ? void 0 : _b.currentPoints) === 0) {
        return Number((_c = inputs.age) === null || _c === void 0 ? void 0 : _c.currentPoints) / 2;
    }
    return ((Number((_d = inputs.EDSS) === null || _d === void 0 ? void 0 : _d.currentPoints) + Number((_e = inputs.age) === null || _e === void 0 ? void 0 : _e.currentPoints)) / 5);
};
var getTotalScore = function () {
    return helpers_1.formatCalculationResult((patientDataScore() + symptomsScore() + impactsScore() + clinicalScore()) *
        25, 1);
};
var isRelapseNoVisible = function () {
    var _a;
    return (helpers_1.isAnswered(inputs.relapse) && ((_a = inputs.relapse) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'yes');
};
var isRecoveryVisible = function () {
    return isRelapseNoVisible() && helpers_1.isAnswered(inputs.relapsesNo);
};
var isMRIVisible = function () {
    var _a, _b;
    return ((helpers_1.isAnswered(inputs.relapse) &&
        ((_a = inputs.relapse) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'no') ||
        (helpers_1.isAnswered(inputs.relapse) &&
            ((_b = inputs.relapse) === null || _b === void 0 ? void 0 : _b.currentIdentifier) === 'yes' &&
            helpers_1.isAnswered(inputs.relapsesNo) &&
            helpers_1.isAnswered(inputs.recovery)));
};
var isNewActivityVisible = function () {
    var _a;
    return helpers_1.isAnswered(inputs.MRI) && ((_a = inputs.MRI) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'yes';
};
var isSymptomsVisible = function () {
    return (helpers_1.isAnswered(inputs.EDSS) &&
        helpers_1.isAnswered(inputs.relapse) &&
        (isRelapseNoVisible() ? helpers_1.isAnswered(inputs.relapsesNo) : true) &&
        (isRecoveryVisible() ? helpers_1.isAnswered(inputs.recovery) : true) &&
        (isMRIVisible() ? helpers_1.isAnswered(inputs.MRI) : true) &&
        (isNewActivityVisible() ? helpers_1.isAnswered(inputs.newActivity) : true));
};
var isSymptomsAnswered = function () {
    var targetInputs = null;
    if (isSymptomsVisible() && isRelapseAnswered('yes')) {
        targetInputs = relapseInputs;
    }
    else if (isSymptomsVisible() && isRelapseAnswered('no')) {
        targetInputs = nonRelapseInputs;
    }
    if (!targetInputs) {
        return false;
    }
    var invalidAnswers = targetInputs.filter(function (input) {
        var _a;
        return ((_a = inputs[input.id]) === null || _a === void 0 ? void 0 : _a.currentPoints) === -2;
    }).length;
    return invalidAnswers === 0;
};
var isImpactsVisible = function () {
    return isSymptomsVisible() && isSymptomsAnswered();
};
var isImpactsAnswered = function () {
    return (helpers_1.isAnswered(inputs.mobility) &&
        helpers_1.isAnswered(inputs.selfcare) &&
        helpers_1.isAnswered(inputs.other) &&
        helpers_1.isAnswered(inputs.hobbies) &&
        helpers_1.isAnswered(inputs.work));
};
var isAnswerAllVisible = function () {
    return (!isSymptomsVisible() ||
        !isImpactsVisible() ||
        (isImpactsVisible() && !isImpactsAnswered()));
};
var isResult1Visible = function () {
    return getTotalScore() < 46.3;
};
var isResult2Visible = function () {
    return getTotalScore() >= 46.3 && getTotalScore() <= 57.8;
};
var isResult3Visible = function () {
    return getTotalScore() >= 57.8;
};
var returnVisibleQuestions = function () {
    visibleQuestions.EDSS = helpers_1.isAnswered(inputs.age);
    visibleQuestions.relapse = helpers_1.isAnswered(inputs.EDSS);
    visibleQuestions.relapsesNo = isRelapseNoVisible();
    visibleQuestions.recovery = isRecoveryVisible();
    visibleQuestions.MRI = isMRIVisible();
    visibleQuestions.newActivity = isNewActivityVisible();
    visibleQuestions.note1 = isSymptomsVisible();
    visibleQuestions.visual1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.visual2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.motor1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.motor2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.ambulatory1 =
        isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.ambulatory2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.coordination1 =
        isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.coordination2 =
        isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.pain1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.pain2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.sensory1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.sensory2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.bladder1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.bladder2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.speech1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.speech2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.cognitive1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.cognitive2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.fatigue1 = isSymptomsVisible() && isRelapseAnswered('yes');
    visibleQuestions.fatigue2 = isSymptomsVisible() && isRelapseAnswered('no');
    visibleQuestions.note2 = isImpactsVisible();
    visibleQuestions.mobility = isImpactsVisible();
    visibleQuestions.selfcare = isImpactsVisible();
    visibleQuestions.other = isImpactsVisible();
    visibleQuestions.hobbies = isImpactsVisible();
    visibleQuestions.work = isImpactsVisible();
    visibleQuestions.resultAnswerAll = isAnswerAllVisible();
    visibleQuestions.result0 = !isAnswerAllVisible();
    visibleQuestions.result1 = !isAnswerAllVisible() && isResult1Visible();
    visibleQuestions.result2 = !isAnswerAllVisible() && isResult2Visible();
    visibleQuestions.result3 = !isAnswerAllVisible() && isResult3Visible();
    visibleQuestions.result4 = !isAnswerAllVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.symptoms = isSymptomsVisible();
    visibleSections.impacts = isImpactsVisible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
