"use strict";


var visibleQuestions = {
    classification: true,
    notDetermined: false,
    noDisease: false,
    physicalExam: false,
    stadium1: false,
    stadium2: false,
    stadium3: false,
    followUp1: false,
    stageA: false,
    followUp2: false,
    stageB: false,
    followUp3: false,
    stageC: false,
    testing: false,
    immunotherapy: false,
    firstLine: false,
    inhibitors1: false,
    inhibitors2: false,
    antiPD1: false,
    meki: false,
    clinicalStudy1a: false,
    clinicalStudy1b: false,
    clinicalStudy2: false,
    radiosurgery: false,
    testingBRAF2: false,
    treatmentMutation: false,
    treatmentWildType: false,
    treatmentCPX: false,
    followingTherapy: false
};
var visibleSections = {
    classificationTNM: true,
    notDeterminedStadium: false,
    stadium0: false,
    initialDiagnosis: false,
    monitoring1: false,
    monitoring2: false,
    monitoring3: false,
    testingBRAF: false,
    brainMetastases: false
};
var inputs = {
    classification: null,
    testing: null,
    immunotherapy: null,
    testingBRAF2: null
};
var isNotDeterminedStadiumVisible = function () {
    return (helpers_1.answerMatches(inputs.classification, 'resultRange2') ||
        helpers_1.answerMatches(inputs.classification, 'noDisease'));
};
var isNotDeterminedVisible = function () {
    return helpers_1.answerMatches(inputs.classification, 'resultRange2');
};
var isNoDiseaseVisible = function () {
    return helpers_1.answerMatches(inputs.classification, 'noDisease');
};
var isStadium0Visible = function () {
    return helpers_1.answerMatches(inputs.classification, 'resultRange3');
};
var isInitialDiagnosisVisible = function () {
    return (helpers_1.isAnswered(inputs.classification) &&
        !helpers_1.answerMatches(inputs.classification, 'resultRange1') &&
        !helpers_1.answerMatches(inputs.classification, 'resultRange2') &&
        !helpers_1.answerMatches(inputs.classification, 'noDisease') &&
        !helpers_1.answerMatches(inputs.classification, 'resultRange3'));
};
var isStadium1Visible = function () {
    return helpers_1.answerMatches(inputs.classification, 'resultRange4');
};
var isStadium2Visible = function () {
    return (helpers_1.answerMatches(inputs.classification, 'resultRange5') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange6') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange7'));
};
var isStadium3Visible = function () {
    return (helpers_1.answerMatches(inputs.classification, 'resultRange8') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange9') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange10') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange11') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange12') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange13') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange14') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange15') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange16'));
};
var isMonitoring1Visible = function () {
    return helpers_1.answerMatches(inputs.classification, 'resultRange4');
};
var isMonitoring2Visible = function () {
    return (helpers_1.answerMatches(inputs.classification, 'resultRange5') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange6') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange7'));
};
var isTestingBRAFVisible = function () {
    return (helpers_1.answerMatches(inputs.classification, 'resultRange9') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange10') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange11') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange12') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange13') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange14') ||
        helpers_1.answerMatches(inputs.classification, 'resultRange15'));
};
var isImmunotherapyVisible = function () {
    return (isTestingBRAFVisible() && helpers_1.answerMatches(inputs.testing, 'mutationBRAF'));
};
var isFirstLineVisible = function () {
    var firstCondition = isTestingBRAFVisible() && helpers_1.answerMatches(inputs.testing, 'wildType');
    var secondCondition = isTestingBRAFVisible() && helpers_1.answerMatches(inputs.testing, 'mutationNRAS');
    var thirdCondition = isTestingBRAFVisible() && helpers_1.answerMatches(inputs.immunotherapy, 'yes');
    return firstCondition || secondCondition || thirdCondition;
};
var isInhibitors1Visible = function () {
    return isTestingBRAFVisible() && helpers_1.answerMatches(inputs.immunotherapy, 'no');
};
var isInhibitors2Visible = function () {
    return isTestingBRAFVisible() && helpers_1.answerMatches(inputs.immunotherapy, 'yes');
};
var isMekiVisible = function () {
    return (isTestingBRAFVisible() && helpers_1.answerMatches(inputs.testing, 'mutationNRAS'));
};
var isClinicalStudy1aVisible = function () {
    var firstCondition = isTestingBRAFVisible() && helpers_1.answerMatches(inputs.testing, 'mutationNRAS');
    var secondCondition = isTestingBRAFVisible() && helpers_1.answerMatches(inputs.immunotherapy, 'yes');
    return firstCondition || secondCondition;
};
var isClinicalStudy1bVisible = function () {
    return isTestingBRAFVisible() && helpers_1.answerMatches(inputs.testing, 'wildType');
};
var isClinicalStudy2Visible = function () {
    return helpers_1.answerMatches(inputs.immunotherapy, 'no');
};
var isBrainMetastatesVisible = function () {
    return helpers_1.answerMatches(inputs.classification, 'resultRange16');
};
var isTreatmentMutationVisible = function () {
    return (isBrainMetastatesVisible() && helpers_1.answerMatches(inputs.testingBRAF2, 'mutation'));
};
var isTreatmentWildTypeVisible = function () {
    return (isBrainMetastatesVisible() && helpers_1.answerMatches(inputs.testingBRAF2, 'wildType'));
};
var isTreatmentCPXVisible = function () {
    return isBrainMetastatesVisible() && helpers_1.isAnswered(inputs.testingBRAF2);
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.notDetermined = isNotDeterminedVisible();
    visibleQuestions.noDisease = isNoDiseaseVisible();
    visibleQuestions.physicalExam = isStadium0Visible();
    visibleQuestions.stadium1 = isStadium1Visible();
    visibleQuestions.stadium2 = isStadium2Visible();
    visibleQuestions.stadium3 = isStadium3Visible();
    visibleQuestions.followUp1 = isMonitoring1Visible();
    visibleQuestions.stageA = isMonitoring1Visible();
    visibleQuestions.followUp2 = isMonitoring2Visible();
    visibleQuestions.stageB = isMonitoring2Visible();
    visibleQuestions.followUp3 = isStadium3Visible();
    visibleQuestions.stageC = isStadium3Visible();
    visibleQuestions.testing = isTestingBRAFVisible();
    visibleQuestions.immunotherapy = isImmunotherapyVisible();
    visibleQuestions.firstLine = isFirstLineVisible();
    visibleQuestions.inhibitors1 = isInhibitors1Visible();
    visibleQuestions.inhibitors2 = isInhibitors2Visible();
    visibleQuestions.antiPD1 = isInhibitors1Visible();
    visibleQuestions.meki = isMekiVisible();
    visibleQuestions.clinicalStudy1a = isClinicalStudy1aVisible();
    visibleQuestions.clinicalStudy1b = isClinicalStudy1bVisible();
    visibleQuestions.clinicalStudy2 = isClinicalStudy2Visible();
    visibleQuestions.radiosurgery = isBrainMetastatesVisible();
    visibleQuestions.testingBRAF2 = isBrainMetastatesVisible();
    visibleQuestions.treatmentMutation = isTreatmentMutationVisible();
    visibleQuestions.treatmentWildType = isTreatmentWildTypeVisible();
    visibleQuestions.treatmentCPX = isTreatmentCPXVisible();
    visibleQuestions.followingTherapy = isTreatmentCPXVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.notDeterminedStadium = isNotDeterminedStadiumVisible();
    visibleSections.stadium0 = isStadium0Visible();
    visibleSections.initialDiagnosis = isInitialDiagnosisVisible();
    visibleSections.monitoring1 = isMonitoring1Visible();
    visibleSections.monitoring2 = isMonitoring2Visible();
    visibleSections.monitoring3 = isStadium3Visible();
    visibleSections.testingBRAF = isTestingBRAFVisible();
    visibleSections.brainMetastases = isBrainMetastatesVisible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var ut_toolScore = function () {
    return calculatePoints();
};
var isExportResultsEnabled = function () {
    return (helpers_1.isAnswered(inputs.classification) &&
        !helpers_1.answerMatches(inputs.classification, 'resultRange1'));
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
