"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    creatinine: false,
    notAnswered: false,
    result1: false,
    result2: false,
    duration1: false,
    warning1: false,
    result3a: false,
    result3b: false,
    result3c: false,
    result3d: false,
    duration2: false,
    warningKidney: false,
    anti2: false
};
var visibleSections = {
    ageSelection: true,
    dosing: false,
    babyDose: false,
    kidsDose: false,
    warningK: false,
    adultsDose: false,
    warningA: false,
    anti: false
};
var inputs = {
    age: null,
    weight: null,
    creatinine: null
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({
        input: inputs.weight,
        min: 1,
        max: 70
    });
};
var isCreatinineVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isDosingVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        (isWeightVisible() && !isWeightInLimits()) ||
        (isCreatinineVisible() && !helpers_1.isAnswered(inputs.creatinine)));
};
var isBabyDoseVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'babies');
};
var isKidsDoseVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids') && isWeightInLimits();
};
var isWarningKVisible = function () {
    return isKidsDoseVisible();
};
var isAdultsDoseVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.isAnswered(inputs.creatinine);
};
var isWarningAVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        (helpers_1.answerMatches(inputs.creatinine, 'less10') ||
            helpers_1.answerMatches(inputs.creatinine, 'middle') ||
            helpers_1.answerMatches(inputs.creatinine, 'upperMiddle')));
};
var isAntiVisible = function () {
    return isAdultsDoseVisible();
};
var isResult3aVisible = function () {
    return isAdultsDoseVisible() && helpers_1.answerMatches(inputs.creatinine, 'above50');
};
var isResult3bVisible = function () {
    return (isAdultsDoseVisible() && helpers_1.answerMatches(inputs.creatinine, 'upperMiddle'));
};
var isResult3cVisible = function () {
    return isAdultsDoseVisible() && helpers_1.answerMatches(inputs.creatinine, 'middle');
};
var isResult3dVisible = function () {
    return isAdultsDoseVisible() && helpers_1.answerMatches(inputs.creatinine, 'less10');
};
var calculatePoints = function () {
    var _a;
    if (isKidsDoseVisible()) {
        var res2 = helpers_1.numberInLimits({ input: inputs.weight, min: 50, max: 70 })
            ? 1000
            : Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 20;
        return {
            result2: {
                qID: 'result2',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(res2, 1), 0, 1)),
                rParams: [],
                titleTexts: 'result1',
                resultTexts: 'result1'
            },
            duration1: {
                qID: 'duration1',
                tParams: [],
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.creatinine = isCreatinineVisible();
    visibleQuestions.notAnswered = isDosingVisible();
    visibleQuestions.result1 = isBabyDoseVisible();
    visibleQuestions.result2 = isKidsDoseVisible();
    visibleQuestions.duration1 = isKidsDoseVisible();
    visibleQuestions.warning1 = isWarningKVisible();
    visibleQuestions.result3a = isResult3aVisible();
    visibleQuestions.result3b = isResult3bVisible();
    visibleQuestions.result3c = isResult3cVisible();
    visibleQuestions.result3d = isResult3dVisible();
    visibleQuestions.duration2 = isAdultsDoseVisible();
    visibleQuestions.warningKidney = isWarningAVisible();
    visibleQuestions.anti2 = isAntiVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = isDosingVisible();
    visibleSections.babyDose = isBabyDoseVisible();
    visibleSections.kidsDose = isKidsDoseVisible();
    visibleSections.warningK = isWarningKVisible();
    visibleSections.adultsDose = isAdultsDoseVisible();
    visibleSections.warningA = isWarningAVisible();
    visibleSections.anti = isAntiVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isDosingVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
