"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    noAnswerElement: true,
    dosingToddlersElement: false,
    doseSix: false,
    durationSix: false,
    doseAboveSixA: false,
    durationAboveSixA: false,
    divider1Second: false,
    warningSixB: false,
    doseAboveSixB: false,
    durationAboveSixB: false,
    doseAdolescentsA: false,
    durationAdolescentsA: false,
    divider1: false,
    doseAdolescentsB: false,
    durationAdolescentsB: false,
    doseAdults: false,
    durationAdults: false,
    kidneyDisease: false,
    kidneyAnuria: false,
    element3: false
};
var visibleSections = {
    ageSection: true,
    noAnswer: true,
    dosingAdults: false,
    dosingAdolescents: false,
    dosingAboveSix: false,
    dosingSix: false,
    dosingUnderSix: false,
    kidney: false,
    antimicrobialWarning: false
};
var inputs = {
    age: null,
    weight: null
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'aboveSix');
};
var isAnswerAllVisible = function () {
    return !(helpers_1.isAnswered(inputs.age) &&
        (isDosingAboveSixVisible() || !helpers_1.answerMatches(inputs.age, 'aboveSix')));
};
var isAgeInputAnswered = function (name) {
    return helpers_1.answerMatches(inputs.age, name);
};
var isKidneyVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'six') ||
        isDosingAboveSixVisible() ||
        helpers_1.answerMatches(inputs.age, 'adults') ||
        helpers_1.answerMatches(inputs.age, 'adolescents'));
};
var isDosingAboveSixVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'aboveSix') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 }));
};
var isDosingAboveSixBVisible = function () {
    return (isDosingAboveSixVisible() &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 20.1, max: 70 }));
};
var calculatePoints = function () {
    var _a;
    if (isDosingAboveSixVisible()) {
        var weight = Number((_a = inputs === null || inputs === void 0 ? void 0 : inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        var X = weight * 15;
        var Y = weight >= 50 ? 2000 : weight * 40;
        return {
            doseAboveSixB: {
                qID: 'doseAboveSixB',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(X, 0), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Y, 0), 0, 0)),
                titleTexts: 'doseAboveSix1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.noAnswerElement = isAnswerAllVisible();
    visibleQuestions.dosingToddlersElement = isAgeInputAnswered('underSix');
    visibleQuestions.doseSix = isAgeInputAnswered('six');
    visibleQuestions.durationSix = isAgeInputAnswered('six');
    visibleQuestions.doseAboveSixA = isDosingAboveSixVisible();
    visibleQuestions.durationAboveSixA = isDosingAboveSixVisible();
    visibleQuestions.divider1Second = isDosingAboveSixVisible();
    visibleQuestions.warningSixB = isDosingAboveSixBVisible();
    visibleQuestions.doseAboveSixB = isDosingAboveSixVisible();
    visibleQuestions.durationAboveSixB = isDosingAboveSixVisible();
    visibleQuestions.doseAdolescentsA = isAgeInputAnswered('adolescents');
    visibleQuestions.durationAdolescentsA = isAgeInputAnswered('adolescents');
    visibleQuestions.divider1 = isAgeInputAnswered('adolescents');
    visibleQuestions.doseAdolescentsB = isAgeInputAnswered('adolescents');
    visibleQuestions.durationAdolescentsB = isAgeInputAnswered('adolescents');
    visibleQuestions.doseAdults = isAgeInputAnswered('adults');
    visibleQuestions.durationAdults = isAgeInputAnswered('adults');
    visibleQuestions.kidneyDisease = isKidneyVisible();
    visibleQuestions.kidneyAnuria = isKidneyVisible();
    visibleQuestions.element3 = isKidneyVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isAnswerAllVisible();
    visibleSections.dosingAdults = isAgeInputAnswered('adults');
    visibleSections.dosingAdolescents = isAgeInputAnswered('adolescents');
    visibleSections.dosingAboveSix = isDosingAboveSixVisible();
    visibleSections.dosingSix = isAgeInputAnswered('six');
    visibleSections.dosingUnderSix = isAgeInputAnswered('underSix');
    visibleSections.kidney = isKidneyVisible();
    visibleSections.antimicrobialWarning = isKidneyVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
