"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    noAnswerElement: true,
    dosingToddlersElement: false,
    doseAboveSixA: false,
    durationAboveSixA: false,
    durationAboveSixB: false,
    divider1: false,
    doseAboveSixB: false,
    doseAdolescentsA: false,
    durationAdolescentsA: false,
    divider2: false,
    doseAdolescentsB: false,
    durationAdolescentsB: false,
    doseAdultsA: false,
    durationAdultsA: false,
    divider3: false,
    doseAdultsB: false,
    durationAdultsB: false,
    element12: false,
    kidneyDisease: false,
    kidneyAnuria: false,
    element1: false
};
var visibleSections = {
    ageSection: true,
    noAnswer: true,
    dosingUnderSix: false,
    dosingAboveSix: false,
    dosingAdolescents: false,
    dosingAdults: false,
    warningPartners: false,
    kidney: false,
    antimicrobialWarning: false
};
var inputs = {
    age: null,
    weight: null
};
var isAnswerAgeMatches = function (name) {
    return helpers_1.answerMatches(inputs.age, name);
};
var isNoAnswerVisible = function () {
    return !(helpers_1.answerMatches(inputs.age, 'underSix') ||
        isDosingAboveSixVisible() ||
        helpers_1.answerMatches(inputs.age, 'adolescents') ||
        helpers_1.answerMatches(inputs.age, 'adults'));
};
var isWarningPartnersVisible = function () {
    return (isDosingAboveSixVisible() ||
        helpers_1.answerMatches(inputs.age, 'adolescents') ||
        helpers_1.answerMatches(inputs.age, 'adults'));
};
var isDosingAboveSixVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'aboveSix') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 }));
};
var calculatePoints = function () {
    var _a;
    if (isDosingAboveSixVisible()) {
        var weight = Number((_a = inputs === null || inputs === void 0 ? void 0 : inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        var X = weight >= 50 ? 2000 : weight * 40;
        var Y = weight * 15;
        var Z = weight >= 66.7 ? 2000 : weight * 30;
        return {
            doseAboveSixA: {
                qID: 'doseAboveSixA',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(X, 0), 0, 0)),
                titleTexts: 'doseAboveSix1'
            },
            doseAboveSixB: {
                qID: 'doseAboveSixB',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Y, 0), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Z, 0), 0, 0)),
                titleTexts: 'doseAboveSix1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isAnswerAgeMatches('aboveSix');
    visibleQuestions.noAnswerElement = isNoAnswerVisible();
    visibleQuestions.dosingToddlersElement = isAnswerAgeMatches('underSix');
    visibleQuestions.doseAboveSixA = isDosingAboveSixVisible();
    visibleQuestions.durationAboveSixA = isDosingAboveSixVisible();
    visibleQuestions.divider1 = isDosingAboveSixVisible();
    visibleQuestions.doseAboveSixB = isDosingAboveSixVisible();
    visibleQuestions.durationAboveSixB = isDosingAboveSixVisible();
    visibleQuestions.doseAdolescentsA = isAnswerAgeMatches('adolescents');
    visibleQuestions.durationAdolescentsA = isAnswerAgeMatches('adolescents');
    visibleQuestions.divider2 = isAnswerAgeMatches('adolescents');
    visibleQuestions.doseAdolescentsB = isAnswerAgeMatches('adolescents');
    visibleQuestions.durationAdolescentsB = isAnswerAgeMatches('adolescents');
    visibleQuestions.doseAdultsA = isAnswerAgeMatches('adults');
    visibleQuestions.durationAdultsA = isAnswerAgeMatches('adults');
    visibleQuestions.divider3 = isAnswerAgeMatches('adults');
    visibleQuestions.doseAdultsB = isAnswerAgeMatches('adults');
    visibleQuestions.durationAdultsB = isAnswerAgeMatches('adults');
    visibleQuestions.element12 = isWarningPartnersVisible();
    visibleQuestions.kidneyDisease = isWarningPartnersVisible();
    visibleQuestions.kidneyAnuria = isWarningPartnersVisible();
    visibleQuestions.element1 = isWarningPartnersVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isNoAnswerVisible();
    visibleSections.dosingUnderSix = isAnswerAgeMatches('underSix');
    visibleSections.dosingAboveSix = isDosingAboveSixVisible();
    visibleSections.dosingAdolescents = isAnswerAgeMatches('adolescents');
    visibleSections.dosingAdults = isAnswerAgeMatches('adults');
    visibleSections.warningPartners = isWarningPartnersVisible();
    visibleSections.kidney = isWarningPartnersVisible();
    visibleSections.antimicrobialWarning = isWarningPartnersVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
