"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: true,
    height: true,
    fasting: true,
    ast: true,
    alt: true,
    plateletes: true,
    albumin: true,
    notAnsweredNAFLD: false,
    notAnsweredFib: false,
    green: false,
    grey: false,
    red: false,
    fibGreen: false,
    fibGrey: false,
    fibRed: false,
    over65: false
};
var visibleSections = {
    questions: true,
    answerAll: false,
    resultRange1: false,
    note: false
};
var inputs = {
    age: null,
    weight: null,
    height: null,
    fasting: null,
    ast: null,
    alt: null,
    plateletes: null,
    albumin: null
};
var isAgeValid = function () {
    return helpers_1.numberInLimits({ input: inputs.age, min: 1, max: 120 });
};
var isWeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 200 });
};
var isHeightValid = function () {
    return helpers_1.numberInLimits({ input: inputs.height, min: 1, max: 250 });
};
var isFastingAnswered = function () {
    return helpers_1.isAnswered(inputs.fasting);
};
var isAstValid = function () {
    var _a;
    switch ((_a = inputs.ast) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return helpers_1.numberInLimits({ input: inputs.ast, min: 0.01, max: 500 });
        case 'UL':
            return helpers_1.numberInLimits({ input: inputs.ast, min: 1, max: 30000 });
        default:
            return false;
    }
};
var isAltValid = function () {
    var _a;
    switch ((_a = inputs.alt) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return helpers_1.numberInLimits({ input: inputs.alt, min: 0.01, max: 500 });
        case 'UL':
            return helpers_1.numberInLimits({ input: inputs.alt, min: 1, max: 30000 });
        default:
            return false;
    }
};
var isPlateletesValid = function () {
    return helpers_1.numberInLimits({ input: inputs.plateletes, min: 1, max: 3000 });
};
var isAlbuminValid = function () {
    var _a;
    switch ((_a = inputs.albumin) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'g/L':
            return helpers_1.numberInLimits({ input: inputs.albumin, min: 0, max: 150 });
        case 'g/dL':
            return helpers_1.numberInLimits({ input: inputs.albumin, min: 0, max: 15 });
        default:
            return false;
    }
};
var isAllAnswered = function () {
    return (isAgeValid() &&
        isWeightValid() &&
        isHeightValid() &&
        isFastingAnswered() &&
        isAstValid() &&
        isAltValid() &&
        isPlateletesValid() &&
        isAlbuminValid());
};
var isNotAnsweredFibVisible = function () {
    return (!isAgeValid() || !isAstValid() || !isAltValid() || !isPlateletesValid());
};
var isNoteVisible = function () {
    return (isAgeValid() &&
        isAstValid() &&
        isAltValid() &&
        isPlateletesValid() &&
        helpers_1.numberInLimits({ input: inputs.age, min: 65.01, max: 120 }));
};
var calculateBMI = function () {
    var _a, _b;
    if (!isAllAnswered())
        return 0;
    return (Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) /
        Math.pow(Number((_b = inputs.height) === null || _b === void 0 ? void 0 : _b.currentPoints) / 100, 2));
};
var convertAltToUL = function () {
    var _a, _b, _c;
    switch ((_a = inputs.alt) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return Number((_b = inputs.alt) === null || _b === void 0 ? void 0 : _b.currentPoints) / 0.0167;
        case 'UL':
            return Number((_c = inputs.alt) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var convertAstToUL = function () {
    var _a, _b, _c;
    switch ((_a = inputs.ast) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'µkatL':
            return Number((_b = inputs.ast) === null || _b === void 0 ? void 0 : _b.currentPoints) / 0.0167;
        case 'UL':
            return Number((_c = inputs.ast) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var convertAlbuminTogdL = function () {
    var _a, _b, _c;
    switch ((_a = inputs.albumin) === null || _a === void 0 ? void 0 : _a.currentIdentifier) {
        case 'g/L':
            return Number((_b = inputs.albumin) === null || _b === void 0 ? void 0 : _b.currentPoints) / 10;
        case 'g/dL':
            return Number((_c = inputs.albumin) === null || _c === void 0 ? void 0 : _c.currentPoints);
        default:
            return 0;
    }
};
var calculateNafldScore = function () {
    var _a, _b, _c;
    if (!isAllAnswered())
        return 0;
    var bmiScore = calculateBMI();
    var albumin = convertAlbuminTogdL();
    var alt = convertAltToUL();
    var ast = convertAstToUL();
    return (-1.675 +
        0.037 * Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        0.094 * bmiScore +
        1.13 * Number((_b = inputs.fasting) === null || _b === void 0 ? void 0 : _b.currentPoints) +
        0.99 * (ast / alt) -
        0.013 * Number((_c = inputs.plateletes) === null || _c === void 0 ? void 0 : _c.currentPoints) -
        0.66 * albumin);
};
var calculateFib4Index = function () {
    var _a, _b;
    if (isAgeValid() && isAstValid() && isAltValid() && isPlateletesValid()) {
        var alt = convertAltToUL();
        var ast = convertAstToUL();
        return ((Number((_a = inputs.age) === null || _a === void 0 ? void 0 : _a.currentPoints) * ast) /
            (Number((_b = inputs.plateletes) === null || _b === void 0 ? void 0 : _b.currentPoints) * Math.sqrt(alt)));
    }
    return 0;
};
var calculatePoints = function () {
    var greenNAFLD = 0;
    var greyNAFLD = 0;
    var redNAFLD = 0;
    var greenFib = 0;
    var greyFib = 0;
    var redFib = 0;
    if (isAllAnswered()) {
        if (calculateNafldScore() < -1.455) {
            greenNAFLD = calculateNafldScore();
        }
        if (calculateNafldScore() >= -1.455 && calculateNafldScore() <= 0.675) {
            greyNAFLD = calculateNafldScore();
        }
        if (calculateNafldScore() > 0.675) {
            redNAFLD = calculateNafldScore();
        }
    }
    if (!isNotAnsweredFibVisible()) {
        if (calculateFib4Index() < 1.3) {
            greenFib = calculateFib4Index();
        }
        if (calculateFib4Index() >= 1.3 && calculateFib4Index() <= 3.25) {
            greyFib = calculateFib4Index();
        }
        if (calculateFib4Index() > 3.25) {
            redFib = calculateFib4Index();
        }
    }
    return {
        green: {
            qID: 'green',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(greenNAFLD, 2), 2, 2)),
            rParams: [],
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        grey: {
            qID: 'grey',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(greyNAFLD, 2), 2, 2)),
            rParams: [],
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        red: {
            qID: 'red',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(redNAFLD, 2), 2, 2)),
            rParams: [],
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        fibGreen: {
            qID: 'fibGreen',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(greenFib, 2), 2, 2)),
            rParams: [],
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        fibGrey: {
            qID: 'fibGrey',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(greyFib, 2), 2, 2)),
            rParams: [],
            titleTexts: 'result1',
            resultTexts: 'result1'
        },
        fibRed: {
            qID: 'fibRed',
            tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(redFib, 2), 2, 2)),
            rParams: [],
            titleTexts: 'result1',
            resultTexts: 'result1'
        }
    };
};
var returnVisibleQuestions = function () {
    visibleQuestions.notAnsweredNAFLD = !isAllAnswered();
    visibleQuestions.notAnsweredFib = isNotAnsweredFibVisible();
    visibleQuestions.green = isAllAnswered() && calculateNafldScore() < -1.455;
    visibleQuestions.grey =
        isAllAnswered() &&
            calculateNafldScore() >= -1.455 &&
            calculateNafldScore() <= 0.675;
    visibleQuestions.red = isAllAnswered() && calculateNafldScore() > 0.675;
    visibleQuestions.fibGreen =
        !isNotAnsweredFibVisible() && calculateFib4Index() < 1.3;
    visibleQuestions.fibGrey =
        !isNotAnsweredFibVisible() &&
            calculateFib4Index() >= 1.3 &&
            calculateFib4Index() <= 3.25;
    visibleQuestions.fibRed =
        !isNotAnsweredFibVisible() && calculateFib4Index() > 3.25;
    visibleQuestions.over65 = isNoteVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.answerAll = !isAllAnswered();
    visibleSections.resultRange1 = !isNotAnsweredFibVisible();
    visibleSections.note = isNoteVisible();
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return isAllAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
