"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    weight: true,
    dvtWithComplications: true,
    crCl: true,
    resultRange11: true,
    resultRange21: false,
    resultRange31: false,
    resultRange411: false,
    resultRange421: false,
    resultRange422: false,
    resultRange511: false,
    resultRange521: false,
    resultRange522: false,
    resultRange61: false
};
var visibleSections = {
    main: true,
    resultRange1: true,
    resultRange2: false,
    resultRange3: false,
    resultRange41: false,
    resultRange42: false,
    resultRange51: false,
    resultRange52: false,
    resultRange6: false
};
var inputs = {
    weight: null,
    dvtWithComplications: null,
    crCl: null
};
var isWeightInputValid = function () {
    return (helpers_1.isAnswered(inputs.weight) &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 40, max: 150 }));
};
var isResultRange2Visible = function () {
    return (isWeightInputValid() &&
        helpers_1.answerMatches(inputs.dvtWithComplications, 'no') &&
        helpers_1.answerMatches(inputs.crCl, 'normal'));
};
var isResultRange3Visible = function () {
    return (isWeightInputValid() &&
        helpers_1.answerMatches(inputs.dvtWithComplications, 'no') &&
        helpers_1.answerMatches(inputs.crCl, 'severe'));
};
var isResultRange4Visible = function () {
    return (isWeightInputValid() &&
        helpers_1.answerMatches(inputs.dvtWithComplications, 'yes') &&
        helpers_1.answerMatches(inputs.crCl, 'severe'));
};
var isResultRange5Visible = function () {
    return (isWeightInputValid() &&
        helpers_1.answerMatches(inputs.dvtWithComplications, 'yes') &&
        helpers_1.answerMatches(inputs.crCl, 'normal'));
};
var isResultRange6Visible = function () {
    return isWeightInputValid() && helpers_1.answerMatches(inputs.crCl, 'terminal');
};
var calculateSmallDosing = function () {
    return Number(inputs.weight.currentPoints);
};
var calculateSmallIU = function () {
    return Number(inputs.weight.currentPoints) * 100;
};
var calculateBigDosing = function () {
    return Number(inputs.weight.currentPoints) * 1.5;
};
var calculateBigIU = function () {
    return Number(inputs.weight.currentPoints) * 150;
};
var calculatePoints = function () {
    if (isWeightInputValid()) {
        var smallDosing = helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateSmallDosing(), 1), 0, 1);
        var smallIU = helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateSmallIU(), 1), 0, 1);
        var bigDosing = helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBigDosing(), 1), 0, 1);
        var bigIU = helpers_1.returnNumberObject(helpers_1.formatCalculationResult(calculateBigIU(), 1), 0, 1);
        if (isResultRange2Visible()) {
            return {
                resultRange21: {
                    qID: 'resultRange21',
                    tParams: __spreadArrays(bigDosing, bigIU),
                    titleTexts: 'regular'
                }
            };
        }
        if (isResultRange3Visible()) {
            return {
                resultRange31: {
                    qID: 'resultRange31',
                    tParams: __spreadArrays(smallDosing, smallIU),
                    titleTexts: 'regular'
                }
            };
        }
        if (isResultRange4Visible()) {
            return {
                resultRange411: {
                    qID: 'resultRange411',
                    tParams: __spreadArrays(smallDosing, smallIU),
                    titleTexts: 'regular'
                },
                resultRange421: {
                    qID: 'resultRange421',
                    tParams: [],
                    titleTexts: 'regular'
                },
                resultRange422: {
                    qID: 'resultRange422',
                    resultTexts: 'regular',
                    tParams: __spreadArrays(smallDosing, smallIU),
                    titleTexts: 'regular'
                }
            };
        }
        if (isResultRange5Visible()) {
            return {
                resultRange511: {
                    qID: 'resultRange511',
                    tParams: __spreadArrays(smallDosing, smallIU),
                    titleTexts: 'regular'
                },
                resultRange521: {
                    qID: 'resultRange521',
                    tParams: [],
                    titleTexts: 'regular'
                },
                resultRange522: {
                    qID: 'resultRange522',
                    resultTexts: 'regular',
                    tParams: __spreadArrays(smallDosing, smallIU, bigDosing, bigIU),
                    titleTexts: 'regular'
                }
            };
        }
        return {
            resultRange61: {
                qID: 'resultRange61',
                tParams: [],
                titleTexts: 'regular'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.resultRange11 = !isWeightInputValid();
    visibleQuestions.resultRange21 = isResultRange2Visible();
    visibleQuestions.resultRange31 = isResultRange3Visible();
    visibleQuestions.resultRange61 = isResultRange6Visible();
    visibleQuestions.resultRange411 = isResultRange4Visible();
    visibleQuestions.resultRange421 = isResultRange4Visible();
    visibleQuestions.resultRange422 = isResultRange4Visible();
    visibleQuestions.resultRange511 = isResultRange5Visible();
    visibleQuestions.resultRange521 = isResultRange5Visible();
    visibleQuestions.resultRange522 = isResultRange5Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.resultRange1 = !isWeightInputValid();
    visibleSections.resultRange2 = isResultRange2Visible();
    visibleSections.resultRange3 = isResultRange3Visible();
    visibleSections.resultRange41 = isResultRange4Visible();
    visibleSections.resultRange42 = isResultRange4Visible();
    visibleSections.resultRange51 = isResultRange5Visible();
    visibleSections.resultRange52 = isResultRange5Visible();
    visibleSections.resultRange6 = isResultRange6Visible();
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
