"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var measurements = [];
var visibleQuestions = {
    info: true,
    date: true,
    psaValue: true,
    addMeasurement: false,
    dateWarning: false,
    measurement1: false,
    measurement2: false,
    measurement3: false,
    measurement4: false,
    measurement5: false,
    measurement6: false,
    measurement7: false,
    measurement8: false,
    measurement9: false,
    measurement10: false,
    measurement11: false,
    measurement12: false,
    measurement13: false,
    measurement14: false,
    measurement15: false,
    measurement16: false,
    measurement17: false,
    measurement18: false,
    measurement19: false,
    measurement20: false,
    deleteMeasurement: false,
    resultsInfo: false,
    result1: false
};
var visibleSections = {
    inputSection: true,
    measurementSection: false,
    resultsSection: false
};
var inputs = {
    date: null,
    psaValue: null
};
var average = function (a) {
    var sum = a.reduce(function (i, j) { return i + j; }, 0);
    return sum / a.length || 0;
};
var multiply = function (arr1, arr2) {
    return arr1.map(function (x, index) {
        return arr2[index] * x;
    });
};
var doublingTime = function (xs, ys) {
    var sum1 = average(multiply(ys, xs)) - average(xs) * average(ys);
    var sum2 = average(multiply(xs, xs)) - Math.pow(average(xs), 2);
    var slope = sum1 / sum2;
    return Math.log(2) / slope;
};
var getDoublingTime = function () {
    var xsYears = measurements.map(function (item) { return Math.round(item.date / 86400) / 365.25; });
    var ys = measurements.map(function (item) { return Math.log(item.value); });
    return doublingTime(xsYears, ys);
};
var doublingTimeOver100 = function () {
    var doublingTimeY = getDoublingTime();
    return doublingTimeY > 100 || isNaN(doublingTimeY);
};
var doublingTimeUnderNeg100 = function () {
    var doublingTimeY = getDoublingTime();
    return doublingTimeY < -100 || isNaN(doublingTimeY);
};
var calculatePoints = function () {
    if (measurements.length === 0)
        return null;
    var result = {};
    var sortedMeasurements = __spreadArrays(measurements).sort(function (a, b) { return a.date - b.date; });
    sortedMeasurements.forEach(function (measurement, index) {
        var _a;
        result = __assign(__assign({}, result), (_a = {}, _a[("measurement" + (index + 1)).toString()] = {
            qID: ("measurement" + (index + 1)).toString(),
            tParams: [{ type: "date", value: measurement.date }],
            rParams: helpers_1.returnNumberObject(measurement.value, 1, 2),
            titleTexts: "date",
            resultTexts: "psaValue"
        }, _a));
    });
    if (measurements.length >= 2) {
        var xsMonths = measurements.map(function (item) { return (Math.round(item.date / 86400) / 365.25) * 12; });
        var xsYears = measurements.map(function (item) { return Math.round(item.date / 86400) / 365.25; });
        var ys = measurements.map(function (item) { return Math.log(item.value); });
        var doublingTimeM = doublingTime(xsMonths, ys);
        var doublingTimeY = doublingTime(xsYears, ys);
        if (doublingTimeOver100()) {
            return __assign(__assign({}, result), { result1: {
                    qID: "result1",
                    titleTexts: "title",
                    rParams: [],
                    resultTexts: "over100"
                } });
        }
        else if (doublingTimeUnderNeg100()) {
            return __assign(__assign({}, result), { result1: {
                    qID: "result1",
                    titleTexts: "title",
                    rParams: [],
                    resultTexts: "underNeg100"
                } });
        }
        return __assign(__assign({}, result), { result1: {
                qID: "result1",
                titleTexts: "title",
                rParams: __spreadArrays(helpers_1.returnNumberObject(doublingTimeM, 1, 1), helpers_1.returnNumberObject(doublingTimeY, 1, 1)),
                resultTexts: "regular"
            } });
    }
    return result;
};
var isPsaValid = function () {
    var _a, _b;
    return (helpers_1.isAnswered(inputs.psaValue) &&
        Number((_a = inputs.psaValue) === null || _a === void 0 ? void 0 : _a.currentPoints) >= 0.1 &&
        Number((_b = inputs.psaValue) === null || _b === void 0 ? void 0 : _b.currentPoints) <= 30000);
};
var isAddMeasurementVisible = function () {
    return helpers_1.isAnswered(inputs.date) && isPsaValid() && !isDateWarningVisible();
};
var isMeasurementVisible = function (nr) {
    return measurements.length >= nr;
};
var isMeasurementsVisible = function () {
    return measurements.length > 0;
};
var isResultsVisible = function () {
    return measurements.length >= 2;
};
var isDateWarningVisible = function () {
    return (measurements.find(function (item) {
        var _a;
        var itemDate = helpers_1.unixToDate(Number(item.date));
        itemDate.setHours(0);
        itemDate.setMinutes(0);
        itemDate.setSeconds(0);
        itemDate.setMilliseconds(0);
        var currentDate = helpers_1.unixToDate(Number((_a = inputs.date) === null || _a === void 0 ? void 0 : _a.currentDate));
        currentDate.setHours(0);
        currentDate.setMinutes(0);
        currentDate.setSeconds(0);
        currentDate.setMilliseconds(0);
        return itemDate.getTime() === currentDate.getTime();
    }) !== undefined);
};
var returnVisibleQuestions = function () {
    visibleQuestions.addMeasurement = isAddMeasurementVisible();
    visibleQuestions.measurement1 = isMeasurementVisible(1);
    visibleQuestions.measurement2 = isMeasurementVisible(2);
    visibleQuestions.measurement3 = isMeasurementVisible(3);
    visibleQuestions.measurement4 = isMeasurementVisible(4);
    visibleQuestions.measurement5 = isMeasurementVisible(5);
    visibleQuestions.measurement6 = isMeasurementVisible(6);
    visibleQuestions.measurement7 = isMeasurementVisible(7);
    visibleQuestions.measurement8 = isMeasurementVisible(8);
    visibleQuestions.measurement9 = isMeasurementVisible(9);
    visibleQuestions.measurement10 = isMeasurementVisible(10);
    visibleQuestions.measurement11 = isMeasurementVisible(11);
    visibleQuestions.measurement12 = isMeasurementVisible(12);
    visibleQuestions.measurement13 = isMeasurementVisible(13);
    visibleQuestions.measurement14 = isMeasurementVisible(14);
    visibleQuestions.measurement15 = isMeasurementVisible(15);
    visibleQuestions.measurement16 = isMeasurementVisible(16);
    visibleQuestions.measurement17 = isMeasurementVisible(17);
    visibleQuestions.measurement18 = isMeasurementVisible(18);
    visibleQuestions.measurement19 = isMeasurementVisible(19);
    visibleQuestions.measurement20 = isMeasurementVisible(20);
    visibleQuestions.deleteMeasurement = isMeasurementsVisible();
    visibleQuestions.resultsInfo = isMeasurementsVisible() && !isResultsVisible();
    visibleQuestions.result1 = isMeasurementsVisible() && isResultsVisible();
    visibleQuestions.dateWarning =
        isMeasurementsVisible() && isDateWarningVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.measurementSection = isMeasurementsVisible();
    visibleSections.resultsSection = isMeasurementsVisible();
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var ut_actionResolver = function (action) {
    return actionResolver(action);
};
var isExportResultsEnabled = function () {
    return isResultsVisible();
};
var actionResolver = function (action) {
    switch (action) {
        case "addMeasurement":
            return addMeasurement();
        case "deleteMeasurement":
            return deleteMeasurement();
        case "deleteAllMeasurements":
            measurements = [];
            return null;
        default:
            return null;
    }
};
var addMeasurement = function () {
    var _a, _b;
    measurements = __spreadArrays(measurements, [
        {
            date: (_a = inputs.date) === null || _a === void 0 ? void 0 : _a.currentDate,
            value: (_b = inputs.psaValue) === null || _b === void 0 ? void 0 : _b.currentPoints
        },
    ]);
    var updatedInputs = {
        date: helpers_1.generatePropsObject("emptyAnswerIdentifier", null, null, "date"),
        psaValue: helpers_1.generatePropsObject("emptyAnswerIdentifier", null, null, "number")
    };
    return updatedInputs;
};
var deleteMeasurement = function () {
    measurements.pop();
    return null;
};
var returnResult = function () {
    var result = calculatePoints();
    return __assign(__assign({}, (result && { result: result })), { exportResultsEnabled: isExportResultsEnabled(), visibleQuestions: ut_visibleQuestions(), visibleSections: ut_visibleSections(), actionResolver: ut_actionResolver });
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return returnResult();
});
