"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    renalA: false,
    renalK: false,
    dosing1: true,
    babyDose1: false,
    kidsDose1: false,
    durationK: false,
    redK: false,
    durationRedK: false,
    infection: false,
    adultDoseResult: false,
    durationA: false,
    redAlow: false,
    redAmedium: false,
    durationRedA: false,
    warA: false,
    warK: false,
    anti2: false
};
var visibleSections = {
    ageSelection: true,
    dosing: true,
    babyDose: false,
    kidsDose: false,
    doseReductionK: false,
    adultsDose: false,
    doseReductionA: false,
    warnings: false,
    anti: false
};
var inputs = {
    age: null,
    weight: null,
    renalA: null,
    renalK: null
};
var calculatePoints = function () {
    var _a;
    var weight = Number((_a = inputs === null || inputs === void 0 ? void 0 : inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
    if (isKidsDoseVisible()) {
        var X = weight >= 40 ? 4000 : weight * 100;
        var Y = weight >= 40 ? 500 : weight * 12.5;
        return {
            kidsDose1: {
                qID: 'kidsDose1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(X, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Y, 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    if (isDoseReductionKVisible()) {
        var X = weight >= 57.1 ? 4000 : weight * 70;
        var Y = weight >= 57.1 ? 500 : weight * 8.75;
        return {
            redK: {
                qID: 'redK',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(X, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(Y, 1), 0, 1)),
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isRenalAVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isRenalKVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 });
};
var isAnswerAllVisible = function () {
    return !(helpers_1.answerMatches(inputs.age, 'babies') ||
        (helpers_1.answerMatches(inputs.age, 'kids') &&
            helpers_1.isAnswered(inputs.weight) &&
            helpers_1.isAnswered(inputs.renalK)) ||
        (helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.isAnswered(inputs.renalA)));
};
var isBabyDoseVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'babies');
};
var isKidsDoseVisible = function () {
    return helpers_1.answerMatches(inputs.renalK, 'highK');
};
var isDoseReductionKVisible = function () {
    return helpers_1.answerMatches(inputs.renalK, 'lowK');
};
var isAdultsDoseVisible = function () {
    return helpers_1.answerMatches(inputs.renalA, 'highA');
};
var isDoseReductionAVisible = function () {
    return (helpers_1.answerMatches(inputs.renalA, 'lowA') ||
        helpers_1.answerMatches(inputs.renalA, 'mediumA'));
};
var isRedAlowVisible = function () {
    return helpers_1.answerMatches(inputs.renalA, 'lowA');
};
var isRedAmediumVisible = function () {
    return helpers_1.answerMatches(inputs.renalA, 'mediumA');
};
var isAntiVisible = function () {
    return helpers_1.isAnswered(inputs.renalA) || helpers_1.isAnswered(inputs.renalK);
};
var isWarningVisible = function () {
    return isRedAlowVisible() || isDoseReductionKVisible();
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.renalA = isRenalAVisible();
    visibleQuestions.renalK = isRenalKVisible();
    visibleQuestions.dosing1 = isAnswerAllVisible();
    visibleQuestions.babyDose1 = isBabyDoseVisible();
    visibleQuestions.kidsDose1 = isKidsDoseVisible();
    visibleQuestions.durationK = isKidsDoseVisible();
    visibleQuestions.redK = isDoseReductionKVisible();
    visibleQuestions.durationRedK = isDoseReductionKVisible();
    visibleQuestions.adultDoseResult = isAdultsDoseVisible();
    visibleQuestions.durationA = isAdultsDoseVisible();
    visibleQuestions.infection = isAdultsDoseVisible();
    visibleQuestions.redAlow = isRedAlowVisible();
    visibleQuestions.redAmedium = isRedAmediumVisible();
    visibleQuestions.durationRedA = isDoseReductionAVisible();
    visibleQuestions.warA = isRedAlowVisible();
    visibleQuestions.warK = isDoseReductionKVisible();
    visibleQuestions.anti2 = isAntiVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = isAnswerAllVisible();
    visibleSections.babyDose = isBabyDoseVisible();
    visibleSections.kidsDose = isKidsDoseVisible();
    visibleSections.doseReductionK = isDoseReductionKVisible();
    visibleSections.adultsDose = isAdultsDoseVisible();
    visibleSections.doseReductionA = isDoseReductionAVisible();
    visibleSections.warnings = isWarningVisible();
    visibleSections.anti = isAntiVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
