"use strict";


var visibleQuestions = {
    age: true,
    clearance: true,
    drug: true,
    gastritis: true,
    bleeding: true,
    dose: true,
    duration: true,
    doseRR: true,
    durationRR: true,
    rc: true,
    doseRC: true,
    durationRC: true,
    warningC: true,
    warningVerapamil: true,
    warningW: true,
    noAnswerResult: true
};
var visibleSections = {
    characteristicsSelection: true,
    dosingNormal: true,
    doseReductionRecommended: true,
    doseReductionConsideration: true,
    warningClearance: true,
    warningWeight: true,
    noAnswer: true
};
var inputs = {
    age: null,
    clearance: null,
    drug: null,
    gastritis: null,
    bleeding: null
};
var isClearanceVisible = function () {
    return helpers_1.isAnswered(inputs.age);
};
var isDrugVisible = function () {
    return (helpers_1.answerMatches(inputs.clearance, 'clearance2') ||
        helpers_1.answerMatches(inputs.clearance, 'clearance3'));
};
var isGastritisVisible = function () {
    return helpers_1.isAnswered(inputs.drug);
};
var isBleedingVisible = function () {
    return helpers_1.isAnswered(inputs.gastritis);
};
var isDosingNormalVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'age1') &&
        helpers_1.answerMatches(inputs.clearance, 'clearance3') &&
        helpers_1.answerMatches(inputs.drug, 'drug1') &&
        helpers_1.answerMatches(inputs.gastritis, 'gastritis1') &&
        helpers_1.answerMatches(inputs.bleeding, 'bleeding1'));
};
var isDoseReductionRecommendedVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.age, 'age3') &&
        isDrugVisible() &&
        helpers_1.isAnswered(inputs.drug) &&
        helpers_1.isAnswered(inputs.gastritis) &&
        helpers_1.isAnswered(inputs.bleeding);
    var condition2 = helpers_1.isAnswered(inputs.age) &&
        isDrugVisible() &&
        helpers_1.answerMatches(inputs.drug, 'drug2') &&
        helpers_1.isAnswered(inputs.gastritis) &&
        helpers_1.isAnswered(inputs.bleeding);
    return condition1 || condition2;
};
var isDoseReductionConsiderationVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.age, 'age2') &&
        isDrugVisible() &&
        helpers_1.answerMatches(inputs.drug, 'drug1') &&
        helpers_1.isAnswered(inputs.gastritis) &&
        helpers_1.isAnswered(inputs.bleeding);
    var condition2 = (helpers_1.answerMatches(inputs.age, 'age1') || helpers_1.answerMatches(inputs.age, 'age2')) &&
        helpers_1.answerMatches(inputs.clearance, 'clearance2') &&
        helpers_1.answerMatches(inputs.drug, 'drug1') &&
        helpers_1.isAnswered(inputs.gastritis) &&
        helpers_1.isAnswered(inputs.bleeding);
    var condition3 = (helpers_1.answerMatches(inputs.age, 'age1') || helpers_1.answerMatches(inputs.age, 'age2')) &&
        isDrugVisible() &&
        helpers_1.answerMatches(inputs.drug, 'drug1') &&
        helpers_1.answerMatches(inputs.gastritis, 'gastritis2') &&
        helpers_1.isAnswered(inputs.bleeding);
    var condition4 = (helpers_1.answerMatches(inputs.age, 'age1') || helpers_1.answerMatches(inputs.age, 'age2')) &&
        isDrugVisible() &&
        helpers_1.answerMatches(inputs.drug, 'drug1') &&
        helpers_1.isAnswered(inputs.gastritis) &&
        helpers_1.answerMatches(inputs.bleeding, 'bleeding2');
    return condition1 || condition2 || condition3 || condition4;
};
var isWarningClearanceVisible = function () {
    return helpers_1.answerMatches(inputs.clearance, 'clearance1');
};
var isWarningWeightVisible = function () {
    return helpers_1.isAnswered(inputs.bleeding);
};
var isWarningVerapamilVisible = function () {
    return isWarningWeightVisible() && helpers_1.answerMatches(inputs.drug, 'drug2');
};
var isNoAnswerVisible = function () {
    var condition1 = !helpers_1.isAnswered(inputs.age);
    var condition2 = helpers_1.isAnswered(inputs.age) && !helpers_1.isAnswered(inputs.clearance);
    var condition3 = !helpers_1.isAnswered(inputs.drug) && isDrugVisible();
    var condition4 = !helpers_1.isAnswered(inputs.gastritis) && isDrugVisible();
    var condition5 = !helpers_1.isAnswered(inputs.bleeding) && helpers_1.isAnswered(inputs.gastritis);
    return condition1 || condition2 || condition3 || condition4 || condition5;
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.clearance = isClearanceVisible();
    visibleQuestions.drug = isDrugVisible();
    visibleQuestions.gastritis = isGastritisVisible();
    visibleQuestions.bleeding = isBleedingVisible();
    visibleQuestions.dose = isDosingNormalVisible();
    visibleQuestions.duration = isDosingNormalVisible();
    visibleQuestions.doseRR = isDoseReductionRecommendedVisible();
    visibleQuestions.durationRR = isDoseReductionRecommendedVisible();
    visibleQuestions.rc = isDoseReductionConsiderationVisible();
    visibleQuestions.doseRC = isDoseReductionConsiderationVisible();
    visibleQuestions.durationRC = isDoseReductionConsiderationVisible();
    visibleQuestions.warningC = isWarningClearanceVisible();
    visibleQuestions.warningVerapamil = isWarningVerapamilVisible();
    visibleQuestions.warningW = isWarningWeightVisible();
    visibleQuestions.noAnswerResult = isNoAnswerVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosingNormal = isDosingNormalVisible();
    visibleSections.doseReductionRecommended =
        isDoseReductionRecommendedVisible();
    visibleSections.doseReductionConsideration =
        isDoseReductionConsiderationVisible();
    visibleSections.warningClearance = isWarningClearanceVisible();
    visibleSections.warningWeight = isWarningWeightVisible();
    visibleSections.noAnswer = isNoAnswerVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
