"use strict";


var visibleQuestions = {
    replacement: true,
    clearance: true,
    drug: true,
    age: true,
    kneeInitiation: true,
    kneeMaintenance: true,
    kneeDuration: true,
    hipInitiation: true,
    hipMaintenance: true,
    hipDuration: true,
    kneeReductionInitiation: true,
    kneeReductionMaintenance: true,
    kneeReductionDuration: true,
    kneeWarning: true,
    hipReductionInitiation: true,
    hipReductionMaintenance1: true,
    hipReductionDuration: true,
    hipWarning: true,
    warningVerapamil: true,
    warningHaemostasis: true,
    warningWeight: true,
    warningC: true,
    noAnswerResult: true
};
var visibleSections = {
    characteristicsSelection: true,
    kneeDosing: true,
    hipDosing: true,
    kneeDosingReduction: true,
    hipDosingReduction: true,
    warnings: true,
    warningClearance: true,
    noAnswer: true
};
var inputs = {
    replacement: null,
    clearance: null,
    drug: null,
    age: null
};
var isClearanceVisible = function () {
    return helpers_1.isAnswered(inputs.replacement);
};
var isDrugVisible = function () {
    return (helpers_1.answerMatches(inputs.clearance, 'clearance2') ||
        helpers_1.answerMatches(inputs.clearance, 'clearance3'));
};
var isAgeVisible = function () {
    return helpers_1.isAnswered(inputs.drug);
};
var isKneeDosingVisible = function () {
    return (helpers_1.answerMatches(inputs.replacement, 'knee') &&
        helpers_1.answerMatches(inputs.clearance, 'clearance3') &&
        helpers_1.answerMatches(inputs.drug, 'no') &&
        helpers_1.answerMatches(inputs.age, 'no'));
};
var isHipDosingVisible = function () {
    return (helpers_1.answerMatches(inputs.replacement, 'hip') &&
        helpers_1.answerMatches(inputs.clearance, 'clearance3') &&
        helpers_1.answerMatches(inputs.drug, 'no') &&
        helpers_1.answerMatches(inputs.age, 'no'));
};
var isKneeDosingReductionVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.replacement, 'knee') &&
        helpers_1.answerMatches(inputs.clearance, 'clearance2') &&
        helpers_1.isAnswered(inputs.drug) &&
        helpers_1.isAnswered(inputs.age);
    var condition2 = helpers_1.answerMatches(inputs.replacement, 'knee') &&
        helpers_1.isAnswered(inputs.clearance) &&
        helpers_1.answerMatches(inputs.drug, 'yes') &&
        helpers_1.isAnswered(inputs.age);
    var condition3 = helpers_1.answerMatches(inputs.replacement, 'knee') &&
        helpers_1.isAnswered(inputs.clearance) &&
        helpers_1.isAnswered(inputs.drug) &&
        helpers_1.answerMatches(inputs.age, 'yes');
    return condition1 || condition2 || condition3;
};
var isKneeWarningVisible = function () {
    return (isKneeDosingReductionVisible() &&
        helpers_1.answerMatches(inputs.clearance, 'clearance2') &&
        helpers_1.answerMatches(inputs.drug, 'yes'));
};
var isHipDosingReductionVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.replacement, 'hip') &&
        helpers_1.answerMatches(inputs.clearance, 'clearance2') &&
        helpers_1.isAnswered(inputs.drug) &&
        helpers_1.isAnswered(inputs.age);
    var condition2 = helpers_1.answerMatches(inputs.replacement, 'hip') &&
        helpers_1.isAnswered(inputs.clearance) &&
        helpers_1.answerMatches(inputs.drug, 'yes') &&
        helpers_1.isAnswered(inputs.age);
    var condition3 = helpers_1.answerMatches(inputs.replacement, 'hip') &&
        helpers_1.isAnswered(inputs.clearance) &&
        helpers_1.isAnswered(inputs.drug) &&
        helpers_1.answerMatches(inputs.age, 'yes');
    return condition1 || condition2 || condition3;
};
var isHipWarningVisible = function () {
    return (isHipDosingReductionVisible() &&
        helpers_1.answerMatches(inputs.clearance, 'clearance2') &&
        helpers_1.answerMatches(inputs.drug, 'yes'));
};
var isWarningClearanceVisible = function () {
    return helpers_1.answerMatches(inputs.clearance, 'clearance1');
};
var isWarningsVisible = function () {
    return helpers_1.isAnswered(inputs.age);
};
var isWarningVerapamil = function () {
    return isWarningsVisible() && helpers_1.answerMatches(inputs.drug, 'yes');
};
var isNoAnswerVisible = function () {
    var condition1 = !helpers_1.isAnswered(inputs.replacement);
    var condition2 = helpers_1.isAnswered(inputs.replacement) && !helpers_1.isAnswered(inputs.clearance);
    var condition3 = !helpers_1.isAnswered(inputs.drug) && isDrugVisible();
    var condition4 = !helpers_1.isAnswered(inputs.age) && isDrugVisible();
    return condition1 || condition2 || condition3 || condition4;
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.clearance = isClearanceVisible();
    visibleQuestions.drug = isDrugVisible();
    visibleQuestions.age = isAgeVisible();
    visibleQuestions.kneeInitiation = isKneeDosingVisible();
    visibleQuestions.kneeMaintenance = isKneeDosingVisible();
    visibleQuestions.kneeDuration = isKneeDosingVisible();
    visibleQuestions.hipInitiation = isHipDosingVisible();
    visibleQuestions.hipMaintenance = isHipDosingVisible();
    visibleQuestions.hipDuration = isHipDosingVisible();
    visibleQuestions.kneeReductionInitiation = isKneeDosingReductionVisible();
    visibleQuestions.kneeReductionMaintenance = isKneeDosingReductionVisible();
    visibleQuestions.kneeReductionDuration = isKneeDosingReductionVisible();
    visibleQuestions.kneeWarning = isKneeWarningVisible();
    visibleQuestions.hipReductionInitiation = isHipDosingReductionVisible();
    visibleQuestions.hipReductionMaintenance1 = isHipDosingReductionVisible();
    visibleQuestions.hipReductionDuration = isHipDosingReductionVisible();
    visibleQuestions.hipWarning = isHipWarningVisible();
    visibleQuestions.warningVerapamil = isWarningVerapamil();
    visibleQuestions.warningHaemostasis = isWarningsVisible();
    visibleQuestions.warningWeight = isWarningsVisible();
    visibleQuestions.warningC = isWarningClearanceVisible();
    visibleQuestions.noAnswerResult = isNoAnswerVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.kneeDosing = isKneeDosingVisible();
    visibleSections.hipDosing = isHipDosingVisible();
    visibleSections.kneeDosingReduction = isKneeDosingReductionVisible();
    visibleSections.hipDosingReduction = isHipDosingReductionVisible();
    visibleSections.warnings = isWarningsVisible();
    visibleSections.warningClearance = isWarningClearanceVisible();
    visibleSections.noAnswer = isNoAnswerVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
