"use strict";


var visibleQuestions = {
    age: true,
    weight: true,
    renal: true,
    warningR: true,
    initiation: true,
    capsule1: true,
    capsule2: true,
    capsule3: true,
    capsule4: true,
    capsule5: true,
    capsule6: true,
    capsule7: true,
    capsuleNo: true,
    intervalCapsules: true,
    durationCapsules: true,
    granule2: true,
    granule3: true,
    granule4: true,
    granule5: true,
    granule6: true,
    granule7: true,
    granule8: true,
    granule9: true,
    granule10: true,
    granule11: true,
    granule12: true,
    granule13: true,
    granule14: true,
    granule15: true,
    granuleNo: true,
    intervalGranules: true,
    durationGranules: true,
    solution1: true,
    solution2: true,
    solution3: true,
    solution4: true,
    solution5: true,
    solution6: true,
    solution7: true,
    solution8: true,
    solution9: true,
    solution10: true,
    solution11: true,
    solutionNo: true,
    intervalSolution: true,
    durationSolution: true,
    noAnswerResult: true
};
var visibleSections = {
    characteristicsSelection: true,
    warningRenal: true,
    start: true,
    dosingCapsules: true,
    dosingGranules: true,
    dosingOralsolution: true,
    noAnswer: true
};
var inputs = {
    age: null,
    weight: null,
    renal: null
};
var currentDate = new Date();
var calculateAgeInMonths = function () {
    return helpers_1.differenceBetweenMonths(currentDate, helpers_1.unixToDate(Number(inputs.age.currentDate)));
};
var ageInLimits = function (_a) {
    var age = _a.age, min = _a.min, max = _a.max;
    return age >= min && age < max;
};
var ageAndWeightInLimits = function (_a) {
    var currentAge = _a.currentAge, minAge = _a.minAge, maxAge = _a.maxAge, minWeight = _a.minWeight, maxWeight = _a.maxWeight;
    return (ageInLimits({
        age: currentAge,
        min: minAge,
        max: maxAge
    }) &&
        helpers_1.numberInLimits({ input: inputs.weight, min: minWeight, max: maxWeight }));
};
var isWeightVisible = function () {
    return helpers_1.isAnsweredDate(inputs.age);
};
var isRenalVisible = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 2.5, max: 300 });
};
var isWarningRenalVisible = function () {
    return helpers_1.answerMatches(inputs.renal, 'less');
};
var isStartVisible = function (ageInMonths) {
    return (helpers_1.answerMatches(inputs.renal, 'more') &&
        ((isDosingCapsulesVisible(ageInMonths) &&
            !isCapsuleNoVisible(ageInMonths)) ||
            (isDosingGranulesVisible(ageInMonths) &&
                !isGranuleNoVisible(ageInMonths)) ||
            (isDosingOralsolutionVisible(ageInMonths) &&
                !isSolutionNoVisible(ageInMonths))));
};
var isDosingCapsulesVisible = function (ageInMonths) {
    var ageInYears = ageInMonths / 12;
    return helpers_1.answerMatches(inputs.renal, 'more') && ageInYears >= 8;
};
var isDosingGranulesVisible = function (ageInMonths) {
    var ageInYears = ageInMonths / 12;
    return helpers_1.answerMatches(inputs.renal, 'more') && ageInYears < 12;
};
var isDosingOralsolutionVisible = function (ageInMonths) {
    return (helpers_1.answerMatches(inputs.renal, 'more') &&
        ageInMonths < 12 &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 2.5, max: 15.99 }));
};
var isNoAnswerVisible = function () {
    return (!isWeightVisible() ||
        (isWeightVisible() && !isRenalVisible()) ||
        (isRenalVisible() && !helpers_1.isAnswered(inputs.renal)));
};
var isCapsule1Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 10,
        maxAge: 18,
        minWeight: 81.1,
        maxWeight: 300
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 8,
            maxAge: 18,
            minWeight: 61,
            maxWeight: 81
        }));
};
var isCapsule2Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 18,
        minWeight: 51,
        maxWeight: 60.99
    });
};
var isCapsule3Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 18,
        minWeight: 41,
        maxWeight: 50.99
    });
};
var isCapsule4Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 18,
        minWeight: 31,
        maxWeight: 40.99
    });
};
var isCapsule5Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 18,
        minWeight: 26,
        maxWeight: 30.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 8,
            maxAge: 16,
            minWeight: 21,
            maxWeight: 25.99
        }));
};
var isCapsule6Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 14,
        minWeight: 16,
        maxWeight: 20.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 8,
            maxAge: 11,
            minWeight: 13,
            maxWeight: 15.99
        }));
};
var isCapsule7Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 9,
        minWeight: 11,
        maxWeight: 12.99
    });
};
var isCapsuleNoVisible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 8,
        maxAge: 10,
        minWeight: 81.1,
        maxWeight: 300
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 16,
            maxAge: 18,
            minWeight: 21,
            maxWeight: 25.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 14,
            maxAge: 18,
            minWeight: 16,
            maxWeight: 20.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 11,
            maxAge: 18,
            minWeight: 13,
            maxWeight: 15.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 9,
            maxAge: 18,
            minWeight: 11,
            maxWeight: 12.99
        }));
};
var isIntervalAndDurationCapsulesVisible = function (ageInMonths) {
    return (isDosingCapsulesVisible(ageInMonths) && !isCapsuleNoVisible(ageInMonths));
};
var isGranule2Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 5,
        maxAge: 12,
        minWeight: 51,
        maxWeight: 60.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 6,
            maxAge: 12,
            minWeight: 61,
            maxWeight: 70.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 7,
            maxAge: 12,
            minWeight: 71,
            maxWeight: 80.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 10,
            maxAge: 12,
            minWeight: 81,
            maxWeight: 299.99
        }));
};
var isGranule3Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 4,
        maxAge: 12,
        minWeight: 41,
        maxWeight: 50.99
    });
};
var isGranule4Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 2.5,
        maxAge: 12,
        minWeight: 31,
        maxWeight: 40.99
    });
};
var isGranule5Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 2.5,
        maxAge: 12,
        minWeight: 26,
        maxWeight: 30.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2,
            maxAge: 12,
            minWeight: 21,
            maxWeight: 25.99
        }));
};
var isGranule6Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 1.5,
        maxAge: 2,
        minWeight: 21,
        maxWeight: 25.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2,
            maxAge: 12,
            minWeight: 13,
            maxWeight: 20.99
        }));
};
var isGranule7Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 1,
        maxAge: 2,
        minWeight: 16,
        maxWeight: 20.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 1.5,
            maxAge: 2,
            minWeight: 13,
            maxWeight: 15.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2.5,
            maxAge: 9,
            minWeight: 11,
            maxWeight: 12.99
        }));
};
var isGranule8Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 11,
        maxAge: 18,
        minWeight: 13,
        maxWeight: 15.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 1.5,
            maxAge: 2.5,
            minWeight: 11,
            maxWeight: 12.99
        }));
};
var isGranule9Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 10,
        maxAge: 11,
        minWeight: 13,
        maxWeight: 15.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 10,
            maxAge: 18,
            minWeight: 11,
            maxWeight: 12.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 1.5,
            maxAge: 7,
            minWeight: 9,
            maxWeight: 10.99
        }));
};
var isGranule10Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 8,
        maxAge: 10,
        minWeight: 11,
        maxWeight: 12.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 11,
            maxAge: 18,
            minWeight: 9,
            maxWeight: 10.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2,
            maxAge: 4,
            minWeight: 7,
            maxWeight: 8.99
        }));
};
var isGranule11Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 6,
        maxAge: 11,
        minWeight: 9,
        maxWeight: 10.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 9,
            maxAge: 24,
            minWeight: 7,
            maxWeight: 8.99
        }));
};
var isGranule12Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 5,
        maxAge: 6,
        minWeight: 9,
        maxWeight: 10.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 4,
            maxAge: 9,
            minWeight: 7,
            maxWeight: 8.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 8,
            maxAge: 24,
            minWeight: 5,
            maxWeight: 6.99
        }));
};
var isGranule13Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 3,
        maxAge: 4,
        minWeight: 7,
        maxWeight: 8.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 5,
            maxAge: 8,
            minWeight: 5,
            maxWeight: 6.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 8,
            maxAge: 10,
            minWeight: 4,
            maxWeight: 4.99
        }));
};
var isGranule14Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 1,
        maxAge: 5,
        minWeight: 5,
        maxWeight: 6.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 3,
            maxAge: 8,
            minWeight: 4,
            maxWeight: 4.99
        }));
};
var isGranule15Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 0,
        maxAge: 1,
        minWeight: 5,
        maxWeight: 6.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 1,
            maxAge: 3,
            minWeight: 4,
            maxWeight: 4.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 3,
            maxAge: 6,
            minWeight: 3,
            maxWeight: 3.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 4,
            maxAge: 5,
            minWeight: 2.5,
            maxWeight: 2.99
        }));
};
var isGranuleNoVisible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths / 12,
        minAge: 2.5,
        maxAge: 10,
        minWeight: 81.1,
        maxWeight: 300
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2.5,
            maxAge: 7,
            minWeight: 71,
            maxWeight: 80.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2.5,
            maxAge: 6,
            minWeight: 61,
            maxWeight: 70.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2.5,
            maxAge: 5,
            minWeight: 51,
            maxWeight: 60.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2.5,
            maxAge: 4,
            minWeight: 41,
            maxWeight: 50.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 18,
            minWeight: 21,
            maxWeight: 25.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 12,
            minWeight: 16,
            maxWeight: 20.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 10,
            minWeight: 13,
            maxWeight: 15.99
        }) ||
        ((ageInLimits({
            age: ageInMonths,
            min: 0,
            max: 8
        }) ||
            ageInLimits({
                age: ageInMonths / 12,
                min: 9,
                max: 12
            })) &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 11, max: 12.99 })) ||
        ((ageInLimits({
            age: ageInMonths,
            min: 0,
            max: 5
        }) ||
            ageInLimits({
                age: ageInMonths / 12,
                min: 7,
                max: 12
            })) &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 9, max: 10.99 })) ||
        ((ageInLimits({
            age: ageInMonths,
            min: 0,
            max: 3
        }) ||
            ageInLimits({
                age: ageInMonths / 12,
                min: 4,
                max: 12
            })) &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 7, max: 8.99 })) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths / 12,
            minAge: 2,
            maxAge: 2.5,
            minWeight: 5,
            maxWeight: 6.99
        }) ||
        ((ageInLimits({
            age: ageInMonths,
            min: 0,
            max: 1
        }) ||
            ageInLimits({
                age: ageInMonths,
                min: 10,
                max: 30
            })) &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 4, max: 4.99 })) ||
        ((ageInLimits({
            age: ageInMonths,
            min: 0,
            max: 3
        }) ||
            ageInLimits({
                age: ageInMonths,
                min: 6,
                max: 30
            })) &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 3, max: 3.99 })) ||
        ((ageInLimits({
            age: ageInMonths,
            min: 0,
            max: 4
        }) ||
            ageInLimits({
                age: ageInMonths,
                min: 5,
                max: 30
            })) &&
            helpers_1.numberInLimits({ input: inputs.weight, min: 2.5, max: 2.99 })));
};
var isIntervalAndDurationGranulesVisible = function (ageInMonths) {
    return (isDosingGranulesVisible(ageInMonths) && !isGranuleNoVisible(ageInMonths));
};
var isSolution1Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 10,
        maxAge: 12,
        minWeight: 13,
        maxWeight: 15.99
    });
};
var isSolution2Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 11,
        maxAge: 12,
        minWeight: 11,
        maxWeight: 12.99
    });
};
var isSolution3Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 8,
        maxAge: 11,
        minWeight: 11,
        maxWeight: 12.99
    });
};
var isSolution4Visible = function (ageInMonths) {
    return ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 9,
        maxAge: 12,
        minWeight: 9,
        maxWeight: 10.99
    });
};
var isSolution5Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 7,
        maxAge: 9,
        minWeight: 9,
        maxWeight: 10.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 10,
            maxAge: 12,
            minWeight: 7,
            maxWeight: 8.99
        }));
};
var isSolution6Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 5,
        maxAge: 7,
        minWeight: 9,
        maxWeight: 10.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 6,
            maxAge: 10,
            minWeight: 7,
            maxWeight: 8.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 11,
            maxAge: 12,
            minWeight: 5,
            maxWeight: 6.99
        }));
};
var isSolution7Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 4,
        maxAge: 6,
        minWeight: 7,
        maxWeight: 8.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 8,
            maxAge: 11,
            minWeight: 5,
            maxWeight: 6.99
        }));
};
var isSolution8Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 3,
        maxAge: 4,
        minWeight: 7,
        maxWeight: 8.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 4,
            maxAge: 8,
            minWeight: 5,
            maxWeight: 6.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 8,
            maxAge: 10,
            minWeight: 4,
            maxWeight: 4.99
        }));
};
var isSolution9Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 2,
        maxAge: 4,
        minWeight: 5,
        maxWeight: 6.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 3,
            maxAge: 8,
            minWeight: 4,
            maxWeight: 4.99
        }));
};
var isSolution10Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 0,
        maxAge: 2,
        minWeight: 5,
        maxWeight: 6.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 1,
            maxAge: 3,
            minWeight: 4,
            maxWeight: 4.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 2,
            maxAge: 6,
            minWeight: 3,
            maxWeight: 3.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 4,
            maxAge: 5,
            minWeight: 2.5,
            maxWeight: 2.99
        }));
};
var isSolution11Visible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 0,
        maxAge: 1,
        minWeight: 4,
        maxWeight: 4.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 2,
            minWeight: 3,
            maxWeight: 3.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 4,
            minWeight: 2.5,
            maxWeight: 2.99
        }));
};
var isSolutionNoVisible = function (ageInMonths) {
    return (ageAndWeightInLimits({
        currentAge: ageInMonths,
        minAge: 0,
        maxAge: 10,
        minWeight: 13,
        maxWeight: 15.99
    }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 8,
            minWeight: 11,
            maxWeight: 12.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 5,
            minWeight: 9,
            maxWeight: 10.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 0,
            maxAge: 3,
            minWeight: 7,
            maxWeight: 8.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 10,
            maxAge: 12,
            minWeight: 4,
            maxWeight: 4.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 6,
            maxAge: 12,
            minWeight: 3,
            maxWeight: 3.99
        }) ||
        ageAndWeightInLimits({
            currentAge: ageInMonths,
            minAge: 5,
            maxAge: 12,
            minWeight: 2.5,
            maxWeight: 2.99
        }));
};
var isIntervalAndDurationSolutionVisible = function (ageInMonths) {
    return (isDosingOralsolutionVisible(ageInMonths) &&
        !isSolutionNoVisible(ageInMonths));
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    var ageInMonths = calculateAgeInMonths();
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.renal = isRenalVisible();
    visibleQuestions.warningR = isWarningRenalVisible();
    visibleQuestions.initiation = isStartVisible(ageInMonths);
    visibleQuestions.capsule1 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule1Visible(ageInMonths);
    visibleQuestions.capsule2 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule2Visible(ageInMonths);
    visibleQuestions.capsule3 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule3Visible(ageInMonths);
    visibleQuestions.capsule4 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule4Visible(ageInMonths);
    visibleQuestions.capsule5 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule5Visible(ageInMonths);
    visibleQuestions.capsule6 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule6Visible(ageInMonths);
    visibleQuestions.capsule7 =
        isDosingCapsulesVisible(ageInMonths) && isCapsule7Visible(ageInMonths);
    visibleQuestions.capsuleNo =
        isDosingCapsulesVisible(ageInMonths) && isCapsuleNoVisible(ageInMonths);
    visibleQuestions.intervalCapsules =
        isDosingCapsulesVisible(ageInMonths) &&
            isIntervalAndDurationCapsulesVisible(ageInMonths);
    visibleQuestions.durationCapsules =
        isDosingCapsulesVisible(ageInMonths) &&
            isIntervalAndDurationCapsulesVisible(ageInMonths);
    visibleQuestions.granule2 =
        isDosingGranulesVisible(ageInMonths) && isGranule2Visible(ageInMonths);
    visibleQuestions.granule3 =
        isDosingGranulesVisible(ageInMonths) && isGranule3Visible(ageInMonths);
    visibleQuestions.granule4 =
        isDosingGranulesVisible(ageInMonths) && isGranule4Visible(ageInMonths);
    visibleQuestions.granule5 =
        isDosingGranulesVisible(ageInMonths) && isGranule5Visible(ageInMonths);
    visibleQuestions.granule6 =
        isDosingGranulesVisible(ageInMonths) && isGranule6Visible(ageInMonths);
    visibleQuestions.granule7 =
        isDosingGranulesVisible(ageInMonths) && isGranule7Visible(ageInMonths);
    visibleQuestions.granule8 =
        isDosingGranulesVisible(ageInMonths) && isGranule8Visible(ageInMonths);
    visibleQuestions.granule9 =
        isDosingGranulesVisible(ageInMonths) && isGranule9Visible(ageInMonths);
    visibleQuestions.granule10 =
        isDosingGranulesVisible(ageInMonths) && isGranule10Visible(ageInMonths);
    visibleQuestions.granule11 =
        isDosingGranulesVisible(ageInMonths) && isGranule11Visible(ageInMonths);
    visibleQuestions.granule12 =
        isDosingGranulesVisible(ageInMonths) && isGranule12Visible(ageInMonths);
    visibleQuestions.granule13 =
        isDosingGranulesVisible(ageInMonths) && isGranule13Visible(ageInMonths);
    visibleQuestions.granule14 =
        isDosingGranulesVisible(ageInMonths) && isGranule14Visible(ageInMonths);
    visibleQuestions.granule15 =
        isDosingGranulesVisible(ageInMonths) && isGranule15Visible(ageInMonths);
    visibleQuestions.granuleNo =
        isDosingGranulesVisible(ageInMonths) && isGranuleNoVisible(ageInMonths);
    visibleQuestions.intervalGranules =
        isDosingGranulesVisible(ageInMonths) &&
            isIntervalAndDurationGranulesVisible(ageInMonths);
    visibleQuestions.durationGranules =
        isDosingGranulesVisible(ageInMonths) &&
            isIntervalAndDurationGranulesVisible(ageInMonths);
    visibleQuestions.solution1 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution1Visible(ageInMonths);
    visibleQuestions.solution2 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution2Visible(ageInMonths);
    visibleQuestions.solution3 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution3Visible(ageInMonths);
    visibleQuestions.solution4 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution4Visible(ageInMonths);
    visibleQuestions.solution5 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution5Visible(ageInMonths);
    visibleQuestions.solution6 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution6Visible(ageInMonths);
    visibleQuestions.solution7 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution7Visible(ageInMonths);
    visibleQuestions.solution8 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution8Visible(ageInMonths);
    visibleQuestions.solution9 =
        isDosingOralsolutionVisible(ageInMonths) && isSolution9Visible(ageInMonths);
    visibleQuestions.solution10 =
        isDosingOralsolutionVisible(ageInMonths) &&
            isSolution10Visible(ageInMonths);
    visibleQuestions.solution11 =
        isDosingOralsolutionVisible(ageInMonths) &&
            isSolution11Visible(ageInMonths);
    visibleQuestions.solutionNo =
        isDosingOralsolutionVisible(ageInMonths) &&
            isSolutionNoVisible(ageInMonths);
    visibleQuestions.intervalSolution =
        isDosingOralsolutionVisible(ageInMonths) &&
            isIntervalAndDurationSolutionVisible(ageInMonths);
    visibleQuestions.durationSolution =
        isDosingOralsolutionVisible(ageInMonths) &&
            isIntervalAndDurationSolutionVisible(ageInMonths);
    visibleQuestions.noAnswerResult = isNoAnswerVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    var ageInMonths = calculateAgeInMonths();
    visibleSections.warningRenal = isWarningRenalVisible();
    visibleSections.start = isStartVisible(ageInMonths);
    visibleSections.dosingCapsules = isDosingCapsulesVisible(ageInMonths);
    visibleSections.dosingGranules = isDosingGranulesVisible(ageInMonths);
    visibleSections.dosingOralsolution = isDosingOralsolutionVisible(ageInMonths);
    visibleSections.noAnswer = isNoAnswerVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var ut_actionResolver = function (action, value) {
    return actionResolver(action, value);
};
var actionResolver = function (action, value) {
    switch (action) {
        case 'setTestDate':
            currentDate = new Date(value);
            return null;
        default:
            return null;
    }
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
