"use strict";

var visibleQuestions = {
    condition: true,
    ultrasound: false,
    conditionWarning: false,
    tricuspidRegurgitation: false,
    otherSigns: false,
    echocardiographicProbabilityLow: false,
    echocardiographicProbabilityMedium: false,
    echocardiographicProbabilityHigh: false,
    otherFactors: false,
    ergospirometry: false,
    personalDoctorCheck: false,
    alternativeDiagnosis: false,
    scheduleErgospirometry: false,
    heartDisease: false,
    lungDisease: false,
    severePH: false,
    adCardiologist: false,
    adPulmonologist: false,
    CTEPH: false,
    VPScintigraphy: false,
    CTA: false,
    anticoagulantProtection: false,
    adAnticoagulantClinic: false,
    rheuma: false,
    adRheumatologist: false,
    gastro: false,
    adGastroenterologist: false,
    congenital: false,
    adCardiologistWithCongenitalHeartProblems: false,
    thyroid: false,
    adThyroidologist: false,
    HIV: false,
    adInfectologist: false,
    familiar: false,
    drugs: false,
    stopDrug: false,
    sarcoidosis: false,
    adAppropriateSpecialist: false,
    idiopathicPH: false,
    adClinicForSeverePH: false,
    alternativePHDiagnosis: false,
    adClinicForLungHyperinflation: false,
    PHClinicCheckUp: false
};
var visibleSections = {
    condition: true,
    probability: false,
    algorithm: false
};
var inputs = {
    condition: null,
    ultrasound: null,
    conditionWarning: null,
    tricuspidRegurgitation: null,
    otherSigns: null,
    echocardiographicProbabilityLow: null,
    echocardiographicProbabilityMedium: null,
    echocardiographicProbabilityHigh: null,
    otherFactors: null,
    ergospirometry: null,
    personalDoctorCheck: null,
    alternativeDiagnosis: null,
    scheduleErgospirometry: null,
    heartDisease: null,
    lungDisease: null,
    severePH: null,
    adCardiologist: null,
    adPulmonologist: null,
    CTEPH: null,
    VPScintigraphy: null,
    CTA: null,
    anticoagulantProtection: null,
    adAnticoagulantClinic: null,
    rheuma: null,
    adRheumatologist: null,
    gastro: null,
    adGastroenterologist: null,
    congenital: null,
    adCardiologistWithCongenitalHeartProblems: null,
    thyroid: null,
    adThyroidologist: null,
    HIV: null,
    adInfectologist: null,
    familiar: null,
    drugs: null,
    stopDrug: null,
    sarcoidosis: null,
    adAppropriateSpecialist: null,
    idiopathicPH: null,
    adClinicForSeverePH: null,
    alternativePHDiagnosis: null,
    adClinicForLungHyperinflation: null,
    PHClinicCheckUp: null
};
var conditionVisibility = function () {
    return true;
};
var ultrasoundVisibility = function () {
    return inputs.condition.currentIdentifier == "yes";
};
var conditionWarningVisibility = function () {
    return inputs.condition.currentIdentifier == "no";
};
var tricuspidRegurgitationVisibility = function () {
    return inputs.condition.currentIdentifier == "yes";
};
var otherSignsVisibility = function () {
    if (!conditionVisibility())
        return false;
    if (!tricuspidRegurgitationVisibility())
        return false;
    return (inputs.condition.currentIdentifier == "yes" &&
        inputs.tricuspidRegurgitation.currentIdentifier != "tricuspidHigh");
};
var echocardiographicProbabilityLowVisibility = function () {
    if (!conditionVisibility())
        return false;
    if (!otherSignsVisibility())
        return false;
    if (!tricuspidRegurgitationVisibility())
        return false;
    return (inputs.condition.currentIdentifier == "yes" &&
        inputs.otherSigns.currentIdentifier == "no" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidLow");
};
var echocardiographicProbabilityMediumVisibility = function () {
    if (!tricuspidRegurgitationVisibility())
        return false;
    if (!otherSignsVisibility())
        return false;
    if (inputs.otherSigns.currentIdentifier == "yes" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidLow")
        return true;
    if (inputs.otherSigns.currentIdentifier == "no" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidMedium")
        return true;
    return false;
};
var echocardiographicProbabilityHighVisibility = function () {
    if (!tricuspidRegurgitationVisibility())
        return false;
    if (inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidHigh")
        return true;
    if (!otherSignsVisibility())
        return false;
    if (inputs.otherSigns.currentIdentifier == "yes" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidMedium")
        return true;
    return false;
};
var otherFactorsVisibility = function () {
    if (!tricuspidRegurgitationVisibility())
        return false;
    if (!otherSignsVisibility())
        return false;
    if (inputs.otherSigns.currentIdentifier == "no" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidLow")
        return true;
    return false;
};
var ergospirometryVisibility = function () {
    if (!tricuspidRegurgitationVisibility())
        return false;
    if (!otherSignsVisibility())
        return false;
    if (!otherFactorsVisibility())
        return false;
    if (inputs.otherSigns.currentIdentifier == "no" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidLow" &&
        inputs.otherFactors.currentIdentifier == "yes")
        return true;
    return false;
};
var personalDoctorCheckVisibility = function () {
    if (!ergospirometryVisibility())
        return false;
    if (inputs.ergospirometry.currentIdentifier == "noSigns")
        return true;
    return false;
};
var alternativeDiagnosisVisibility = function () {
    if (!otherFactorsVisibility())
        return false;
    if (inputs.otherFactors.currentIdentifier == "no")
        return true;
    return false;
};
var scheduleErgospirometryVisibility = function () {
    if (!otherFactorsVisibility())
        return false;
    if (inputs.otherFactors.currentIdentifier == "no")
        return true;
    return false;
};
var heartDiseaseVisibility = function () {
    if (!tricuspidRegurgitationVisibility())
        return false;
    if (inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidHigh")
        return true;
    if (!otherSignsVisibility())
        return false;
    if (inputs.otherSigns.currentIdentifier == "yes" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidLow")
        return true;
    if (inputs.otherSigns.currentIdentifier == "no" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidMedium")
        return true;
    if (inputs.otherSigns.currentIdentifier == "yes" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidMedium")
        return true;
    return false;
};
var lungDiseaseVisibility = function () {
    if (!heartDiseaseVisibility())
        return false;
    if (inputs.heartDisease.currentIdentifier == "no")
        return true;
    return false;
};
var severePHVisibility = function () {
    if (!heartDiseaseVisibility())
        return false;
    if (inputs.heartDisease.currentIdentifier == "yes")
        return true;
    if (!lungDiseaseVisibility())
        return false;
    if (inputs.lungDisease.currentIdentifier == "yes")
        return true;
    return false;
};
var adCardiologistVisibility = function () {
    if (!heartDiseaseVisibility())
        return false;
    if (!severePHVisibility())
        return false;
    if (inputs.heartDisease.currentIdentifier == "yes" &&
        inputs.severePH.currentIdentifier == "belowOrEq60")
        return true;
    if (inputs.heartDisease.currentIdentifier == "yes" &&
        inputs.severePH.currentIdentifier == "above60")
        return true;
    return false;
};
var adPulmonologistVisibility = function () {
    if (!lungDiseaseVisibility())
        return false;
    if (!severePHVisibility())
        return false;
    if (inputs.lungDisease.currentIdentifier == "yes" &&
        inputs.severePH.currentIdentifier == "belowOrEq60")
        return true;
    if (inputs.lungDisease.currentIdentifier == "yes" &&
        inputs.severePH.currentIdentifier == "above60")
        return true;
    return false;
};
var CTEPHVisibility = function () {
    if (!lungDiseaseVisibility())
        return false;
    if (inputs.lungDisease.currentIdentifier == "no")
        return true;
    return false;
};
var VPScintigraphyVisibility = function () {
    if (!CTEPHVisibility())
        return false;
    if (inputs.CTEPH.currentIdentifier == "yes")
        return true;
    return false;
};
var CTAVisibility = function () {
    if (!CTEPHVisibility())
        return false;
    if (!VPScintigraphyVisibility())
        return false;
    if (inputs.CTEPH.currentIdentifier == "yes" &&
        inputs.VPScintigraphy.currentIdentifier == "undetermined")
        return true;
    return false;
};
var anticoagulantProtectionVisibility = function () {
    if (!VPScintigraphyVisibility())
        return false;
    if (inputs.VPScintigraphy.currentIdentifier == "thromboembolismSigns")
        return true;
    if (!CTAVisibility())
        return false;
    if (inputs.VPScintigraphy.currentIdentifier == "undetermined" &&
        inputs.CTA.currentIdentifier == "thromboembolismSigns")
        return true;
    return false;
};
var adAnticoagulantClinicVisibility = function () {
    if (!VPScintigraphyVisibility())
        return false;
    if (inputs.VPScintigraphy.currentIdentifier == "thromboembolismSigns")
        return true;
    if (!CTAVisibility())
        return false;
    if (inputs.VPScintigraphy.currentIdentifier == "undetermined" &&
        inputs.CTA.currentIdentifier == "thromboembolismSigns")
        return true;
    return false;
};
var rheumaVisibility = function () {
    if (!CTEPHVisibility())
        return false;
    if (inputs.CTEPH.currentIdentifier == "no")
        return true;
    if (!VPScintigraphyVisibility())
        return false;
    if (inputs.VPScintigraphy.currentIdentifier == "negative")
        return true;
    if (!VPScintigraphyVisibility())
        return false;
    if (inputs.VPScintigraphy.currentIdentifier == "negative")
        return true;
    if (!CTAVisibility())
        return false;
    if (inputs.CTA.currentIdentifier == "negative")
        return true;
    return false;
};
var adRheumatologistVisibility = function () {
    if (!rheumaVisibility())
        return false;
    if (inputs.rheuma.currentIdentifier == "yes")
        return true;
    return false;
};
var gastroVisibility = function () {
    if (!rheumaVisibility())
        return false;
    if (inputs.rheuma.currentIdentifier == "no")
        return true;
    return false;
};
var adGastroenterologistVisibility = function () {
    if (!gastroVisibility())
        return false;
    if (inputs.gastro.currentIdentifier == "yes")
        return true;
    return false;
};
var congenitalVisibility = function () {
    if (!gastroVisibility())
        return false;
    if (inputs.gastro.currentIdentifier == "no")
        return true;
    return false;
};
var adCardiologistWithCongenitalHeartProblemsVisibility = function () {
    if (!congenitalVisibility())
        return false;
    if (inputs.congenital.currentIdentifier == "yes")
        return true;
    return false;
};
var thyroidVisibility = function () {
    if (!congenitalVisibility())
        return false;
    if (inputs.congenital.currentIdentifier == "no")
        return true;
    return false;
};
var adThyroidologistVisibility = function () {
    if (!thyroidVisibility())
        return false;
    if (inputs.thyroid.currentIdentifier == "yes")
        return true;
    return false;
};
var HIVVisibility = function () {
    if (!thyroidVisibility())
        return false;
    if (inputs.thyroid.currentIdentifier == "no")
        return true;
    return false;
};
var adInfectologistVisibility = function () {
    if (!HIVVisibility())
        return false;
    if (inputs.HIV.currentIdentifier == "yes")
        return true;
    return false;
};
var familiarVisibility = function () {
    if (!HIVVisibility())
        return false;
    if (inputs.HIV.currentIdentifier == "no")
        return true;
    return false;
};
var drugsVisibility = function () {
    if (!familiarVisibility())
        return false;
    if (inputs.familiar.currentIdentifier == "no")
        return true;
    return false;
};
var stopDrugVisibility = function () {
    if (!drugsVisibility())
        return false;
    if (inputs.drugs.currentIdentifier == "yes")
        return true;
    return false;
};
var sarcoidosisVisibility = function () {
    if (!drugsVisibility())
        return false;
    if (inputs.drugs.currentIdentifier == "no")
        return true;
    return false;
};
var adAppropriateSpecialistVisibility = function () {
    if (!sarcoidosisVisibility())
        return false;
    if (inputs.sarcoidosis.currentIdentifier == "yes")
        return true;
    return false;
};
var idiopathicPHVisibility = function () {
    if (!sarcoidosisVisibility())
        return false;
    if (inputs.sarcoidosis.currentIdentifier == "no")
        return true;
    return false;
};
var adClinicForSeverePHVisibility = function () {
    if (!sarcoidosisVisibility())
        return false;
    if (inputs.sarcoidosis.currentIdentifier == "no")
        return true;
    return false;
};
var alternativePHDiagnosisVisibility = function () {
    if (!sarcoidosisVisibility())
        return false;
    if (inputs.sarcoidosis.currentIdentifier == "no")
        return true;
    return false;
};
var adClinicForLungHyperinflationVisibility = function () {
    if (ergospirometryVisibility() &&
        inputs.ergospirometry.currentIdentifier == "signsPH")
        return true;
    if (heartDiseaseVisibility() &&
        inputs.heartDisease.currentIdentifier == "yes" &&
        severePHVisibility() &&
        inputs.severePH.currentIdentifier == "above60")
        return true;
    if (lungDiseaseVisibility() &&
        inputs.lungDisease.currentIdentifier == "yes" &&
        severePHVisibility() &&
        inputs.severePH.currentIdentifier == "above60")
        return true;
    if (VPScintigraphyVisibility() &&
        inputs.VPScintigraphy.currentIdentifier == "thromboembolismSigns")
        return true;
    if (CTAVisibility() &&
        inputs.CTA.currentIdentifier == "thromboembolismSigns" &&
        VPScintigraphyVisibility() &&
        inputs.VPScintigraphy.currentIdentifier == "undetermined")
        return true;
    if (rheumaVisibility() && inputs.rheuma.currentIdentifier == "yes")
        return true;
    if (gastroVisibility() && inputs.gastro.currentIdentifier == "yes")
        return true;
    if (HIVVisibility() && inputs.HIV.currentIdentifier == "yes")
        return true;
    if (familiarVisibility() && inputs.familiar.currentIdentifier == "yes")
        return true;
    if (drugsVisibility() && inputs.drugs.currentIdentifier == "yes")
        return true;
    if (sarcoidosisVisibility() &&
        inputs.sarcoidosis.currentIdentifier == "yes")
        return true;
    return false;
};
var PHClinicCheckUpVisibility = function () {
    if (ergospirometryVisibility() &&
        inputs.ergospirometry.currentIdentifier == "signsPH")
        return true;
    if (heartDiseaseVisibility() &&
        inputs.heartDisease.currentIdentifier == "yes" &&
        severePHVisibility() &&
        inputs.severePH.currentIdentifier == "above60")
        return true;
    if (lungDiseaseVisibility() &&
        inputs.lungDisease.currentIdentifier == "yes" &&
        severePHVisibility() &&
        inputs.severePH.currentIdentifier == "above60")
        return true;
    if (CTEPHVisibility() && inputs.CTEPH.currentIdentifier == "yes")
        return false;
    if (rheumaVisibility() && inputs.rheuma.currentIdentifier == "yes")
        return true;
    if (gastroVisibility() && inputs.gastro.currentIdentifier == "yes")
        return true;
    if (HIVVisibility() && inputs.HIV.currentIdentifier == "yes")
        return true;
    if (familiarVisibility() && inputs.familiar.currentIdentifier == "yes")
        return true;
    if (drugsVisibility() && inputs.drugs.currentIdentifier == "yes")
        return true;
    if (sarcoidosisVisibility() &&
        inputs.sarcoidosis.currentIdentifier == "yes")
        return true;
    if (sarcoidosisVisibility() && inputs.sarcoidosis.currentIdentifier == "no")
        return true;
    return false;
};
var returnVisibleQuestions = function () {
    visibleQuestions.condition = conditionVisibility();
    visibleQuestions.ultrasound = ultrasoundVisibility();
    visibleQuestions.conditionWarning = conditionWarningVisibility();
    visibleQuestions.tricuspidRegurgitation = tricuspidRegurgitationVisibility();
    visibleQuestions.otherSigns = otherSignsVisibility();
    visibleQuestions.echocardiographicProbabilityLow = echocardiographicProbabilityLowVisibility();
    visibleQuestions.echocardiographicProbabilityMedium = echocardiographicProbabilityMediumVisibility();
    visibleQuestions.echocardiographicProbabilityHigh = echocardiographicProbabilityHighVisibility();
    visibleQuestions.otherFactors = otherFactorsVisibility();
    visibleQuestions.ergospirometry = ergospirometryVisibility();
    visibleQuestions.personalDoctorCheck = personalDoctorCheckVisibility();
    visibleQuestions.alternativeDiagnosis = alternativeDiagnosisVisibility();
    visibleQuestions.scheduleErgospirometry = scheduleErgospirometryVisibility();
    visibleQuestions.heartDisease = heartDiseaseVisibility();
    visibleQuestions.lungDisease = lungDiseaseVisibility();
    visibleQuestions.severePH = severePHVisibility();
    visibleQuestions.adCardiologist = adCardiologistVisibility();
    visibleQuestions.adPulmonologist = adPulmonologistVisibility();
    visibleQuestions.CTEPH = CTEPHVisibility();
    visibleQuestions.VPScintigraphy = VPScintigraphyVisibility();
    visibleQuestions.CTA = CTAVisibility();
    visibleQuestions.anticoagulantProtection = anticoagulantProtectionVisibility();
    visibleQuestions.adAnticoagulantClinic = adAnticoagulantClinicVisibility();
    visibleQuestions.rheuma = rheumaVisibility();
    visibleQuestions.adRheumatologist = adRheumatologistVisibility();
    visibleQuestions.gastro = gastroVisibility();
    visibleQuestions.adGastroenterologist = adGastroenterologistVisibility();
    visibleQuestions.congenital = congenitalVisibility();
    visibleQuestions.adCardiologistWithCongenitalHeartProblems = adCardiologistWithCongenitalHeartProblemsVisibility();
    visibleQuestions.thyroid = thyroidVisibility();
    visibleQuestions.adThyroidologist = adThyroidologistVisibility();
    visibleQuestions.HIV = HIVVisibility();
    visibleQuestions.adInfectologist = adInfectologistVisibility();
    visibleQuestions.familiar = familiarVisibility();
    visibleQuestions.drugs = drugsVisibility();
    visibleQuestions.stopDrug = stopDrugVisibility();
    visibleQuestions.sarcoidosis = sarcoidosisVisibility();
    visibleQuestions.adAppropriateSpecialist = adAppropriateSpecialistVisibility();
    visibleQuestions.idiopathicPH = idiopathicPHVisibility();
    visibleQuestions.adClinicForSeverePH = adClinicForSeverePHVisibility();
    visibleQuestions.alternativePHDiagnosis = alternativePHDiagnosisVisibility();
    visibleQuestions.adClinicForLungHyperinflation = adClinicForLungHyperinflationVisibility();
    visibleQuestions.PHClinicCheckUp = PHClinicCheckUpVisibility();
    return visibleQuestions;
};
var probabilityVisibility = function () {
    return inputs.condition.currentIdentifier == "yes";
};
var algorithmVisibility = function () {
    if (inputs.condition.currentIdentifier == "yes" &&
        inputs.tricuspidRegurgitation.currentIdentifier == "tricuspidHigh")
        return true;
    if (inputs.condition.currentIdentifier == "yes" &&
        inputs.otherSigns.currentIdentifier != null &&
        inputs.tricuspidRegurgitation.currentIdentifier != null)
        return true;
    return false;
};
var returnVisibleSections = function () {
    visibleSections.condition = conditionVisibility();
    visibleSections.probability = probabilityVisibility();
    visibleSections.algorithm = algorithmVisibility();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        result: {},
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
