"use strict";


var visibleQuestions = {
    age65: true,
    vascularImpairment: false,
    riskFactors: false,
    coindication: false,
    contraindications: false,
    answerAll: true,
    result1: false,
    result2: false,
    info: false
};
var visibleSections = {
    main: true,
    answerAllSection: true,
    result1Section: false,
    result2Section: false
};
var inputs = {
    age65: null,
    vascularImpairment: null,
    riskFactors: null,
    coindication: null,
    contraindications: null
};
var isAgeBelow65 = function () {
    return helpers_1.answerMatches(inputs.age65, 'below65');
};
var isVascularImpairmentNegative = function () {
    return helpers_1.answerMatches(inputs.vascularImpairment, 'no');
};
var isCoindicationVisible = function () {
    return (helpers_1.answerMatches(inputs.age65, 'aboveOrEquals65') ||
        helpers_1.answerMatches(inputs.vascularImpairment, 'yes') ||
        helpers_1.answerMatches(inputs.riskFactors, 'yes'));
};
var isCoindicationNegative = function () {
    return helpers_1.answerMatches(inputs.coindication, 'no');
};
var isResult1Visible = function () {
    return ((isAgeBelow65() &&
        isVascularImpairmentNegative() &&
        helpers_1.answerMatches(inputs.riskFactors, 'no')) ||
        helpers_1.answerMatches(inputs.coindication, 'yes') ||
        helpers_1.answerMatches(inputs.contraindications, 'yes'));
};
var isResult2Visible = function () {
    return (isCoindicationVisible() &&
        isCoindicationNegative() &&
        helpers_1.answerMatches(inputs.contraindications, 'no'));
};
var areAllQuestionsAnswered = function () {
    return isResult1Visible() || isResult2Visible();
};
var returnVisibleQuestions = function () {
    visibleQuestions.vascularImpairment = isAgeBelow65();
    visibleQuestions.riskFactors =
        isAgeBelow65() && isVascularImpairmentNegative();
    visibleQuestions.coindication = isCoindicationVisible();
    visibleQuestions.contraindications = isCoindicationNegative();
    visibleQuestions.answerAll = !areAllQuestionsAnswered();
    visibleQuestions.result1 = isResult1Visible();
    visibleQuestions.result2 = isResult2Visible();
    visibleQuestions.info = isResult2Visible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.answerAllSection = !areAllQuestionsAnswered();
    visibleSections.result1Section = isResult1Visible();
    visibleSections.result2Section = isResult2Visible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return areAllQuestionsAnswered();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
