"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight1: false,
    weight2: false,
    warningNewborns: false,
    doseBabies: false,
    doseBabiesSulf: false,
    durationBabies: false,
    warningAdults: false,
    resultDosingAdults: false,
    durationDosingAdults: false,
    kidneyInfo: false,
    kidneyGrey: false,
    kidneyYellow: false,
    kidneyRed: false,
    result131: false,
    result211: false
};
var visibleSections = {
    weightSection: true,
    dosingBabies: false,
    dosingAdults: false,
    kidneyDosing: false,
    result13: false,
    result21: false
};
var inputs = {
    age: null,
    weight1: null,
    weight2: null,
    kidneyInfo: null
};
var isAgeMatching = function (name) {
    return helpers_1.answerMatches(inputs.age, name);
};
var isWeight1Answered = function () {
    return helpers_1.numberInLimits({ input: inputs.weight1, min: 1, max: 70 });
};
var isNewBornAnswered = function () {
    return helpers_1.numberInLimits({ input: inputs.weight1, min: 1, max: 6.9 });
};
var isWeight2Answered = function () {
    return helpers_1.numberInLimits({ input: inputs.weight2, min: 10, max: 200 });
};
var isWarning2Answered = function () {
    return helpers_1.numberInLimits({ input: inputs.weight2, min: 100.1, max: 200 });
};
var isOpen = function () {
    return helpers_1.answerMatches(inputs.kidneyInfo, 'close');
};
var isAnswerAllVisible = function () {
    return !((isAgeMatching('babies') && isWeight1Answered()) ||
        (isAgeMatching('adults') && isWeight2Answered()));
};
var calculatePoints = function () {
    var _a, _b;
    if (isWeight1Answered()) {
        var weight = Number((_a = inputs.weight1) === null || _a === void 0 ? void 0 : _a.currentPoints);
        return {
            doseBabies: {
                qID: 'doseBabies',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(weight * 0.46875, 0, 1), helpers_1.returnNumberObject(weight * 0.625, 0, 1))
            },
            doseBabiesSulf: {
                qID: 'doseBabiesSulf',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject((weight * 75) / 4, 0, 1), helpers_1.returnNumberObject((weight * 100) / 4, 0, 1), helpers_1.returnNumberObject((weight * 15) / 4, 0, 1), helpers_1.returnNumberObject((weight * 20) / 4, 0, 1))
            }
        };
    }
    if (isWeight2Answered()) {
        var weight = Number((_b = inputs.weight2) === null || _b === void 0 ? void 0 : _b.currentPoints);
        return {
            resultDosingAdults: {
                qID: 'resultDosingAdults',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject((weight * 75) / 4, 0, 1), helpers_1.returnNumberObject((weight * 100) / 4, 0, 1), helpers_1.returnNumberObject((weight * 15) / 4, 0, 1), helpers_1.returnNumberObject((weight * 20) / 4, 0, 1))
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight1 = isAgeMatching('babies');
    visibleQuestions.weight2 = isAgeMatching('adults');
    visibleQuestions.warningNewborns = isNewBornAnswered();
    visibleQuestions.doseBabies = isWeight1Answered();
    visibleQuestions.doseBabiesSulf = isWeight1Answered();
    visibleQuestions.durationBabies = isWeight1Answered();
    visibleQuestions.warningAdults = isWarning2Answered();
    visibleQuestions.resultDosingAdults = isWeight2Answered();
    visibleQuestions.durationDosingAdults = isWeight2Answered();
    visibleQuestions.kidneyInfo = !isAnswerAllVisible();
    visibleQuestions.kidneyGrey = !isAnswerAllVisible() && isOpen();
    visibleQuestions.kidneyYellow = !isAnswerAllVisible() && isOpen();
    visibleQuestions.kidneyRed = !isAnswerAllVisible() && isOpen();
    visibleQuestions.result131 = !isAnswerAllVisible();
    visibleQuestions.result211 = isAnswerAllVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosingBabies = isWeight1Answered();
    visibleSections.dosingAdults = isWeight2Answered();
    visibleSections.kidneyDosing = !isAnswerAllVisible();
    visibleSections.result13 = !isAnswerAllVisible();
    visibleSections.result21 = isAnswerAllVisible();
    return visibleSections;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections(),
        exportResultsEnabled: isExportResultsEnabled()
    };
});
