"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    resultAnswerAll: true,
    dose400Adults: false,
    amount400: false,
    duration400Adults: false,
    babies: false,
    warningDose: false,
    doseChildren: false,
    durationChildren: false,
    babies2: false,
    kidneyInfo: false,
    kidneyHigh: false,
    kidneyMiddle: false,
    kidneyLow: false,
    antibiotic: false
};
var visibleSections = {
    ageSection: true,
    noAnswer: true,
    adults400: false,
    doseChildrenResult: false,
    dosingTooSmallWeight: false,
    kidneyFunction: false,
    antibiticResult: false
};
var inputs = {
    age: null,
    weight: null,
    kidneyInfo: null
};
var isChildren = function () {
    return helpers_1.answerMatches(inputs.age, 'children');
};
var isChildrenAnswerd = function () {
    return (helpers_1.answerMatches(inputs.age, 'children') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 }));
};
var isChildrenMinMaxAnswerd = function (min, max) {
    return (helpers_1.answerMatches(inputs.age, 'children') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: min, max: max }));
};
var isAdultsAnswered = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isAnsweredAllVisible = function () {
    return !(isChildrenAnswerd() || isAdultsAnswered());
};
var kidneyInfo = function () {
    return inputs.kidneyInfo.currentIdentifier === 'close';
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isChildren();
    visibleQuestions.resultAnswerAll = isAnsweredAllVisible();
    visibleQuestions.dose400Adults = isAdultsAnswered();
    visibleQuestions.amount400 = isAdultsAnswered();
    visibleQuestions.duration400Adults = isAdultsAnswered();
    visibleQuestions.babies = isChildrenMinMaxAnswerd(5, 6.99);
    visibleQuestions.warningDose = isChildrenMinMaxAnswerd(40.01, 70);
    visibleQuestions.doseChildren = isChildrenMinMaxAnswerd(5, 70);
    visibleQuestions.durationChildren = isChildrenMinMaxAnswerd(5, 70);
    visibleQuestions.babies2 = isChildrenMinMaxAnswerd(1, 4.99);
    visibleQuestions.kidneyInfo =
        isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70);
    visibleQuestions.kidneyHigh =
        (isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70)) && kidneyInfo();
    visibleQuestions.kidneyMiddle =
        (isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70)) && kidneyInfo();
    visibleQuestions.kidneyLow =
        (isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70)) && kidneyInfo();
    visibleQuestions.antibiotic =
        isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70);
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isAnsweredAllVisible();
    visibleSections.adults400 = isAdultsAnswered();
    visibleSections.doseChildrenResult = isChildrenMinMaxAnswerd(5, 70);
    visibleSections.dosingTooSmallWeight = isChildrenMinMaxAnswerd(1, 4.99);
    visibleSections.kidneyFunction =
        isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70);
    visibleSections.antibiticResult =
        isAdultsAnswered() || isChildrenMinMaxAnswerd(5, 70);
    return visibleSections;
};
var calculatePoints = function () {
    var _a;
    if (isChildrenMinMaxAnswerd(5, 70)) {
        var weight = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        return {
            doseChildren: {
                qID: 'doseChildren',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 20, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 4, 1), 0, 1)),
                titleTexts: 'regular'
            }
        };
    }
    return null;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnsweredAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections(),
        result: calculatePoints()
    };
});
