"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    use: false,
    weightChildren: false,
    weightAdults: false,
    resultAnswerAll: true,
    weightAdultsMax: false,
    doseInfusionAdults: false,
    amountInfusion: false,
    duration400AdultsInfusion: false,
    intravenousWarning: false,
    weightAdultsMax2: false,
    doseAdults: false,
    durationAdults: false,
    babies0: false,
    doseInfusionChildren: false,
    amountInfusionChildren: false,
    durationChildrenInfusion: false,
    babies: false,
    intravenousWarning2: false,
    doseChildren: false,
    durationChildren: false,
    dose400AdultsPrevent: false,
    amount400prevent: false,
    dose400ChildrenPrevent: false,
    amount400preventChildren: false,
    dose100ChildrenPrevent: false,
    amount100preventChildren: false,
    babiesSmpc: false,
    kidneyInfo: false,
    kidneyHigh: false,
    kidneyMiddle: false,
    kidneyLow: false,
    antibiotic: false
};
var visibleSections = {
    ageSection: true,
    noAnswer: true,
    adultsInfusion: false,
    adultsTablets: false,
    childrenInfusion: false,
    doseChildrenResult: false,
    prophylaxisAdults: false,
    prophylaxisChildren400: false,
    prophylaxisChildren100: false,
    babiesPreventSection: false,
    kidneyFunction: false,
    antibiticResult: false
};
var inputs = {
    age: null,
    use: null,
    weightChildren: null,
    weightAdults: null,
    kidneyInfo: null
};
var weightChildren = function () {
    return ((helpers_1.answerMatches(inputs.age, 'children') &&
        helpers_1.answerMatches(inputs.use, 'treat')) ||
        (helpers_1.answerMatches(inputs.age, 'babies') && helpers_1.answerMatches(inputs.use, 'treat')));
};
var weightAdults = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.answerMatches(inputs.use, 'treat'));
};
var isAnswerdAllVisible = function () {
    return !(helpers_1.numberInLimits({ input: inputs.weightChildren, min: 1, max: 70 }) ||
        helpers_1.numberInLimits({ input: inputs.weightAdults, min: 1, max: 200 }) ||
        helpers_1.answerMatches(inputs.use, 'prevent'));
};
var isAdults = function (min) {
    if (min === void 0) { min = 1; }
    return (weightAdults() &&
        helpers_1.numberInLimits({ input: inputs.weightAdults, min: min, max: 200 }));
};
var isChildren = function (max) {
    if (max === void 0) { max = 70; }
    return (weightChildren() &&
        helpers_1.numberInLimits({ input: inputs.weightChildren, min: 1, max: max }));
};
var isPrevent = function (name) {
    return (helpers_1.answerMatches(inputs.age, name) && helpers_1.answerMatches(inputs.use, 'prevent'));
};
var kidneyInfo = function () {
    var _a;
    return ((_a = inputs.kidneyInfo) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'close';
};
var kidneyInfoVisible = function () {
    return !isAnswerdAllVisible() && !isPrevent('babies');
};
var returnVisibleQuestions = function () {
    visibleQuestions.use = helpers_1.isAnswered(inputs.age);
    visibleQuestions.weightChildren = weightChildren();
    visibleQuestions.weightAdults = weightAdults();
    visibleQuestions.resultAnswerAll = isAnswerdAllVisible();
    visibleQuestions.weightAdultsMax = isAdults(100.01);
    visibleQuestions.doseInfusionAdults = isAdults();
    visibleQuestions.amountInfusion = isAdults();
    visibleQuestions.duration400AdultsInfusion = isAdults();
    visibleQuestions.intravenousWarning = isAdults();
    visibleQuestions.weightAdultsMax2 = isAdults(100.01);
    visibleQuestions.doseAdults = isAdults();
    visibleQuestions.durationAdults = isAdults();
    visibleQuestions.babies0 = isChildren(6.99);
    visibleQuestions.doseInfusionChildren = isChildren();
    visibleQuestions.amountInfusionChildren = isChildren();
    visibleQuestions.durationChildrenInfusion = isChildren();
    visibleQuestions.babies = isChildren(6.99);
    visibleQuestions.intravenousWarning2 = isChildren();
    visibleQuestions.doseChildren = isChildren();
    visibleQuestions.durationChildren = isChildren();
    visibleQuestions.dose400AdultsPrevent = isPrevent('adults');
    visibleQuestions.amount400prevent = isPrevent('adults');
    visibleQuestions.dose400ChildrenPrevent = isPrevent('children');
    visibleQuestions.amount400preventChildren = isPrevent('children');
    visibleQuestions.dose100ChildrenPrevent = isPrevent('children');
    visibleQuestions.amount100preventChildren = isPrevent('children');
    visibleQuestions.babiesSmpc = isPrevent('babies');
    visibleQuestions.kidneyInfo = kidneyInfoVisible();
    visibleQuestions.kidneyHigh = kidneyInfoVisible() && kidneyInfo();
    visibleQuestions.kidneyMiddle = kidneyInfoVisible() && kidneyInfo();
    visibleQuestions.kidneyLow = kidneyInfoVisible() && kidneyInfo();
    visibleQuestions.antibiotic = kidneyInfoVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isAnswerdAllVisible();
    visibleSections.adultsInfusion = isAdults();
    visibleSections.adultsTablets = isAdults();
    visibleSections.childrenInfusion = isChildren();
    visibleSections.doseChildrenResult = isChildren();
    visibleSections.prophylaxisAdults = isPrevent('adults');
    visibleSections.prophylaxisChildren400 = isPrevent('children');
    visibleSections.prophylaxisChildren100 = isPrevent('children');
    visibleSections.babiesPreventSection = isPrevent('babies');
    visibleSections.kidneyFunction = kidneyInfoVisible();
    visibleSections.antibiticResult = kidneyInfoVisible();
    return visibleSections;
};
var calculatePoints = function () {
    var _a, _b;
    if (isAdults()) {
        var weight = Number((_a = inputs.weightAdults) === null || _a === void 0 ? void 0 : _a.currentPoints);
        return {
            doseInfusionAdults: {
                qID: 'doseInfusionAdults',
                titleTexts: 'regular',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((weight * 5) / 4, 1), 0, 1))
            },
            amountInfusion: {
                qID: 'amountInfusion',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 100, 1), 0, 1)),
                resultTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 20, 1), 0, 1))
            },
            doseAdults: {
                qID: 'doseAdults',
                titleTexts: 'regular',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 100, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 20, 1), 0, 1))
            }
        };
    }
    if (isChildren()) {
        var weight = Number((_b = inputs.weightChildren) === null || _b === void 0 ? void 0 : _b.currentPoints);
        return {
            doseInfusionChildren: {
                qID: 'doseInfusionChildren',
                titleTexts: 'regular',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult((weight * 5) / 4, 1), 0, 1))
            },
            amountInfusionChildren: {
                qID: 'amountInfusionChildren',
                titleTexts: 'result1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 100, 1), 0, 1)),
                resultTexts: 'result1',
                rParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 20, 1), 0, 1))
            },
            doseChildren: {
                qID: 'doseChildren',
                titleTexts: 'regular',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 100, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 20, 1), 0, 1))
            }
        };
    }
    return null;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerdAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections(),
        result: calculatePoints()
    };
});
