"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    use: false,
    resultAnswerAll: true,
    dose400Adults: false,
    amount400: false,
    duration400Adults: false,
    dose400AdultsRecidiv: false,
    amount400recidiv: false,
    duration400AdultsRecidiv: false,
    babies2: false,
    babies: false,
    warningDose: false,
    doseChildren: false,
    durationChildren: false,
    kidneyInfo: false,
    kidneyHigh: false,
    kidneyMiddle: false,
    kidneyLow: false,
    antibiotic: false
};
var visibleSections = {
    ageSection: true,
    noAnswer: true,
    adults400: false,
    recidiv: false,
    dosingTooSmallWeight: false,
    doseChildrenResult: false,
    kidneyFunction: false,
    antibiticResult: false
};
var inputs = {
    age: null,
    weight: null,
    use: null,
    kidneyInfo: null
};
var isAnswerdAllVisible = function () {
    return !(helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 }) ||
        helpers_1.isAnswered(inputs.use));
};
var isAdultsUse = function (name) {
    return helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.answerMatches(inputs.use, name);
};
var isChildren = function (min, max) {
    if (min === void 0) { min = 1; }
    if (max === void 0) { max = 70; }
    return (helpers_1.answerMatches(inputs.age, 'children') &&
        helpers_1.numberInLimits({ input: inputs.weight, min: min, max: max }));
};
var isInfoVisible = function () {
    return (isChildren(5) ||
        (helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.isAnswered(inputs.use)));
};
var kidneyInfo = function () {
    var _a;
    return ((_a = inputs.kidneyInfo) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === 'close';
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = helpers_1.answerMatches(inputs.age, 'children');
    visibleQuestions.use = helpers_1.answerMatches(inputs.age, 'adults');
    visibleQuestions.resultAnswerAll = isAnswerdAllVisible();
    visibleQuestions.dose400Adults = isAdultsUse('acute');
    visibleQuestions.amount400 = isAdultsUse('acute');
    visibleQuestions.duration400Adults = isAdultsUse('acute');
    visibleQuestions.dose400AdultsRecidiv = isAdultsUse('recidiv');
    visibleQuestions.amount400recidiv = isAdultsUse('recidiv');
    visibleQuestions.duration400AdultsRecidiv = isAdultsUse('recidiv');
    visibleQuestions.babies2 = isChildren(1, 4.99);
    visibleQuestions.babies = isChildren(5, 6.99);
    visibleQuestions.warningDose = isChildren(40.01);
    visibleQuestions.doseChildren = isChildren(5);
    visibleQuestions.durationChildren = isChildren(5);
    visibleQuestions.kidneyInfo = isInfoVisible();
    visibleQuestions.kidneyHigh = kidneyInfo();
    visibleQuestions.kidneyMiddle = kidneyInfo();
    visibleQuestions.kidneyLow = kidneyInfo();
    visibleQuestions.antibiotic = isInfoVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isAnswerdAllVisible();
    visibleSections.adults400 = isAdultsUse('acute');
    visibleSections.recidiv = isAdultsUse('recidiv');
    visibleSections.dosingTooSmallWeight = isChildren(1, 4.99);
    visibleSections.doseChildrenResult = isChildren(5);
    visibleSections.kidneyFunction = isInfoVisible();
    visibleSections.antibiticResult = isInfoVisible();
    return visibleSections;
};
var calculatePoints = function () {
    var _a;
    if (isChildren(5)) {
        var weight = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints);
        return {
            doseChildren: {
                qID: 'doseChildren',
                titleTexts: 'regular',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 20, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(weight * 4, 1), 0, 1))
            }
        };
    }
    return null;
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isAnswerdAllVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections(),
        result: calculatePoints()
    };
});
