"use strict";


var visibleQuestions = {
    colonoscopyFinding: true,
    strictures: true,
    dysplasiaLessFive: true,
    psc: true,
    colitisMedium: true,
    colitisMild: true,
    familyLessFifty: true,
    familyMoreFifty: true,
    polyps: true,
    dysplasiaMore: true,
    lesionType: false,
    resectionType: false,
    incompleteResection: false,
    dysplasiaGrade: false,
    size: false,
    specialisedCentreResult: false,
    controlFinding: false,
    previousFinding: false,
    surveillanceColonoscopy1: false,
    surveillanceColonoscopy2: false,
    surveillanceColonoscopy3: false,
    surveillanceColonoscopy4: false,
    surveillanceColonoscopy5: false,
    resultOperation: false,
    resultResection: false,
    warningAnswerAll: false
};
var visibleSections = {
    section1: true,
    section2: false,
    section3: false,
    resultsSection: true
};
var inputs = {
    colonoscopyFinding: null,
    strictures: null,
    dysplasiaLessFive: null,
    psc: null,
    colitisMedium: null,
    colitisMild: null,
    familyLessFifty: null,
    familyMoreFifty: null,
    polyps: null,
    dysplasiaMore: null,
    lesionType: null,
    resectionType: null,
    incompleteResection: null,
    dysplasiaGrade: null,
    size: null,
    controlFinding: null,
    previousFinding: null
};
var isSection2Visible = function () {
    return helpers_1.answerMatches(inputs.colonoscopyFinding, 'noDysplasia');
};
var isSection3Visible = function () {
    return (helpers_1.answerMatches(inputs.colonoscopyFinding, 'invisibleDysplasia') ||
        helpers_1.answerMatches(inputs.colonoscopyFinding, 'visibleDysplasia'));
};
var isLesionTypeVisible = function () {
    return helpers_1.answerMatches(inputs.colonoscopyFinding, 'visibleDysplasia');
};
var isResectionTypeVisible = function () {
    return helpers_1.answerMatches(inputs.lesionType, 'resectable');
};
var isIncompleteRestrictionVisible = function () {
    return helpers_1.answerMatches(inputs.resectionType, 'incomplete');
};
var isDysplasiaGradeVisible = function () {
    return helpers_1.answerMatches(inputs.resectionType, 'complete');
};
var isSizeVisible = function () {
    return helpers_1.answerMatches(inputs.dysplasiaGrade, 'lowGrade');
};
var isSpecialisedCentreResultVisible = function () {
    return helpers_1.answerMatches(inputs.colonoscopyFinding, 'invisibleDysplasia');
};
var isPreviousFindingVisible = function () {
    return helpers_1.answerMatches(inputs.controlFinding, 'unifocalLowGrade');
};
var areVisibleQuestionsInSection2Answered = function () {
    return isSection2Visible() ? areAllQuestionsInSection2Answered() : true;
};
var areAllQuestionsInSection2Answered = function () {
    return (helpers_1.isAnswered(inputs.strictures) &&
        helpers_1.isAnswered(inputs.dysplasiaLessFive) &&
        helpers_1.isAnswered(inputs.psc) &&
        helpers_1.isAnswered(inputs.colitisMedium) &&
        helpers_1.isAnswered(inputs.colitisMild) &&
        helpers_1.isAnswered(inputs.familyLessFifty) &&
        helpers_1.isAnswered(inputs.familyMoreFifty) &&
        helpers_1.isAnswered(inputs.polyps) &&
        helpers_1.isAnswered(inputs.dysplasiaMore));
};
var areVisibleQuestionsInSection3Answered = function () {
    return isSection3Visible()
        ? !areAnyVisibleQuestionsInSection3NotAnswered()
        : true;
};
var areAnyVisibleQuestionsInSection3NotAnswered = function () {
    return ((isLesionTypeVisible() && !helpers_1.isAnswered(inputs.lesionType)) ||
        (isResectionTypeVisible() && !helpers_1.isAnswered(inputs.resectionType)) ||
        (isIncompleteRestrictionVisible() &&
            !helpers_1.isAnswered(inputs.incompleteResection)) ||
        (isDysplasiaGradeVisible() && !helpers_1.isAnswered(inputs.dysplasiaGrade)) ||
        (isSizeVisible() && !helpers_1.isAnswered(inputs.size)) ||
        (isSpecialisedCentreResultVisible() &&
            !helpers_1.isAnswered(inputs.controlFinding)) ||
        (isPreviousFindingVisible() && !helpers_1.isAnswered(inputs.previousFinding)));
};
var isSurveillanceColonoscopy1Visible = function () {
    return (helpers_1.answerMatches(inputs.previousFinding, 'highGradeDysplasia') ||
        helpers_1.answerMatches(inputs.dysplasiaGrade, 'highGrade') ||
        helpers_1.answerMatches(inputs.size, 'moreTwo'));
};
var isSurveillanceColonoscopy2Visible = function () {
    var condition1 = helpers_1.answerMatches(inputs.size, 'lessTwo');
    var condition2 = helpers_1.answerMatches(inputs.strictures, 'yes') ||
        helpers_1.answerMatches(inputs.dysplasiaLessFive, 'yes') ||
        helpers_1.answerMatches(inputs.psc, 'yes') ||
        helpers_1.answerMatches(inputs.colitisMedium, 'yes') ||
        helpers_1.answerMatches(inputs.familyLessFifty, 'yes');
    var condition3 = isSection2Visible() &&
        helpers_1.isAnswered(inputs.polyps) &&
        helpers_1.isAnswered(inputs.colitisMild) &&
        helpers_1.isAnswered(inputs.familyMoreFifty) &&
        helpers_1.isAnswered(inputs.dysplasiaMore);
    return condition1 || (condition2 && condition3);
};
var isSurveillanceColonoscopy3Visible = function () {
    var condition1 = helpers_1.answerMatches(inputs.colitisMild, 'yes') ||
        helpers_1.answerMatches(inputs.polyps, 'yes') ||
        helpers_1.answerMatches(inputs.familyMoreFifty, 'yes') ||
        helpers_1.answerMatches(inputs.dysplasiaMore, 'yes');
    var condition2 = isSection2Visible() &&
        helpers_1.answerMatches(inputs.strictures, 'no') &&
        helpers_1.answerMatches(inputs.dysplasiaLessFive, 'no') &&
        helpers_1.answerMatches(inputs.psc, 'no') &&
        helpers_1.answerMatches(inputs.colitisMedium, 'no') &&
        helpers_1.answerMatches(inputs.familyLessFifty, 'no');
    return condition1 && condition2;
};
var isSurveillanceColonoscopy4Visible = function () {
    return (isSection2Visible() &&
        helpers_1.answerMatches(inputs.strictures, 'no') &&
        helpers_1.answerMatches(inputs.dysplasiaLessFive, 'no') &&
        helpers_1.answerMatches(inputs.psc, 'no') &&
        helpers_1.answerMatches(inputs.colitisMedium, 'no') &&
        helpers_1.answerMatches(inputs.colitisMild, 'no') &&
        helpers_1.answerMatches(inputs.familyLessFifty, 'no') &&
        helpers_1.answerMatches(inputs.familyMoreFifty, 'no') &&
        helpers_1.answerMatches(inputs.polyps, 'no') &&
        helpers_1.answerMatches(inputs.dysplasiaMore, 'no'));
};
var isSurveillanceColonoscopy5Visible = function () {
    return helpers_1.answerMatches(inputs.previousFinding, 'lowGradeDysplasia');
};
var isResultOperationVisible = function () {
    return (helpers_1.answerMatches(inputs.lesionType, 'unresectable') ||
        helpers_1.answerMatches(inputs.incompleteResection, 'incompleteAttempts') ||
        helpers_1.answerMatches(inputs.controlFinding, 'invisibleHighGrade') ||
        helpers_1.answerMatches(inputs.controlFinding, 'invisibleMultifocal'));
};
var isResultResectionVisible = function () {
    return helpers_1.answerMatches(inputs.incompleteResection, 'noMalignancy');
};
var areAllVisibleQuestionsAnswered = function () {
    return (helpers_1.isAnswered(inputs.colonoscopyFinding) &&
        areVisibleQuestionsInSection2Answered() &&
        areVisibleQuestionsInSection3Answered());
};
var calculatePoints = function () {
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.lesionType = isLesionTypeVisible();
    visibleQuestions.resectionType = isResectionTypeVisible();
    visibleQuestions.incompleteResection = isIncompleteRestrictionVisible();
    visibleQuestions.dysplasiaGrade = isDysplasiaGradeVisible();
    visibleQuestions.size = isSizeVisible();
    visibleQuestions.specialisedCentreResult = isSpecialisedCentreResultVisible();
    visibleQuestions.controlFinding = isSpecialisedCentreResultVisible();
    visibleQuestions.previousFinding = isPreviousFindingVisible();
    visibleQuestions.surveillanceColonoscopy1 =
        areAllVisibleQuestionsAnswered() && isSurveillanceColonoscopy1Visible();
    visibleQuestions.surveillanceColonoscopy2 =
        areAllVisibleQuestionsAnswered() && isSurveillanceColonoscopy2Visible();
    visibleQuestions.surveillanceColonoscopy3 =
        areAllVisibleQuestionsAnswered() && isSurveillanceColonoscopy3Visible();
    visibleQuestions.surveillanceColonoscopy4 =
        areAllVisibleQuestionsAnswered() && isSurveillanceColonoscopy4Visible();
    visibleQuestions.surveillanceColonoscopy5 =
        areAllVisibleQuestionsAnswered() && isSurveillanceColonoscopy5Visible();
    visibleQuestions.resultOperation =
        areAllVisibleQuestionsAnswered() && isResultOperationVisible();
    visibleQuestions.resultResection =
        areAllVisibleQuestionsAnswered() && isResultResectionVisible();
    visibleQuestions.warningAnswerAll = !areAllVisibleQuestionsAnswered();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.section2 = isSection2Visible();
    visibleSections.section3 = isSection3Visible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return areAllVisibleQuestionsAnswered();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
