"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    score: true,
    other: false,
    plateletCount1: false,
    plateletCount2: false,
    hemolysis: false,
    activeCancer: false,
    transplant: false,
    mcv: false,
    inr: false,
    creatinineF: false,
    creatinineP: false,
    ana: false,
    noAnswerText: true,
    warningText: true,
    answerAll: false,
    riskGroupLow: false,
    riskGroupIntermediate: false,
    riskGroupHigh: false,
    lowRisk: false,
    intermediateRisk: false,
    severeRisk: false,
    warning: false,
    answerAll2: false,
    lowRisk3v: false,
    intermediateRisk3v: false,
    severeRisk3v: false
};
var visibleSections = {
    inputSection: true,
    noAnswer: false,
    warningSection: false,
    resultPlasmic: false,
    resultFrench2v: false,
    resultFrench3v: false
};
var inputs = {
    score: null,
    other: null,
    plateletCount1: null,
    plateletCount2: null,
    hemolysis: null,
    activeCancer: null,
    transplant: null,
    mcv: null,
    inr: null,
    creatinineF: null,
    creatinineP: null,
    ana: null
};
var isScorePlasmic = function () {
    return helpers_1.answerMatches(inputs.score, 'plasmic');
};
var isScoreFrench = function () {
    return helpers_1.answerMatches(inputs.score, 'french');
};
var isScoreFrenchAndOtherNo = function () {
    return (helpers_1.answerMatches(inputs.score, 'french') && helpers_1.answerMatches(inputs.other, 'no'));
};
var isNoAnswerVisible = function () {
    return !helpers_1.isAnswered(inputs.score);
};
var isWarningSectionVisible = function () {
    return (helpers_1.answerMatches(inputs.score, 'french') && helpers_1.answerMatches(inputs.other, 'yes'));
};
var calculatePlasmicResult = function () {
    var _a, _b, _c, _d, _e, _f, _g;
    return (Number((_a = inputs.plateletCount1) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        Number((_b = inputs.hemolysis) === null || _b === void 0 ? void 0 : _b.currentPoints) +
        Number((_c = inputs.activeCancer) === null || _c === void 0 ? void 0 : _c.currentPoints) +
        Number((_d = inputs.transplant) === null || _d === void 0 ? void 0 : _d.currentPoints) +
        Number((_e = inputs.mcv) === null || _e === void 0 ? void 0 : _e.currentPoints) +
        Number((_f = inputs.inr) === null || _f === void 0 ? void 0 : _f.currentPoints) +
        Number((_g = inputs.creatinineP) === null || _g === void 0 ? void 0 : _g.currentPoints));
};
var calculateFrenchResult = function () {
    var _a, _b, _c;
    return (Number((_a = inputs.plateletCount2) === null || _a === void 0 ? void 0 : _a.currentPoints) +
        Number((_b = inputs.creatinineF) === null || _b === void 0 ? void 0 : _b.currentPoints) +
        Number((_c = inputs.ana) === null || _c === void 0 ? void 0 : _c.currentPoints));
};
var areVisibleQuestionsAnsweredIfScorePlasmic = function () {
    return isScorePlasmic()
        ? helpers_1.isAnswered(inputs.plateletCount1) &&
            helpers_1.isAnswered(inputs.hemolysis) &&
            helpers_1.isAnswered(inputs.activeCancer) &&
            helpers_1.isAnswered(inputs.transplant) &&
            helpers_1.isAnswered(inputs.mcv) &&
            helpers_1.isAnswered(inputs.inr) &&
            helpers_1.isAnswered(inputs.creatinineP)
        : true;
};
var isAnswerAllVisible = function () {
    return isScorePlasmic() && !areVisibleQuestionsAnsweredIfScorePlasmic();
};
var isRiskGroupLowVisible = function () {
    return (isScorePlasmic() &&
        !isAnswerAllVisible() &&
        calculatePlasmicResult() >= 0 &&
        calculatePlasmicResult() <= 4);
};
var isRiskGroupIntermediateVisible = function () {
    return (isScorePlasmic() && !isAnswerAllVisible() && calculatePlasmicResult() === 5);
};
var isRiskGroupHighVisible = function () {
    return (helpers_1.answerMatches(inputs.score, 'plasmic') &&
        !isAnswerAllVisible() &&
        (calculatePlasmicResult() === 6 || calculatePlasmicResult() === 7));
};
var isAnswerAll2Visible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        (!helpers_1.isAnswered(inputs.plateletCount2) || !helpers_1.isAnswered(inputs.creatinineF)));
};
var isLowRisk3vVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        helpers_1.isAnswered(inputs.ana) &&
        calculateFrenchResult() === 0);
};
var isIntermediateRisk3vVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        helpers_1.isAnswered(inputs.ana) &&
        calculateFrenchResult() === 1);
};
var isSevereRisk3vVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        helpers_1.isAnswered(inputs.ana) &&
        (calculateFrenchResult() === 2 || calculateFrenchResult() === 3));
};
var isResultFrench2vVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        !helpers_1.isAnswered(inputs.ana));
};
var isResultFrench3vVisible = function () {
    var firstCondition = isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        helpers_1.isAnswered(inputs.ana);
    var secondCondition = isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        (!helpers_1.isAnswered(inputs.plateletCount2) || !helpers_1.isAnswered(inputs.creatinineF));
    return firstCondition || secondCondition;
};
var isLowRiskVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        !helpers_1.isAnswered(inputs.ana) &&
        calculateFrenchResult() === 0);
};
var isIntermediateRiskVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        !helpers_1.isAnswered(inputs.ana) &&
        calculateFrenchResult() === 1);
};
var isSevereRiskVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        !helpers_1.isAnswered(inputs.ana) &&
        calculateFrenchResult() === 2);
};
var isWarningVisible = function () {
    return (isScoreFrench() &&
        helpers_1.answerMatches(inputs.other, 'no') &&
        helpers_1.isAnswered(inputs.plateletCount2) &&
        helpers_1.isAnswered(inputs.creatinineF) &&
        !helpers_1.isAnswered(inputs.ana));
};
var calculatePoints = function () {
    var plasmicScoreLow = 0;
    var plasmicScoreIntermediate = 0;
    var plasmicScoreHigh = 0;
    var frenchScoreLow = 0;
    var frenchScoreIntermediate = 0;
    var frenchScoreHigh = 0;
    if (!isAnswerAllVisible() && isScorePlasmic()) {
        if (isRiskGroupLowVisible()) {
            plasmicScoreLow = calculatePlasmicResult();
        }
        if (isRiskGroupIntermediateVisible()) {
            plasmicScoreIntermediate = calculatePlasmicResult();
        }
        if (isRiskGroupHighVisible()) {
            plasmicScoreHigh = calculatePlasmicResult();
        }
    }
    if (!isAnswerAll2Visible() && isScoreFrench()) {
        if (isLowRisk3vVisible()) {
            frenchScoreLow = calculateFrenchResult();
        }
        if (isIntermediateRisk3vVisible()) {
            frenchScoreIntermediate = calculateFrenchResult();
        }
        if (isSevereRisk3vVisible()) {
            frenchScoreHigh = calculateFrenchResult();
        }
    }
    return {
        riskGroupLow: {
            qID: 'riskGroupLow',
            tParams: __spreadArrays(helpers_1.returnNumberObject(plasmicScoreLow, 0, 0)),
            titleTexts: 'result1'
        },
        riskGroupIntermediate: {
            qID: 'riskGroupIntermediate',
            tParams: __spreadArrays(helpers_1.returnNumberObject(plasmicScoreIntermediate, 0, 0)),
            titleTexts: 'result1'
        },
        riskGroupHigh: {
            qID: 'riskGroupHigh',
            tParams: __spreadArrays(helpers_1.returnNumberObject(plasmicScoreHigh, 0, 0)),
            titleTexts: 'result1'
        },
        lowRisk3v: {
            qID: 'lowRisk3v',
            tParams: __spreadArrays(helpers_1.returnNumberObject(frenchScoreLow, 0, 0)),
            titleTexts: 'result1'
        },
        intermediateRisk3v: {
            qID: 'intermediateRisk3v',
            tParams: __spreadArrays(helpers_1.returnNumberObject(frenchScoreIntermediate, 0, 0)),
            titleTexts: 'result1'
        },
        severeRisk3v: {
            qID: 'severeRisk3v',
            tParams: __spreadArrays(helpers_1.returnNumberObject(frenchScoreHigh, 0, 0)),
            titleTexts: 'result1'
        }
    };
};
var returnVisibleQuestions = function () {
    visibleQuestions.other = isScoreFrench();
    visibleQuestions.plateletCount1 = isScorePlasmic();
    visibleQuestions.plateletCount2 = isScoreFrenchAndOtherNo();
    visibleQuestions.hemolysis = isScorePlasmic();
    visibleQuestions.activeCancer = isScorePlasmic();
    visibleQuestions.transplant = isScorePlasmic();
    visibleQuestions.mcv = isScorePlasmic();
    visibleQuestions.inr = isScorePlasmic();
    visibleQuestions.creatinineF = isScoreFrenchAndOtherNo();
    visibleQuestions.creatinineP = isScorePlasmic();
    visibleQuestions.ana = isScoreFrenchAndOtherNo();
    visibleQuestions.noAnswerText = isNoAnswerVisible();
    visibleQuestions.answerAll = isAnswerAllVisible();
    visibleQuestions.riskGroupLow = isRiskGroupLowVisible();
    visibleQuestions.riskGroupIntermediate = isRiskGroupIntermediateVisible();
    visibleQuestions.riskGroupHigh = isRiskGroupHighVisible();
    visibleQuestions.lowRisk = isLowRiskVisible();
    visibleQuestions.intermediateRisk = isIntermediateRiskVisible();
    visibleQuestions.severeRisk = isSevereRiskVisible();
    visibleQuestions.warning = isWarningVisible();
    visibleQuestions.answerAll2 = isAnswerAll2Visible();
    visibleQuestions.lowRisk3v = isLowRisk3vVisible();
    visibleQuestions.intermediateRisk3v = isIntermediateRisk3vVisible();
    visibleQuestions.severeRisk3v = isSevereRisk3vVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isNoAnswerVisible();
    visibleSections.warningSection = isWarningSectionVisible();
    visibleSections.resultPlasmic = isScorePlasmic();
    visibleSections.resultFrench2v = isResultFrench2vVisible();
    visibleSections.resultFrench3v = isResultFrench3vVisible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return (!isNoAnswerVisible() && !isAnswerAll2Visible() && !isAnswerAllVisible());
};
var ut_formatTexts = function () {
    return calculatePoints();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
