"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    indication: true,
    age: true,
    weight: false,
    pain: false,
    answerAll: false,
    therapyBaby1: false,
    therapyKids1: false,
    therapyKids2: false,
    warningSection11: false,
    warningSection12: false,
    warningSection12Car: false,
    warningKidsKidneyMild: false,
    warningKidsKidneySevere: false,
    therapyAdultsModerate12: false,
    therapyAdultsModerate32: false,
    therapyAdultsModerate123: false,
    therapyAdultsModerate323: false,
    therapyAdultsModerate1: false,
    therapyAdultsModerate3: false,
    warningSection21: false,
    warningSection22: false,
    warningSection22Car: false,
    warningAdultsModerateKidneyMild: false,
    warningAdultsModerateKidneySevere: false,
    therapyAdultsSevere12: false,
    therapyAdultsSevere32: false,
    therapyAdultsSevere123: false,
    therapyAdultsSevere323: false,
    therapyAdultsSevere1: false,
    therapyAdultsSevere2: false,
    warningSection31: false,
    warningSection32: false,
    warningSection32Car: false,
    warningAdultsSevereKidneyMild: false,
    warningAdultsSevereKidneySevere: false,
    therapyAdultsOP12: false,
    therapyAdultsOP32: false,
    therapyAdultsOP123: false,
    therapyAdultsOP323: false,
    therapyAdultsOP1: false,
    therapyAdultsOP3: false,
    warningSection41: false,
    warningSection42: false,
    warningSection42Car: false,
    warningAdultsOperationKidneyMild: false,
    warningAdultsOperationKidneySevere: false
};
var visibleSections = {
    info: true,
    patientSection: true,
    dosing: false,
    therapyBaby: false,
    therapyKids: false,
    warningSection1: false,
    warningKids: false,
    therapyAdultsModerateBigTablets: false,
    therapyAdultsModerateSmallTablets: false,
    therapyAdultsModerate: false,
    warningSection2: false,
    warningAdultsModerate: false,
    therapyAdultsSevereBigTablets: false,
    therapyAdultsSevereSmallTablets: false,
    therapyAdultsSevere: false,
    warningSection3: false,
    warningAdultsSevere: false,
    therapyAdultsOPBigTablets: false,
    therapyAdultsOPSmallTablets: false,
    therapyAdultsOP: false,
    warningSection4: false,
    warningAdultsOperation: false
};
var inputs = {
    age: null,
    weight: null,
    pain: null
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 });
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isPainVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isDosingVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        (isWeightVisible() && !isWeightInLimits()) ||
        (isPainVisible() && !helpers_1.isAnswered(inputs.pain)));
};
var isTherapyBabyVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'baby');
};
var isTherapyKidsVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids') && isWeightInLimits();
};
var isTherapyAdultsModerateBigTabletsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.pain, 'moderate'));
};
var isTherapyAdultsSevereBigTabletsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.answerMatches(inputs.pain, 'severe'));
};
var isTherapyAdultsOPBigTabletsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.pain, 'operation'));
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    if (isTherapyKidsVisible()) {
        var therapyKidsRes1 = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) / 2.5;
        var therapyKidsRes2 = (Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 2) / 2.5;
        var therapyKidsRes3 = Number((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints) / 12.5;
        var therapyKidsRes4 = (Number((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints) * 2) / 12.5;
        var therapyKidsRes5 = Number((_e = inputs.weight) === null || _e === void 0 ? void 0 : _e.currentPoints);
        var therapyKidsRes6 = Number((_f = inputs.weight) === null || _f === void 0 ? void 0 : _f.currentPoints) * 2;
        var warningRes1 = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 70
        })
            ? 400
            : helpers_1.formatCalculationResult(Number((_g = inputs.weight) === null || _g === void 0 ? void 0 : _g.currentPoints) * 8, 1);
        var warningRes2 = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 70
        })
            ? 160
            : helpers_1.formatCalculationResult((Number((_h = inputs.weight) === null || _h === void 0 ? void 0 : _h.currentPoints) * 8) / 2.5, 0);
        return {
            therapyKids1: {
                qID: 'therapyKids1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(therapyKidsRes1, 0), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(therapyKidsRes2, 0), 0, 0), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(therapyKidsRes3, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(therapyKidsRes4, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(therapyKidsRes5, 1), 0, 1), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(therapyKidsRes6, 1), 0, 1)),
                titleTexts: 'result1'
            },
            therapyKids2: {
                qID: 'therapyKids2',
                tParams: [],
                titleTexts: 'result1'
            },
            warningSection11: {
                qID: 'warningSection11',
                tParams: [],
                titleTexts: 'result1'
            },
            warningSection12: {
                qID: 'warningSection12',
                tParams: __spreadArrays(helpers_1.returnNumberObject(warningRes1, 0, 1), helpers_1.returnNumberObject(warningRes2, 0, 0)),
                titleTexts: 'result1'
            },
            warningSection12Car: {
                qID: 'warningSection12Car',
                tParams: [],
                titleTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.pain = isPainVisible();
    visibleQuestions.answerAll = isDosingVisible();
    visibleQuestions.therapyBaby1 = isTherapyBabyVisible();
    visibleQuestions.therapyKids1 = isTherapyKidsVisible();
    visibleQuestions.therapyKids2 = isTherapyKidsVisible();
    visibleQuestions.warningSection11 = isTherapyKidsVisible();
    visibleQuestions.warningSection12 = isTherapyKidsVisible();
    visibleQuestions.warningSection12Car = isTherapyKidsVisible();
    visibleQuestions.warningKidsKidneyMild = isTherapyKidsVisible();
    visibleQuestions.warningKidsKidneySevere = isTherapyKidsVisible();
    visibleQuestions.therapyAdultsModerate12 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.therapyAdultsModerate32 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.therapyAdultsModerate123 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.therapyAdultsModerate323 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.therapyAdultsModerate1 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.therapyAdultsModerate3 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.warningSection21 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.warningSection22 =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.warningSection22Car =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.warningAdultsModerateKidneyMild =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.warningAdultsModerateKidneySevere =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleQuestions.therapyAdultsSevere12 =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.therapyAdultsSevere32 =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.therapyAdultsSevere123 =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.therapyAdultsSevere323 =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.therapyAdultsSevere1 =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.therapyAdultsSevere2 =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.warningSection31 = isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.warningSection32 = isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.warningSection32Car =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.warningAdultsSevereKidneyMild =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.warningAdultsSevereKidneySevere =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleQuestions.therapyAdultsOP12 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.therapyAdultsOP32 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.therapyAdultsOP123 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.therapyAdultsOP323 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.therapyAdultsOP1 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.therapyAdultsOP3 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.warningSection41 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.warningSection42 = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.warningSection42Car = isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.warningAdultsOperationKidneyMild =
        isTherapyAdultsOPBigTabletsVisible();
    visibleQuestions.warningAdultsOperationKidneySevere =
        isTherapyAdultsOPBigTabletsVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.dosing = isDosingVisible();
    visibleSections.therapyBaby = isTherapyBabyVisible();
    visibleSections.therapyKids = isTherapyKidsVisible();
    visibleSections.warningSection1 = isTherapyKidsVisible();
    visibleSections.warningKids = isTherapyKidsVisible();
    visibleSections.therapyAdultsModerateBigTablets =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleSections.therapyAdultsModerateSmallTablets =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleSections.therapyAdultsModerate =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleSections.warningSection2 = isTherapyAdultsModerateBigTabletsVisible();
    visibleSections.warningAdultsModerate =
        isTherapyAdultsModerateBigTabletsVisible();
    visibleSections.therapyAdultsSevereBigTablets =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleSections.therapyAdultsSevereSmallTablets =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleSections.therapyAdultsSevere =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleSections.warningSection3 = isTherapyAdultsSevereBigTabletsVisible();
    visibleSections.warningAdultsSevere =
        isTherapyAdultsSevereBigTabletsVisible();
    visibleSections.therapyAdultsOPBigTablets =
        isTherapyAdultsOPBigTabletsVisible();
    visibleSections.therapyAdultsOPSmallTablets =
        isTherapyAdultsOPBigTabletsVisible();
    visibleSections.therapyAdultsOP = isTherapyAdultsOPBigTabletsVisible();
    visibleSections.warningSection4 = isTherapyAdultsOPBigTabletsVisible();
    visibleSections.warningAdultsOperation = isTherapyAdultsOPBigTabletsVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isDosingVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
