"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    indications: true,
    age: true,
    fibrinolyse: false,
    creatinine: false,
    weight: false,
    localisedDosing: false,
    generalisedDosing: false,
    kidsDose: false,
    warning1: false,
    babyResult: false,
    dosingHigh: false,
    dosingVeryHigh: false,
    dosingSuperHigh: false,
    kidneyText: false,
    noAnswer: false,
    smpc: true
};
var visibleSections = {
    indicationsSection: true,
    ageSelection: true,
    resultAdults: false,
    resultAdults2: false,
    kidsResult: false,
    babyDosing: false,
    highDosingAdults: false,
    veryHighDosing: false,
    superHighDosing: false,
    warningKidney: false,
    noAnswerSection: false
};
var inputs = {
    age: null,
    fibrinolyse: null,
    creatinine: null,
    weight: null
};
var isFibrinolyseVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isCreatinineVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults') && helpers_1.isAnswered(inputs.fibrinolyse);
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 300 });
};
var isWeightVisible = function () {
    var condition1 = helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.fibrinolyse, 'generalised') &&
        helpers_1.isAnswered(inputs.creatinine);
    var condition2 = helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.fibrinolyse, 'localised') &&
        helpers_1.answerMatches(inputs.creatinine, 'high');
    var condition3 = helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.fibrinolyse, 'localised') &&
        helpers_1.answerMatches(inputs.creatinine, 'veryHigh');
    var condition4 = helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.fibrinolyse, 'localised') &&
        helpers_1.answerMatches(inputs.creatinine, 'superHigh');
    return (helpers_1.answerMatches(inputs.age, 'kids') ||
        condition1 ||
        condition2 ||
        condition3 ||
        condition4);
};
var isResultAdultsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.fibrinolyse, 'localised') &&
        helpers_1.answerMatches(inputs.creatinine, 'normal'));
};
var isResultAdults2Visible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.fibrinolyse, 'generalised') &&
        isWeightInLimits() &&
        helpers_1.answerMatches(inputs.creatinine, 'normal'));
};
var isKidsResultVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids') && isWeightInLimits();
};
var isBabyDosingVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'baby');
};
var isHighDosingAdultsVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        isWeightInLimits() &&
        helpers_1.isAnswered(inputs.fibrinolyse) &&
        helpers_1.answerMatches(inputs.creatinine, 'high'));
};
var isVeryHighDosingVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        isWeightInLimits() &&
        helpers_1.isAnswered(inputs.fibrinolyse) &&
        helpers_1.answerMatches(inputs.creatinine, 'veryHigh'));
};
var isSuperHighDosingVisible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        isWeightInLimits() &&
        helpers_1.isAnswered(inputs.fibrinolyse) &&
        helpers_1.answerMatches(inputs.creatinine, 'superHigh'));
};
var isWarningKidneyVisible = function () {
    return (helpers_1.answerMatches(inputs.creatinine, 'superHigh') && !isNoAnswerSectionVisible());
};
var isNoAnswerSectionVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        (isFibrinolyseVisible() && !helpers_1.isAnswered(inputs.fibrinolyse)) ||
        (isCreatinineVisible() && !helpers_1.isAnswered(inputs.creatinine)) ||
        (isWeightVisible() && !isWeightInLimits()));
};
var calculatePoints = function () {
    var _a, _b, _c, _d, _e, _f, _g;
    if (isResultAdults2Visible()) {
        var resultAdults2G = Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 0.015;
        var resultAdults2Ml = (Number((_b = inputs.weight) === null || _b === void 0 ? void 0 : _b.currentPoints) * 15) / 100;
        return {
            generalisedDosing: {
                qID: 'generalisedDosing',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(resultAdults2G, 2), 0, 2), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(resultAdults2Ml, 2), 0, 2)),
                rParams: [],
                titleTexts: 'generalisedDose',
                resultTexts: 'result1'
            }
        };
    }
    if (isKidsResultVisible()) {
        var kidsResultMg = Number((_c = inputs.weight) === null || _c === void 0 ? void 0 : _c.currentPoints) * 20;
        var kidsResultMl = (Number((_d = inputs.weight) === null || _d === void 0 ? void 0 : _d.currentPoints) * 20) / 100;
        return {
            kidsDose: {
                qID: 'kidsDose',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(kidsResultMg, 2), 0, 2), helpers_1.returnNumberObject(helpers_1.formatCalculationResult(kidsResultMl, 2), 0, 2)),
                rParams: [],
                titleTexts: 'result1',
                resultTexts: 'result1'
            }
        };
    }
    if (isHighDosingAdultsVisible()) {
        var highDosingAdultsResultMg = Number((_e = inputs.weight) === null || _e === void 0 ? void 0 : _e.currentPoints) * 10;
        return {
            dosingHigh: {
                qID: 'dosingHigh',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(highDosingAdultsResultMg, 2), 0, 2)),
                rParams: [],
                titleTexts: 'result1',
                resultTexts: 'result1'
            }
        };
    }
    if (isVeryHighDosingVisible()) {
        var veryHighDosingAdultsResultMg = Number((_f = inputs.weight) === null || _f === void 0 ? void 0 : _f.currentPoints) * 10;
        return {
            dosingVeryHigh: {
                qID: 'dosingVeryHigh',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(veryHighDosingAdultsResultMg, 2), 0, 2)),
                rParams: [],
                titleTexts: 'result1',
                resultTexts: 'result1'
            }
        };
    }
    if (isSuperHighDosingVisible()) {
        var superHighDosingAdultsResultMg = Number((_g = inputs.weight) === null || _g === void 0 ? void 0 : _g.currentPoints) * 5;
        return {
            dosingSuperHigh: {
                qID: 'dosingSuperHigh',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(superHighDosingAdultsResultMg, 2), 0, 2)),
                rParams: [],
                titleTexts: 'result1',
                resultTexts: 'result1'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.fibrinolyse = isFibrinolyseVisible();
    visibleQuestions.creatinine = isCreatinineVisible();
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.localisedDosing = isResultAdultsVisible();
    visibleQuestions.generalisedDosing = isResultAdults2Visible();
    visibleQuestions.kidsDose = isKidsResultVisible();
    visibleQuestions.warning1 = isKidsResultVisible();
    visibleQuestions.babyResult = isBabyDosingVisible();
    visibleQuestions.dosingHigh = isHighDosingAdultsVisible();
    visibleQuestions.dosingVeryHigh = isVeryHighDosingVisible();
    visibleQuestions.dosingSuperHigh = isSuperHighDosingVisible();
    visibleQuestions.kidneyText = isWarningKidneyVisible();
    visibleQuestions.noAnswer = isNoAnswerSectionVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.resultAdults = isResultAdultsVisible();
    visibleSections.resultAdults2 = isResultAdults2Visible();
    visibleSections.kidsResult = isKidsResultVisible();
    visibleSections.babyDosing = isBabyDosingVisible();
    visibleSections.highDosingAdults = isHighDosingAdultsVisible();
    visibleSections.veryHighDosing = isVeryHighDosingVisible();
    visibleSections.superHighDosing = isSuperHighDosingVisible();
    visibleSections.warningKidney = isWarningKidneyVisible();
    visibleSections.noAnswerSection = isNoAnswerSectionVisible();
    return visibleSections;
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
var isExportResultsEnabled = function () {
    return !isNoAnswerSectionVisible();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
