"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};


var visibleQuestions = {
    age: true,
    weight: false,
    adultsForm: false,
    noAnswerText: false,
    kidsDose1: false,
    kidsDuration: false,
    kidsWarningAb: false,
    kidsWarning: false,
    adultsDose1: false,
    adultsDuration1: false,
    adultsWarningAb: false,
    adultsDose31: false,
    adultsDuration3: false,
    following: false,
    adultsDose32: false,
    adultsDuration30: false,
    divider: false,
    adultsDose33: false,
    adultsDuration31: false,
    adultsWarning3: false,
    warningDuration23: false,
    anti: false
};
var visibleSections = {
    weightSelection: true,
    noAnswer: false,
    kidsDosing: false,
    adultsDosing1: false,
    adultsDosing3: false,
    warningA: false
};
var inputs = {
    age: null,
    weight: null,
    adultsForm: null
};
var isWeightVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids');
};
var isWeightInLimits = function () {
    return helpers_1.numberInLimits({ input: inputs.weight, min: 1, max: 70 });
};
var isAdultsFormVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'adults');
};
var isNoAnswerVisible = function () {
    return (!helpers_1.isAnswered(inputs.age) ||
        (isWeightVisible() && !isWeightInLimits()) ||
        (isAdultsFormVisible() && !helpers_1.isAnswered(inputs.adultsForm)));
};
var isKidsDosingVisible = function () {
    return helpers_1.answerMatches(inputs.age, 'kids') && isWeightInLimits();
};
var isAdultsDosing1Visible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.adultsForm, 'first'));
};
var isAdultsDosing3Visible = function () {
    return (helpers_1.answerMatches(inputs.age, 'adults') &&
        helpers_1.answerMatches(inputs.adultsForm, 'recidiv'));
};
var isWarningAVisible = function () {
    return !isNoAnswerVisible();
};
var calculatePoints = function () {
    var _a;
    if (isKidsDosingVisible()) {
        var kidsDoseResultResult = helpers_1.numberInLimits({
            input: inputs.weight,
            min: 50,
            max: 70
        })
            ? 500
            : Number((_a = inputs.weight) === null || _a === void 0 ? void 0 : _a.currentPoints) * 10;
        return {
            kidsDose1: {
                qID: 'kidsDose1',
                tParams: __spreadArrays(helpers_1.returnNumberObject(helpers_1.formatCalculationResult(kidsDoseResultResult, 1), 0, 1)),
                titleTexts: 'kidsDose12'
            }
        };
    }
    return null;
};
var returnVisibleQuestions = function () {
    visibleQuestions.weight = isWeightVisible();
    visibleQuestions.adultsForm = isAdultsFormVisible();
    visibleQuestions.noAnswerText = isNoAnswerVisible();
    visibleQuestions.kidsDose1 = isKidsDosingVisible();
    visibleQuestions.kidsDuration = isKidsDosingVisible();
    visibleQuestions.kidsWarningAb = isKidsDosingVisible();
    visibleQuestions.kidsWarning = isKidsDosingVisible();
    visibleQuestions.adultsDose1 = isAdultsDosing1Visible();
    visibleQuestions.adultsDuration1 = isAdultsDosing1Visible();
    visibleQuestions.adultsWarningAb = isAdultsDosing1Visible();
    visibleQuestions.adultsDose31 = isAdultsDosing3Visible();
    visibleQuestions.adultsDuration3 = isAdultsDosing3Visible();
    visibleQuestions.following = isAdultsDosing3Visible();
    visibleQuestions.adultsDose32 = isAdultsDosing3Visible();
    visibleQuestions.adultsDuration30 = isAdultsDosing3Visible();
    visibleQuestions.divider = isAdultsDosing3Visible();
    visibleQuestions.adultsDose33 = isAdultsDosing3Visible();
    visibleQuestions.adultsDuration31 = isAdultsDosing3Visible();
    visibleQuestions.adultsWarning3 = isAdultsDosing3Visible();
    visibleQuestions.warningDuration23 = isAdultsDosing3Visible();
    visibleQuestions.anti = isWarningAVisible();
    return visibleQuestions;
};
var returnVisibleSections = function () {
    visibleSections.noAnswer = isNoAnswerVisible();
    visibleSections.kidsDosing = isKidsDosingVisible();
    visibleSections.adultsDosing1 = isAdultsDosing1Visible();
    visibleSections.adultsDosing3 = isAdultsDosing3Visible();
    visibleSections.warningA = isWarningAVisible();
    return visibleSections;
};
var isExportResultsEnabled = function () {
    return !isNoAnswerVisible();
};
var ut_formatTexts = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
var ut_exportResultsEnabled = function () {
    return isExportResultsEnabled();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        exportResultsEnabled: isExportResultsEnabled(),
        result: result,
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});
