"use strict";


var visibleQuestions = {
    warning1: true,
    timingDefined: true,
    timingContinued: true,
    lymphNodes: true,
    spleenLiverSize: true,
    constitutionalSymptoms: true,
    lymphocyteCount: true,
    numberA: false,
    plateletCount: true,
    hemoglobin: true,
    marrow: true,
    numberB: false,
    answerAll: true,
    completeRemission: false,
    partialRemission: false,
    stableDisease: false,
    progressiveDisease: false
};
var visibleSections = {
    warningSection: true,
    groupA: true,
    groupB: true,
    resultsSection: true
};
var inputs = {
    lymphNodes: null,
    spleenLiverSize: null,
    constitutionalSymptoms: null,
    lymphocyteCount: null,
    numberA: null,
    plateletCount: null,
    hemoglobin: null,
    marrow: null,
    numberB: null
};
var calculatePoints = function () {
    return null;
};
var resultID = function () {
    if (allInputsAnswered()) {
        if (resultRange4()) {
            return "progressiveDisease";
        }
        else if (resultRange1()) {
            return "completeRemission";
        }
        else if (resultRange2()) {
            return "partialRemission";
        }
        return "stableDisease";
    }
    return "answerAll";
};
var allInputsAnswered = function () {
    var allInputs = [
        inputs.lymphNodes,
        inputs.spleenLiverSize,
        inputs.constitutionalSymptoms,
        inputs.lymphocyteCount,
        inputs.plateletCount,
        inputs.hemoglobin,
        inputs.marrow,
    ];
    return (allInputs.filter(function (input) { return !helpers_1.isAnswered(input); }).length === 0 &&
        (numberAVisibility() ? helpers_1.isAnswered(inputs.numberA) : true) &&
        (numberBVisibility() ? helpers_1.isAnswered(inputs.numberB) : true));
};
var resultRange1 = function () {
    return (answeredAndMatches(inputs.lymphNodes, "lymphNodesCR") &&
        answeredAndMatches(inputs.spleenLiverSize, "sizeCR") &&
        answeredAndMatches(inputs.constitutionalSymptoms, "symptomsCR") &&
        answeredAndMatches(inputs.lymphocyteCount, "lymphocyteCR") &&
        answeredAndMatches(inputs.plateletCount, "plateletCR") &&
        answeredAndMatches(inputs.hemoglobin, "hemCR") &&
        answeredAndMatches(inputs.marrow, "marrowCR"));
};
var resultRange2 = function () {
    var _a, _b;
    var aCounts = groupACounts();
    var bCounts = groupBCounts();
    var groupAPR = aCounts.prCount;
    var groupACR = aCounts.crCount;
    var groupBPR = bCounts.prCount;
    var groupBCR = bCounts.crCount;
    return (((groupAPR >= 2 || groupACR >= 2 || (groupAPR === 1 && groupACR === 1)) &&
        (groupBPR >= 1 || groupBCR >= 1)) ||
        (((_a = inputs.numberA) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === "one" &&
            (numberBVisibility()
                ? ((_b = inputs.numberB) === null || _b === void 0 ? void 0 : _b.currentIdentifier) === "one"
                : true) &&
            (groupACR === 1 || groupAPR === 1) &&
            (groupBCR === 1 || groupBPR === 1)));
};
var resultRange4 = function () {
    return (answeredAndMatches(inputs.lymphNodes, "lymphNodesPD") ||
        answeredAndMatches(inputs.spleenLiverSize, "sizePD") ||
        answeredAndMatches(inputs.lymphocyteCount, "lymphocytePD") ||
        answeredAndMatches(inputs.plateletCount, "plateletPD") ||
        answeredAndMatches(inputs.hemoglobin, "hemPD") ||
        answeredAndMatches(inputs.marrow, "marrowPD"));
};
var groupACounts = function () {
    var prAnswers = [
        { input: inputs.lymphNodes, answer: "lymphNodesPR" },
        { input: inputs.spleenLiverSize, answer: "sizePR" },
        { input: inputs.lymphocyteCount, answer: "lymphocytePR" },
    ];
    var crAnswers = [
        { input: inputs.lymphNodes, answer: "lymphNodesCR" },
        { input: inputs.spleenLiverSize, answer: "sizeCR" },
        { input: inputs.lymphocyteCount, answer: "lymphocyteCR" },
    ];
    var pdAnswers = [
        { input: inputs.lymphNodes, answer: "lymphNodesPD" },
        { input: inputs.spleenLiverSize, answer: "sizePD" },
        { input: inputs.lymphocyteCount, answer: "lymphocytePD" },
    ];
    var prCount = prAnswers.filter(function (item) { var _a; return ((_a = item.input) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === item.answer; }).length;
    var crCount = crAnswers.filter(function (item) { var _a; return ((_a = item.input) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === item.answer; }).length;
    var pdCount = pdAnswers.filter(function (item) { var _a; return ((_a = item.input) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === item.answer; }).length;
    return { crCount: crCount, pdCount: pdCount, prCount: prCount };
};
var groupBCounts = function () {
    var prAnswers = [
        { input: inputs.plateletCount, answer: "plateletPR" },
        { input: inputs.hemoglobin, answer: "hemPR" },
        { input: inputs.marrow, answer: "marrowPR" },
    ];
    var crAnswers = [
        { input: inputs.plateletCount, answer: "plateletCR" },
        { input: inputs.hemoglobin, answer: "hemCR" },
        { input: inputs.marrow, answer: "marrowCR" },
    ];
    var pdAnswers = [
        { input: inputs.plateletCount, answer: "plateletPD" },
        { input: inputs.hemoglobin, answer: "hemPD" },
        { input: inputs.marrow, answer: "marrowPD" },
    ];
    var prCount = prAnswers.filter(function (item) { var _a; return ((_a = item.input) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === item.answer; }).length;
    var crCount = crAnswers.filter(function (item) { var _a; return ((_a = item.input) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === item.answer; }).length;
    var pdCount = pdAnswers.filter(function (item) { var _a; return ((_a = item.input) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === item.answer; }).length;
    return { crCount: crCount, pdCount: pdCount, prCount: prCount };
};
var answeredAndMatches = function (input, result) {
    return helpers_1.isAnswered(input) && (input === null || input === void 0 ? void 0 : input.currentIdentifier) === result;
};
var numberAVisibility = function () {
    var _a, _b, _c;
    var _d = groupACounts(), crCount = _d.crCount, pdCount = _d.pdCount, prCount = _d.prCount;
    return (helpers_1.isAnswered(inputs.lymphNodes) &&
        helpers_1.isAnswered(inputs.spleenLiverSize) &&
        helpers_1.isAnswered(inputs.lymphocyteCount) &&
        (((((_a = inputs.lymphNodes) === null || _a === void 0 ? void 0 : _a.currentIdentifier) === "lymphNodesCR" ||
            ((_b = inputs.spleenLiverSize) === null || _b === void 0 ? void 0 : _b.currentIdentifier) === "sizeCR" ||
            ((_c = inputs.lymphocyteCount) === null || _c === void 0 ? void 0 : _c.currentIdentifier) === "lymphocyteCR") &&
            prCount === 0 &&
            pdCount === 0) ||
            (prCount === 1 && crCount === 0 && pdCount === 0)));
};
var numberBVisibility = function () {
    var _a = groupBCounts(), crCount = _a.crCount, pdCount = _a.pdCount, prCount = _a.prCount;
    return (helpers_1.isAnswered(inputs.plateletCount) &&
        helpers_1.isAnswered(inputs.hemoglobin) &&
        helpers_1.isAnswered(inputs.marrow) &&
        crCount >= 1 &&
        prCount === 0 &&
        pdCount === 0);
};
var returnVisibleQuestions = function () {
    visibleQuestions.numberA = numberAVisibility();
    visibleQuestions.numberB = numberBVisibility();
    var result = resultID();
    visibleQuestions.answerAll = result === "answerAll";
    visibleQuestions.completeRemission = result === "completeRemission";
    visibleQuestions.partialRemission = result === "partialRemission";
    visibleQuestions.stableDisease = result === "stableDisease";
    visibleQuestions.progressiveDisease = result === "progressiveDisease";
    return visibleQuestions;
};
var returnVisibleSections = function () {
    return visibleSections;
};
var ut_toolScore = function () {
    return calculatePoints();
};
var ut_visibleQuestions = function () {
    return returnVisibleQuestions();
};
var ut_visibleSections = function () {
    return returnVisibleSections();
};
exports["default"] = (function (props) {
    Object.keys(props).forEach(function (propName) {
        inputs[propName] = props[propName];
    });
    var result = calculatePoints();
    return {
        result: { number: result, range: result },
        visibleQuestions: ut_visibleQuestions(),
        visibleSections: ut_visibleSections()
    };
});